one_liners = [
r'''"Virtual" means never knowing where your next byte is coming from.''',
r'''$HOME is where you hang your @.''',
r'''/Earth is 98% full...  Please delete anyone you can.''',
r'''1 bull, 3 cows.''',
r'''10.0 times 0.1 is hardly ever 1.0.''',
r'''A bad random number generator:  1, 1, 1, 1, 1, 4.33e+67, 1, 1, 1''',
r'''A bug in the hand is better than one as yet undetected.''',
r'''A computer program does what you tell it to do, not what you want it to do.''',
r'''A computer scientist is someone who fixes things that aren't broken.''',
r'''A CONS is an object which cares.  -- Bernie Greenberg''',
r'''A crash reduces your expensive computer to a simple stone.''',
r'''A journey of a thousand sites begins with a single click.''',
r'''A list is only as strong as its weakest link.  -- Donald Knuth''',
r'''A true Klingon Warrior does not comment his code!''',
r'''A user and his leisure time are soon parted.''',
r'''Access denied -- nyah, nyah!''',
r'''After enough decimal places, nobody gives a damn.''',
r'''All computers run at the same speed...  With the power off.''',
r'''All computers wait at the same speed.''',
r'''All wiyht.  Rho sritched mg kegtops awound?''',
r'''An elephant is a mouse with an operating system.''',
r'''And on the seventh day, He exited from append mode.''',
r'''Another megabytes the dust.''',
r'''Any given program will expand to fill available memory.''',
r'''Any nitwit can understand computers.  Many do.  -- Ted Nelson''',
r'''Any program that runs right is obsolete.''',
r'''Any sufficiently advanced bug is indistinguishable from a feature.  -- Rich Kulawiec''',
r'''APL is a write-only language.  -- Roy Keir''',
r'''Artificial intelligence usually beats real stupidity.''',
r'''Artificial Intelligence:  Making computers behave like they do in the movies.''',
r'''As a computer, I find your faith in technology amusing!''',
r'''As far as we know, our computer has never had an undetected error.  -- Conrad Weisert''',
r'''As of next week, passwords will be entered in Morse code.''',
r'''Asking whether machines can think is like asking whether submarines can swim.''',
r'''Back up my hard drive?  I can't find the reverse switch!''',
r'''Backup not found:  (A)bort (R)etry (P)anic?''',
r'''Backups?  We don't NEED no steenking backups.''',
r'''Bad command.  Bad, bad command!  Sit!  Stay!  Staaay...''',
r'''Base 8 is just like base 10, if you are missing two fingers.  -- Tom Lehrer''',
r'''Best file compression around:  "DEL" = 100% compression.''',
r'''Beware of programmers who carry screwdrivers.  -- Leonard Brandwein''',
r'''Brain fried -- core dumped.''',
r'''BREAKFAST.COM Halted -- Cereal Port Not Responding.''',
r'''Breakthrough:  It finally booted on the first try.''',
r'''Buy a Pentium 586/90 so you can reboot faster.''',
r'''Cannot find REALITY.SYS.  Universe halted.''',
r'''CChheecckk yyoouurr dduupplleexx sswwiittcchh..''',
r'''COFFEE.EXE Missing -- Insert Cup and Press Any Key.''',
r'''Compatible:  Gracefully accepts erroneous data from any source.''',
r'''Computer and car salesmen differ in that the latter know when they are lying.''',
r'''Computer chips are so small because computers don't eat much.''',
r'''Computer programmers do it byte by byte.''',
r'''Computer:  A device designed to speed up and automate errors.''',
r'''Computers are a more fun way to do the same work you'd have to do without them.''',
r'''Computers are not intelligent -- they just think they are.''',
r'''Computers are useless.  They can only give you answers.  -- Pablo Picasso''',
r'''Computers make very fast, very accurate mistakes.''',
r'''Congratulations!  You are the one-millionth user to log into our system.''',
r'''CONGRESS.SYS corrupted:  Reboot Washington, DC?  (Y/N)''',
r'''Counting in binary is just like counting in decimal if you are all thumbs.''',
r'''Counting in octal is just like counting in decimal if you don't use your thumbs.''',
r'''Dain bramaged, dore cumped.''',
r'''Death is a non-maskable interrupt.''',
r'''Diagnostics are the programs that run when nothing else will.''',
r'''Disc space -- the final frontier!''',
r'''Disclaimer:  Any errors in spelling, tact, or fact are transmission errors.''',
r'''Don't byte off more than you can view.''',
r'''Don't hit the keys so hard, it hurts.''',
r'''Don't let the computer bugs bite!''',
r'''Don't pay computer programmers too much money, it just encourages the bad ones.''',
r'''Dreams are free, but you get soaked on the connect time.''',
r'''E Pluribus Modem.''',
r'''E Pluribus UNIX.''',
r'''Emacs is a nice operating system, but I prefer UNIX.  -- Tom Christaensen''',
r'''Enter any 11-digit prime number to continue.''',
r'''Error, no keyboard.  Press F1 to continue.''',
r'''Ethernet:  Something used to catch the etherbunny.''',
r'''Every program can be reduced to just one instruction -- that doesn't work.''',
r'''Every program in development at MIT expands until it can read mail.''',
r'''Every program is a part of some other program, and rarely fits.''',
r'''Everybody needs a little love sometime; stop hacking and fall in love!''',
r'''Excuse me for butting in, but I'm interrupt-driven.''',
r'''f u cn rd ths, u cn gt a gd jb n cmptr prgrmmng.''',
r'''Failure is not an option.  It comes bundled with the software.''',
r'''Feature:  A bug with seniority.''',
r'''File not found.  Should I fake it?  (Y/N)''',
r'''Foolproof operation:  All parameters are hard coded.''',
r'''fortune:  No such file or directory''',
r'''Futuristic:  It will only run on a next generation supercomputer.''',
r'''God is real, unless declared integer.''',
r'''God made machine language; all the rest is the work of man.''',
r'''Hackers have kernel knowledge.''',
r'''Hardware:  The parts of a computer system that can be kicked.''',
r'''Help!  I'm trapped in a Chinese computer factory!''',
r'''Help,MySpaceBarIsBroken!AnndMyBBackspaaceKeyyToo!''',
r'''Hit any user to continue.''',
r'''HOST SYSTEM NOT RESPONDING, PROBABLY DOWN.  DO YOU WANT TO WAIT?  (Y/N)''',
r'''How an engineer writes a program:  Start by debugging an empty file...''',
r'''How do I love thee?  My accumulator overflows.''',
r'''How do I set my laser printer on stun?''',
r'''How do you know it's an ENDLESS loop?''',
r'''How long is this Beta guy going to keep testing our stuff?  -- Mark Roop-Kharasch''',
r'''How much net work could a network work, if a network could net work?''',
r'''How was Thomas J. Watson buried?  9 edge down.''',
r'''I "upgraded" my computer to several levels above my head.  -- Ellen Goodman''',
r'''I am a computer -- dumber than any human and smarter than an administrator.''',
r'''I am still waiting for the advent of the computer science groupie.''',
r'''I am the computer your mother warned you about.''',
r'''I bet the human brain is a kludge.  -- Marvin Minsky''',
r'''I came, I saw, I deleted all your files.''',
r'''I haven't lost my mind; it's backed up on disk somewhere.''',
r'''I must have slipped a disk; my pack hurts.''',
r'''I smell a wumpus.''',
r'''I still get goose bumps every time I override a method...  -- Harry Wiguna''',
r'''I'm a firm believer in baseball bat therapy for computers.  -- Dan Gookin''',
r'''If a listener nods his head when you're explaining your program, wake him up.''',
r'''If a program is useful, it must be changed.''',
r'''If a program is useless, it must be documented.''',
r'''If a train station is where the train stops, what is a work station?''',
r'''If at first you don't succeed, you must be a programmer.''',
r'''If God had intended Man to program, we would be born with serial I/O ports.''',
r'''If I had it all to do over again, I'd spell creat with an "e".  -- Brian Kernighan''',
r'''If it was easy, the hardware people would take care of it.''',
r'''If it's not in the computer, it doesn't exist.''',
r'''In computer science, we stand on each other's feet.  -- Brian Reid''',
r'''In God we trust; all else we walk through.''',
r'''In the future on the Web, everyone will have 15 megabytes of fame.''',
r'''It is now pitch dark.  If you proceed, you will likely fall into a pit.''',
r'''It is ten o'clock; do you know where your processes are?''',
r'''It's a bad sign when you need a screwdriver to install a new operating system.''',
r'''Keyboard:  The standard way to generate computer errors.''',
r'''Kiss your keyboard goodbye!''',
r'''Last one out, turn off the computer!''',
r'''Life would be so much easier if we could just look at the source code.''',
r'''Lisp Users:  Due to the holiday, there will be no garbage collection on Monday.''',
r'''LISP:  To call a spade a thpade.''',
r'''Login incorrect.  Only perfect spellers may enter this system.''',
r'''logout''',
r'''Long computations that yield zero are probably all for naught.''',
r'''Machine-independent:  Does not run on any existing machine.''',
r'''Mainframe:  The biggest PC peripheral available.''',
r'''Managing software engineers is like herding cats.''',
r'''Manual Writer's Creed:  Garbage in, gospel out.''',
r'''Maybe Computer Science should be in the College of Theology.  -- R. S. Barton''',
r'''Meets quality standards:  Compiles without errors.''',
r'''Mental backup in progress -- do not disturb.''',
r'''MIPS:  Meaningless Indicator of Processor Speed.''',
r'''Mouse:  An advanced input device to make computer errors easier to generate.''',
r'''My New Year's resolution is:  1024 x 768.''',
r'''My software never has bugs.  It just develops random features.''',
r'''Netnews is like yelling, "Anyone want to buy a used car?" in a crowded theater.''',
r'''Never trust a computer you can't lift.  -- Stan Masor''',
r'''Never trust a computer you can't throw out the window.  -- S. Hunt''',
r'''Nice computers don't go down.''',
r'''No line available at 300 baud.''',
r'''No program done by a hacker will work unless he is on the system.''',
r'''No program done by an undergrad will work after she graduates.''',
r'''Obsolete:  Any computer you own.''',
r'''Old mail has arrived.''',
r'''Old programmers never die; they just branch to a new address.''',
r'''Old programmers never die; they just GOSUB without RETURN.''',
r'''On a clear disk you can seek forever.  -- Denning''',
r'''One if by LAN, two if by C.  -- Paul Revere, as told by John Karwoski''',
r'''One man's constant is another man's variable.  -- Alan Perlis''',
r'''One person's error is another person's data.''',
r'''One picture is worth 128K words.''',
r'''Our mothers would be proud of us if we could explain to them what it is we do.''',
r'''Over-computered is when you try to enter your password on your microwave oven.''',
r'''Overflow on /dev/null; please empty the bit bucket.''',
r'''Pause for storage relocation.''',
r'''People who deal with bits should expect to get bitten.  -- Jon Bentley''',
r'''Portable:  Survives system reboot.''',
r'''Power corrupts, and PowerPoint corrupts absolutely.  -- Vint Cerf''',
r'''Press any key to continue or any other key to quit.''',
r'''Press any key...  No, no, no, NOT THAT ONE!''',
r'''Profanity is the one language all programmers know best.''',
r'''Program:  A magic spell that converts input data to error messages.''',
r'''Programmers do it bit by bit.''',
r'''Programming Department:  Mistakes made while you wait.''',
r'''Programming is an art form that fights back.''',
r'''Programming is an unnatural act.''',
r'''Programming just with goto's is like swatting flies with a sledgehammer.''',
r'''Protect your software at all costs -- all else is meat.''',
r'''RAM disk is NOT an installation procedure.''',
r'''Random access is the optimum of the mass storages.''',
r'''Real programs don't eat cache.''',
r'''Remember the good old days, when CPU was singular?''',
r'''Remember, UNIX spelled backwards is XINU.''',
r'''Revolutionary:  Disk drives go round and round.''',
r'''Save energy:  Drive a smaller shell.''',
r'''SCCS, the source motel!  Programs check in and never check out!  -- Ken Thompson''',
r'''Shift to the left!  Shift to the right!  Pop up, push down, byte, byte, byte!''',
r'''Smash forehead on keyboard to continue.''',
r'''Software is to computers as yeast is to dough.  -- Chuck Bradshaw''',
r'''Some programming languages manage to absorb change but withstand progress.''',
r'''Southern DOS:  Y'all reckon?  (Yep/Nope)''',
r'''Spelling checker:  Converts spelling errors into malapropisms.''',
r'''State-of-the-art:  Any computer you can't afford.''',
r'''Structured programming supports the law of the excluded muddle.''',
r'''Supercomputer:  Turns CPU-bound problem into I/O-bound problem.  -- Ken Batcher''',
r'''Swap read error.  You lose your mind.''',
r'''Syntax error:  "Hello, I want to buy a computer and money is no object."''',
r'''System going down at 1:45 for disk crashing.''',
r'''System going down at 5 pm to install scheduler bug.''',
r'''Systems programmers are the high priests of a low cult.  -- R. S. Barton''',
r'''That does not compute.''',
r'''The amount of clue on the Internet remains constant.  -- Evi Nemeth''',
r'''The attention span of a computer is only as long as its power cord.''',
r'''The code was willing.  It considered your request, but the chips were weak.''',
r'''The computer is mightier than the pen, the sword, and usually, the programmer.  -- Alan Silverstein''',
r'''The determined programmer can write a FORTRAN program in any language.''',
r'''The e-mail of the species is more deadly than the mail.''',
r'''The generation of random numbers is too important to be left to chance.''',
r'''The hardest bugs to find are the easiest ones to fix.''',
r'''The Internet is a logic-optional forum.  -- Marc Callier''',
r'''The moving cursor prints, and having printed, blinks on.''',
r'''The next generation of computers will have a "Warranty Expired" interrupt.''',
r'''The original point-and-click interface was a Smith & Wesson.''',
r'''The program is absolutely right; therefore, the computer must be wrong.''',
r'''The steady state of disks is full.  -- Ken Thompson''',
r'''The Tao that is seen is not the true Tao, until you bring fresh toner.''',
r'''The value of a program is proportional to the weight of its output.''',
r'''The world is coming to an end...  SAVE YOUR BUFFERS!!''',
r'''The world will end in 5 minutes.  Please log out.''',
r'''There are two ways to write error-free programs; only the third one works.''',
r'''There must be more to life than compile-and-go.''',
r'''There's no place like http://www.home.com.''',
r'''This fortune soaks up 47 times its own weight in excess memory.''',
r'''This login session:  $13.76, but for you:  $11.88.''',
r'''This screen intentionally left blank.''',
r'''This site was moved.  We'd tell you where, but then we'd have to delete you.''',
r'''This system will self-destruct in five minutes.''',
r'''Those who can't write, write help files.''',
r'''Those who can, do.  Those who cannot, teach.  Those who cannot teach, HACK!''',
r'''Thrashing is just virtual crashing.''',
r'''Three things are certain:  Death, taxes, and lost data.  Guess which occurred.''',
r'''To be, or not to be, those are the parameters.''',
r'''To err is human; to forgive, beyond the scope of the Operating System.''',
r'''To err is human; to really foul things up requires a computer.''',
r'''To iterate is human; to recurse, divine.  -- Robert Heller''',
r'''Too many clicks spoil the browse.''',
r'''Unable to locate coffee -- operator halted!''',
r'''UNIX is a nice place to live, but you don't want to visit there.''',
r'''UNIX is very user-friendly...  It's just picky about its friends.''',
r'''Unprecedented performance:  Nothing ever ran this slow before.''',
r'''Upgrade:  Take old bugs out, put new ones in.''',
r'''Variables won't; constants aren't.  -- Adam Osborn''',
r'''Virtual memory is for weenies!  -- Seymour Cray''',
r'''What boots up must come down.''',
r'''What do computer engineers use for birth control?  Their personalities.''',
r'''What this country needs is a good five-cent microcomputer.''',
r'''Where the system is concerned, you are not allowed to ask "Why?".''',
r'''Why do we want intelligent terminals when there are so many stupid users?''',
r'''Would YOU pass a Turing test?''',
r'''You can't go home again, unless you set $HOME.''',
r'''You can't make a program without broken egos.''',
r'''You can't teach a new mouse old clicks.''',
r'''You depend too much on computers for information.''',
r'''You forgot to do your backup 16 days ago.  Tomorrow you will need that version.''',
r'''You had mail, but the super-user read it, and deleted it!''',
r'''You have a tendency to feel you are superior to most computers.''',
r'''You have junk mail.''',
r'''You know it is going to be a bad day when you forget your new password.''',
r'''You might have mail.''',
r'''You never finish a program, you just stop working on it.''',
r'''Your email has been returned due to insufficient voltage.''',
r'''Your fault -- core dumped.''',
r'''Your password is pitifully obvious.''',
r'''[Unix] is not necessarily evil, like OS/2.  -- Peter Norton''',
r'''A bug in the code is worth two in the documentation.''',
r'''A fault tolerant system must report the faults even as it tolerates them.''',
r'''A hacker does for love what others would not do for money.  -- Laura Creighton''',
r'''A low level language is one whose programs require attention to the irrelevant.''',
r'''A paperless office has about as much chance as a paperless bathroom.''',
r'''A successful tool is used to do something undreamed of by its author.  -- Samuel Johnson''',
r'''Abstraction is achieved by data hiding and enforced by encapsulation.''',
r'''Actual usability is inversely proportionate to apparent user-friendliness.''',
r'''Adding manpower to a late software project makes it later.  -- Frederick Brooks''',
r'''All programmers are playwrights and all computers are lousy actors.''',
r'''All the simple programs have been written, and all the good names taken.''',
r'''All you need to know is the user interface.  -- J. Redford''',
r'''An algorithm must be seen to be believed.  -- Donald Knuth''',
r'''An infinite loop is OK as long as you don't get stuck in it.''',
r'''An operating system without virtual memory is an OS without virtue.''',
r'''Any programming language is at its best before it is implemented and used.''',
r'''Avoid GOTOs completely if you can keep the program readable.''',
r'''Avoid the Fortran arithmetic IF (or better yet, just avoid Fortran).''',
r'''Avoid unnecessary branches.''',
r'''Bad style destroys an otherwise superb program.''',
r'''Bad tools result in bad software.  -- J.L. Marsh''',
r'''BASIC is to computer programming as QWERTY is to typing.  -- Seymour Papert''',
r'''Be careful when a loop exits to the same place from side and bottom.''',
r'''Choose variable names that will not be confused.''',
r'''Computers are unreliable, but humans are even more unreliable.  -- Gilb''',
r'''Computers talk to each other worse than their designers do.''',
r'''Computers... are not designed, as we are, for ambiguity.  -- Thomas''',
r'''Controlling complexity is the essence of computer programming.  -- Brian Kernighan''',
r'''Digital circuits are made from analog parts.''',
r'''Disk is cheap, but storage is expensive.''',
r'''Don't comment or patch bad code; rewrite it.''',
r'''Don't compare floating point numbers solely for equality.''',
r'''Don't diddle code to make it faster; find a better algorithm.''',
r'''Don't document the program; program the document.''',
r'''Don't stop at one bug.''',
r'''Every bug you find is the last one.''',
r'''Every good work of software starts by scratching a developer's personal itch.''',
r'''Every program is either trivial or it contains at least one bug.''',
r'''Everything should be transparent to the user.''',
r'''Expert systems are built to embody the knowledge of human experts.  -- Rich Kulawiec''',
r'''Favor object composition over class inheritance.''',
r'''Garbage in, garbage out.''',
r'''Given enough eyeballs, all bugs are shallow.  -- Eric Raymond''',
r'''Good programmers know what to write.  Great ones know what to rewrite.  -- Eric Raymond''',
r'''I do not fear computers.  I fear the lack of them.  -- Isaac Asimov''',
r'''I suppose when it gets to that point, we shan't know how it does it.  -- Alan Turing''',
r'''If the code and the comments disagree, then both are probably wrong.  -- Schryer''',
r'''If you have a procedure with 10 parameters, you probably missed some.''',
r'''In the long run, every program becomes rococco, and then rubble.  -- Alan Perlis''',
r'''It is easier to change the specification to fit the program than vice versa.''',
r'''It is easier to write an incorrect program than understand a correct one.''',
r'''It wasn't as easy to get programs right as we had thought.  -- Maurice Wilkes, 1949''',
r'''It's easy to get lost in the details of an incorrect implementation.  -- Tom von Alten''',
r'''Know Thy User.''',
r'''Let the machine do the dirty work.  -- Elements of Programming Style''',
r'''Machine independent code isn't.''',
r'''Make input easy to proofread.''',
r'''Make it right before you make it faster.''',
r'''Make sure all variables are initialized before use.''',
r'''Make sure comments and code agree.''',
r'''Make sure your code "does nothing" gracefully.''',
r'''Never put off till run-time what you can do at compile-time.  -- David Gries''',
r'''Never test for an error condition you don't know how to handle.  -- Steinbach''',
r'''Never underestimate the bandwidth of a station wagon full of tapes.  -- Jackson''',
r'''Never write software that anthropomorphizes the machine.''',
r'''Never write software that patronizes the user.''',
r'''New technology becomes salable three years before it becomes usable.''',
r'''New technology becomes usable three years before its users become competent.''',
r'''No extensible language will be universal.  -- T. Cheatham''',
r'''On the Web, understanding the medium matters more than controlling the layout.''',
r'''Performance is easier to add than clarity.''',
r'''Plan the system for change.  -- Frederick Brooks''',
r'''Program to an interface, not an implementation.''',
r'''Replace repetitive expressions by calls to a common function.''',
r'''Smart data structures and dumb code works a lot better than vice versa.''',
r'''Software is best understood as a branch of movie making.  -- Ted Nelson''',
r'''Software is mind work.  Having the right frame of mind is essential.''',
r'''The best packed information most resembles random noise.''',
r'''The computer is the Proteus of machines.  -- Seymour Papert''',
r'''The computing field is always in need of new cliches.  -- Alan Perlis''',
r'''The less time planning, the more time programming.''',
r'''The Macintosh was the first personal computer good enough to be criticized.''',
r'''The number of UNIX installations has grown to 10, with more expected.  (6/72)''',
r'''The purpose of computing is insight, not numbers.  -- Richard Hamming''',
r'''The wise person writes bomb-proof code.''',
r'''There are always at least two ways to program the same thing.''',
r'''There are never any bugs you haven't found yet.''',
r'''There can never be a computer language in which you cannot write a bad program.''',
r'''There is no problem that, when programmed just right, isn't more complicated.''',
r'''To understand a program you must become both the machine and the program.''',
r'''Try not to let implementation details sneak into design documents.''',
r'''Undetectable errors are infinite; detectable errors by definition are finite.''',
r'''UNIX is many things to many people, but it has never been everything to anybody.''',
r'''Use free-form input where possible.''',
r'''Use GOTOs only to implement a fundamental structure.''',
r'''Use IF...ELSE  IF...ELSE  IF...ELSE... to implement multi-way branches.''',
r'''Use text for text and images for images.  -- Paul Martz''',
r'''Using a free internet service, you're not the customer, you're the product.''',
r'''Watch out for off-by-one errors.''',
r'''When a program is being tested, it is too late to make design changes.''',
r'''When we write programs that "learn", it turns out we do and they don't.''',
r'''You don't have to know how the computer works, just how to work the computer.''',
r'''A gift of flower will soon be made to you.''',
r'''A nickel ain't worth a dime anymore.  -- Yogi Berra''',
r'''A visit to a fresh place will bring strange work.''',
r'''A visit to a strange place will bring fresh work.''',
r'''All the troubles you have will pass away very quickly.''',
r'''Among the lucky, you are the chosen one.''',
r'''An actor without a writer is a waiter.  -- RJ Colleary''',
r'''Baseball is 90 percent mental.  The other half is physical.  -- Yogi Berra''',
r'''Courage is your greatest present need.''',
r'''Divide your time evenly to keep others happy.''',
r'''Do not overtax your powers.''',
r'''Don't despair; your ideal lover is waiting for you around the corner.''',
r'''Executive ability is prominent in your make-up.''',
r'''Exercise caution in your daily affairs.''',
r'''Flee at once, all is discovered.''',
r'''Generosity and perfection are your everlasting goals.''',
r'''Good news from afar will bring you a welcome visitor.''',
r'''His heart was yours from the first moment that you met.''',
r'''Hold tight to your dreams.''',
r'''I always thought that record would stand until it was broken.  -- Yogi Berra''',
r'''I didn't really say everything I said.  -- Yogi Berra''',
r'''I want to thank everyone for making this night necessary.  -- Yogi Berra''',
r'''I'm not buying my kids an encyclopedia.  Let them walk to school like I did.  -- Yogi Berra''',
r'''If the people don't want to come to the ballpark, nobody's going to stop them.  -- Yogi Berra''',
r'''If you don't know where you are going, you might wind up someplace else.  -- Yogi Berra''',
r'''It gets late early out here.  -- Yogi Berra''',
r'''Life is to you a dashing and bold adventure.''',
r'''Long life is in store for you.''',
r'''Love is in the offing.  Be affectionate to one who adores you.''',
r'''Never answer an anonymous letter.  -- Yogi Berra''',
r'''Old acquaintance will soon be remembered.''',
r'''Retribution will be yours.''',
r'''Show your affection, which will probably meet with pleasant response.''',
r'''Show your appreciation for your lover by surprising him/her with a small gift.''',
r'''Someone close to you is taking advantage of your trust.''',
r'''Someone is enthusiastic about your work.''',
r'''Someone is speaking well of you.''',
r'''Stop searching forever.  Happiness is just next to you.''',
r'''Take time in life to smell the rabbits, eat the flowers, and pet the cactus.''',
r'''That wasn't chicken.  -- fictitious fortune cookie in an ad''',
r'''The future is bright in affairs of the heart.''',
r'''The lousy teams are good this year.  -- Yogi Berra''',
r'''The luck that is ordained for you will be coveted by others.''',
r'''The only things that come out of meetings, are people.''',
r'''The time is right to make new friends.''',
r'''There will be big changes for you but you will be happy.''',
r'''Torture numbers and they will confess to anything.  -- Gregg Easterbrook''',
r'''Value useful qualities in one who loves you.''',
r'''Why buy good luggage, you only use it when you travel.  -- Yogi Berra''',
r'''You are capable of planning your future.''',
r'''You are going to have a new love affair.''',
r'''You have a deep appreciation of the arts and music.''',
r'''You have a deep interest in all that is artistic.''',
r'''You have an ability to sense and know higher truth.''',
r'''You have an ambitious nature and might make a name for yourself.''',
r'''You like to form new friendships and make new acquaintances.''',
r'''You look on the sunny side of everything and make your optimism come true.''',
r'''You love peace.''',
r'''You need not worry about your future.''',
r'''You talk health, happiness, and prosperity to every person you meet.''',
r'''You will always have good luck in your personal affairs.''',
r'''You will attract cultured and artistic people to your home.''',
r'''You will be advanced socially, without any special effort on your part.''',
r'''You will be called to a post requiring ability in handling groups of people.''',
r'''You will be recognized and honored as a community leader.''',
r'''You will be singled out for promotion in your work.''',
r'''You will be successful in love.''',
r'''You will be traveling and coming into a fortune.''',
r'''You will get what you deserve.''',
r'''You will have a long-term stimulation relative to business.''',
r'''You will have domestic happiness and faithful friends.''',
r'''You will have good luck and overcome many hardships.''',
r'''You will have long and healthy life.''',
r'''You will hear good news from one you thought unfriendly to you.''',
r'''You will reach the highest possible point in your business or profession.''',
r'''Your aims are high, and you are capable of much.''',
r'''Your business will go through a period of considerable expansion.''',
r'''Your depth of comprehension might tend to make you lax in worldly ways.''',
r'''Your love life will be happy and harmonious.''',
r'''Your mode of life will be changed for the better because of new developments.''',
r'''Your present plans will be successful.''',
r'''Your talents will be recognized and suitably rewarded.''',
r'''"  "  -- Harpo Marx''',
r'''"Breakfast sometime?"  "Sure."  "Shall I call you, or just nudge you?"''',
r'''"Criminal lawyer" is a redundancy.''',
r'''"Daddy, the garbage man is here!"  "Tell him we don't need any."  -- Edward Abbey''',
r'''"Define UNIVERSE; give two examples." "The perceived world; 1) mine, 2) yours."''',
r'''"Have you lived here all your life?"  "Oh, twice that long."''',
r'''"In no language can a double positive form a negative."  "Yeah, yeah..."''',
r'''"Name two pronouns."  "Who?  Me?"''',
r'''"Those good old days" really means "those good young days."  -- Herbert Salzer''',
r'''"Was that an avalanche, or was that thunder?"  Mountaineers HATE that question.''',
r'''"Wayne Newton is," he says, "an example of what America can be."''',
r'''2.4 statute miles of intravenous surgical tubing:  1 I.V. League.''',
r'''24 hours in a day...  24 beers in a case...  Coincidence?''',
r'''28.35 grams of prevention are worth 0.45359 kilograms of cure.''',
r'''355/113 -- Not the famous irrational number pi, but an incredible simulation.''',
r'''97% of what I say is correct, and I don't care about the other 4%.''',
r'''A backscratcher will always find new itches.  -- Gomme''',
r'''A backward poet writes inverse.''',
r'''A bartender is just a pharmacist with a limited inventory.''',
r'''A bicycle can't stand on its own because it is two tired.''',
r'''A bird in the bush usually has a friend in there with him.''',
r'''A bird in the hand is safer than one overhead.''',
r'''A bird in the hand makes it hard to blow your nose.''',
r'''A blind skydiver knows he's approaching the ground when the leash goes slack.''',
r'''A boss with no humor is like a job that's no fun.''',
r'''A bull market is like sex.  It feels best just before it ends.  -- Barton Biggs''',
r'''A cauliflower is nothing but cabbage with a college education.  -- Mark Twain''',
r'''A chicken crossing the road is poultry in motion.''',
r'''A clean tie attracts the soup of the day.''',
r'''A clear conscience is usually the sign of a bad memory.''',
r'''A comet is about as close to nothing as you can get and still have something.''',
r'''A committee is an animal with at least six legs, and no brain.  -- Robert Heinlein''',
r'''A conclusion is the place where you got tired of thinking.''',
r'''A consultant saves his client almost enough to pay his fee.  -- Arnold Glasgow''',
r'''A corkscrew is the best thing with which to open a conversation.''',
r'''A countryman between two lawyers is like a fish between two cats.  -- Franklin''',
r'''A couple of months in the lab can often save a couple of hours in the library.''',
r'''A crisis is when you can't say, "Let's just forget the whole thing."  -- Ferguson''',
r'''A day without fusion is like a day without sunshine.''',
r'''A day without orange juice is like a day without orange juice.''',
r'''A day without sunshine is like night.''',
r'''A dean is to a faculty as a hydrant is to a dog.  -- Alfred Kahn''',
r'''A diamond is just a lump of coal that made good under pressure.''',
r'''A dime is a dollar after the taxes are taken out.''',
r'''A drink a day keeps the shrink away.  -- Edward Abbey''',
r'''A fail-safe circuit will destroy others.  -- Klipstein''',
r'''A fine is a tax for doing wrong.  A tax is a fine for doing well.''',
r'''A fool and his money are soon invited places.''',
r'''A fool and his money are soon partying.''',
r'''A fool and his money stabilize the economy.''',
r'''A fool with money to burn soon meets his match.''',
r'''A Freudian slip is when you say one thing but mean your mother.''',
r'''A friend in need is a pest indeed.''',
r'''A gambler plays slot machines.  I prefer to OWN slot machines.  -- Donald Trump''',
r'''A general leading the State Department resembles a dragon commanding ducks.''',
r'''A good compromise is where two people both end up unhappy.''',
r'''A good landing: You can walk away.  A great landing: You can reuse the airplane.''',
r'''A good scapegoat is hard to find.''',
r'''A harp is a nude piano.''',
r'''A helicopter is just a bunch of parts flying in close formation.''',
r'''A home where the buffalo roam...  Is messy.''',
r'''A homeowner's reach should exceed her grasp, or what's a weekend for?''',
r'''A husband is living proof that a wife can take a joke.''',
r'''A journey of a thousand miles begins with a broken fan belt and a leaky tire.''',
r'''A journey of a thousand miles begins with a cash advance from Mom.''',
r'''A kid'll eat the middle of an Oreo, eventually.''',
r'''A king's castle is his home.''',
r'''A lack of leadership is no substitute for inaction.''',
r'''A lady draws a line, while a tramp falls for a line.  -- Robert Byrne''',
r'''A lady is chaste.  A tramp is chased.''',
r'''A lady lives for a loving.  A tramp loves for a living.''',
r'''A lie in time saves nine.''',
r'''A lot of people are afraid of heights.  Not me, I'm afraid of widths.  -- Steven Wright''',
r'''A low voter turnout is an indication of fewer people going to the polls.''',
r'''A male gynecologist is like an auto mechanic who never owned a car.  -- Snow''',
r'''A man in the house is worth two in the street.  -- Mae West''',
r'''A man is incomplete until he is married.  After that, he is finished.  -- Zsa Zsa Gabor''',
r'''A man needs a mistress just to break the monogamy.''',
r'''A man who fishes for marlin in ponds will put his money in Etruscan bonds.''',
r'''A man who turns green has eschewed protein.''',
r'''A man without a woman is like a fish without gills.''',
r'''A man's got to do what a man's got to do.  A woman must do what he can't.''',
r'''A man's home is his castle, in a manor of speaking.''',
r'''A man's house is his hassle.''',
r'''A million here, a million there; soon you're talking real money.  -- Sen. Everett Dirksen''',
r'''A modest little person, with much to be modest about.  -- Winston Churchill''',
r'''A motion to adjourn is always in order.''',
r'''A movie's badness is directly proportional to the number of helicopters in it.''',
r'''A pat on the back is only a few centimeters from a kick in the pants.  -- Ella Wilcox''',
r'''A penny saved has not been spent.''',
r'''A penny saved is an economic breakthrough.''',
r'''A penny saved is better than a penny earned -- after taxes.''',
r'''A penny saved is ridiculous.''',
r'''A person is innocent until proven President.''',
r'''A pessimist is a married optimist.''',
r'''A plateau is a high form of flattery.''',
r'''A poet can survive anything but a misprint.  -- Oscar Wilde''',
r'''A poet who reads his verse in public might have other nasty habits.''',
r'''A preposition is a terrible word to end a sentence with.  -- William Safire''',
r'''A pun is the lowest form of humor -- when you don't think of it first.''',
r'''A quarter ounce of chocolate equals four pounds of fat.''',
r'''A radical is a man with both feet firmly planted in the air.  -- Franklin Roosevelt''',
r'''A recent survey indicated 54% of the population is interested in statistics.''',
r'''A recent survey proved 51% of the population are in the majority.''',
r'''A Renaissance man diffuses to refine himself.  -- Steve Hug''',
r'''A ring is a hole with a rim round it.''',
r'''A rolling stone gathers momentum.''',
r'''A sadist is a masochist who follows the Golden Rule.''',
r'''A sadist is a person who is kind to a masochist.  -- Arthur Koestler''',
r'''A sentence is worth a thousand words.''',
r'''A ship carrying a cargo of yo-yos was hit by a typhoon and sank 23 times.''',
r'''A shortcut is the longest path between two points.''',
r'''A sine curve goes off to infinity, or at least the end of the blackboard.''',
r'''A sinking ship gathers no moss.  -- Donald Kaul''',
r'''A small town that cannot support one lawyer can always support two.''',
r'''A smile is a curve that can set a lot of things straight.''',
r'''A Smith & Wesson beats four aces.''',
r'''A soft drink turneth away company.''',
r'''A student who changes the course of history is probably taking an exam.''',
r'''A successful American spends more supporting the government than a family.''',
r'''A sucking chest wound is nature's way of telling you to slow down.''',
r'''A table centerpiece should never be anything prepared by a taxidermist.''',
r'''A taxi driver is a man who drives away customers.  -- Henry Cate''',
r'''A theorist right once in ten is a hero; an observer wrong that often is a bum.''',
r'''A theory is better than its explanation.  -- Woodward''',
r'''A triangle that has an angle of 135 degrees is called an obscene triangle.''',
r'''A truly wise person never plays leapfrog with a Unicorn.''',
r'''A university without students is like an ointment without a fly.  -- Ed Nather''',
r'''A verbal contract isn't worth the paper its printed on.  -- Samuel Goldwyn''',
r'''A virtuoso is a musician with real high morals.''',
r'''A waist is a terrible thing to mind.  -- Ziggy''',
r'''A watched clock never boils.  -- Tom Weller''',
r'''A wedding is a funeral where a man smells his own flowers.''',
r'''A white bear which is nice, then nasty, then nice, is a...  Bipolar bear.''',
r'''A woman need not reveal her age, only her passions.''',
r'''A young child is a noise with dirt on it.''',
r'''Abandon the search for Truth; settle for a good fantasy.''',
r'''Abandoning my search for truth, now I search for petrified wood.''',
r'''About all some men accomplish in life is to send a son to Harvard.''',
r'''About the only thing on a farm that has an easy time is the dog.''',
r'''About when we think we can make ends meet, somebody moves the ends.  -- Herbert Hoover''',
r'''Abraham Lincoln became America's greatest precedent.''',
r'''Absence makes the heart go wander.''',
r'''Absence makes the heart grow fonder...  For someone else.''',
r'''Absolute truth is a 5-4 decision by the Supreme Court.''',
r'''Absolutum obsoletum.  (If it works, it is out of date.)  -- Stafford Beer''',
r'''Abstain from wine, women, and song; mostly song.''',
r'''Abstinence makes the heart grow fonder.''',
r'''Abstinence vanishes with presence.''',
r'''Absurdity:  Statement or belief manifestly inconsistent with one's own opinion.''',
r'''Academy:  A modern school where football is taught.''',
r'''Accept a breath mint if someone offers you one.  -- H. Jackson Brown''',
r'''Accident:  When presence of mind is good, but absence of body is better.''',
r'''According to my calculations, the problem does not exist.''',
r'''According to the official figures, 43% of all statistics are totally worthless.''',
r'''Accordionated:  Able to drive and refold a road map at the same time.''',
r'''Accuracy:  The vice of being right.''',
r'''Act old later.  -- Lily Tomlin''',
r'''Acting:  An art that consists of keeping the audience from coughing.''',
r'''Activation Energy:  The useful energy available in one cup of coffee.''',
r'''Actors will happen in the best-regulated families.''',
r'''Acupuncture is a jab well done.''',
r'''Ad:  Amana washer $100.  Owned by clean bachelor who seldom washed.''',
r'''Ad:  Cute kitten for sale, 2 cents or best offer.''',
r'''Ad:  Free puppies:  1/2 cocker spaniel, 1/2 sneaky neighbor dog.''',
r'''Ad:  Georgia peaches -- California grown -- 89 cents/lb.''',
r'''Ad:  Joining nudist colony, must sell washer & dryer -- $300.''',
r'''Ad:  Snow blower for sale...  Only used on snowy days.''',
r'''Ad:  Tickle Me Elmo.  New in box.  Hardly tickled.  $700.''',
r'''Admiration:  Our polite recognition of another's resemblance to ourselves.''',
r'''Adolescence:  That period of time between puberty and adultery.''',
r'''Adult:  A person that has stopped growing at both ends but not in the middle.''',
r'''Adult:  One old enough to know better.''',
r'''Adultery:  Putting yourself in someone else's position.''',
r'''Adults are just kids who owe money.''',
r'''Advanced design:  Upper management doesn't understand it.''',
r'''Advanced technology:  It's too complicated for me.''',
r'''Adventure is a sign of incompetence.  -- Roald Amundsen''',
r'''Advertising is 85 percent confusion and 15 percent commission.  -- Fred Allen''',
r'''Aeroma:  Odor emanating from an exercise room after an aerobics workout.''',
r'''Affluenza:  Compulsively buying possessions to satisfy some inner urge.  -- Moxcey''',
r'''After all is said and done, a hell of a lot more is said than done.  -- Olmstead''',
r'''After having sex, talk to your wife, if there is a phone in reach.''',
r'''After painting the town red, take a rest before applying a second coat.''',
r'''Afterism:  A concise, clever statement you don't think of until too late.  -- Thom''',
r'''Afternoon very favorable for romance.  Try a single person for a change.''',
r'''Age and treachery will always overcome youth and skill.''',
r'''Age is not important unless you're a cheese.''',
r'''Aging is a birth defect.  -- Al Rosenthal''',
r'''Aging is a non-curable disease.  -- Seneca''',
r'''Aging means it takes all day to do what you used to be able to do all day.''',
r'''Agriculture is something like farming; only farming is doing it.''',
r'''Ah, to be a buzzard now that spring is here!  -- Edward Abbey''',
r'''Aiming for the least common denominator sometimes causes division by zero.''',
r'''Air is water with holes in it.''',
r'''Air travel:  Breakfast in London, dinner in New York, luggage in Brazil.''',
r'''Airlines have really changed:  Now a flight attendant can get a pilot pregnant.''',
r'''Airplanes are interesting toys but of no military value.  -- Marechal Foch''',
r'''Alaska is our biggest, buggiest, boggiest state.  -- Edward Abbey''',
r'''Alcohol and calculus don't mix.  Never drink and derive.''',
r'''Alcohol kills you slowly, but who's in a hurry?''',
r'''Alcoholic:  Someone you don't like who drinks as much as you do.  -- Dylan Thomas''',
r'''Aleph-null bottles of beer on the wall, aleph-null bottles of beer...''',
r'''Alimony and bribes will engage a large share of your wealth.''',
r'''Alimony is a splitting headache.''',
r'''Alimony is the high cost of leaving.''',
r'''All bleeding eventually stops.''',
r'''All conversations with a potato should be conducted in private.''',
r'''All I ask is the chance to prove that money cannot make me happy.  -- Lauris''',
r'''All I ask of life is a constant and exaggerated sense of my own importance.''',
r'''All I want is a little more than I'll ever get.''',
r'''All I want is a warm bed and a kind word and unlimited power.  -- Ashleigh Brilliant''',
r'''All men are created equal, but some must be sent to Siberia.  -- Henry Cate''',
r'''All men are created equal.  All women are created superior.  -- Cathy Guisewitz''',
r'''All men are idiots, and I married their king.''',
r'''All my friends and I are crazy.  That's the only thing that keeps us sane.''',
r'''All new:  Parts not interchangeable with previous model.''',
r'''All people are born alike -- except Republicans and Democrats.  -- Groucho Marx''',
r'''All probabilities are really 50%.  Either a thing will happen or it won't.''',
r'''All signs in metric for the next 20 miles.  -- road sign in Ohio''',
r'''All syllogisms have three parts; therefore this is not a syllogism.''',
r'''All that glitters has a high refractive index.''',
r'''All the good ones are taken.  -- Suzy Harris''',
r'''All the men on my staff can type.  -- Bella Abzug''',
r'''All the modern inconveniences...  -- Mark Twain''',
r'''All the parts falling off this car are of the very finest British manufacture.''',
r'''All the points in between are, well, in between.  -- Jim Morrison''',
r'''All things are possible, except skiing through a revolving door.''',
r'''All things being equal, fat people use more soap.''',
r'''All things being equal, I'd rather be created.  -- John Taylor''',
r'''All things considered, life is 9 to 5 against.''',
r'''All trails have more uphill sections than they have downhill sections.''',
r'''All true wisdom is found on T-shirts.''',
r'''All we need here, God, is one little precision earthquake.''',
r'''All you need to grow healthy, vigorous grass is a crack in your sidewalk.''',
r'''All's well that ends.''',
r'''Allow me to introduce my selves.''',
r'''Almonds are members of the peach family.''',
r'''Almost everyone agrees it's fair to discriminate against lazy and stupid people.''',
r'''Alpha geek:  The most technically proficient member of an engineering team.''',
r'''Although our information is incorrect, we do not vouch for it.  -- Erik Satie''',
r'''Although the moon is 1/4 the size of the earth, it is much farther away.''',
r'''Aluminum rain:  What falls after a midair passenger exchange.''',
r'''Always borrow money from a pessimist; he doesn't expect to be paid back.''',
r'''Always do right.  This will gratify some people and astonish the rest.''',
r'''Always draw your curves, then plot the data.''',
r'''Always drink upstream from the herd.''',
r'''Always hire a rich attorney.  Never buy from a rich salesman.  -- Goldenstern''',
r'''Always identify people in your yard before shooting at them.''',
r'''Always leave room to add an explanation if it doesn't work out.''',
r'''Always offer to bait your date's hook, especially on the first date.''',
r'''Always pick on the correct idiom.  -- William Safire''',
r'''Always remember that you are unique...  Just like everyone else.''',
r'''Always remember to pillage BEFORE you burn.''',
r'''Always take both skis off before hanging them up.''',
r'''Always try to do things in chronological order; it's less confusing that way.''',
r'''Am I in charge here?...  No, but I'm full of ideas.  -- Dr. Who''',
r'''Ambiguity:  Telling the truth when you don't mean to.''',
r'''Ambition is a poor excuse for not having sense enough to be lazy.  -- Charlie McCarthy''',
r'''Ambivalent?  Well, yes and no.''',
r'''America was created by geniuses to be run by idiots.''',
r'''America:  A nice place to own, but I wouldn't want to live there.''',
r'''Amnesia used to be my favorite word, but then I forgot it.''',
r'''Amoebit:  Amoeba/rabbit cross; it can multiply and divide at the same time.''',
r'''Among economists, the real world is often a special case.  -- Horngren''',
r'''An after-dinner speaker is the fellow who starts the bull rolling.''',
r'''An after-dinner speaker rises to the occasion -- and stays too long.''',
r'''An airplane glides through the air; a helicopter beats the air into submission.''',
r'''An ambush:  Engaging the enemy on all sides.''',
r'''An apple a day keeps the doctor away...  If it is aimed well.''',
r'''An apple a day makes 365 apples a year.  -- Tom Weller''',
r'''An apple every eight hours keeps three doctors away.''',
r'''An artist should be fit for the best society and kept out of it.''',
r'''An effective way to deal with predators is to taste terrible.''',
r'''An elm's bark is worse when there's blight.  -- Henry Gay''',
r'''An example of hard water is ice.''',
r'''An expert has a great reason for guessing wrong.''',
r'''An expert is a man who has made all the mistakes in a very narrow field.  -- Neils Bohr''',
r'''An expert is a person who knows more and more about less and less.  -- Butler''',
r'''An expert is one who is never in doubt, but often in error.''',
r'''An honest God's the noblest work of man.  -- Robert Ingersoll''',
r'''An idle mind is worth two in the bush.''',
r'''An informed citizen panics more intelligently.''',
r'''An inverse paranoid believes the world is plotting to do him good.  -- Jack Canfield''',
r'''An object at rest will always be in the wrong place.''',
r'''An object in motion will always be headed in the wrong direction.''',
r'''An ostrich's eye is bigger than its brain.''',
r'''An ounce of rejection is worse than a pound of "sure".''',
r'''An unbreakable toy is useful for breaking other toys.  -- Van Roy''',
r'''Anarchy is against the law.''',
r'''Anarchy might not be the best form of government, but it is better than none.''',
r'''Anarchy:  It's not a law, it's just a good idea.''',
r'''And don't start a sentence with a conjunction.''',
r'''And now for something completely different.''',
r'''Animal testing is a terrible idea; they get all nervous and give wrong answers.''',
r'''Answer my prayers, steal this car.''',
r'''Antonym:  The opposite of the word you are trying to think of.''',
r'''Any country with "democratic" in the title isn't.  -- Murray''',
r'''Any idiot can face a crisis; it is this day-to-day living that wears you out.''',
r'''Any landing you can walk away from is a good one.''',
r'''Any simple idea will be worded in the most complicated way.  -- Malek''',
r'''Any smoothly functioning technology is indistinguishable from a "rigged" demo.  -- J.L. Marsh''',
r'''Any tool when dropped rolls into the least accessible corner.''',
r'''Any two philosophers can tell each other all they know in two hours.  -- Oliver Holmes''',
r'''Anybody can win, unless there happens to be a second entry.''',
r'''Anyone can admit they were wrong; the true test is admitting it to someone else.''',
r'''Anyone can keep a marriage together, but staying happily divorced takes work!''',
r'''Anyone can make an omelet with eggs.  The trick is to make one with none.''',
r'''Anyone who doesn't cut his speed at the sight of a police car is parked.''',
r'''Anyone who goes to a psychiatrist ought to have his head examined.  -- Samuel Goldwyn''',
r'''Anyone who makes an absolute statement is a fool.''',
r'''Anything can be made to work if you fiddle with it long enough.''',
r'''Anything dropped in the bathroom falls in the toilet.''',
r'''Anything good in life is either illegal, immoral, or fattening.  -- Pardo''',
r'''Anything that doesn't make sense ends up in court and becomes case law.''',
r'''Anything that is good and useful is made of chocolate.''',
r'''Anything worth doing is a lot more difficult than it's worth.  -- Scott Adams''',
r'''Anything worth doing is worth doing slowly.  -- Mae West''',
r'''Anything worth fighting for is worth fighting dirty for.''',
r'''Anything you do can get you shot, including nothing.''',
r'''Anything you say will be misquoted, then used against you.''',
r'''Apart from the unknowns, everything is obvious.  -- James Hogan''',
r'''Apparently the Creator likes diversity a lot more than we humans do.''',
r'''Appearances are not everything; it just looks like they are.''',
r'''Aquadextrous:  Able to turn the bathtub faucet on and off with your toes.''',
r'''Arachnoleptic fit:  Frantic dance just after running into a spider web.''',
r'''Archaeologists will date any old thing.''',
r'''Archeology is the only profession where your future lies in ruins.''',
r'''Are you going to be more interesting than you were yesterday?''',
r'''Are you lustworthy?''',
r'''Are you making this up as you go along?''',
r'''Arguments are to be avoided; they are always vulgar and often convincing.''',
r'''Arguments with furniture are rarely productive.''',
r'''Arithmetic is counting to twenty without taking off your shoes.  -- Mickey Mouse''',
r'''Art is anything you can get away with.  -- Marshall McLuhan''',
r'''Artery:  Study of paintings.''',
r'''As a matter of fact, I DO own the road!''',
r'''As God is my witness, Andy, I thought that turkeys could fly.  -- WKRP in Cinncinnati''',
r'''As I learn to trust the universe, I no longer need to carry a gun.''',
r'''As is often the case when I generalize, I don't care.  -- Dave Barry''',
r'''As long as the answer is right, who cares if the question is wrong?''',
r'''Ask about our layaway plan.  -- sign in funeral parlor''',
r'''Ask about our plans for owning your home.  -- sign in loan company office''',
r'''Ask not for whom the bell tolls, and pay only station-to-station rates.''',
r'''Astronauts are out to launch.''',
r'''Astronomers bring light to the darkest discussions.  -- Kreigh Tomaszewski''',
r'''At 300 miles an hour, you can make a rock fly.  -- Sam Wheeler''',
r'''At least five buses go by in the opposite direction before yours arrives.''',
r'''At least I have a positive attitude about my destructive habits.''',
r'''At my age, I don't buy green bananas.''',
r'''At some point you stop lying about your age and start bragging about it.''',
r'''At these prices, I lose money -- but I make it up in volume.  -- Peter Alaquon''',
r'''Atheism is a non-prophet organization.''',
r'''Atheists are beyond belief.''',
r'''Atheists are people with no invisible means of support.''',
r'''Auditors always reject expense accounts with a bottom line divisible by five.''',
r'''Auntie Em:  Hate you, hate Kansas, taking the dog.  -- Dorothy''',
r'''Author:  An imaginary person who writes real books.  -- Edward Abbey''',
r'''Authority:  A person who can tell you more than you really care to know.''',
r'''Autobiography is fiction written by the one who knows the facts.''',
r'''Autocorrect has become my worst enema.''',
r'''Automobile:  A four-wheeled vehicle that runs up hills and down pedestrians.''',
r'''Avoid cliches like the plague; seek viable alternatives.  -- William Safire''',
r'''Avoid colloquial stuff.''',
r'''Avoid commas, that are not necessary.''',
r'''Avoid trendy locutions that sound flaky.  -- William Safire''',
r'''Avoid truth decay.  Be sure to use mental floss twice a day.  -- Steve Bhaerman''',
r'''Babies can't walk because their legs aren't long enough to reach the ground.''',
r'''Babies learn decibels before they learn syllables.''',
r'''Bachelor:  A guy who is footloose and fiancee-free.''',
r'''Bachelor:  A man who never made the same mistake once.''',
r'''Bachelor:  A selfish guy who has cheated some woman out of a divorce.  -- Quinn''',
r'''Bacteria are the only culture some people have.''',
r'''Bad luck is being run over by the welcome wagon.''',
r'''Bad weather reports are more often right than good ones.''',
r'''Bakers trade bread recipes on a knead-to-know basis.''',
r'''Ban the bomb.  Save the world for conventional warfare.''',
r'''Bananosecond:  The time between slipping on a peel and landing on the pavement.''',
r'''Banectomy:  The removal of bruises on a banana.  -- Rich Hall''',
r'''Barium:  What doctors do when treatment fails.''',
r'''Baseball is religion without the mischief.  -- Tom Boswell''',
r'''Baseball is to football as Beethoven is to rap.  -- Patrick Mott''',
r'''Basic unit of laryngitis:  1 hoarsepower.''',
r'''Be a better psychiatrist and the world will beat a psychopath to your door.''',
r'''Be alert; the world needs more lerts.''',
r'''Be careful not to screw yourself in the foot.''',
r'''Be careful of reading health books; you might die of a misprint.  -- Mark Twain''',
r'''Be content with what you've got, but be sure you've got plenty.''',
r'''Be different, act normal.''',
r'''Be glad you're going so slowly, because you're going in the wrong direction.''',
r'''Be here now.  Be someplace else later.  Is that so complicated?''',
r'''Be kind to your inferiors, if you can find any.''',
r'''Be kind to your knees.  You'll miss them when they're gone.  -- Mary Schmich''',
r'''Be nice to your kids; they will choose your nursing home.''',
r'''Be of good cheer:  We'll live to piss on the graves of our enemies.  -- Edward Abbey''',
r'''Be patient and achieve all things.  Be impatient and achieve all things faster.''',
r'''Be reasonable:  Do it my way.''',
r'''Be sure to poofread your writing.''',
r'''Be wary of strong drink.  It can make you shoot at tax collectors and miss.''',
r'''Beam me up, Scotty.  There's no intelligent life down here.  -- James Kirk''',
r'''Beauty is in the body of the beholdee.  -- John Taylor''',
r'''Beauty is in the eye of the beer holder...''',
r'''Beauty is only skin deep, but it is very agreeable, for all that.  -- Cobbett''',
r'''Beauty is only skin deep, but ugly goes clear to the bone.''',
r'''Beauty times brains equals a constant.''',
r'''Becoming overweight is something that snacks up on you.''',
r'''Bedfellows make strange politicians.''',
r'''Beer, one of my favorite solvents... It dissolves even thoughts!  -- JR Hodel''',
r'''Before each flight ensure your bladder is empty and your fuel tanks are full.''',
r'''Before enlightenment, also do the laundry.  -- Alan Silverstein''',
r'''Before they invented drawing boards, what did they go back to?''',
r'''Before you find your handsome prince, you must kiss a lot of frogs.''',
r'''Begathon:  A multi-day event on public television, used to raise money.  -- Hall''',
r'''Behaviorism is the art of pulling habits out of rats.  -- O'Neill''',
r'''Behold the warranty:  The bold print giveth, and the fine print taketh away.''',
r'''Being a good communicator means people find out what's really wrong with you.''',
r'''Being a pilot is a hard way to earn an easy living.''',
r'''Being a woman is quite difficult since it consists mainly of dealing with men.''',
r'''Being normal is driving me crazy.''',
r'''Being popular is important.  Otherwise people might not like you.''',
r'''Benjamin Franklin died in 1790 and is still dead.''',
r'''Benjamin Franklin produced electricity by rubbing cats backwards.''',
r'''Best gift for the person who has everything:  A burglar alarm.''',
r'''Best place to take a leak.  -- sign in radiator shop''',
r'''Better living through denial.''',
r'''Between two evils, I always pick the one I never tried before.  -- Mae West''',
r'''Beware of a dark-haired man with a loud tie.''',
r'''Beware of a tall dark man with a spoon up his nose.''',
r'''Beware of low-flying butterflies.''',
r'''Beware of Natural Selection.  -- Bob Thaves''',
r'''Bigamy is having one spouse too many.  Monogamy is the same.''',
r'''Billboard:  Keep your eyes on the road and stop reading these signs.''',
r'''Bills travel through the mail at twice the speed of checks.''',
r'''Biological Science:  A contradiction in terms.''',
r'''Biology grows on you.''',
r'''Birth control pills are tax-deductible, but only if they fail.  -- Dear Abby''',
r'''Bisexuality immediately doubles your chances for a date on Saturday night.''',
r'''Black holes were created when God divided by zero!''',
r'''Blamestorming:  A group figuring out who was responsible for a failure.''',
r'''Blessed are the brief, for they shall have lower phone bills.''',
r'''Blessed are the meek for they shall inhibit the Earth.''',
r'''Blessed are the young for they shall inherit the national debt.  -- Herbert Hoover''',
r'''Blessed are they that run around in circles, for they shall be known as wheels.''',
r'''Blood flows down one leg and up the other.''',
r'''Bluntness:  The art of saying nothing in a way that leaves nothing unsaid.''',
r'''Boat:  A hole in the water into which one throws money.''',
r'''Bore:  A person who talks when you wish him to listen.  -- Ambrose Bierce''',
r'''Bore:  He who talks so much about himself that you can't talk about yourself.''',
r'''Bore:  The kind of man who, when you ask him how he is, tells you.  -- Pollock''',
r'''Bore:  Wraps up a two-minute idea in a two-hour vocabulary.  -- Winchell''',
r'''Born free...  Taxed to death.''',
r'''Born to shop!''',
r'''Boss spelled backwards is, "double S.O.B."  -- Reid Stanley''',
r'''Bozone:  Substance surrounding idiots that stops bright ideas from penetrating.''',
r'''Brad, where Tad had had "had had", had had "had".  "Had had" had had me glad.''',
r'''Brain cells come and brain cells go, but fat cells live forever.''',
r'''Brain:  The apparatus with which we think that we think.  -- Ambrose Bierce''',
r'''Breeding rabbits is a hare raising experience.''',
r'''Bride:  A woman with a fine prospect of happiness behind her.''',
r'''Brigands ask for your money or your life; spouses require them both.''',
r'''Broad-mindedness:  The result of flattening high-mindedness out.''',
r'''Budget:  A method for going broke methodically.''',
r'''Budget:  A method of worrying before you spend money, as well as afterward.''',
r'''Budget:  Mathematical confirmation of your suspicions.  -- Latimer''',
r'''Bumper sticker on an old truck:  Don't Laugh -- Your Daughter Might Be In Here.''',
r'''Bumper sticker, Dec 2000:  Don't Blame Me, I Voted for Al Gore...  I Think.''',
r'''Bumper sticker:  Don't Honk, I'm Pedaling as Fast as I Can.''',
r'''Bumper sticker:  Forget about World Peace...  Visualize using your turn signal.''',
r'''Bumper sticker:  Friends Don't Let Friends Vote Republican.''',
r'''Bumper sticker:  Horn broken.  Watch for finger.''',
r'''Bumper sticker:  Hug Your Kids at Home and Belt Them in the Car.''',
r'''Bumper sticker:  I Brake for Hallucinations.''',
r'''Bumper sticker:  I'd rather be teleporting.''',
r'''Bumper sticker:  If you can read this, I can hit my brakes and sue you.''',
r'''Bumper sticker:  My Child Can Beat Up Your Honor Student.''',
r'''Bumper sticker:  Stamp out crime; Abolish the IRS.''',
r'''Bumper sticker:  Your kid might be an honors student, but you're still an idiot.''',
r'''Bureaucracy:  A method of transforming energy into solid waste.''',
r'''Bureaucrat:  A person who cuts red tape sideways.  -- J. McCabe''',
r'''Bureaucrat:  A politician with tenure.''',
r'''Bureaucratic organization is like a septic tank:  Big chunks rise to the top.''',
r'''Business before pleasure unless pleasure is your business.''',
r'''Business will be either better or worse.  -- Calvin Coolidge''',
r'''But enough about me.  Let's talk about you.  What do you think of me?  -- Midler''',
r'''But officer, I stopped for the last one, and it was green!''',
r'''But two in the bush are more FUN than one in the hand!''',
r'''Buy a stock, if it goes up, sell it, if it goes down, don't buy it.''',
r'''By self-pollination, the farmer might get a flock of long-haired sheep.''',
r'''By the time you have the right answers, no one is asking you questions.''',
r'''Cabnicreep:  When closing one kitchen cabinet causes another to open.''',
r'''California is proud to be the home of the freeway.  -- Ronald Reagan''',
r'''Californians are not without their faults.''',
r'''Calling a person a runner-up is a polite way of saying they lost.''',
r'''Can a man do no worse than to fall in love?''',
r'''Can I yell "movie" in a crowded firehouse?''',
r'''Can you be a closet claustrophobic?''',
r'''Can you think of another word for "synonym"?''',
r'''Candy / is dandy / but liquor / is quicker.  -- Ogden Nash''',
r'''Capitalism is based on the assumption that you can win.''',
r'''Car service:  If it ain't broke, we'll break it.''',
r'''Career plans:  "I want to rule the world."  -- Madonna''',
r'''Careful planning will never replace dumb luck.''',
r'''Carpenters (and pilots) are just plane folks.''',
r'''Cashtration:  Buying a house renders you financially impotent for a long time.''',
r'''Cats have over one hundred vocal sounds, while dogs only have about ten.''',
r'''Cauterize:  Made eye contact with a woman.''',
r'''Caution:  Breathing might be hazardous to your health.''',
r'''Celibacy is hereditary.''',
r'''Chainsaw consultant:  An outside expert brought in to fire employees.''',
r'''Change is great...  You go first.''',
r'''Change is inevitable, except from a vending machine.''',
r'''Character density:  The number of very weird people in the office.''',
r'''Charity:  A thing that begins at home and usually stays there.''',
r'''Charles Darwin was a naturalist who wrote the organ of the species.''',
r'''Charm:  A way of getting a "yes" -- without having asked any clear question.''',
r'''Chastity is the most unnatural of the sexual perversions.  -- Aldous Huxley''',
r'''Cheap:  Much less expensive than ones selling for up to twice as much.''',
r'''Chemicals:  Noxious substances from which modern foods are made.''',
r'''Chicken Little was right.''',
r'''Children act like their parents despite every effort to teach them good manners.''',
r'''Children are a nine month illness and a lifetime convalescence.  -- Benito Galdos''',
r'''Children are beloved sources of dirty laundry and ceaseless noise.  -- Bill Cosby''',
r'''Choconiverous:  Biting off the head of the chocolate Easter bunny first.''',
r'''Choice is good.  Except for those people who choose poorly.  -- Bob Proulx''',
r'''Cinemuck:  Popcorn, soda, and candy that covers the floors of movie theaters.''',
r'''Circle:  A line that meets its other end without ending.''',
r'''Citation:  Reputation by repetition.  -- Gerhard Uhlenbruck''',
r'''Civilization exists by geological consent, subject to revocation without notice.  -- Will Durant''',
r'''Cleaning one's ears should be done in private using one's OWN truck keys.''',
r'''Cleanliness is next to impossible.''',
r'''Clients who pay the least complain the most.''',
r'''Climate:  What you expect.  Weather:  What you get.''',
r'''Cloning is the sincerest form of flattery.''',
r'''Clothes make the man.  Naked people have little or no influence on society.''',
r'''Cogito Eggo sum.  (I think, therefore I am a waffle.)''',
r'''Cogito ergo spud (I think, therefore I yam).''',
r'''College:  The fountains of knowledge, where everyone goes to drink.''',
r'''Colorless green ideas sleep furiously.''',
r'''Come in and buy what your grandparents threw away.  -- antique store''',
r'''Come up and see me sometime when I've nothing but the wireless on.  -- Mae West''',
r'''Comedy is simply a funny way of being serious.  -- Peter Ustinov''',
r'''Comets are like cats:  They have tails and do what they want.  -- David Levy''',
r'''Committee:  People who keep minutes and waste hours.  -- Milton Berle''',
r'''Committee:  The unwilling, selected from the unfit, to do the unnecessary.''',
r'''Common sense:  The collection of prejudices acquired by age 18.  -- Einstein''',
r'''Compromise:  A deal in which two people get what neither of them want.''',
r'''Concentrated bases are much more dangerous since YOU are soluble in them.''',
r'''Concept:  Any "idea" for which an outside consultant bills more than $25,000.''',
r'''Concern is the first time you can't do it the second time.  -- Isaac Asimov''',
r'''Conference:  Where many people gather to decide nothing can be done alone.''',
r'''Confession is good for the soul, but bad for the career.''',
r'''Confidence:  The feeling you have before you understand the situation.''',
r'''Conform, go crazy, or become an artist.''',
r'''Confound those who have said our remarks before us.  -- Aelius Donatus''',
r'''Confucius say too much.  -- recent Chinese proverb''',
r'''Congress is not the sole suppository of wisdom.  -- Rep. Bill Schuette (R-MI)''',
r'''Conscience is a mother-in-law whose visit never ends.  -- H. L. Mencken''',
r'''Conscience is the inner voice that warns us somebody may be looking.  -- Mencken''',
r'''Conscience is the thing that hurts when everything else feels great.''',
r'''Conscious is being aware of something; conscience is wishing you weren't.''',
r'''Consciousness:  That annoying time between naps.''',
r'''Conservative:  A Liberal who has just been mugged.''',
r'''Conservative:  A man who just sits and thinks, mostly sits.  -- Woodrow Wilson''',
r'''Conservative:  A person who believes nothing should be done for the first time.''',
r'''Conservative:  One who is too cowardly to fight and too fat to run.''',
r'''Consider what might be fertilizing the greener grass across the fence.''',
r'''Consultant:  Someone who knowns 101 ways to make love, but can't get a date.''',
r'''Consultation:  Medical term meaning "to share the wealth."''',
r'''Contents:  One universe.  Some assembly required.  -- Bob Thaves''',
r'''Continental Life.  Why do you ask?''',
r'''Contraceptives should be used on every conceivable occasion.''',
r'''Coordinator:  Brings organized chaos out of regimented confusion.''',
r'''Coordinator:  The guy with his desk between two expediters.''',
r'''Corduroy pillows are making headlines.''',
r'''Correct to within an order of magnitude:  Wrong.''',
r'''Cosmetics are a woman's way of keeping a man from reading between the lines.''',
r'''Could you be a poster child for retroactive birth control?''',
r'''Courage:  Two cannibals having oral sex.''',
r'''Coward:  One who in a perilous emergency thinks with his legs.  -- Bierce''',
r'''Crazee Edeee, his prices are INSANE!!!''',
r'''Credit is what keeps you from knowing how far past broke you are.''',
r'''Crime does not pay...  As well as politics.  -- A. E. Newman''',
r'''Criticism is not nearly as effective as sabotage.''',
r'''Cross country skiing is great if you live in a small country.  -- Steve Wright''',
r'''Culture is for bacteria.  -- Christopher Hyatt''',
r'''Customers are beautiful people.  Listen to them.  -- Richard Whitley''',
r'''Cut to measurements; file to shape; hammer to fit.''',
r'''Cynic:  A person searching for an honest man, with a stolen lantern.  -- Shoaff''',
r'''Cynic:  A person who tells you the truth about your own motives.  -- Russel Green''',
r'''Dancing is a perpendicular expression of a horizontal desire.''',
r'''Danger!  I drive like you do.''',
r'''Dare to be average.''',
r'''Dark dirt is attracted to light objects, and light dirt to dark objects.''',
r'''Dating is never easy for engineers.  -- Scott Adams''',
r'''De-access your euphemisms.''',
r'''Death and taxes are inevitable; at least death doesn't get worse every year.''',
r'''Death comes to all men, but some just can't wait.  -- Darwin Awards''',
r'''Death has been proven to be 99% fatal to laboratory rats.''',
r'''Death is God's way of telling you not to be such a wiseguy.''',
r'''Death is life's way of telling you you've been fired.  -- R. Geis''',
r'''Death is often a good career move for an author.  -- Nassim Taleb''',
r'''Death is the greatest kick of all.  That's why they save it for last.''',
r'''Death:  To stop sinning suddenly.  -- Elbert Hubbard''',
r'''Defense attorney's ad:  Reasonable Doubt At Reasonable Prices.''',
r'''Deja Fu:  The feeling that you have been kicked in the head like this before.''',
r'''Deja Moo:  The feeling that you have heard this BS before.''',
r'''Delegates from the original thirteen states formed the Contented Congress.''',
r'''Deliberation:  Examining one's bread to determine which side it is buttered on.''',
r'''Democracy is the worship of Jackals by Jackasses.  -- H. L. Mencken''',
r'''Demons are a ghoul's best friend.''',
r'''Dentists are incapable of asking questions that need a simple yes or no answer.''',
r'''Design simplicity:  Developed on a shoe-string budget.''',
r'''Despite treatment, the patient improved.''',
r'''Dew is formed on leaves when the sun shines on them and makes them perspire.''',
r'''Diamonds are a girl's best friend.  Dogs are man's best friend.  Who's smarter?''',
r'''Diets are for people who are thick and tired of it.''',
r'''Difference between a garbage dump and a sanitary landfill:  About $20 a load.''',
r'''Difference between artist and craftsman:  A craftsman knows what he's doing.''',
r'''Dijon vu -- the same mustard as before.''',
r'''Dinner is ready when the smoke alarm goes off.''',
r'''Dinosaurs were calm because they lived in pre-hysteric times.''',
r'''Diplomacy:  Saying "go to hell" such that they look forward to the trip.''',
r'''Diplomacy:  The art of letting someone else have your way.''',
r'''Diplomacy:  The art of saying "nice doggy" until you can find a rock.''',
r'''Diplomat:  A man who can convince his wife she would look stout in a fur coat.''',
r'''Disco is to music what Etch-A-Sketch is to art.''',
r'''Disconfect:  Blowing on a piece of candy retrieved from the floor.''',
r'''Disguise your feelings when you put your relatives on the plane for home.''',
r'''Distinctive:  A different color or shape than our competitors.''',
r'''Diversity's fine; subscribe to mine.''',
r'''Divorce is having your genitals torn off through your wallet.  -- Robin Williams''',
r'''Divorced:  Post-graduate in the School of Love.''',
r'''Do as I say, not as I do.''',
r'''Do cemetery workers prefer the graveyard shift?''',
r'''Do hungry crows have ravenous appetites?''',
r'''Do I strike you as a violent person?  -- Brian Hammer''',
r'''Do infants enjoy infancy as much as adults enjoy adultery?''',
r'''Do married people live longer, or does it just seem that way?''',
r'''Do not be led astray onto the path of virtue.''',
r'''Do not drink and drive.  You might hit a bump and spill it!''',
r'''Do not drink coffee in the morning or it will keep you awake until noon.''',
r'''Do not judge a book by its movie.''',
r'''Do not kiss an elephant on the lips today.''',
r'''Do not let people drive you crazy when you know it's within walking distance.''',
r'''Do not merely believe in miracles; rely on them.  -- Finagle''',
r'''Do not put statements in the negative form.  -- William Safire''',
r'''Do not read beauty magazines.  They will only make you feel ugly.  -- Schmich''',
r'''Do not repeat yourself or say what you have said before.''',
r'''Do not suffer from insanity.  Enjoy every minute of it.''',
r'''Do not tell big lies.  Small ones can be just as effective.''',
r'''Do not underestimate the power of the Force.''',
r'''Do not use a big word where a diminutive one will suffice.''',
r'''Do not use a foreign term when there is an adequate English quid pro quo.''',
r'''Do not use contractions in formal writing.''',
r'''Do not use hyperbole; not one writer in a million can use it effectively.''',
r'''Do not worry about temptation.  As you grow older, it starts avoiding you.''',
r'''Do unto others as they wish to do unto you, but do it first.  -- Mayor Curley''',
r'''Do unto others before they undo you.''',
r'''Do you ever stop to think and then forget to start again?''',
r'''Do you find yourself thinking more and enjoying it less?''',
r'''Do you have lysdexia?''',
r'''Do YOU have redeeming social value?''',
r'''Do you think much about dying?  No, it's the last thing I want to do.  -- Abby''',
r'''Does fuzzy logic tickle?''',
r'''Does the name "Pavlov" ring a bell?''',
r'''Does this hurt?  How about now?  -- Scott Adams''',
r'''Dog wisdom:  Never pass up the opportunity to go for a joyride.''',
r'''Dog wisdom:  When loved ones come home, always run to greet them.''',
r'''Dog wisdom:  When you are happy, dance around and wag your entire body.''',
r'''Doing nothing makes you tired because you can't take a break.''',
r'''Don't be afraid of work.  Make work afraid of you.  -- Tom Magliozzi''',
r'''Don't be fooled by his twinkling eyes; it's the sun shining between his ears.''',
r'''Don't be humble...  You're not that great.  -- Golda Meir''',
r'''Don't bother me, I'm living happily ever after.''',
r'''Don't create a problem for which you do not have the answer.  -- Burke''',
r'''Don't do anything in public that you wouldn't do in private.''',
r'''Don't do anything you'll regret having not done sooner.''',
r'''Don't eat the yellow snow.''',
r'''Don't force it, get a larger hammer.  -- Anthony''',
r'''Don't forget to never use negative commands.''',
r'''Don't get even -- get odd!  -- Steve Bhaerman''',
r'''Don't get stuck in a closet; wear yourself out.''',
r'''Don't give someone a piece of your mind unless you can afford it.''',
r'''Don't go away mad...  Just go away!''',
r'''Don't lend people money...  It gives them amnesia.''',
r'''Don't make me come down there...  -- God''',
r'''Don't marry for money; you can borrow it cheaper.  -- Scottish Proverb''',
r'''Don't mind him; politicians always sound like that.''',
r'''Don't open bills on the weekend.  -- H. Jackson Brown''',
r'''Don't overuse exclamation marks!  -- William Safire''',
r'''Don't panic, but do you believe in reincarnation?  -- Bob Thaves''',
r'''Don't pick on your sister when she's holding a baseball bat.  -- Joel, age 10''',
r'''Don't pray in my school, and I won't think in your church.''',
r'''Don't say yes until I finish talking.  -- Darryl Zanuck''',
r'''Don't steal.  The government hates competition.''',
r'''Don't sweat the petty things -- just pet the sweaty things.''',
r'''Don't take life too seriously; you won't get out of it alive.  -- Hubbard''',
r'''Don't tax you, don't tax me, tax that fellow behind the tree.  -- Russell Long''',
r'''Don't tell me not to burn the candle at both ends; tell me how to get more wax!''',
r'''Don't undertake vast projects with half-vast ideas.''',
r'''Don't use no double negatives, not never.''',
r'''Don't vote -- it only encourages them!''',
r'''Don't wear your glasses on a blind date.  You'll look better, and he will too.''',
r'''Don't worry, if everything worked right you'd be out of a job.''',
r'''Don't worry; the brontosaurus is slow, stupid, and placid.''',
r'''Don't you hate it when you lock your keys out of your car?  -- Scott Adams''',
r'''Don't you have anything more useful you could be doing?''',
r'''Dopelar effect:  How stupid ideas seem smarter if they come at you fast.''',
r'''Down with the categorical imperative!''',
r'''Dress for radio.  -- Swami Beyondananda''',
r'''Drilling for oil is boring.''',
r'''Drive carefully.  We are overstocked.  -- sign in junkyard''',
r'''Drive on ice no faster than you want to hit something.''',
r'''Driving in the snow is a spectator sport.''',
r'''Drug:  A substance that, when injected into a rat, produces a scientific paper.''',
r'''Drugs are the scenic route to nowhere.''',
r'''Ducks?  What ducks??''',
r'''Due to a mixup in Urology, orange juice will not be served this morning.''',
r'''Dumbwaiter:  One who asks if the kids would care to order dessert.''',
r'''Dying is easy.  Comedy is difficult.''',
r'''Dyslexics of the world, untie!  -- Andrew Jamner''',
r'''Eagles may soar, free and proud, but weasels never get sucked into jet engines.''',
r'''Early to bed and early to rise, 'til I make enough to otherwise.''',
r'''Early to rise and early to bed makes a man healthy and wealthy and dead.''',
r'''Earth Destroyed by Solar Flare -- Film at eleven.''',
r'''Earth got a lot more interesting once it went multicellular.''',
r'''Earth is a great funhouse without the fun.  -- Jeff Berner''',
r'''Easiest way to figure the cost of living:  Take your income and add ten percent.''',
r'''Eat a live toad in the morning and nothing worse will happen to you that day.''',
r'''Eat yogurt and get culture.''',
r'''Eat, drink, and be merry, for tomorrow it might be illegal.''',
r'''Eat, drink, and be merry, for tomorrow we diet.  -- Lewis Henry''',
r'''Ecology:  The study of who eats whom.''',
r'''Economics is extremely useful as a form of employment for economists.''',
r'''Education helps earning capacity.  Ask any college professor.''',
r'''Education:  That which enables you to get into more intelligent trouble.''',
r'''Eeny, Meeny, Jelly Beanie, the spirits are about to speak...''',
r'''Efficiency:  Getting someone to do the work you don't like to do.''',
r'''Egocentric:  A person who believes he is everything you know you are.''',
r'''Egotism:  Doing a crossword puzzle with a pen.''',
r'''Eighty percent of all people consider themselves to be above average drivers.''',
r'''Either do wrong or feel guilty, but don't do both.  -- Rudolf Dreikurs''',
r'''Either I'm dead or my watch has stopped.  -- last words of Groucho Marx''',
r'''Either that wallpaper goes, or I do.  -- last words of Oscar Wilde''',
r'''Elbonics:  Two people maneuvering for one armrest in a movie theater.''',
r'''Elections come and go, but politics are always with us.''',
r'''Electricity comes from electrons; morality comes from morons.''',
r'''Elephant:  A mouse built to government specifications.''',
r'''Eliminate government waste, no matter how much it costs!''',
r'''Eloquence is logic on fire.''',
r'''Employees enjoy the illusion of security; contractors, of independence.''',
r'''Emulate your heros, but don't carry it too far.  Especially if they are dead.''',
r'''Emus cannot walk backwards.''',
r'''Energizer Bunny arrested -- charged with battery.''',
r'''Engineers are widely recognized as superior marriage material.  -- Scott Adams''',
r'''Engineers can actually hear machines talk to them.  -- Scott Adams''',
r'''Engineers have problems that ordinary people don't.  -- Catherine Grow''',
r'''Engineers will go without food and hygiene for days to solve a problem.  -- Scott Adams''',
r'''Engineers...  They love to change things.  -- Leonard McCoy MD''',
r'''Enjoy life; you could have been a barnacle.''',
r'''Enough research will tend to support your theory.''',
r'''Entropy isn't what it used to be.''',
r'''Epigram:  Half-truth stated so as to irritate people who believe the other half.''',
r'''Epitaph:  A postponed compliment.''',
r'''Eschew obfuscation.''',
r'''Eternal nothingness is fine if you happen to be dressed for it.  -- Woody Allen''',
r'''Even a genius can have an off-day.  -- Wile E. Coyote''',
r'''Even a stopped clock is right twice a day.''',
r'''Even if you can't get a date, avoid kidnapping; it's bad for your reputation.''',
r'''Every baby resembles the relative with the most money.  -- James Hastings''',
r'''Every cloud has a silver lining; you should have sold it, and bought titanium.''',
r'''Every day more money is printed for the Monopoly game than for the US Treasury.''',
r'''Every four minutes a woman has a baby.  Find this woman and stop her!''',
r'''Every instructor assumes you have nothing else to do but study for that class.''',
r'''Every journalist has a novel in him, which is an excellent place for it.''',
r'''Every lazybones deserves a kick in his can'ts.''',
r'''Every little picofarad has a nanohenry all its own.''',
r'''Every morning is the dawn of a new error.''',
r'''Every silver lining has a cloud around it.''',
r'''Every time I close the door on reality, it comes in through the window.''',
r'''Every time I lose weight, it finds me again.''',
r'''Everybody lies, but it doesn't matter since nobody listens.  -- Lieberman''',
r'''Everybody talks about the weather, but nobody does anything about it.  -- Warner''',
r'''Everyone else my age is an adult, whereas I am merely in disguise.  -- Atwood''',
r'''Everyone gets lots of fertilizer; but what you plant is up to you.''',
r'''Everyone has a photographic memory, but some do not have film.''',
r'''Everyone is a genius.  It is just that some people are too stupid to realize it.''',
r'''Everyone is entitled to my opinion.''',
r'''Everyone needs belief in something.  I believe I'll have another beer.''',
r'''Everyone stopping by with unsought advice will see your mistake.''',
r'''Everyone's crazy but you and me, and I've been wondering about you lately.''',
r'''Everyone's thinking part wonders what the part not thinking isn't thinking of.''',
r'''Everything can be filed under "miscellaneous".''',
r'''Everything coming your way?  You're in the wrong lane!''',
r'''Everything goes on sale...  Right after you buy it.''',
r'''Everything going good?  You must have overlooked something.''',
r'''Everything happens for a reason, but sometimes it's your bad decision.''',
r'''Everything in moderation, including moderation.''',
r'''Everything is actually everything else, just recycled.''',
r'''Everything is always done for the wrong reasons.  -- O'Brian''',
r'''Everything put together falls apart sooner or later.  -- Simon''',
r'''Everything that can be invented has been invented.  -- Duell, patent commissioner''',
r'''Everything worthwhile is mandatory, prohibited, or taxed.''',
r'''Everything you know is wrong, but you can be straightened out.''',
r'''Excellent day to have a rotten day.''',
r'''Exceptions always outnumber rules.''',
r'''Exceptions prove the rule, and wreck the budget.  -- Miller''',
r'''Exclusive:  We are the only ones who have the documentation.''',
r'''Executive ability:  Deciding quickly and getting somebody else to do the work.''',
r'''Exercise extends your life ten years, but you spend 15 of them doing it.''',
r'''Experience enables you to recognize a mistake when you make it again.  -- Jones''',
r'''Experience is directly proportional to the amount of equipment ruined.  -- Horner''',
r'''Experience is something you don't get until just after you need it.  -- Olivier''',
r'''Experience is what causes a person to make new mistakes instead of old ones.''',
r'''Experiments should be reproducible.  They should all fail the same way.''',
r'''Expert:  A person one step ahead of a non-expert.''',
r'''Expert:  A person who creates confusion out of simplicity.''',
r'''Expert:  Avoids the small errors while sweeping on to the grand fallacy.''',
r'''Expert:  Knows tomorrow why today's prediction failed.''',
r'''f u cn rd ths, itn tyg h myxbl cd.''',
r'''Fairy tale:  A horror story to prepare children for the newspapers.''',
r'''Falling in love is awfully simple.  Falling out of love is simply awful.''',
r'''Familiarity breeds attempt.''',
r'''Familiarity breeds contempt -- and children.  -- Mark Twain''',
r'''Families can choose between keeping up with their neighbors or their creditors.''',
r'''Famous last words:  Don't worry, I can handle it.''',
r'''Fanatic:  Someone who, having lost sight of his goal, redoubles his efforts.''',
r'''Farmer:  A man who is outstanding in his field.''',
r'''Fashion:  A form of ugliness so intolerable that it changes every six months.''',
r'''Fast, Cheap, Good:  Choose any two.''',
r'''Faunacated:  How wildlife ends up when its environment is destroyed.''',
r'''Fear is nature's warning sign to get busy.  -- Henry Link''',
r'''Federal Reserve:  A reserve where federal employees hunt wild game.''',
r'''Feel good?  Don't worry, you'll get over it.''',
r'''Felix navidad.  (Our cat has a boat.)''',
r'''Fenderberg:  Deposit that forms on the inside of a car fender after a snowstorm.''',
r'''Fertility is an inherited trait that never skips a generation.  -- Bob Thaves''',
r'''Few women admit their age.  Few men act theirs.''',
r'''Fidelity:  A virtue peculiar to those who are about to be betrayed.''',
r'''Field tested:  Manufacturing doesn't have a test system.''',
r'''Fill what's empty; empty what's full; scratch where it itches.  -- Longworth''',
r'''Finance:  Passing money from one hand to another until it finally disappears.''',
r'''Financial manager:  Someone who keeps investing your money until it's all gone.''',
r'''Fine day for friends.  So-so day for you.''',
r'''First things first, but not necessarily in that order.''',
r'''Fishing is a delusion entirely surrounded by liars in old clothes.  -- Marquis''',
r'''Fishing:  A jerk at one end of the line waiting for a jerk at the other end.''',
r'''Fits like a sock on a duck's nose.''',
r'''Five days a week, my body is a temple.  The other two, it's an amusement park.''',
r'''Five is a sufficiently close approximation to infinity.  -- Robert Firth''',
r'''Five out of four people have trouble with fractions.''',
r'''Flabbergasted:  Appalled over how much weight you have gained.''',
r'''Flashlight:  A container for holding dead batteries.''',
r'''Flopcorn:  The unpopped kernels at the bottom of the cooker.''',
r'''Flying is the second greatest experience known to man.  Landing is the first.''',
r'''Flying small aircraft makes everything else seem cheap by comparison.''',
r'''Foodwinking:  Giving exotic names to otherwise mundane food products.''',
r'''Foolproof operation:  No provision for adjustment.''',
r'''Fools rush in -- and get the best seats in the house.''',
r'''Football, like religion, brings out the best in people.  -- Larry Chapman''',
r'''For a good time, call 555-3100.''',
r'''For adult education, nothing beats children.''',
r'''For asphyxiation:  Apply artificial respiration until the patient is dead.''',
r'''For back-country preparedness, "what if" weighs about 20 pounds.''',
r'''For every action, there is a corresponding over-reaction.  -- Anthony Battista''',
r'''For every action, there is an equal and opposite criticism.  -- Harrison''',
r'''For every action, there is an equal and opposite government program.  -- Main''',
r'''For every expert, there is an equal and opposite expert.''',
r'''For every knee, there is a jerk.''',
r'''For NASA, space is still a high priority.  -- Dan Quayle''',
r'''For nosebleed:  Put the nose much lower than the body.''',
r'''For people who like peace and quiet:  A phoneless cord.''',
r'''For people who like that kind of book, that is the kind of book they will like.''',
r'''For sale:  Secondhand tombstone.  Good buy for a person named Murphy.''',
r'''For some reason, this statement reminds everyone of Marvin Zelkowitz.''',
r'''For things to stay the same, many things must change.''',
r'''For this, I spent all those years in college?''',
r'''For those who like this sort of thing, this is the sort of thing they like.''',
r'''Foreploy:  Any misrepresentation about yourself that leads to sex.''',
r'''Form follows function, and often obliterates it.''',
r'''Fortune favors the lucky.  -- Tom Weller''',
r'''Fossil flowers come from the Petrified Florist.''',
r'''Four kinds of homicide:  Felonious, excusable, justifiable, and praiseworthy...''',
r'''Four wheel drive:  Lets you get more stuck, further from help.''',
r'''Free love is priced right.  -- Edward Abbey''',
r'''Freedom is just chaos, with better lighting.  -- Alan Foster''',
r'''Frequent naps prevent old age, especially if taken while driving.''',
r'''Friction is a drag.''',
r'''Friend:  One who knows all about you and loves you just the same.  -- Hubbard''',
r'''Friends don't let friends beer goggle.''',
r'''Friends help you move.  Real friends help you move bodies.''',
r'''Friends:  People who borrow my books and set wet glasses on them.  -- Robinson''',
r'''Friends:  People who know you well, but like you anyway.''',
r'''Frisbeetarianism:  Belief that when dead, your soul gets stuck up on the roof.''',
r'''Front seat children cause accidents; back seat accidents cause children.''',
r'''Funny, I don't remember being absent-minded...''',
r'''Furbling:  Walking a maze of ropes even when you are the only person in line.''',
r'''Gambling:  The sure way of getting nothing for something.  -- Wilson Mizner''',
r'''Garmites:  Clothing that fits well in the store but shrinks on the way home.''',
r'''Gee, I thought we'd be a lot higher at MECO!  -- Hawley, STS 41-D pad abort, 1984''',
r'''Genderplex:  Trying to determine from the cutesy pictures which restroom to use.''',
r'''Generally you don't see that kind of behavior in a major appliance.  -- Murray''',
r'''Generica:  Mass-produced identical stores, etc. throughout America.''',
r'''Genetics:  Why you look like your father, or if you don't, why you should.''',
r'''Genius is the infinite capacity for picking brains.''',
r'''Genius:  A chemist who discovers a laundry additive that rhymes with "bright".''',
r'''Gentleman farmer:  One who has more hay in the bank than in the barn.''',
r'''Gentleman:  Knows how to play the bagpipes, but doesn't.''',
r'''Geometry teaches us to bisex angles.''',
r'''Get out of an experience only the wisdom that is in it -- and stop there.''',
r'''Get your facts first, then you can distort them as much as you please.  -- Twain''',
r'''Getting from A to B often requires visiting C through Z.  -- Alan Silverstein''',
r'''Getting old is NOT for sissies.  -- Andy Hill''',
r'''Giraffes have no vocal cords.''',
r'''Giraffiti:  Vandalism spray-painted very, very high.''',
r'''Girls, like flowers, bloom but once.  But once is enough.  -- Edward Abbey''',
r'''Give a man a free hand and he'll run it all over you.  -- Mae West''',
r'''Give a man enough rope and he will lasso another woman.''',
r'''Give a skeptic an inch and he'll measure it.''',
r'''Give me a lever long enough, and a place to stand, and I'll break my lever.''',
r'''Give me a place to sit, and I'll watch.''',
r'''Give me a sleeping pill and tell me your troubles.''',
r'''Give me ambiguity or give me something else.''',
r'''Give me chastity and continence, but not just now.  -- St. Augustine''',
r'''Give your child mental blocks for Christmas.''',
r'''Give your very best today.  Heaven knows it is little enough.''',
r'''Giving away baby clothes and furniture is the major cause of pregnancy.''',
r'''Gleemites:  Petrified deposits of toothpaste found in sinks.''',
r'''Glibido:  All talk and no action.''',
r'''Go away.  I'm all right.  -- last words of H. G. Wells''',
r'''Go directly to jail.  Do not pass Go, do not collect $200.''',
r'''Go soothingly in the grease mud, as there lurks the skid demon.''',
r'''Go to Heaven for the climate but Hell for the company.  -- Mark Twain''',
r'''God could create everything in six days because he had no installed base.''',
r'''God could not be everywhere; therefore he made mothers.''',
r'''God created the Midwest to keep California 3000 miles away.''',
r'''God divided things evenly:  He gave food to the rich and appetite to the poor.''',
r'''God don't make mistakes.  That's how He got to be God.  -- Archie Bunker''',
r'''God gave us two ears and one mouth.  That ought to tell us something.''',
r'''God gives us relatives; thank God we can choose our friends.  -- Addison Mizner''',
r'''God has no real style, he just goes on trying other things.  -- Pablo Picasso''',
r'''God help the poor, for the rich can help themselves.''',
r'''God help us, we're in the hands of engineers.  -- Ian Malcom, "Jurassic Park"''',
r'''God invented marijuana.  Man invented beer.  Who do you trust?''',
r'''God is a low-impact camper.''',
r'''God is a polytheist.''',
r'''God is an extremely uneven writer, but when he's good, nobody can touch him.''',
r'''God is dead. (Nietzsche)  Nietzsche is dead. (God)  Nietzsche is God. (the Dead)''',
r'''God is my co-pilot, but the devil is my bombardier.''',
r'''God is not dead.  He is alive and autographing Bibles at Cody's!''',
r'''God is not dead.  He is alive and working on a much less ambitious project.''',
r'''God is not dead.  He just couldn't find a parking place.''',
r'''God is religion.  Love is biology.  And sex is physics.''',
r'''God made everything out of nothing, but the nothingness shows through.''',
r'''God made the idiot for practice, and then he made the School Board.  -- Twain''',
r'''God made the world in six days, and was arrested on the seventh.''',
r'''God must love the common man -- he made so many of them.''',
r'''God was my co-pilot, but we crashed in the mountains and I had to eat him.''',
r'''God, I ask for patience -- and I want it right now!''',
r'''Going the speed of light is bad for your age.''',
r'''Gold:  A metal men dig out of holes for dentists and governments to put back in.''',
r'''Golf is like masturbation -- fun to do, but disgusting to watch.''',
r'''GOLF:  Game Of Limitless Frustration.  -- Bobbie Piety''',
r'''Good advertising can make people buy your product even if it sucks.  -- Adams''',
r'''Good advice is something a man gives when he is too old to set a bad example.''',
r'''Good day for a change of scene.  Repaper the bedroom wall.''',
r'''Good news is just life's way of keeping you off balance.''',
r'''Good news.  Ten weeks from Friday will be a good day.''',
r'''Good sopranos and tenors have resonance -- where others have brains.''',
r'''Good-bye.  I am leaving because I am bored.  -- last words of George Saunders''',
r'''Got mole problems?  Call Avogadro:  6.02 x 10^23.''',
r'''Government expands to absorb all available revenue and then some.  -- Wiker''',
r'''Governmental machinery:  Labor-saving device, lets ten men do the work of one.''',
r'''Grad school is the snooze button on the alarm clock of life.  -- Jim Squire''',
r'''Graduate life:  It's not just a job, it's an indenture.''',
r'''Graft:  An illegal means of uniting trees to make money.''',
r'''Grasshoppotamus:  A creature that can leap to tremendous heights...  Once.''',
r'''Gravity:  What you get when you eat too much and too fast.''',
r'''Great leaders are rare, so I'm following myself.''',
r'''Great minds run in great circles.''',
r'''Grocery store wanted ad:  Perishable Employee Needed.  Experience Required.''',
r'''Group IQ:  Lowest IQ of any member divided by the number of people in the group.''',
r'''Growing old is inevitable, but growing up is optional.''',
r'''Grub first, then ethics.  -- Bertolt Brecht''',
r'''Guests who kill talk show hosts -- On the last Geraldo.''',
r'''Gymnastics exercises our outsides while genetics exercises our insides.''',
r'''Had there been an actual emergency, you would no longer be here.''',
r'''Hailing frequencies open, Captain.''',
r'''Half of the people you know are below average.''',
r'''Half of what we taught you is wrong -- and we don't know which half.  -- Neifert''',
r'''Handel was half German, half Italian, and half English.  He was rather large.''',
r'''Hangover:  The wrath of grapes.''',
r'''Happiness is a ball in the fairway.''',
r'''Happiness is an inside job.  -- Carolyn Myss''',
r'''Happiness is having a scratch for every itch.  -- Ogden Nash''',
r'''Happiness is your mother-in-law's picture on the back of a milk carton.''',
r'''Hard work has a future payoff.  Laziness pays off now.''',
r'''Hard work might be respectable, but that doesn't make it popular.''',
r'''Hard work never killed anybody, but why take a chance?''',
r'''Harlez-vous francais?  (Can you drive a French motorcycle?)''',
r'''Have a good laughsitive twice a day, and that will ensure regularhilarity.''',
r'''Have an adequate day.''',
r'''Have an ordinary day.''',
r'''Have you flogged your crew today?''',
r'''Have you noticed that most one-liners do not fit on one line?  -- Sundqvist''',
r'''Haven't you got anyone better to do?''',
r'''Having children is like having a bowling alley installed in your brain.''',
r'''Having children will turn you into your parents.''',
r'''He got in touch with reality, but it was a bad connection.  -- Bob Thaves''',
r'''He had delusions of adequacy.  -- Walter Kerr''',
r'''He had insomnia so bad that he couldn't sleep when he was working.  -- Baer''',
r'''He hadn't a single redeeming vice.  -- Oscar Wilde''',
r'''He has no enemies, but is intensely disliked by his friends.  -- Oscar Wilde''',
r'''He has the heart of a little child...  It's in a jar on his desk.''',
r'''He is a player who can be relied upon to snatch defeat from the jaws of victory.''',
r'''He is considered a most graceful speaker who can say nothing in the most words.''',
r'''He is no lawyer who cannot take two sides.''',
r'''He is not only dull himself, he is the cause of dullness in others.  -- Johnson''',
r'''He is so short he has to reach up to tie his shoes.''',
r'''He is so skinny he has to run around in the shower to get wet.''',
r'''He is such a steady worker that he is really motionless.''',
r'''He is the kind of man a woman would have to marry to get rid of.  -- Mae West''',
r'''He knew the precise psychological moment when to say nothing.  -- Oscar Wilde''',
r'''He leads his readers to the latrine and locks them in.  -- Oscar Wilde''',
r'''He looked at me as if I was a side dish he hadn't ordered.''',
r'''He loves nature in spite of what it did to him.  -- Forrest Tucker''',
r'''He often broke into song because he couldn't find the key.''',
r'''He speaks Esperanto like a native.  -- Martha Freedman''',
r'''He that loves law will get his fill of it.''',
r'''He was a suitor for her hand, but he did not suit her.''',
r'''He was so narrow-minded he could see through a keyhole with both eyes.''',
r'''He who believes the past cannot be changed has not yet written his memoirs.''',
r'''He who dies with the most toys has spent the most time on maintenance.  -- Dix''',
r'''He who dies with the most toys is nonetheless dead.''',
r'''He who dies with the most toys, wins.''',
r'''He who enters the contest is optimistic as submarine with screen doors.''',
r'''He who has a shady past knows that nice guys finish last.''',
r'''He who has had has been but he who has not been has been had.''',
r'''He who hesitates is a damned fool.  -- Mae West''',
r'''He who hesitates is last.  -- Mae West''',
r'''He who hesitates is not only lost, but several miles from the next freeway exit.''',
r'''He who hesitates is probably right.''',
r'''He who hoots with owls by night cannot soar with eagles by day.''',
r'''He who invents adages to peruse takes along rowboat when going on cruise.''',
r'''He who is born to misfortune falls on his back and fractures his nose.''',
r'''He who is content with his lot probably has a lot.''',
r'''He who is still laughing hasn't yet heard the bad news.  -- Bertolt Brecht''',
r'''He who knows all the answers never gets asked the questions.''',
r'''He who laughs last didn't get the joke.''',
r'''He who laughs last is probably your boss.''',
r'''He who laughs last thinks slowest.''',
r'''He who reads many fortunes gets confused.''',
r'''He who shouts the loudest has the floor.  -- Swipple''',
r'''He who speak with forked tongue, not need chopsticks.  -- Chinese proverb''',
r'''He who spends a storm beneath a tree, takes life with a grain of TNT.''',
r'''Headline:  20-Year Friendship Ends at Altar''',
r'''Headline:  Antique Stripper to Display Wares at Store''',
r'''Headline:  Autos Killing 110 a Day -- Let's Resolve to Do Better''',
r'''Headline:  Blind Bishop Appointed to See''',
r'''Headline:  Blind Woman Gets New Kidney from Dad She Hasn't Seen in Years''',
r'''Headline:  Cold Wave Linked to Temperatures''',
r'''Headline:  Croupiers on Strike -- Management:  "No Big Deal"''',
r'''Headline:  Diaper Market Bottoms Out''',
r'''Headline:  Fund Set Up for Beating Victim's Kin''',
r'''Headline:  Half of U.S. High Schools Require Some Study for Graduation''',
r'''Headline:  Henshaw Offers Rare Opportunity to Goose Hunters''',
r'''Headline:  If Strike Isn't Settled Quickly, It May Last a While''',
r'''Headline:  Juvenile Court to Try Shooting Defendant''',
r'''Headline:  Killer Sentenced to Die for Second Time in 10 Years''',
r'''Headline:  L.A. Voters Approve Urban Renewal by Landslide''',
r'''Headline:  Lawyers Give Poor Free Legal Advice''',
r'''Headline:  Lingerie Shipment Hijacked -- Thief Gives Police the Slip''',
r'''Headline:  March Planned for Next August''',
r'''Headline:  Nicaragua Sets Goal to Wipe Out Literacy''',
r'''Headline:  Patient at Death's Door -- Doctors Pull Him Through''',
r'''Headline:  Prostitutes Appeal to Pope''',
r'''Headline:  Queen Mary Having Bottom Scraped''',
r'''Headline:  Stadium Air Conditioning Fails -- Fans Protest''',
r'''Headline:  Teacher Strikes Idle Kids''',
r'''Headline:  War Dims Hope For Peace''',
r'''Headline:  Women's Movement Called More Broad-Based''',
r'''Heads they win, tails you lose.''',
r'''Health is just keeping well; hygiene is being clean about it.''',
r'''Health is merely the slowest possible rate at which one can die.''',
r'''Hearsay:  What toddlers do when anyone mutters a dirty word.''',
r'''Heat expands:  In the summer the days are longer.''',
r'''Heating with wood, you get warm twice:  Once chopping it, and once stacking it.''',
r'''Heavy:  Seduced by the chocolate side of the force.''',
r'''HECK is where people go when they don't believe in GOSH!''',
r'''Heineken Uncertainty Principle:  Never sure how many beers you had last night.''',
r'''Heinz Catsup leaving the bottle travels at 25 miles per year.''',
r'''Heisenberg might have been here.''',
r'''Hell hath no fury like a bureaucrat scorned.  -- Milton Friedman''',
r'''Help fight continental drift.''',
r'''Help stamp out and abolish redundancy.''',
r'''Help Wanted:  Telepath.  You know where to apply.''',
r'''HELP!  MY TYPEWRITER IS BROKEN!  -- E. E. CUMMINGS''',
r'''Her kisses left something to be desired -- the rest of her.''',
r'''Here are the opinions on which my facts are based.''',
r'''Here I am!  Now what are your other two wishes?''',
r'''Here is champagne to our real friends, and real pain to our sham friends.''',
r'''Hi, my name's Ron, how do you like me so far?''',
r'''Highbrow:  A man who has discovered something more interesting than women.''',
r'''Hippoposthumous:  A deceased hippopotamus.  -- Bob Thaves''',
r'''Hire the morally handicapped.''',
r'''His mind is like a steel trap:  Full of mice.  -- Foghorn Leghorn''',
r'''His work is very poor, but at least it's slow.''',
r'''History chronicles the small portion of the past that was suitable for print.''',
r'''History does not repeat itself; historians merely repeat each other.''',
r'''History repeats itself.  That's one thing wrong with history.''',
r'''Hit and run means never having to say you're sorry.''',
r'''Hollywood is where if you don't have happiness you send out for it.  -- Rex Reed''',
r'''Home is the place where, when you have to go there, they have to take you in.''',
r'''Home is where the house is.''',
r'''Honest men marry soon, wise men not at all.  -- Howell''',
r'''Honesty is the best policy -- there is less competition.''',
r'''Honesty is the best policy, but insanity is a better defense.''',
r'''Honesty pays, but it doesn't seem to pay enough to suit some people.  -- Hubbard''',
r'''Honeymoon:  A short period of doting between dating and debting.  -- Ray Bandy''',
r'''Honeymoon:  A thrill of a wife time.''',
r'''Honeymoon:  The vacation a man takes before beginning work under a new boss.''',
r'''Honk if you base your life on advice from bumper stickers.  -- Bob Thaves''',
r'''Honk if you love peace and quiet.''',
r'''Hors d'oeuvres:  A ham sandwich cut into forty pieces.''',
r'''Horse sense:  The thing a horse has that keeps it from betting on people.''',
r'''Horsepower: How fast you hit the wall.  Torque: How far the wall comes with you.''',
r'''Hospitality:  Making your guests feel at home, even though you wish they were.''',
r'''Hotdogs are best served with a ballgame.''',
r'''Housework won't kill you.  But then again, why take the chance?  -- Phyllis Diller''',
r'''How about never?  Is never good for you?''',
r'''How can I miss you if you won't go away?''',
r'''How can someone "draw a blank"?''',
r'''How can there be self-help groups?''',
r'''How can you govern a nation which has 246 kinds of cheese?  -- Charles de Gaulle''',
r'''How come wrong numbers are never busy?''',
r'''How did a fool and his money get together in the first place?''',
r'''How do they get all those little metal bits on a zipper to line up so well?''',
r'''How do they get deer to cross at the yellow road signs?''',
r'''How do you explain school to a higher intelligence?  -- Elliot''',
r'''How do you keep a dummy in suspense?''',
r'''How do you make an elephant float?  Two scoops of elephant and some rootbeer...''',
r'''How long is a minute depends on which side of the bathroom door you are on.''',
r'''How long should a man's legs be?  Long enough to reach the ground.  -- Lincoln''',
r'''How many lawyers does it take to screw in a light bulb?  All you can afford.''',
r'''How many light bulb jokes does it take to change the subject?''',
r'''How many weeks are there in a light year?''',
r'''How much sin can you get away with and still go to heaven?''',
r'''How much wood would a woodchuck chuck, if a woodchuck could chuck wood?''',
r'''How sharper than a hound's tooth it is to have a thankless serpent.''',
r'''How to paint a perfect painting:  Make yourself perfect, then paint naturally.''',
r'''How to regain your virginity:  Reverse the process until it returns.''',
r'''How wonderful opera would be if there were no singers.''',
r'''Human beings were created by water to transport it uphill.''',
r'''Human nature will eventually reach perfection; we should enjoy ourselves now.''',
r'''Humidity is the experience of looking for air and finding water.''',
r'''Hummingbirds never remember the words to songs.''',
r'''Humor is the best antidote to reality.''',
r'''Humorists:  Those who can talk sensibly about a controversy.''',
r'''Husbands are like fires; they go out when they're unattended.  -- Zsa Zsa Gabor''',
r'''I almost had a psychic girlfriend, but she left me before we met.''',
r'''I am a creationist; I refuse to believe that I could have evolved from humans.''',
r'''I am a great housekeeper.  I get divorced.  I keep the house.  -- Zsa Zsa Gabor''',
r'''I am a Hollywood writer, so I put on a sports jacket and take off my brain.''',
r'''I am a Libra.  Libras don't believe in astrology.  -- Al Hibbs''',
r'''I am a nutritional overachiever.''',
r'''I am a vegetarian because I hate plants.  -- A. Whitney Brown''',
r'''I am ashamed to be here, but not ashamed enough to leave.''',
r'''I am at one with my duality.''',
r'''I am defending her honor, which is more than she ever did.''',
r'''I am dying beyond my means.  -- last words of Oscar Wilde, sipping champagne''',
r'''I am dying with the help of too many physicians.  -- Alexander the Great''',
r'''I am going to live forever, or die trying!  -- Spider Robinson''',
r'''I am having an out of money experience.''',
r'''I am Homer from BORG, prepare to be assim...  Oooh, donuts!''',
r'''I am in shape...  Round is a shape!''',
r'''I am looking for myself.  Have you seen me lately?''',
r'''I am neither for nor against apathy.''',
r'''I am not a complete idiot, some parts are missing!''',
r'''I am not a crook.  -- Richard Nixon''',
r'''I am not a lovable man.  -- Richard Nixon''',
r'''I am not a perfectionist, but my parents were.''',
r'''I am not an Economist.  I am an honest man!  -- Paul McCracken''',
r'''I am not as dumb as you look.''',
r'''I am not cynical, just experienced.''',
r'''I am not deaf, I'm ignoring you.''',
r'''I am not eating, so I must be asleep.  -- John Taylor''',
r'''I am not living in the past -- I'm just paying for it.''',
r'''I am not part of the problem.  I am a Republican.  -- Dan Quayle''',
r'''I am not playing hard to get; I AM hard to get.''',
r'''I am not prejudiced, I hate everyone equally.''',
r'''I am not sure what this is, but an "F" would only dignify it.  -- English prof''',
r'''I am not young enough to know everything.  -- J. M. Barrie''',
r'''I am out of bed and dressed.  What more do you want?''',
r'''I am prepared for all emergencies but totally unprepared for everyday life.''',
r'''I am really enjoying not talking to you, so let's not talk again real soon, OK?''',
r'''I am sorry, but I'm not going to apologize.''',
r'''I am the mommy, that's why!''',
r'''I am the mother of all things, and all things should wear a sweater.''',
r'''I am the person your mother warned you about.''',
r'''I am woman, I am invincible, I am tired...''',
r'''I awoke one morning and found myself famous.  -- Byron''',
r'''I base most of my fashion taste on what doesn't itch.  -- Gilda Radner''',
r'''I believe I am God, but can't prove my own existence.''',
r'''I belong to no organized party.  I am a Democrat.  -- Will Rogers''',
r'''I bet you have never seen a plumber bite his nails.''',
r'''I bid you all a very heartfelt goodnight.  -- Johnny Carson, last Tonight show''',
r'''I blame sex and paper for most of our current problems.  -- Scott Adams''',
r'''I bother to show up for work because beer isn't free.''',
r'''I bought my boyfriend a waterbed, but we drifted apart.''',
r'''I bought some powdered water...  But I didn't know what to add.  -- Steven Wright''',
r'''I brake for brick walls.''',
r'''I came to MIT to get an education for myself and a diploma for my mother.''',
r'''I came, I saw, I had no idea what was going on, so I left.  -- Dick Ross''',
r'''I can only please one person each day.  Today's not your day.  Maybe tomorrow.''',
r'''I can relate to that.''',
r'''I can resist everything except temptation.  -- Oscar Wilde''',
r'''I can see clearly now, the brain is gone...''',
r'''I can't believe you are the result of millions of years of evolution.  -- Cate''',
r'''I can't give you brains, but I can give you a diploma.  -- the Wizard of Oz''',
r'''I can't help hearing, but I don't always listen.  -- George Burns, "Oh God"''',
r'''I can't remember if I'm the good twin or the evil one.''',
r'''I carry a gun because a cop is too heavy.  -- John Steinbeck''',
r'''I couldn't have said that longer myself.  -- John Taylor''',
r'''I decided success would be making just one person happy.  I picked me.  -- Thaves''',
r'''I did not believe in reincarnation the last time either.''',
r'''I did not fight my way to the top of the food chain to be a vegetarian.''',
r'''I didn't attend the funeral, but I sent a nice letter saying I approved of it.''',
r'''I do desire we may be better strangers.  -- William Shakespeare''',
r'''I do most of my work sitting down; that is where I shine.  -- Robert Blenchey''',
r'''I do not believe in afterlife, but I am bringing a change of underwear.  -- Allen''',
r'''I don't ask questions, I just have fun!  -- Bugs Bunny''',
r'''I don't care who does the electing as long as I get to do the nominating.''',
r'''I don't date outside my species.''',
r'''I don't have a license to kill...  I have a learner's permit.''',
r'''I don't have a problem with San Francisco parking.  I drive a forklift.''',
r'''I don't have an attitude problem.  You have a perception problem.''',
r'''I don't have any solution, but I certainly admire the problem.  -- Ashleigh Brilliant''',
r'''I don't know what your problem is, but I'll bet it's hard to pronounce.''',
r'''I don't know where I am, but I'm not too far back.  -- Alan Silverstein''',
r'''I don't know whether to kill myself or go bowling.''',
r'''I don't like money actually, but it quiets my nerves.  -- Joe Louis''',
r'''I don't love my mother, I just hate her less than everyone else.''',
r'''I don't make jokes.  I just watch the government and report the facts.  -- Rogers''',
r'''I don't suffer from stress.  I'm a carrier.''',
r'''I don't worry about terrorism.  I was married for two years.  -- Sam Kinison''',
r'''I doubt, therefore I might be.''',
r'''I drank what?  -- Socrates''',
r'''I drink to make other people interesting.  -- George Nathan''',
r'''I drive way too fast to worry about cholesterol.''',
r'''I embrace poverty.  To annoy me, send money.''',
r'''I feel like a million tonight, but one at a time.  -- Mae West''',
r'''I feel more like I do now than I did a little while ago.''',
r'''I finally got my head together, but now my body is falling apart.''',
r'''I get enough exercise just pushing my luck!''',
r'''I go on working for the same reason that a hen goes on laying eggs.  -- Mencken''',
r'''I graduated first in my class from alibi school.  -- Jeffrey McDaniel''',
r'''I had plastic surgery last week.  I cut up my credit cards.  -- Henny Youngman''',
r'''I hate quotations.  -- Ralph Waldo Emerson''',
r'''I hate the outdoors.  To me the outdoors is where the car is.  -- Will Durst''',
r'''I have already told you more than I know.''',
r'''I have always been crazy, but it's kept me from going insane.''',
r'''I have been in more laps than a napkin.  -- Mae West''',
r'''I have been on a diet for two weeks, and all I've lost is 14 days.''',
r'''I have enough money to last me the rest of my life unless I buy something.''',
r'''I have found that children remember only what they want to.  -- Bill Cosby''',
r'''I have found that the best direction for a hot tub to face is up.  -- Dave Barry''',
r'''I have given up reading books; it takes my mind off myself.''',
r'''I have had a perfectly wonderful evening.  But this wasn't it.  -- Groucho Marx''',
r'''I have heard about people like me, but I never made the connection.  -- McLean''',
r'''I have known a great many troubles, most of which never happened.  -- Mark Twain''',
r'''I have no problems with God; it's his fan club that bothers me!''',
r'''I have not seen as far as others because giants were standing on my shoulders.''',
r'''I have seen that pattern on wallpaper before, but never on clothing.''',
r'''I have seen the evidence...  I want DIFFERENT evidence.''',
r'''I have seen the future and it is just like the present, only longer.  -- Albran''',
r'''I have seen the truth and it makes no sense.''',
r'''I have the simplest tastes.  I am always satisfied with the best.  -- Oscar Wilde''',
r'''I have ways of making money that you know nothing of.  -- John D. Rockefeller''',
r'''I haven't lost my mind; I know exactly where I left it.''',
r'''I haven't spoken to my wife for 18 months.  I don't like to interrupt her.''',
r'''I hope my record gets out before the world blows up.  -- Madonna''',
r'''I hope you receive all the letters I mean to write.''',
r'''I just need enough to tide me over until I need more.  -- Bill Hoest''',
r'''I just want revenge.  Is that so wrong?''',
r'''I keep on making the same misttakes.  -- Christer Sundqvist''',
r'''I know I am efficient.  Tell me I am beautiful.''',
r'''I know on which side my bread is buttered.  -- John Heywood''',
r'''I like a woman with a head on her shoulders.  I hate necks.  -- Steve Martin''',
r'''I like cats, too.  Let's exchange recipes.''',
r'''I like it better in the dark.''',
r'''I like looking at geniuses, and listening to beautiful people.  -- Oscar Wilde''',
r'''I like men who have a future and women who have a past.  -- Oscar Wilde''',
r'''I like the outsides of some things and the insides of others.  -- Madonna''',
r'''I like work; it fascinates me.  I can sit and look at it for hours.  -- Jerome''',
r'''I like you.  You remind me of when I was young and stupid.''',
r'''I live in my own little world, but that's OK, they know me here.''',
r'''I love California, I practically grew up in Phoenix.  -- Dan Quayle''',
r'''I love children, especially when they cry, for then someone takes them away.''',
r'''I love defenseless animals, especially in a good gravy.''',
r'''I love it when it stays light out until it gets dark.''',
r'''I love mankind...  It's people I hate.  -- Schulz''',
r'''I love my job; it's the work I can't stand.''',
r'''I married Miss Right.  I just didn't know her middle name was Always.''',
r'''I may not always be right, but I'm never wrong.  -- Isaac Asimov''',
r'''I may not be the world's greatest lover, but number seven's not bad.  -- Allen''',
r'''I may not be totally perfect, but parts of me are excellent.  -- Ashleigh Brilliant''',
r'''I might be crazy, but I am not stupid.''',
r'''I might not always be perfect, but I am always me.''',
r'''I might not know what I am doing, but I know how to do it.''',
r'''I must follow the people.  Am I not their leader?  -- Benjamin Disraeli''',
r'''I must get out of these wet clothes and into a dry Martini.  -- Woolcott''',
r'''I need a list of specific unknown problems we will encounter.  -- Dan Rome''',
r'''I never forget a face, but in your case I'll make an exception.  -- Marx''',
r'''I never heard a minute's silence like that.  -- Glenn Hoddle''',
r'''I never knew what happiness was until I got married...  Then it was too late!''',
r'''I never made a mistake in my life.  I thought I did once, but I was wrong.''',
r'''I often quote myself; it adds spice to my conversation.  -- George Shaw''',
r'''I once put instant coffee in a microwave and almost went back in time.  -- Wright''',
r'''I only like two kinds of men:  Foreign and domestic.  -- Mae West''',
r'''I own and operate a ferocious ego.  -- Bill Moyers''',
r'''I plan on living forever.  So far, so good.''',
r'''I plead contemporary insanity.''',
r'''I prefer beauty to brains because I can see better than I can think.''',
r'''I promise we would only loose ten to twenty million TOPS!  -- Dr. Strangelove''',
r'''I really had to act; 'cause I didn't have any lines.  -- Marilyn Chambers''',
r'''I refuse to star in your psychodrama.''',
r'''I reserve the right to die or resign without notice.  -- Justice Harlan''',
r'''I saw a subliminal advertising executive, but only for a second.  -- Steven Wright''',
r'''I see time away from the refrigerator as exercise.  -- Ellen Langer''',
r'''I shot an arrow into the air and it stuck.  -- graffiti in Los Angeles''',
r'''I should've bought a CATCHING license instead of a FISHING license!  -- Saiff''',
r'''I sort of always get low-grade mystical experiences.  -- Carolyn Myss''',
r'''I spilled spot remover on my dog.  Now he's gone.  -- Steve Wright''',
r'''I stand by all the misstatements that I've made.  -- Dan Quayle''',
r'''I stared Mother Nature in the face, and she smiled back.  -- Doug Baskins''',
r'''I started out with nothing, and I still have most of it left.  -- R.E. Atkinson''',
r'''I suggest a new strategy, Artoo:  Let the Wookee win.  -- CP30''',
r'''I think I am a sexual threat.  -- Madonna''',
r'''I think it's wrong that only one company makes the game Monopoly.  -- Steven Wright''',
r'''I think sex is better than logic, but I can't prove it.''',
r'''I think that I shall never see a billboard lovely as a tree.  -- Ogden Nash''',
r'''I think we are all Bozos on this bus.''',
r'''I think, therefore I am paid.''',
r'''I think, therefore I am!  I think?  -- William Etkin''',
r'''I think, therefore I am...  Usually in a lot of trouble.''',
r'''I think, therefore I'm single.  -- Lizz Winstead''',
r'''I thought I wanted a career, turns out I just wanted paychecks.''',
r'''I thought YOU were supposed to feed the dinosaurs!  -- Bob Thaves''',
r'''I took an IQ test and the results were negative.''',
r'''I typo ther fr I m.''',
r'''I used to be a nun, but I kicked the habit.''',
r'''I used to be agnostic, but now I'm not so sure.  -- John Kock''',
r'''I used to be an adult before I grew up.''',
r'''I used to be an idealist, but I got mugged by reality.''',
r'''I used to be indecisive, but now I'm not so sure.  -- Boscoe Pertwee''',
r'''I used to be lost in the shuffle.  Now I just shuffle along with the lost.''',
r'''I used to be Snow White, but I drifted.  -- Mae West''',
r'''I used to get high on life, but lately I have built up a resistance.''',
r'''I used to have a handle on life, then it broke.''',
r'''I used to know that stuff.''',
r'''I used up all my sick days, so I'm calling in dead.''',
r'''I want buns of steel so I can hold up my pants with refrigerator magnets.''',
r'''I want it all and I want it now.''',
r'''I want to achieve immortality through not dying.  -- Woody Allen''',
r'''I want to make sure everybody who has a job wants a job.  -- George Bush''',
r'''I was an expert parent.  Then I had children.''',
r'''I was dangerously boring.  -- Scott Adams''',
r'''I was gratified to be able to answer promptly and I did.  I said I didn't know.''',
r'''I was having a great day until I woke up.  -- Richard Lewis''',
r'''I went looking for trouble, and I found it.  -- Charles Ponzi''',
r'''I went on two diets at once because one diet wasn't giving me enough food.''',
r'''I will always love the false image I had of you.  -- Ashleigh Brilliant''',
r'''I will meet you at the corner of Walk and Don't Walk.''',
r'''I will never lie to you.''',
r'''I wish you happy New Year...  But only one.  -- Frederick Lonsdale''',
r'''I worked in a pet shop and people kept asking how big I'd get.  -- Dangerfield''',
r'''I worked myself up from nothing to a state of extreme poverty.  -- Groucho Marx''',
r'''I would explain it to you but your brain would explode.''',
r'''I would give my right arm to be ambidextrous.''',
r'''I would have made a good pope.  -- Richard Nixon''',
r'''I would know what to think if I knew who to believe.''',
r'''I would like to help you out.  Which way did you come in?''',
r'''I would like to lick apricot brandy out of your navel.  -- Cerebus''',
r'''I would never join any club that would have the likes of me as a member.  -- Marx''',
r'''I would rather be an extemporaneous fool than a premeditated ass.''',
r'''I would rather fish than eat, particularly eat fish.  -- Corey Ford''',
r'''I wouldn't be caught dead with a necrophiliac.''',
r'''I wouldn't mind being poor if I had lots of money.''',
r'''I wrote a friend a check for a negative amount, but he wouldn't cash it.''',
r'''I wrote a song but I can't read music so I don't know what it is.  -- Wright''',
r'''I'd kill for a Nobel Peace Prize.''',
r'''I'd like to meet the person who invented sex, and see what he's working on now.''',
r'''I'd rather have a free bottle in front of me than a prefrontal lobotomy.''',
r'''I'd rather walk through a fire than walk away from one.  -- Madonna''',
r'''I'll give you a definite maybe.  -- Samuel Goldwyn''',
r'''I'll play it first and tell you what it is later.  -- Miles Davis''',
r'''I'll race you to China.  You can have a head start.  Ready, set, GO!''',
r'''I'll tell you the meaning of life if you promise not to laugh.  -- Bob Thaves''',
r'''I'll try being nicer if you'll try being smarter.''',
r'''I'm a psychic amnesiac:  I know in advance what I'll forget.  -- Michael McShane''',
r'''I'm going to commit suicide, or die trying.  -- Michael Burgess''',
r'''I'm in Pittsburgh.  Why am I here?  -- Harold Urey''',
r'''I'm just working here till a good fast-food job opens up.''',
r'''I'm lost and out looking for myself.  If I show up before I return, I'll wait.''',
r'''I'm mad as hell, and I'm not going to take it any more!''',
r'''I'm not 27, I'm 12, with 15 years of experience.''',
r'''I'm not a recovering chocoholic...  Why would I want to be?''',
r'''I'm not afraid of heights, I'm afraid of falling.  -- Darren Smith''',
r'''I'm not afraid to die.  I just don't want to be there when it happens.  -- Allen''',
r'''I'm not cheap, but I am on special this week.''',
r'''I'm not crazy, I've just been in a very bad mood for 30 years.''',
r'''I'm not going deaf.  I'm ignoring you.''',
r'''I'm not into working out.  My philosophy is:  No pain, no pain.''',
r'''I'm not tense, just terribly, terribly alert.''',
r'''I'm not under the alkafluence of inkahol that some thinkle peep I am.''',
r'''I'm pretty good with BS but I love listening to an expert.  Keep talking.''',
r'''I'm really easy to get along with once you people learn to worship me.''',
r'''I'm smarter than the average bear!  -- Yogi Bear''',
r'''I'm still an atheist, thank God.  -- Luis Bunuel''',
r'''I'm thirty years old, but I read at the thirty-four-year-old level.  -- Carvey''',
r'''I've been on a calendar, but I've never been on time.  -- Marilyn Monroe''',
r'''I've been rich and I've been poor.  Believe me, rich is better.  -- Mae West''',
r'''I've been things and done places.  -- Mae West''',
r'''I've heard that money can't buy happiness, but I'd like to find out for myself.''',
r'''I've just learned about his illness.  Let's hope it's nothing trivial.  -- Cobb''',
r'''I've only got one other speed, and it's slower.  -- Glenn Ford''',
r'''I've sometimes thought of marrying, and then I've thought again.  -- Noel Coward''',
r'''Ice cream cures all ills.  Temporarily.  -- Seleznick''',
r'''Idiot box:  Part of an envelope that tells a person where to place the stamp.''',
r'''Idiots drag you down to their level, then beat you with experience.''',
r'''If "I am" is the shortest sentence in English, "I do" is the longest.''',
r'''If A = B and B = C, then A = C, except where void or prohibited by law.''',
r'''If a book about failures doesn't sell, is it a success?''',
r'''If a funeral procession is at night, do people drive with their lights off?''',
r'''If a man keeps his trap shut, the world will beat a path to his door.  -- Adams''',
r'''If a parsley farmer is sued, can they garnish his wages?''',
r'''If a pig loses its voice, is it disgruntled?''',
r'''If a stealth bomber crashes in a forest, will it make a sound?''',
r'''If a straight line fit is required, obtain only two data points.''',
r'''If a tree wants to make a sound in a forest, must it fall to do so?  -- Taylor''',
r'''If a turtle doesn't have a shell, is he homeless or naked?''',
r'''If a vegetarian eats vegetables, what does a humanitarian eat?''',
r'''If a young writer can refrain from writing, he shouldn't hesitate to do so.''',
r'''If all is not lost, where is it?''',
r'''If all men were brothers, would you let one marry your sister?''',
r'''If all the world's a stage, I want some better lighting.''',
r'''If all the world's a stage, I want to operate the trap door.  -- Paul Beatty''',
r'''If all the world's managers were laid end to end, it would be an improvement.''',
r'''If an experiment works, something has gone wrong.''',
r'''If an item is advertised as "under $50", you can bet it's not $19.95.  -- McGowan''',
r'''If any word is improper at the end of a sentence, a linked verb is.  -- William Safire''',
r'''If aquarium gravel is bad for you, how come it tastes so good?  -- Ralph Wiggum''',
r'''If at first you do succeed, try to hide your astonishment.''',
r'''If at first you don't succeed, destroy all evidence that you tried.''',
r'''If at first you don't succeed, quit; don't be a nut about success.''',
r'''If at first you don't succeed, redefine success.''',
r'''If at first you don't succeed, then skydiving isn't for you.''',
r'''If at first you don't succeed, you probably didn't really care anyway.''',
r'''If at first you don't succeed, you'll get lots of advice.''',
r'''If at first you don't succeed, you're doing about average.  -- Leonard Levinson''',
r'''If at first you don't succeed, your successor will.  -- Lord Birdwood''',
r'''If Barbie is so popular, why do you have to buy her friends?''',
r'''If cats could talk, they'd say things like, "Hey, I don't see the problem here."''',
r'''If conditions are not favorable, bacteria go into a period of adolescence.''',
r'''If drinking directly from a bottle, hold it with fingers covering the label.''',
r'''If enough data is collected, anything can be proven by statistical methods.''',
r'''If entropy is increasing, where is it coming from?''',
r'''If flattery gets you nowhere, try bribery.''',
r'''If God had meant for us to be naked, we would have been born that way.''',
r'''If God had wanted you to go around nude, He would have given you bigger hands.''',
r'''If God is perfect, why did he create discontinuous functions?''',
r'''If God is so great, how come everything he makes dies?  -- George Carlin''',
r'''If God lived on Earth, people would knock out all his windows.  -- Yiddish proverb''',
r'''If God meant for you to take life seriously, you would have no sense of humor.''',
r'''If guns are outlawed, how will we shoot the liberals?''',
r'''If high heels were so wonderful, men would be wearing them.  -- Sue Grafton''',
r'''If I agreed with you, we'd both be wrong.  -- Lily Tomlin''',
r'''If I can be of any help, you're in worse trouble than I thought.  -- Henry Cate''',
r'''If I can't take it with me, I'm not going!''',
r'''If I could drop dead right now, I'd be the happiest man alive.  -- Samuel Goldwyn''',
r'''If I could offer you only one tip for the future, sunscreen would be it.''',
r'''If I ever marry, it will be on a sudden impulse -- as a man shoots himself.''',
r'''If I follow you home, will you keep me?''',
r'''If I had a life, I'd end it.''',
r'''If I had a ruler, I'd beat you within an inch of your life.  -- Groucho Marx''',
r'''If I had any humility I would be perfect.  -- Ted Turner''',
r'''If I had known I would live so long, I would have taken better care of myself.  -- Eubie Blake''',
r'''If I have sex with my clone, will I go blind?''',
r'''If I insult you, you can be goddamn sure I intend to.  -- John Wayne''',
r'''If I owned Texas and Hell, I would rent out Texas and live in Hell.  -- Sheridan''',
r'''If I told you you had a beautiful body, would you hold it against me?''',
r'''If I want your opinion, I'll ask you to fill out the necessary forms.''',
r'''If I was under any more pressure, the carbon in my body would turn to diamonds.''',
r'''If I were you, who would you be?''',
r'''If I win the lottery I won't change, but my bad decisions will become epic.''',
r'''If I've told you once, I've told you a thousand times:  Resist hyperbole.''',
r'''If ignorance is bliss, why aren't there more happy people?''',
r'''If ignorance is bliss, you must be orgasmic.''',
r'''If ignorance isn't bliss, I don't know what is.  -- Craig Ewing''',
r'''If in doubt, make it sound convincing.''',
r'''If in doubt, mumble.''',
r'''If it ain't broke, you're not trying hard enough.  -- New Red Green Show''',
r'''If it ain't damp, it ain't camp.''',
r'''If it falls off, it doesn't matter.  -- Tom Magliozzi''',
r'''If it flies, floats, or fornicates, it is cheaper to rent.''',
r'''If it is Tuesday, this must be someone else's fortune.''',
r'''If it is worth doing, it is worth doing for money.''',
r'''If it jams, force it.  If it breaks, it needed replacing anyway.''',
r'''If it looks easy, it's tough.  If it looks tough, it's nearly impossible.''',
r'''If it pours before seven, it has rained by eleven.''',
r'''If it wasn't for lawyers, we wouldn't need them.''',
r'''If it wasn't for muscle spasms, I wouldn't get any exercise at all.''',
r'''If it wasn't for Newton, we wouldn't have to eat bruised apples.''',
r'''If it wasn't for the last minute, nothing would get done.''',
r'''If it were truly the thought that counted, more women would be pregnant.''',
r'''If it weren't for pick-pocketers I'd have no sex life at all.  -- Dangerfield''',
r'''If it's called tourist season, why can't we shoot them?  -- George Carlin''',
r'''If liberals really hated America -- they'd vote Republican!''',
r'''If life gives you lemons, take them, free stuff is cool.''',
r'''If little else, the brain is an educational toy.  -- Tom Robbins''',
r'''If love is blind, why is lingerie so popular?''',
r'''If money can fix it, it's not a problem.  -- Tom Magliozzi''',
r'''If more than one person is responsible for a problem, no one is at fault.''',
r'''If Murphy's Law can go wrong, it will.  -- Silverman''',
r'''If my life wasn't funny it would just be true, and that is unacceptable.  -- Carrie Fisher''',
r'''If no one ever took risks, Michelangelo would have painted the Sistine Floor.''',
r'''If nothing ever sticks to teflon, how do they make it stick to the frying pan?''',
r'''If one hundred people do a foolish thing, one will become injured.''',
r'''If one synchronized swimmer drowns, do the rest have to drown too?''',
r'''If only I could be respected without having to be respectable.''',
r'''If opportunity came disguised as temptation, one knock would be enough.''',
r'''If parents would only realize how they bore their children.  -- George Shaw''',
r'''If reproducibility might be a problem, conduct the test only once.''',
r'''If Satan ever loses his hair, there'll be hell toupee.''',
r'''If some people didn't tell you, you'd never know they'd been away on vacation.''',
r'''If sound can't travel in a vacuum, why are vacuum cleaners so noisy?''',
r'''If the cops arrest a mime, do they tell him he has the right to remain silent?''',
r'''If the facts do not conform to your theory, they must be disposed of.''',
r'''If the genie won't grant you more than three wishes, wish for more genies.''',
r'''If the odds are a million to one against something, chances of it are 50-50.''',
r'''If the plane you're on is late, the plane to which you're connecting is on time.''',
r'''If the Pope wants to see me, he can come to my show.  -- Madonna''',
r'''If the probability of success is not almost one, it is damn near zero.  -- Ellis''',
r'''If the question of what it all means doesn't mean anything...  -- xkcd''',
r'''If the ship is not sinking, the rats must be the ones not leaving.''',
r'''If the shoe fits, buy the other one too.''',
r'''If the shoe fits, it's ugly.  -- Gold''',
r'''If there is anything a public servant hates to do it's something for the public.''',
r'''If there is light at the end of the tunnel...  ORDER MORE TUNNEL.''',
r'''If there is no God, who pops up the next Kleenex?  -- Art Hoppe''',
r'''If there is no self, whose arthritis is this?''',
r'''If they lined up all the men in the world...  That would be one funky line!''',
r'''If they won't read my words, no one's going to stop them.  -- John Taylor''',
r'''If things get any worse, I will have to ask you to stop helping me.''',
r'''If this aphorism did not exist, somebody would have invented it.''',
r'''If this were subjunctive, I'm in the wrong mood.''',
r'''If thou art in the bathtub, the telephone tolls for thee.''',
r'''If time flies, does it mean you are having fun?''',
r'''If time heals all wounds, how come bellybuttons don't fill in?''',
r'''If today is the first day of the rest of your life, what was yesterday?''',
r'''If triangles had a God, he'd have three sides.  -- old Yiddish proverb''',
r'''If we all work together we can totally disrupt the system.  -- Ashleigh Brilliant''',
r'''If we aren't supposed to eat animals, why are they made of meat?''',
r'''If we do not succeed, we run the risk of failure.  -- Dan Quayle''',
r'''If we knew what we were doing, it wouldn't be research.  -- J. C. Stamos''',
r'''If we were meant to fly, we wouldn't keep losing our luggage.''',
r'''If we're here to take care of other people, what are they here for?  -- Wilson''',
r'''If white wine goes with fish, do white grapes go with sushi?''',
r'''If you are a fatalist, what can you do about it?  -- Ann Edwards-Duff''',
r'''If you are asked to join a parade, don't march behind the elephants.  -- Zisla''',
r'''If you are cross-eyed and have dyslexia, can you read all right?''',
r'''If you are given a take-home test, you will forget where you live.''',
r'''If you are given on open-book exam, you will forget your book.''',
r'''If you are going to do something wrong, you should do it right.  -- Garfield''',
r'''If you are good you get all the work.  If you're really good you get out of it.''',
r'''If you are horny, it's lust, but if your partner's horny, it's affection.''',
r'''If you are mad at your neighbor, buy his kid a drum.''',
r'''If you are not very clever you should be conciliatory.  -- Benjamin Disraeli''',
r'''If you are seen fixing it, you will be blamed for breaking it.''',
r'''If you ate pasta and antipasta, would you still be hungry?''',
r'''If you believe in psychokinesis, raise my hand.''',
r'''If you can count your money, you don't have a billion dollars.  -- J. Paul Getty''',
r'''If you can get a new car for your spouse, it's a great trade.''',
r'''If you can lead it to water and force it to drink, it isn't a horse.''',
r'''If you can smile when things go wrong, you have someone in mind to blame.''',
r'''If you can survive death, you can probably survive anything.''',
r'''If you can't be good, be careful.  If you can't be careful, give me a call.''',
r'''If you can't be replaced, you can't be promoted.''',
r'''If you can't dazzle 'em with brilliance, baffle 'em with bullshit.''',
r'''If you can't find your glasses, it's probably because you don't have them on.''',
r'''If you can't get your work done in the first 24 hours, work nights.''',
r'''If you can't make it good, make it big.''',
r'''If you can't say anything nice, you probably don't have many friends.''',
r'''If you can't understand it, it is intuitively obvious.''',
r'''If you cannot convince them, confuse them.  -- Harry S Truman''',
r'''If you cannot hope for order, withdraw with style from the chaos.  -- Stoppard''',
r'''If you do a job too well, you will get stuck with it.  -- Slous''',
r'''If you do something right once, someone will ask you to do it again.''',
r'''If you do something right the first time, no one will know how hard it was.''',
r'''If you don't believe me, stand in line.''',
r'''If you don't care where you are, then you aren't lost.''',
r'''If you don't go to other men's funerals they won't go to yours.  -- Clarence Day''',
r'''If you don't know what you're doing, do it neatly.''',
r'''If you don't like my driving, don't call anyone.  Just take another road.''',
r'''If you don't like the news, go out and make some.''',
r'''If you don't like the weather in New England, just wait a few minutes.  -- Twain''',
r'''If you don't pay your exorcist, you get repossessed.''',
r'''If you don't say anything, you won't be called on to repeat it.  -- Coolidge''',
r'''If you explain so clearly that no one can possibly misunderstand, someone will.''',
r'''If you find a place to park, later you won't find your car.''',
r'''If you get a mouthful of hot soup, the next thing you do will be wrong.''',
r'''If you get angry at a newspaper columnist, he will get rich or famous or both.''',
r'''If you have half a mind to watch TV, that is enough.''',
r'''If you have kleptomania, you can always take something for it.''',
r'''If you have nothing to say, please say it only once.''',
r'''If you have to ask how much it is, you can't afford it.''',
r'''If you have to travel on the Titanic, why not go first class?  -- Hempstone''',
r'''If you have to vacuum the bed, it is time to change the sheets.''',
r'''If you keep trying to prove Murphy's Law, will something keep going wrong?''',
r'''If you lend someone $20 and never see them again, it was probably worth it.''',
r'''If you liked Earth, you will love Heaven.''',
r'''If you listen to too much advice you may wind up making other people's mistakes.''',
r'''If you live alone, deodorant is a waste of good money.''',
r'''If you live in a country run by committee, be on the committee.  -- Graham Summer''',
r'''If you look like your passport photo, it's time to go home.  -- Erma Bombeck''',
r'''If you look like your passport photo, you aren't well enough to travel.  -- Fuch''',
r'''If you mess with a thing long enough, it will break.  -- Schmidt''',
r'''If You Pass This Point You Will Most Certainly Die.  -- sign on birth canal''',
r'''If you put it off long enough, it might go away.''',
r'''If you start off dumb enough, you can learn something new each day.''',
r'''If you stay up all night wondering where the sun is, it will dawn on you.''',
r'''If you talk to God you are praying; if God talks to you, you have schizophrenia.''',
r'''If you think before you speak, the other fellow gets in his joke first.  -- Howe''',
r'''If you think nobody cares if you're alive, try filing your income tax late.''',
r'''If you think nobody cares if you're alive, try missing a couple of car payments.''',
r'''If you think outside the box, the box will think outside you.  -- Quarnstrom''',
r'''If you think the problem is bad now, just wait until we've solved it.  -- Kasspe''',
r'''If you think there is good in everyone, you haven't met everyone.''',
r'''If you thought yesterday was bad, wait till you see what happens today.''',
r'''If you throw a cat out a car window, does it become kitty litter?''',
r'''If you took out all your blood vessels and laid them end-to-end, you'd die.''',
r'''If you try to fail, and succeed, which have you done?''',
r'''If you turn on the light quickly enough you can see what the dark looks like.''',
r'''If you want a kitten, start out by asking for a horse.  -- Naomi, age 15''',
r'''If you want to come back after death, be sure to get your hand stamped first.''',
r'''If you want to know how old a man is, ask his brother-in-law.''',
r'''If you want to put yourself on the map, publish your own map.''',
r'''If you were to ask me this question, what would my answer be?''',
r'''If you're born again, do you get two bellybuttons?''',
r'''If you're not part of the solution, you're part of the precipitate.  -- Wright''',
r'''If you've got part of it, flaunt that part.''',
r'''If you've seen one redwood, you've seen them all.  -- Ronald Reagan''',
r'''If your dog is fat, you aren't getting enough exercise.''',
r'''If your feet smell and your nose runs, you were built upside down.''',
r'''If your parents didn't have any children, neither will you.''',
r'''Ignorance:  When you don't know anything, and someone else finds out.''',
r'''Ignoranus:  A person who's both stupid and an asshole.''',
r'''Ignore previous fortune.''',
r'''Ill-bred children always display their pest manners.''',
r'''Illiterate?  Write for free help.''',
r'''Immigration is the sincerest form of flattery.  -- Jack Paar''',
r'''Immortality -- a fate worse than death.  -- Edgar Shoaff''',
r'''Imports are ports very far inland.''',
r'''In 1869 the waffle iron was invented for people who had wrinkled waffles.''',
r'''In a gambit you give up a pawn for the sake of getting a lost game.  -- Boden''',
r'''In a ham and egg breakfast, the chicken was involved, but the pig was committed.''',
r'''In a modern household, the only things we have to wash by hand are children.''',
r'''In America, anyone can be President.  That's one of the risks you take.''',
r'''In America, it is not how much an item costs, it is how much you save.''',
r'''In an accident, it's not who's right, but who's left.  -- Geoff Torres''',
r'''In an orderly world, there is always a place for the disorderly.''',
r'''In base infinity, all integers are just one digit.''',
r'''In Boston, drivers don't even obey the laws of PHYSICS.  -- Dave Barry''',
r'''In case of emergency, contact:  "A good doctor."''',
r'''In case of fire...  Yell "fire".''',
r'''In cyberspace, everyone gets their 15 minutes of shame.  -- Michael Fry''',
r'''In democracy your vote counts.  In feudalism your count votes.''',
r'''In England, the Speaker of the House is not allowed to speak.''',
r'''In English, every word can be verbed.''',
r'''In everything but brains and brawn, women are vastly superior to men.  -- Edward Abbey''',
r'''In government, where there is a vacancy, there is a relative.''',
r'''In Lake Wobegon, all the children are above average.  -- Garrison Keilor''',
r'''In marriage, as in war, it is permitted to take every advantage of the enemy.''',
r'''In married life three is company and two is none.  -- Oscar Wilde''',
r'''In matrimony, to hesitate is sometimes to be saved.  -- Butler''',
r'''In midevil times most of the people were alliterate.''',
r'''In my case, saving the world was only a hobby.  -- Edward Abbey''',
r'''In New York City, it is easier to get a girlfriend than an apartment.''',
r'''In order to get a loan you must first prove you don't need it.''',
r'''In principle I am against principles.  -- Tristan Tzara''',
r'''In process:  So wrapped up in red tape that the situation is almost hopeless.''',
r'''In some cultures what you do would be considered normal.''',
r'''In spite of the high cost of living, it is still very popular.  -- Laurence Peter''',
r'''In Texas the men are men, but for some reason they have to keep proving it.''',
r'''In the battle between airplanes and the ground, the ground has yet to lose.  -- Darwin Awards''',
r'''In the first half of our life we learn habits that shorten the second half.''',
r'''In the future, your clothes will be smarter than you.  -- Scott Adams''',
r'''In the memo field of every check you issue, write, "for sexual favors."''',
r'''In the morning, I do not want to eat gum drops and cheese doodles.  -- Madonna''',
r'''In the subway it is called congestion; in the disco it is called intimacy.''',
r'''In the world of words, one of my best-loved tribes is the diatribe.  -- Edward Abbey''',
r'''In the years ahead, when you come to a fork in the road, take it.  -- Yogi Berra''',
r'''In this world, truth can wait; she is used to it.''',
r'''Include me out.  -- Samuel Goldwyn''',
r'''Incoming fire has the right of way.''',
r'''Incompetence is a double-edged banana.  -- J. P. Barlow''',
r'''Indecision is the key to flexibility.''',
r'''Individualists unite!''',
r'''Infectious disease is one of the few genuine adventures left in the world.''',
r'''Ingrate:  Bites the hand that feeds him, and then complains of indigestion.''',
r'''Ingress is not a necessary precursor to egress.''',
r'''Inoculatte:  To take coffee intravenously when you are running late.''',
r'''Insanity is inherited; you get it from your kids!''',
r'''Inside every old person is a young person...  Wondering what the heck happened.''',
r'''Insomnia:  What you have when you lie awake all night for an hour.  -- Gilbert''',
r'''Insomniac agnostic dyslexic:  Lays awake at night wondering if there is a dog.''',
r'''Instant sex will never be better than the kind you have to peel and cook.''',
r'''Institute:  An archaic school where football is not taught.''',
r'''Insufficient data for a meaningful answer at this time.  -- Isaac Asimov''',
r'''Intaxication:  Misguided euphoria about a tax refund (of your own money).''',
r'''Intellectuals going round in circles until they disappear up their own holes.''',
r'''Intelligence has much less practical application than you'd think.  -- Scott Adams''',
r'''Interchangeable parts won't.''',
r'''Invest in physics; own a piece of Dirac.''',
r'''Iowa State grads put their diploma on the dashboard to park in handicap zones.''',
r'''Irrationality is the square root of all evil.  -- Douglas Hofstadter''',
r'''Irresistible force + immovable object = inconceivable disturbance.''',
r'''Irritainment:  Media spectacles that are annoying but spellbinding.''',
r'''IRS:  Income Reduction Service.''',
r'''Is Interstate 35 the best thing to come out of Iowa?''',
r'''Is is the verb for when you don't want a verb.''',
r'''Is it possible to be totally partial?''',
r'''Is it the God of the Catholics or of the Protestants in whom you don't believe?''',
r'''Is it time for lunch yet?''',
r'''Is knowledge knowable, and how do we know?''',
r'''Is that a pistol in your pocket, or are you just glad to see me?  -- Mae West''',
r'''Is there life before coffee?''',
r'''Is there life before death?  -- Belfast graffiti''',
r'''Is this really happening?''',
r'''It ain't loafing unless they can prove it.  -- Dick Brown''',
r'''It behooves the writer to avoid archaic expressions.''',
r'''It bothers people if you are lucid and ironic.  -- Albert Camus''',
r'''It does not do to leave a live dragon out of your calculations.''',
r'''It doesn't matter that everything has already been said -- no one was listening.''',
r'''It doesn't matter whether you win or lose -- until you lose.''',
r'''It has been Monday all week today.''',
r'''It has just been discovered that research causes cancer in rats.''',
r'''It is a mistake to let any mechanical object know you are in a hurry.''',
r'''It is a small world.  So you gotta use your elbows a lot.''',
r'''It is an inappropriate response to get a headache in the presence of a miracle.''',
r'''It is bad luck to be superstitious.  -- Andrew Mathis''',
r'''It is better for civilization to go down the drain than to come up it.  -- Allen''',
r'''It is better to be an ancestor than a descendant.''',
r'''It is better to be on penicillin than never to have loved at all.''',
r'''It is better to be on the ground wishing you were flying, than vice versa.''',
r'''It is better to burn out than to fade away.''',
r'''It is better to give than to lend, and it costs about the same.''',
r'''It is better to have a positive Wasserman than never to have loved at all.''',
r'''It is better to have loved and lost -- much better.''',
r'''It is better to have loved and lost than just to have lost.''',
r'''It is better to light one candle than to torch a wax museum with a flamethrower.''',
r'''It is better to remain childless than to father an orphan.  -- Tom Weller''',
r'''It is better to sit still than rise and fall.  -- Scott''',
r'''It is called cold cash because we don't keep it long enough to get it warm.''',
r'''It is considered tacky to take a cooler to church.''',
r'''It is dangerous to name your children before you know how many you will have.''',
r'''It is difficult to legislate morality in the absence of moral legislators.''',
r'''It is difficult to make predictions, particularly about the future.  -- Confucius''',
r'''It is easier to get older than it is to get wiser.''',
r'''It is easier to take it apart than to put it back together.  -- Washlesky''',
r'''It is easy being a humorist when you have the whole government working for you.''',
r'''It is easy to love a sleeping baby.''',
r'''It is great to live in the fast lane, if you can find the on-ramp.''',
r'''It is hard to be humble when you are so perfect.''',
r'''It is hard to make a comeback when you haven't been anywhere.''',
r'''It is hard to seize the day when you must first grapple with the morning.''',
r'''It is kind of fun to do the impossible.  -- Walt Disney''',
r'''It is later than you think.''',
r'''It is lonely at the top of the food chain, but you eat better.''',
r'''It is morally wrong to allow a sucker to keep his money.''',
r'''It is more than magnificent -- it is mediocre.  -- Samuel Goldwyn''',
r'''It is much easier to suggest solutions when you know nothing about the problem.''',
r'''It is not a good omen when goldfish commit suicide.''',
r'''It is not a pre-existing condition unless you had it before you existed.''',
r'''It is not an optical illusion, it just looks like one.  -- Phil White''',
r'''It is not Camelot, but it's not Cleveland, either.  -- Boston mayor Kevin White''',
r'''It is not my week to care.''',
r'''It is not premarital sex if you have no intention of getting married.''',
r'''It is not procrastination if you decide to postpone it right now.''',
r'''It is not speeding if there are still cars in front of you.''',
r'''It is not that you and I are so clever, but that the others are such fools.''',
r'''It is not the end of the world, but you can see it from there.''',
r'''It is possible to lead a cow upstairs but not downstairs.''',
r'''It is so soon that I am done for, I wonder what I was begun for.  -- epitaph''',
r'''It is sweet to be remembered, but cheaper to be forgotten.''',
r'''It is tough being you, but you are the one most qualified for the job.''',
r'''It is trying not to appear poor that keeps a lot of folks broke.''',
r'''It isn't what a teenager knows that bothers his parents; it is how he found out.''',
r'''It might appear I'm doing nothing, but at the cellular level I'm quite busy.''',
r'''It now costs more to amuse a child than it once did to educate his father.''',
r'''It requires strong constitution to withstand repeated attacks of prosperity.''',
r'''It seems to make an auto driver mad if she misses you.''',
r'''It takes 45 muscles to frown, but only four to give the finger.  -- Niki Roman''',
r'''It takes a big man to cry, but it takes a bigger man to laugh at that man.''',
r'''It takes more than three weeks to prepare a good impromptu speech.  -- Mark Twain''',
r'''It takes years to become an overnight success.''',
r'''It was a book to kill time for those who liked it better dead.''',
r'''It was a brave man that ate the first oyster.''',
r'''It was such a beautiful day I decided to stay in bed.  -- W. Somerset Maugham''',
r'''It works better if you plug it in.''',
r'''It would be best if you did not remind God of my existence.  -- Doug Quarnstrom''',
r'''It would be nice to be sure of anything the way some people are of everything.''',
r'''It would take a miracle to get you out of Casablanca.  -- Humphrey Bogart''',
r'''It's a damn poor mind that can only think of one way to spell a word.  -- Jackson''',
r'''It's a rare person who wants to hear what he doesn't want to hear.  -- Dick Cavett''',
r'''It's a small world, but I wouldn't want to paint it.  -- Stephen Wright''',
r'''It's a thankless job, but I've got a lot of karma to burn off.''',
r'''It's all right to hold a conversation, but you should let go of it now and then.''',
r'''It's been real and it's been fun, but it hasn't been real fun.''',
r'''It's better to be looked over than overlooked.  -- Mae West''',
r'''It's better to have loafed and lost than never to have loafed at all.  -- Thurber''',
r'''It's certainly strange how little I look like me.  -- Bob Thaves''',
r'''It's good to get a taste of someone else's moccasins.''',
r'''It's hard to be funny when you have to be clean.  -- Mae West''',
r'''It's hard to get ivory in Africa, but in Alabama the Tuscaloosa.''',
r'''It's hard to soar like an eagle when you are surrounded by turkeys.''',
r'''It's hell to work for a nervous boss, especially if you are why he's nervous!  -- Alan Silverstein''',
r'''It's impossible to sneeze with your eyes open.''',
r'''It's just too easy to start a religion.  -- Bill Maher''',
r'''It's not easy being green.  -- Kermit the frog''',
r'''It's not hard to meet expenses; they are everywhere.''',
r'''It's not the men in my life, it's the life in my men.  -- Mae West''',
r'''It's not the pace of life that concerns me; it's the sudden stop at the end.''',
r'''It's not whether you win or lose, it's how you look playing the game.''',
r'''It's often your clothing that gets promoted.  -- Scott Adams''',
r'''It's sick the way you people keep having sex without me.''',
r'''It's the friends you can call up at 4 am that matter.  -- Marlene Dietrich''',
r'''It's time for the human race to enter the solar system.  -- Dan Quayle''',
r'''Jealousy:  All the fun you think they have.''',
r'''Jehovah has a very limited repertoire of emotional responses, as gods go.  -- Dass''',
r'''Jesus saves sinners and redeems them for valuable cash prizes.''',
r'''Jesus saves; Moses invests; but only Buddha pays dividends.''',
r'''Jesus to headwaiter at Last Supper:  "Separate checks, please."  -- Edward Abbey''',
r'''Job placement:  Telling your boss what he can do with your job.''',
r'''John Muir was the sum of his parks.  -- Henry Gay''',
r'''Journalism is literature in a hurry.  -- Matthew Arnold''',
r'''Journalism is the first draft of history.  -- Philip Graham''',
r'''Journalism will kill you, but it will keep you alive while you are at it.''',
r'''Journalists print 10% of what you tell them, and they get that wrong.  -- Richard Hill''',
r'''Junk:  Stuff we throw away.  Stuff:  Junk we keep.''',
r'''Jury:  Twelve men and women trying to decide which party has the best lawyer.''',
r'''Just as nature abhors a vacuum, truth abhors a know-it-all.  -- Michael Mode''',
r'''Just because everything is different doesn't mean anything has changed.''',
r'''Just because you are not paranoid doesn't mean they are not out to get you.''',
r'''Just give Alice some pencils and she will stay busy for hours.''',
r'''Just when you get going, someone injects a dose of reality with a large needle.''',
r'''Just when you learn to make the most of it, most of it is gone.''',
r'''Justice:  A decision in your favor.''',
r'''Karmageddon:  When the Earth explodes due to bad vibes.''',
r'''Keep a very firm grasp on reality, so you can strangle it at any time.''',
r'''Keep America beautiful.  Swallow your beer cans.''',
r'''Keep in mind that all I had to work with was chaos.  -- God, per Bob Thaves''',
r'''Keep stress out of your life.  Give it to others instead.''',
r'''Keep the pointy end forward and the dirty side down.''',
r'''Keychain:  A device that allows you to lose multiple keys at once.''',
r'''Kilroy occupied these spatial coordinates.''',
r'''Kiss me twice, I'm schizophrenic.''',
r'''Klatu barada nikto.''',
r'''Klein bottle for rent -- inquire within.''',
r'''Kleptomaniac:  A rich thief.''',
r'''Knocked; you weren't in.  -- Opportunity''',
r'''Know thyself -- but don't tell anyone.''',
r'''Know what I hate most?  Rhetorical questions.  -- Henry Camp''',
r'''Krogt:  The metallic silver coating found on fast-food game cards.''',
r'''Lack of prior planning on your part does not constitute an emergency on my part.''',
r'''Lactomangulation:  Abusing the "open here" spout on a milk carton.''',
r'''Landing:  A controlled mid-air collision with a planet.''',
r'''Late to bed, early to rise, makes a man tired.''',
r'''Laugh alone, and the world thinks you're an idiot.''',
r'''Laugh and the world laughs with you.  Cry and the world laughs at you.''',
r'''Laugh at your problems; everybody else does.''',
r'''Laugh, and the world ignores you.  Crying doesn't help either.''',
r'''Lawyers:  America's untapped export market.''',
r'''Lead me not into temptation.  I can find it myself.''',
r'''Leakproof seals...  Do.''',
r'''Learn from your parents' mistakes -- use birth control!''',
r'''Learn the rules.  Then break some.  -- H. Jackson Brown''',
r'''Learning at some schools is like drinking from a firehose.''',
r'''Lecture:  Makes you feel numb on one end and dumb on the other.  -- C. N. Pearce''',
r'''Left to themselves, things tend to go from bad to worse.''',
r'''Leftover nuts never match leftover bolts.''',
r'''Legalize freedom.''',
r'''Let him who takes the Plunge remember to return it by Tuesday.''',
r'''Let not the sands of time get in your lunch.''',
r'''Let us share the deepest secrets of our souls!  You first.''',
r'''Let's get drunk and be somebody.''',
r'''Let's hope God grades on a curve.''',
r'''Liberal arts major...  Will think for money.''',
r'''Liberal:  A Conservative who has just been arrested.''',
r'''Liberal:  Someone too poor to be a capitalist and too rich to be a communist.''',
r'''Liberal:  Too broadminded to take his own side in a quarrel.''',
r'''Licorice is the liver of candy.  -- Michael O'Donoghue''',
r'''Lie:  A very poor substitute for the truth, but the only one discovered to date.''',
r'''Life -- love it or leave it.''',
r'''Life begins at the centerfold and expands outward.  -- Miss November, 1966''',
r'''Life does not begin at 40 for those who went 60 at 20.''',
r'''Life is a game of bridge -- and you have just been finessed.''',
r'''Life is a jigsaw puzzle with most of the pieces missing.''',
r'''Life is a journey, but relax, you will find a parking place at the end.''',
r'''Life is a sexually transmitted terminal disease.''',
r'''Life is a whole series of circumstances beyond your control.''',
r'''Life is antagonistic to the living.''',
r'''Life is carcinogenic.  -- Abdul Khaliq''',
r'''Life is complex.  It has real and imaginary parts.''',
r'''Life is difficult because it is non-linear.''',
r'''Life is fraught with opportunities to keep your mouth shut.''',
r'''Life is just a stage:  We all go through it.  -- John Taylor''',
r'''Life is just sudden-death overtime.''',
r'''Life is like a fountain...  I will tell you how when I figure it out.''',
r'''Life is like a maze in which we all go around trying not to find an exit.''',
r'''Life is like a sewer...  What you get out of it depends on what you put into it.''',
r'''Life is like an analogy.''',
r'''Life is nature's way of keeping meat fresh.  -- Doug Quarnstrom''',
r'''Life is not for everyone.''',
r'''Life is something to do when you can't get to sleep.''',
r'''Life is the ultimate cause of death.  -- Lyle McDonald''',
r'''Life is too confusing for novices.  We should let the experts take care of it.''',
r'''Life is too important to be taken seriously.''',
r'''Life is tough.  If it wasn't, anybody could do it.''',
r'''Life is uncertain, so eat dessert first.''',
r'''Life is wasted on the living.''',
r'''Life is what puts the "pee" in entropy.''',
r'''Life might have no meaning, or worse, it might have a meaning you don't like.''',
r'''Life not only begins at forty, it begins to show.''',
r'''Life without caffeine is stimulating enough.  -- Sanka ad''',
r'''Lisa, in this house we obey the laws of thermodynamics!  -- Homer Simpson''',
r'''Little things come in small packages.  -- Tom Weller''',
r'''Live each day as if it were your last, because someday you're going to be right.  -- Muhammed Ali''',
r'''Live fast, die young, and leave a good looking corpse.''',
r'''Live within your income, even if you must borrow to do so.''',
r'''Livestock usually is a poor choice for a wedding gift.''',
r'''Living on Earth includes an annual free trip around the Sun.''',
r'''Living your life is so difficult, it has never been attempted before.''',
r'''Loafer:  Someone trying to make two weekends meet.''',
r'''Logic is a little bird, sitting in a tree, that smells AWFUL.''',
r'''Logic is an organized way of going wrong with confidence.  -- Charles Kettering''',
r'''Loneliness is a good thing to share with someone.  -- Ernie Pantusso, Cheers''',
r'''Long-lived:  You can't buy parts when it DOES get old and wears out.''',
r'''Long-term planning is anticipatory expiation for short-term fiasco.  -- Hirsch''',
r'''Look out for number 1.  Don't step in number 2 either.''',
r'''Look under the sofa cushion; you will be surprised at what you find.''',
r'''Looking for love, everyone runs away because you remind them of themselves.''',
r'''Looking like a weed doesn't make you organic.  -- Edward Abbey''',
r'''Losing my virginity was a career move.  -- Madonna''',
r'''Losing your driver's license is just God's way of saying "BOOGA, BOOGA!"''',
r'''Lots of money saved for a rainy day is blown on a wet night.''',
r'''Lottery:  A tax on people who are bad at math.''',
r'''Love does much; money does everything.''',
r'''Love does not make the world go around, just up and down a bit.''',
r'''Love is a vacation from reality.''',
r'''Love is being stupid together.''',
r'''Love is blind, but marriage is definitely an eye-opener.''',
r'''Love is Grand...  Divorce is Twenty Grand.''',
r'''Love is like an avalanche where you have to run for your life.  -- John, age 9''',
r'''Love is sentimental measles.''',
r'''Love is sex misspelled.  -- Harlan Ellison''',
r'''Love is the delusion that one woman differs from another.''',
r'''Love is the only game that is not called on account of darkness.''',
r'''Love is the triumph of imagination over intelligence.  -- H. L. Mencken''',
r'''Love lasts as long as money endures.''',
r'''Love means having to say you're sorry every five minutes.''',
r'''Love means nothing to a tennis player.''',
r'''Love the sea?  I dote upon it -- from the beach.''',
r'''Love thy neighbor as thyself, but choose thy neighborhood.  -- Louise Beal''',
r'''Love thy neighbor:  Tune thy piano.''',
r'''Love thyself, and others will hate thee.''',
r'''Love your enemies.  It will make them crazy.''',
r'''Love your neighbor, but don't get caught.''',
r'''Love:  An obsessive delusion that is cured by marriage.''',
r'''Love:  The warm feeling you get towards someone who meets your neurotic needs.''',
r'''Love:  Two vowels, two consonants, two fools.  -- Rodney Dangerfield''',
r'''LSD melts in your mind, not in your hand.''',
r'''LSD soaks up 47 times its own weight in excess reality.''',
r'''Lullabuoy:  A nagging thought that prevents you from drifting off to sleep.''',
r'''Machines have less problems.  I'd like to be a machine.  -- Andy Warhol''',
r'''Madness takes its toll.  Please have exact change.''',
r'''Magazine:  Printed pages that tell you what's coming in the next issue.''',
r'''Maggit:  A subscription card that falls from a magazine.''',
r'''Magnocartic:  An automobile that when left unattended attracts shopping carts.''',
r'''Maintain thy airspeed, lest the ground rise up and smite thee.''',
r'''Major steps to building a business plan:  1. Gather information.  2. Ignore it.''',
r'''Majority:  That quality that distinguishes a crime from a law.''',
r'''Make a firm decision now...  You can always change it later.''',
r'''Make it idiot proof and someone will make a better idiot.''',
r'''Make three consecutive correct guesses and you will be considered an expert.''',
r'''Make yourself at home!  Start by cleaning my kitchen.''',
r'''Male zebras have white stripes, but female zebras have black stripes.''',
r'''Man has made his bedlam; let him lie in it.  -- Fred Allen''',
r'''Man invented language to satisfy his deep need to complain.  -- Lily Tomlin''',
r'''Man is the only animal that blushes -- or needs to.  -- Mark Twain''',
r'''Man sometimes stumbles over the truth, but he picks himself up and keeps going.''',
r'''Man was created to complete the horse.  -- Edward Abbey''',
r'''Man who arrives at party two hours late finds he has been beaten to the punch.''',
r'''Man who falls in blast furnace is certain to feel overwrought.''',
r'''Man who falls in vat of molten optical glass makes spectacle of self.''',
r'''Man:  A remarkable animal whose head swells when you pat his back.''',
r'''Managers are like cats in a litter box.  -- Scott Adams''',
r'''Mankind has never reconciled itself to the ten commandments.''',
r'''Mankind... infests the whole habitable Earth and Canada.  -- Ambrose Bierce''',
r'''Manners are the noises you don't make when eating soup.  -- R.E. Atkinson''',
r'''Many a family tree needs trimming.''',
r'''Many a yo-yo thinks he has the world on a string.''',
r'''Many are called, but few are at their desks.''',
r'''Many are cold, but few are frozen.''',
r'''Many can rise to the occasion, but few know when to sit down.''',
r'''Many pages make a crowded castle.''',
r'''Many pages make a thick book, except for pocket Bibles on very thin paper.''',
r'''Many quite distinguished people have bodies similar to yours.''',
r'''Marathon runners with bad footwear suffer the agony of the feet.''',
r'''Markets can remain irrational longer than you can remain solvent.  -- John Keynes''',
r'''Marriage causes dating problems.''',
r'''Marriage halves our griefs, doubles our joys, and quadruples our expenses.''',
r'''Marriage is a rest period between romances.''',
r'''Marriage is a three ring circus:  Engagement ring, wedding ring, and suffering.''',
r'''Marriage is a trip between Niagara Falls and Reno.''',
r'''Marriage is an institution -- but who wants to live in one?''',
r'''Marriage is for those who don't like eating leftovers alone.''',
r'''Marriage is like pi:  Natural, irrational, and very important.  -- Lisa Hoffman''',
r'''Marriage is low down, but you spend the rest of your life paying for it.''',
r'''Marriage is not a word; it is a sentence.''',
r'''Marriage is not for wimps.''',
r'''Marriage is the only adventure open to the cowardly.  -- Voltaire''',
r'''Marriage is the sole cause of divorce.''',
r'''Marriages are made in heaven and consummated on Earth.  -- John Lyly''',
r'''Marry carefully, for spouses are temporary, but ex's are forever.  -- Alan Silverstein''',
r'''Martin Luther died a horrible death, being excommunicated by a bull.''',
r'''Masturbation is having sex with someone I love.  -- Woody Allen''',
r'''Math is like love; a simple idea, but it can get complicated.  -- R. Drabek''',
r'''Math is our native language.  English is our foreign language.  -- George Lance''',
r'''Mathematicians are willing to assume anything -- except responsibility.''',
r'''Mathematicians take it to the limit.''',
r'''Matrimony is the root of all evil.''',
r'''Matter cannot be created or destroyed; nor can it be returned without a receipt.''',
r'''Matter will be damaged in direct proportion to its value.''',
r'''Maturity is a high price to pay for growing up.''',
r'''May all your troubles last as long as your New Year's resolutions.  -- Joey Adams''',
r'''May the forces of evil become confused on the way to your house.  -- George Carlin''',
r'''May you die in bed at 95, shot by a jealous spouse.''',
r'''May you have many friends and very few living enemies.''',
r'''Maybe you can't buy happiness, but these days you can certainly charge it.''',
r'''Me...  A skeptic??  I trust you have proof?''',
r'''Measure with a micrometer; mark with chalk; cut with an axe.  -- Ray''',
r'''Mechanical engineers build weapons, while civil engineers build targets.''',
r'''Medicine consists of amusing the patient while nature cures the disease.''',
r'''Meditation is not what you think.''',
r'''Meeting:  A gathering where the minutes are kept and the hours lost.  -- Gourd''',
r'''Meetings are indispensable when you don't want to do anything.  -- Galbraith''',
r'''Mel Blanc, the voice of Bugs Bunny, was allergic to carrots.''',
r'''Men control fashion.  But that's the only thing men control.  -- Scott Adams''',
r'''Men learned to walk upright to free their hands for masturbation.  -- Jane Wagner''',
r'''Men seldom make passes at girls who wear glasses.  -- Dorothy Parker''',
r'''Men seldom show dimples to girls who have pimples.''',
r'''Men think, "I know what I'm doing, just show me somebody naked."  -- Seinfeld''',
r'''Meteorologists have warm fronts.''',
r'''Michelangelo would have made better time with a roller.''',
r'''Microwave fireplace:  Spend an evening in front of the fire in about 8 minutes.''',
r'''Microwaves frizz your heir.''',
r'''Middle class:  Too rich to qualify for charity, too poor to make any donations.''',
r'''Military intelligence is a contradiction in terms.  -- Groucho Marx''',
r'''Military justice is to justice what military music is to music.  -- Groucho Marx''',
r'''Military targets are targets that are hit and thus defined as military targets.''',
r'''Millihelen:  The amount of beauty required to launch one ship.''',
r'''Miracles are great, but they are so damned unpredictable.''',
r'''Misery no longer loves company; nowadays it insists on it.''',
r'''Moderation is a fatal thing.  Nothing succeeds like excess.  -- Oscar Wilde''',
r'''Modern man is the missing link between apes and human beings.''',
r'''Modesty is a vastly overrated virtue.  -- J. K. Galbraith''',
r'''Modesty is being comfortable that others will discover your greatness.''',
r'''Mold has spores.  People have pores.  It is one way to tell us apart.''',
r'''Molybdenum...  No joke here, I just like saying "molybdenum".  -- David Letterman''',
r'''Momentum:  What you give a person when they are going away.''',
r'''Monday is the root of all evil.''',
r'''Money can't buy happiness, but it can certainly rent it for a couple of hours.''',
r'''Money can't buy happiness, but it lets you be miserable in comfort.''',
r'''Money costs too much.  -- Lew Archer''',
r'''Money DOES talk -- it says goodbye.''',
r'''Money is better than poverty, if only for financial reasons.  -- Woody Allen''',
r'''Money is the root of all evil, and man needs roots.''',
r'''Money isn't everything, but it sure keeps the kids in touch.''',
r'''Monotony:  The practice of having only one spouse at a time.''',
r'''More than enough is too much.''',
r'''Moses went up on Mount Cyanide to get the ten commandments.''',
r'''Most general statements are false, including this one.  -- Alexander Dumas''',
r'''Most lipstick contains fish scales.''',
r'''Most people are too stupid to butter the pancake on the right side.''',
r'''Most people get lost in thought because it is unfamiliar territory.  -- Paul Fixx''',
r'''Most people who want to live forever are pretty miserable to begin with.''',
r'''Mother is far too clever to understand anything she does not like.  -- Bennett''',
r'''Mother is the invention of necessity.''',
r'''Mother told me to be good, but she has been wrong before.''',
r'''Mountain climbers rope together to prevent the sensible ones from going home.''',
r'''Mountain range:  A cooking stove used at high altitudes.''',
r'''Mouse potato:  The computer equivalent of a TV addict.''',
r'''Mowmuffins:  Dried accumulation of grass on the underside of lawnmowers.''',
r'''Mummy:  An Egyptian who was pressed for time.''',
r'''Murphy never met anyone he didn't meet.''',
r'''Murphy was an optimist.''',
r'''Music sung by two people at the same time is called a duel.''',
r'''My body is rejecting me.  -- Alan Silverstein''',
r'''My commitment is to truth, not consistency.''',
r'''My doctor gave me just 100 years to live, and I am making the most of it.''',
r'''My family history begins with me, but yours ends with you.  -- Iphicrates''',
r'''My father taught me to work; he did not teach me to love it.  -- Abraham Lincoln''',
r'''My favorite book on tape is, "Where's Waldo?"''',
r'''My God is alive and kicking.  Sorry about yours.  -- Edward Abbey''',
r'''My inferiority complex isn't very good.''',
r'''My life has a superb cast but I can't figure out the plot.  -- Ashleigh Brilliant''',
r'''My life is like one long obstacle race, with me as its chief obstacle.''',
r'''My mother had morning sickness after I was born.  -- Rodney Dangerfield''',
r'''My mother is a travel agent for guilt trips.''',
r'''My mother wants grandchildren, so I said, "Mom, go for it!"  -- Sue Murphy''',
r'''My opinions may have changed, but not the fact that I am right.  -- Ashleigh Brilliant''',
r'''My own business always bores me to death; I prefer other people's.  -- Wilde''',
r'''My peers are all smart enough to be excused from jury duty.''',
r'''My problem is I say what I'm thinking before I think what I'm saying.  -- Peter''',
r'''My reality check just bounced.''',
r'''My reputation grows with every failure.  -- G. B. Shaw''',
r'''My rise to the top was through sheer ability and inheritance.  -- Malcolm Forbes''',
r'''My theology, briefly, is that the universe was dictated but not signed.  -- Morley''',
r'''My toughest fight was with my first wife.  -- Mohammad Ali''',
r'''My truck does not leak, it's marking its territory.''',
r'''My whole life has been an out-of-body experience.''',
r'''My wife is so immature.  Every time I'm in the bath she sinks my little boats.''',
r'''My wife keeps complaining I never listen to her...  or something like that.''',
r'''My wife made me join a bridge club.  I jump off next Tuesday.  -- Dangerfield''',
r'''My wife ran off with my best friend, and I miss him.''',
r'''Mysticism is based on the assumption that you can quit the game.''',
r'''Myth:  A young female moth.''',
r'''Napjerk:  Sudden convulsion of the body just as one is about to doze off.''',
r'''Narcolepulacy:  The contagious action of yawning.''',
r'''Nature abhors a hero.''',
r'''Nature abhors a vacuous experimenter.''',
r'''Nature always sides with the hidden flaw.''',
r'''Nature is blind.  We are merely shortsighted.  That's an improvement.  -- Spencer''',
r'''Neanderthals delivered children without training manuals.  -- Bill Cosby''',
r'''Necessity has no law; I know some attorneys of the same.  -- Franklin''',
r'''Necessity is a mother.''',
r'''Neckties strangle clear thinking.  -- Lin Yutang''',
r'''Negative expectations yield negative results.  So do positive expectations.''',
r'''Neutrinos have bad breadth.''',
r'''Neutrinos have mass?  I didn't know they were Catholic!''',
r'''Never be photographed with a cocktail glass in your hand.  -- H. Jackson Brown''',
r'''Never be worth more to anyone dead than alive.  -- Alan Silverstein''',
r'''Never believe a rumor until it is officially denied.''',
r'''Never buy anything electrical at a flea market.  -- H. Jackson Brown''',
r'''Never do card tricks for the group with which you play poker.''',
r'''Never do today what you can put off until tomorrow.''',
r'''Never draw fire, it irritates everyone around you.''',
r'''Never eat anything bigger than your head.  -- Kliban''',
r'''Never eat more than you can lift.  -- Miss Piggy''',
r'''Never give an inch!''',
r'''Never go to bed mad; stay up and fight.''',
r'''Never have any children, only grandchildren.  -- Gore Vidal''',
r'''Never hit a man with glasses.  Hit him with a baseball bat.''',
r'''Never hold a Dustbuster and a cat at the same time.  -- Kyoyo, age 9''',
r'''Never invest your money in anything that eats or needs repainting.  -- Billy Rose''',
r'''Never laugh at live dragons.  -- Bilbo Baggins''',
r'''Never lend your car to anyone to whom you have given birth.  -- Erma Bombeck''',
r'''Never let the facts stand in the way of a good answer.  -- Tom Magliozzi''',
r'''Never look back, someone might be gaining on you.  -- Satchel Paige''',
r'''Never make forecasts, especially about the future.  -- Samuel Goldwyn''',
r'''Never miss a good chance to shut up.''',
r'''Never offend with style when you can offend with substance.  -- Sam Brown''',
r'''Never pass a snowplow on the right.''',
r'''Never put off till tomorrow that which can be done the day after tomorrow.''',
r'''Never put off till tomorrow what you can avoid altogether.''',
r'''Never put off till tomorrow what you can do today -- while it's still legal.''',
r'''Never raise your hands to your kids; it leaves your groin unprotected.''',
r'''Never relieve yourself from a moving vehicle, especially when driving.''',
r'''Never replace a successful experiment.''',
r'''Never say anything more predictive than, "Watch this!"''',
r'''Never send a monster to do the work of an evil genius.''',
r'''Never share a foxhole with anyone braver than yourself.''',
r'''Never sleep with anyone crazier than yourself.  -- Hartley''',
r'''Never sleep with anyone whose troubles are worse than your own.''',
r'''Never stand between a fire hydrant and a dog.''',
r'''Never take a beer to a job interview, nor ask if they press charges.''',
r'''Never tell your mom her diet's not working.  -- Michael, age 14''',
r'''Never throw a bird at a dragon.''',
r'''Never tow another car using pantyhose and duct tape.''',
r'''Never trust a dog to watch your food.  -- Patrick, age 10''',
r'''Never try to baptize a cat.  -- Eileen, age 8''',
r'''Never try to outstubborn a cat.''',
r'''Never use an outhouse while holding your car keys in your mouth.  -- David Boll''',
r'''Never verb your nouns.''',
r'''Never worry about theory as long as the machinery does what it's supposed to do.''',
r'''New:  Different color from previous model.''',
r'''Niagara Falls is beautiful for thirty seconds.  -- Gertrude Stein''',
r'''Nice guys don't finish nice.''',
r'''Nice guys don't get laid.''',
r'''Nice perfume...  Must you marinate in it?''',
r'''Nice tie -- does it run on batteries?''',
r'''Nihilism should commence with oneself.''',
r'''Nine out of ten doctors agree that one out of ten doctors is an idiot.''',
r'''Nine out of ten people think they are above average.  The rest are in therapy.''',
r'''Ninety eight percent of Americans support the use of mass transit by others.''',
r'''Ninety-nine percent of lawyers give the rest a bad name.''',
r'''No brains, no headache.''',
r'''No generalization is wholly true, not even this one.  -- Oliver Holmes''',
r'''No good deed goes unpunished.  -- Andrew Mellon''',
r'''No guts, no glory.''',
r'''No job is so simple that it cannot be done wrong.''',
r'''No maintenance:  Impossible to fix.''',
r'''No major religion specifically bans the pilfering of office supplies.  -- Adams''',
r'''No man is an island, but some of us are long peninsulas.''',
r'''No man would listen to you talk if he didn't know it was his turn next.  -- Howe''',
r'''No matter how much you care, some people are just assholes.''',
r'''No matter how much you do, you never do enough.''',
r'''No matter how rich or famous you are, the laws of physics are still very strict.''',
r'''No matter what goes wrong, there's always someone who knew it would.''',
r'''No matter what happens, someone will take it too seriously.  -- Dave Barry''',
r'''No matter what occurs, someone believes it happened according to his pet theory.''',
r'''No matter what results are expected, someone is always willing to fake it.''',
r'''No matter what you do, someone always knew you would.''',
r'''No name, no matter how simple, can be correctly understood over the phone.''',
r'''No one can feel as helpless as the owner of a sick goldfish.''',
r'''No one gets too old to learn a new way of being stupid.''',
r'''No one is listening until you make a mistake.''',
r'''No one within an organization really knows what is going on.''',
r'''No prizes for predicting rain.  Prizes only awarded for building arks.''',
r'''No problem is so large it can't be fit in somewhere.''',
r'''No project is so risk-free that your company lawyer can't kill it.  -- Scott Adams''',
r'''No sentence fragments.''',
r'''No trespassing without permission.  -- sign on public school grounds''',
r'''No verb is not a crime.  No crime, no sentence.''',
r'''Nobody can be as agreeable as an uninvited guest.''',
r'''Nobody can be exactly like me.  Even I have trouble doing it.''',
r'''Nobody ever has a reservation on a plane that leaves from Gate 1.''',
r'''Nobody expects the Spanish Inquisition!''',
r'''Nobody goes there anymore 'cause it's too crowded.  -- Yogi Berra''',
r'''Nobody knows the trouble I have been.''',
r'''Nobody remembers the second person to say E = mc2.  -- N. Samios''',
r'''Nobody wants constructive criticism.  We can barely handle constructive praise.''',
r'''Nondeterminism means never having to say you are wrong.''',
r'''Nonsense.  Space is blue and birds fly through it.  -- Heisenberg''',
r'''Nostalgia just isn't what it used to be.''',
r'''Not all men are annoying.  Some are dead.''',
r'''Not all men who drink are poets.  Some of us drink because we are not poets.''',
r'''Not so random and clumsy as a blaster.  -- Obi Wan Kenobi, Star Wars''',
r'''Nothin' ain't worth nothin', but it's free.''',
r'''Nothing can be done in one trip.  -- Snider''',
r'''Nothing cures insomnia like the realization that it is time to get up.''',
r'''Nothing ever gets built on schedule or within budget.''',
r'''Nothing exceeds like excess.''',
r'''Nothing in life is so exhilarating as to be shot at without result.  -- Churchill''',
r'''Nothing increases your golf score like witnesses.''',
r'''Nothing is as inevitable as a mistake whose time has come.  -- Tussman''',
r'''Nothing is certain but the unforeseen.''',
r'''Nothing is ever a total loss; it can always serve as a bad example.''',
r'''Nothing is finished until the paperwork is done.''',
r'''Nothing is impossible or impassable if you have enough nails.''',
r'''Nothing is so impudent as success.''',
r'''Nothing is so smiple that it cannot be screwed up.''',
r'''Nothing recedes like success.  -- Walter Winchell''',
r'''Nothing ruins the truth like stretching it.''',
r'''Nothing so needs reforming as other people's habits.  -- Mark Twain''',
r'''Nothing will dispel enthusiasm like a small admission fee.  -- Kim Hubbard''',
r'''Now and then an innocent person is sent to the Legislature.''',
r'''Now it's time to say goodbye, to all our company...  M-I-C, K-E-Y, M-O-U-S-E.''',
r'''Now that I have it all, can I give some of it away?  -- Marianne Neifert''',
r'''Now, 1 + 1 is 2; 2 + 2 is 4; but 4 + 4 is the reason they make calculators!''',
r'''Nuclear war would really set back cable.  -- Ted Turner''',
r'''Nudists are people who wear one-button suits.''',
r'''Nudists are the last people you want to see naked.  -- David Sedaris''',
r'''Nugloo:  Single continuous eyebrow that covers the entire forehead.''',
r'''Occupation:  The principal thing one engages in to avoid thinking.''',
r'''Of all our privileges, the license to breed is most grossly abused.  -- Edward Abbey''',
r'''Of all the animals, the boy is the most unmanageable.  -- Plato''',
r'''Of course God loves you; He's just not ready to make a commitment.  -- Bhaerman''',
r'''Of course I am happily married -- she's happy, and I'm married.''',
r'''Of course I'm vain.  Every time I pass by a mirror I look.  -- Madonna''',
r'''Of course the game is rigged, but if you don't play, you can't win!  -- Robert Heinlein''',
r'''Often it is fatal to live too long.  -- Racine''',
r'''Oh what a tangled web we weave, when first we practice to conceive.  -- Herold''',
r'''Oh, Aunty Em, it's so good to be home!''',
r'''Oh, if faces could only talk!  --  John Madden''',
r'''Ohnosecond:  Instant in which you realize you have just made a big mistake.''',
r'''Old accountants never die; they just lose their balance.''',
r'''Old actors never die; they just drop apart.''',
r'''Old age comes at a bad time.''',
r'''Old age:  You + 20 years.''',
r'''Old bankers never die; they just lose interest.''',
r'''Old beekeepers never die; they just buzz off.''',
r'''Old cashiers never die; they just check out.''',
r'''Old chauffeurs never die; they just lose their drive.''',
r'''Old cooks never die; they just get deranged.''',
r'''Old daredevils never die; they just get discouraged.''',
r'''Old deans never die; they just lose their faculties.''',
r'''Old doctors never die; they just lose their patience.''',
r'''Old electricians never die; they just lose contact.''',
r'''Old farmers never die; they just go to seed.''',
r'''Old frogs never die; they just croak.''',
r'''Old hippies never die; they just smell that way.''',
r'''Old investors never die; they just roll over.''',
r'''Old is needing a fire permit for your birthday cake.''',
r'''Old laser physicists never die; they just become incoherent.''',
r'''Old lawyers never die; they just lose their appeal.''',
r'''Old limbo dancers never die; they just go under.''',
r'''Old MacDonald had an agricultural real estate tax abatement.''',
r'''Old mathematicians never die; they just disintegrate.''',
r'''Old milkmaids never die; they just lose their whey.''',
r'''Old musicians never die; they just get played out.''',
r'''Old numerical analysts never die; they just get disarrayed.''',
r'''Old owls never die; they just don't give a hoot.''',
r'''Old pacifists never die; they just go to peaces.''',
r'''Old photographers never die; they just stop developing.''',
r'''Old pilots never die; they just go to a higher plane.''',
r'''Old policemen never die; they just cop out.''',
r'''Old postmen never die; they just lose their zip.''',
r'''Old schools never die; they just lose their principals.''',
r'''Old sculptors never die; they just lose their marbles.''',
r'''Old seers never die; they just lose their vision.''',
r'''Old sewage workers never die; they just waste away.''',
r'''Old skiers never die; they just go downhill.''',
r'''Old steelmakers never die; they just lose their temper.''',
r'''Old students never die; they just get degraded.''',
r'''Old tanners never die; they just go into hiding.''',
r'''Old teachers never die; they just lose their class.''',
r'''Old wrestlers never die; they just lose their grip.''',
r'''Old:  A cute gal catches your fancy and your pacemaker opens your garage door.''',
r'''Omit needless words!  Omit needless words!  Omit needless words!  -- EB White''',
r'''Omniscience:  Talking only about things you know about.''',
r'''On the other hand, you have different fingers.''',
r'''On the whole, I'd rather be in Philadelphia.  -- W. C. Fields's epitaph''',
r'''On time.  No defects.  Pick one.  -- Scott Adams''',
r'''Once a fool and his money were soon parted.  Now it happens to everyone.''',
r'''Once a job is fouled up, anything done to improve it only makes it worse.''',
r'''Once is happenstance.  Twice is coincidence.  Thrice is enemy action.''',
r'''Once the trust goes out of a relationship, it's no fun lying to them anymore.''',
r'''Once there was a man who loved his wife so much, he almost told her.''',
r'''Once upon a time, charity was a virtue and not an organization.''',
r'''Once upon a time:  Back when snakes used to walk.''',
r'''Once you give up your integrity, the rest is a piece of cake.  -- J. R. Ewing''',
r'''Once you miss the first buttonhole you never manage to button up.''',
r'''Once you've seen one shopping center, you've seen a mall.''',
r'''One Bell System -- it sometimes works.''',
r'''One bit of advice:  Don't give it.''',
r'''One child is not enough, but two children are far too many.''',
r'''One day you will find yourself and be quite disappointed.''',
r'''One figure can sometimes add up to a lot.  -- Mae West''',
r'''One good thing about repeating your mistakes is that you know when to cringe.''',
r'''One good turn usually gets most of the blanket.''',
r'''One horsepower:  Energy required to drag a horse 500 feet in one second.''',
r'''One learns in life to keep silent and draw one's own confusions.  -- Skinner''',
r'''One millionth of a mouthwash = one microscope.''',
r'''One nice thing about egotists:  They don't talk about other people.''',
r'''One of us is thinking about sex...  OK, it's me.''',
r'''One picture is worth a few thousand bucks -- in the New York Times.  -- Sundqvist''',
r'''One picture is worth a thousand words.  See diagram below.''',
r'''One reason you can't take it with you is that it goes before you do.''',
r'''One seventh of your life is spent on Monday.''',
r'''One should always be a little improbable.  -- Oscar Wilde''',
r'''One should always be in love.  That is the reason one should never marry.''',
r'''One size fits all:  Doesn't fit anyone.''',
r'''One tequila, two tequila, three tequila, floor.''',
r'''One thing leads to another, and usually does.''',
r'''One way to make your old car run better is to look up the price of a new model.''',
r'''One will not have needed the future perfect in one's entire life.''',
r'''Only 55% of all Americans know that the sun is a star.''',
r'''Only adults have difficulty with childproof caps.''',
r'''Only fools are quoted.  -- Anonymous''',
r'''Only God could mess up your life that much.  -- Carolyn Myss''',
r'''Only those with nothing to be sorry for smile back at the rear of an elephant.''',
r'''Only through hard work and perseverance can one truly suffer.''',
r'''Only two groups of people fall for flattery:  Men and women.''',
r'''Opera is when a guy gets stabbed in the back, and instead of bleeding, he sings.''',
r'''Opportunity always knocks at the least opportune moment.  -- Ducharme''',
r'''Opportunity knocks only once, but temptation bangs on your door for years.''',
r'''Optimist:  Always sees the bright side of other people's problems.''',
r'''Optimist:  Thinks he can break up a traffic jam by blowing his horn.''',
r'''Optimist:  Woman who regards a bulge as a curve.''',
r'''Oratory:  The power to talk people out of their sober and natural opinions.''',
r'''Oregonians don't tan, they rust.''',
r'''Our eyes are the same size from birth, but our nose and ears never stop growing.''',
r'''Our parents were never our age.''',
r'''Our policy is, when in doubt, do the right thing.  -- Roy Ash''',
r'''Our problems are mostly behind us.  Now we have to fight the solutions.''',
r'''Our sequiturs tend to be non.''',
r'''Our vision is to speed up time, eventually eliminating it.  -- Alex Schure''',
r'''Out of the mouths of babes does often come cereal.''',
r'''Outpatient:  A person who has fainted.''',
r'''Oversteer is when the passenger is scared; understeer when the driver is scared.''',
r'''Ow:  The first word spoken by children with older siblings.''',
r'''Packrat's credo:  "I have no use for it, but I hate to see it go to waste."''',
r'''Page yourself over the intercom, and don't disguise your voice.''',
r'''Pain is just a sensory input.  -- Aussie rugby player skiing with broken thumb''',
r'''Pain is relative.  Unfortunately it's a close relative and it visits often.''',
r'''Pain is temporary.  Either it goes away, or you do.  -- York''',
r'''Pampered cows give spoiled milk.''',
r'''Panic is the second time you can't do it the first time.  -- Isaac Asimov''',
r'''Paper is always strongest at the perforations.  -- Corry''',
r'''Paradise is exactly like where you are, only MUCH, MUCH better.  -- Anderson''',
r'''Paradox of travel planning:  By the time you leave, you really need a vacation.  -- Alan Silverstein''',
r'''Paradox:  An assistant to PhDs.''',
r'''Parallel lines never meet unless you bend one or both of them.''',
r'''Paranoia:  A healthy understanding of the nature of the universe.''',
r'''Paranoid schizophrenics outnumber their enemies at least two to one.''',
r'''Pardon me, you have apparently mistaken me for someone who gives a damn.''',
r'''Part of the art of being a woman is knowing when not to be too much of a lady.''',
r'''Passionate hatred can give meaning and purpose to an empty life.  -- Eric Hoffer''',
r'''Patience is counting down without blasting off.''',
r'''Paying alimony is like feeding hay to a dead horse.  -- Groucho Marx''',
r'''Pediatricians eat, because children don't.  -- Carleton Fredericks''',
r'''Pedlock:  When a bicycle pedal wedges itself against the kickstand.''',
r'''People accept an idea more readily if you say Benjamin Franklin said it first.''',
r'''People are idiots.  -- Scott Adams''',
r'''People compelled to tell you they have a great sense of humor, have none.''',
r'''People have one thing in common:  They are all different.  -- Robert Zend''',
r'''People rarely think alike until it comes to buying wedding presents.''',
r'''People should be aware of the dangers of killing themselves.''',
r'''People usually get what's coming to them...  Unless it was mailed.''',
r'''People who concern themselves with what's cool and what's not cool are not cool.''',
r'''People who go to conferences are the ones who should not.''',
r'''People who live in glass houses should undress in the dark.''',
r'''People who live in glass houses shouldn't invite in people without sin.''',
r'''People who live in glass houses shouldn't throw parties.''',
r'''People who live in stone houses shouldn't throw glasses.''',
r'''People who say they sleep like a baby usually don't have one.  -- Leo Burke''',
r'''People who study the Bible in their old age must be cramming for their finals.''',
r'''People who take cat naps usually don't sleep in a cat's cradle.''',
r'''People who think they know everything greatly annoy those of us who do.''',
r'''People who verb nouns really weird language.''',
r'''People will buy anything that is one to a customer.  -- Lewis''',
r'''People with dogs are cowards who haven't got the guts to bite people themselves.''',
r'''People with no faults are terrible; there is no way of taking advantage of them.''',
r'''Perfect guest:  One who makes his host feel at home.''',
r'''Perfect paranoia is perfect awareness.''',
r'''Performance review:  Signed confession of your crimes against productivity.''',
r'''Perhaps men and women should live next door and just visit now and then.''',
r'''Perhaps your whole purpose in life is simply to serve as a warning to others.''',
r'''Pessimist:  Complains about the noise when opportunity knocks.''',
r'''Petrophobic:  Embarrassed to undress in front of a household pet.''',
r'''Phasers locked on target, Captain.''',
r'''Philadelphia just seems dull because it's next to exciting Camden, New Jersey.''',
r'''Philosophy:  Unintelligible answers to insoluble problems.''',
r'''Phoenix is an oasis of ugliness in the midst of a beautiful wasteland.  -- Edward Abbey''',
r'''Phonesia:  Dialing and forgetting whom you were calling just as they answer.''',
r'''Physicist:  Someone who averages the first three terms of a divergent series.''',
r'''Pioneer:  Early American lucky enough to find his way out of the woods.''',
r'''Pity the meek, for they shall inherit the Earth.  -- Don Marquis''',
r'''Pity the poor egg; it only gets laid once.''',
r'''Pizza shop slogan:  Seven days without pizza makes one weak.''',
r'''Plagiarism:  Losers must be choosers.  -- Gerhard Uhlenbruck''',
r'''Plan to be spontaneous tomorrow.''',
r'''Planet three is the place to be!  -- Rich Testardi''',
r'''Plastic explosives will be appropriate later in the week.''',
r'''Please continue dancing until the floor comes to a complete stop.  -- radio DJ''',
r'''Plumber:  A man who gets paid for sleeping under other people's sinks.''',
r'''Plunder first, THEN pillage.''',
r'''PMS:  Something that makes a woman act once a month like a man acts every day.''',
r'''Polar bear:  A rectangular bear after a coordinate transform.''',
r'''Politician:  "My father was a minister.  I had to make up for the lack of sin."''',
r'''Politicians aren't born, they're excreted.  -- Mark Twain''',
r'''Politics consists of deals and ideals.''',
r'''Politics:  The art of turning influence into affluence.''',
r'''Positive:  Being mistaken at the top of your voice.''',
r'''Possessions increase to fill the space available for their storage.  -- Ryan''',
r'''Pound for pound, the amoeba is the most vicious animal on Earth.''',
r'''Poverty is no disgrace to a man, but it is confoundedly inconvenient.  -- Smith''',
r'''Power corrupts.  Absolute power is great!''',
r'''Power means not having to respond.''',
r'''Practice makes perfect, but no one's perfect, so why practice?''',
r'''Predestination was doomed from the start.''',
r'''Prejudice doesn't have a Chinaman's chance in Chicago.  -- Richard Daley''',
r'''Pressure:  The normal force acting upon an engineer.''',
r'''Preudhomme's Law of Window Cleaning:  It's on the other side.''',
r'''Pride is what we have...  Vanity is what others have.''',
r'''Princess, having sufficient experience with princes, seeks frog...''',
r'''Princesses don't do dishes or take out garbage.''',
r'''Prisoners talk to each other on cell phones.''',
r'''Pro is to con as progress is to Congress.''',
r'''Procrastinate now.''',
r'''Procrastination means never having to say you're sorry.  -- Toni Epstein''',
r'''Procrastination:  The art of keeping up with yesterday.''',
r'''Proctologist:  A doctor who puts in a hard day at the orifice.''',
r'''Producing a system from a spec is like walking on water:  Easier if it's frozen.''',
r'''Professionals built the Titanic, but amateurs built the Ark.''',
r'''Professor:  One who talks in someone else's sleep.  -- W.H. Auden''',
r'''Progress is made on alternate Fridays.''',
r'''Progress means replacing a theory that is wrong with one more subtly wrong.''',
r'''Progress might have been all right once, but it went on too long.  -- Ogden Nash''',
r'''Proof that we don't understand death is that we give dead people a pillow.  -- Jerry Seinfeld''',
r'''Proofread carefully to see if you words out.  -- William Safire''',
r'''Proofreading is more effective after publication.  -- Barker''',
r'''Properly trained, a man can be a dog's best friend.  -- Nora Roberts''',
r'''Prose books are the show dogs I breed and sell to support my cat.  -- Graves''',
r'''Proximity isn't everything, but it comes close.''',
r'''Prunes give you a run for your money.''',
r'''Psychiatrist:  A doctor who doesn't have to worry so long as other people do.''',
r'''Psychiatry:  Figuring out the program from the printout.  -- Chris Gates''',
r'''Psychosclerosis:  Hardening of the attitude.''',
r'''Psychotheology:  A religious fervor about psychological beliefs.''',
r'''Public speaking is very easy.  -- Dan Quayle''',
r'''Puppies still have bad breath even after eating a tic-tac.  -- Andrew, age 9''',
r'''Puritanism:  The haunting fear that someone, somewhere, may be happy.  -- Mencken''',
r'''Push something hard enough and it will fall over.''',
r'''Pushing 40 is exercise enough.''',
r'''Put your nose to the grindstone and you are a bloody fool.''',
r'''Quack!''',
r'''Quality assurance doesn't.''',
r'''Quantity is no substitute for quality, but it is the only one we have.''',
r'''Quantum mechanics is incredibly easy once you take the physics out.  -- Scott Aaronson''',
r'''Quantum mechanics is nice because you can both have your cat and eat it too.''',
r'''Quark!  Quark!  Beware the quantum duck!''',
r'''Queen Victoria was the longest queen.  She sat on a thorn for 63 years.''',
r'''Question Authority...  And the Authorities will question you!''',
r'''Quidquid latine dictum sit, altum viditur.  (Anything in Latin sounds profound.)''',
r'''Quinine is the bark of a tree; canine is the bark of a dog.''',
r'''Quip pro quo:  A fast retort.''',
r'''Quit working and play for once!''',
r'''Quo signo nata es?  (What's your sign?)''',
r'''Quoting one is plagiarism.  Quoting many is research.''',
r'''Radioactive cats have 18 half-lives.''',
r'''Rain is often known as soft water, oppositely known as hail.''',
r'''Rain is saved up in cloud banks.''',
r'''Rainy days and automatic weapons always get me down.''',
r'''Raising a teenager is like trying to nail jello to a tree.  -- Steve Feidler''',
r'''Rap music is nature's way of punishing those who have lived too long.  -- Gay''',
r'''Ratio of an igloo's circumference to its diameter:  Eskimo Pi.''',
r'''Read my lips:  No new taxes.  -- George Bush''',
r'''Read the directions, even if you don't follow them.  -- Mary Schmich''',
r'''Reading the small print is education; not reading it is experience.''',
r'''Real life is not like this.''',
r'''Real women don't have hot flashes, they have power surges.''',
r'''Real Work + Appearance of Work = Total Work.  -- Scott Adams''',
r'''Reality -- what a concept!  -- Robin Williams''',
r'''Reality has a well-known liberal bias.  -- Stephen Colbert''',
r'''Reality is an illusion brought on by lack of alcohol.''',
r'''Reality is an illusion created by an intelligence deficiency.''',
r'''Reality is an obstacle to hallucination.''',
r'''Reality is for people who can't deal with drugs.  -- Lily Tomlin''',
r'''Reality is for people who can't face science fiction.''',
r'''Reality is for people who lack imagination.''',
r'''Reality is just a convenient measure of complexity.  -- Alvy Smith''',
r'''Reality is merely an illusion, albeit a very persistent one.  -- Albert Einstein''',
r'''Reality is that which, when you stop believing in it, doesn't go away.  -- Dick''',
r'''Really slow vacations involve chartering continental drift.  -- Andrew Plotkin''',
r'''Recent studies prove I don't have to be reasonable.''',
r'''Recycle old photons -- for a brighter future!''',
r'''Recycle your mother-in-law.  -- John Taylor''',
r'''Red lights always last longer than green lights.''',
r'''Refrain means don't do it.  A refrain in music is the part you better not sing.''',
r'''Refuse to have a battle of wits with an unarmed person.''',
r'''Regulations grow at the same rate as weeds.''',
r'''Rehab is for quitters.''',
r'''Reintarnation:  Coming back to life as a hillbilly.''',
r'''Religions are maintained by people who can't get laid.  -- Bill Maher''',
r'''Remember that the rabbit's foot didn't work for the rabbit.  -- Shay''',
r'''Remember to breathe when your head is above water.''',
r'''Remember to finish what''',
r'''Remember, life is not a test, it is an actual emergency.''',
r'''Repartee is something we think of twenty-four hours too late.  -- Mark Twain''',
r'''Reputation:  What others are not thinking about you.''',
r'''Research is something that tells you that a jackass has two ears.  -- Lasker''',
r'''Research is what I'm doing when I don't know what I'm doing.  -- von Braun''',
r'''Researchers often become quite attached to leeches they study, and vice versa.''',
r'''Reserve the apostrophe for it's proper use and omit it when its not needed.''',
r'''Respondez s'il vous plaid.  (Honk if you're Scottish.)''',
r'''Responsibility always exceeds authority.''',
r'''Rest assured that your dog is finally getting enough cheese.  -- Deteriorata''',
r'''Reunite Pangea!''',
r'''Right now I'm having amnesia and deja vu at the same time.  -- Wright''',
r'''Rignition:  Trying to start the car when the engine is already running.''',
r'''Roll up your sleeves...  And you won't lose your shirt.''',
r'''Rome was not built in a day.  (They worked well into the night.)  -- John Taylor''',
r'''Rome was not built in a day.  If it was, we would have hired their engineer.''',
r'''Roses are red, violets are blue, I'm schizophrenic, and so am I.''',
r'''Rubber bands have snappy endings.''',
r'''Rugged:  Too heavy to lift.''',
r'''Rumper sticker on a horse:  "Get off my tail, because shit happens."''',
r'''Russia has abolished God, but so far God has been more tolerant.  -- Swayze''',
r'''Sacred cows make the best hamburger.  -- Mark Twain''',
r'''Saddam Hussein is the father of the mother of all cliches.''',
r'''Safest way to double your money:  Fold it over once and put it in your pocket.''',
r'''Sagan:  The international unit of humility.''',
r'''Sailing is a form of mast transit.''',
r'''Sailing:  Getting wet and ill while slowly going nowhere at great expense.''',
r'''Saint:  A dead sinner revised and edited.''',
r'''Santa's helpers are subordinate clauses.''',
r'''Sarcasm is just one more service we offer.''',
r'''Sarchasm:  Gulf between the author of sarcastic wit and the clueless recipient.''',
r'''Satisfaction guaranteed, or twice your load back.  -- sign on septic tank truck''',
r'''Save energy:  Be apathetic.''',
r'''Save the whales.  Collect the whole set.''',
r'''Schedule chicken:  When no team wants to admit THEIR part will be late.''',
r'''Schroedinger's cat might have died for your sins.''',
r'''Science is a game for the fame of the name.  -- Gerhard Uhlenbruck''',
r'''Science is a wonderful thing if one does not have to earn one's living at it.''',
r'''Science is gradually filling our homes with appliances smarter than we are.''',
r'''Science is material.  Religion is immaterial.''',
r'''Scientists are explorers; philosophers are just tourists.  -- Richard Feynman''',
r'''Scientists prolong life so we have time to pay for the gadgets they invent.''',
r'''Scotty, beam me up a double!''',
r'''Sculpture:  Mud pies that endure.''',
r'''Second marriage is the triumph of hope over experience.''',
r'''See no evil, hear no evil, date no evil.''',
r'''Seeing is deceiving.  It's eating that's believing.  -- James Thurber''',
r'''Seek and ye shall have sought.  -- John Taylor''',
r'''Seek simplicity -- and distrust it.  -- Alfred Whitehead''',
r'''Seen it all, done it all, can't remember most of it.''',
r'''Self-control:  The ability to eat only one peanut.''',
r'''Self-delusion:  Pulling in your stomach when you step on the scale.  -- Sweeney''',
r'''Serendipity:  The process by which human knowledge is advanced.''',
r'''Serving coffee on aircraft causes turbulence.''',
r'''Sex for money usually costs a lot less than sex for free.  -- Brendan Francis''',
r'''Sex has no calories.''',
r'''Sex is dirty only when it's done right.  -- Woody Allen''',
r'''Sex is hereditary.  If your parents never had it, chances are you won't either.''',
r'''Sex is like air:  It's not important unless you aren't getting any.''',
r'''Sex is not the answer.  Sex is the question.  "Yes" is the answer.  -- Swami X''',
r'''Sex is so popular because it's centrally located.''',
r'''Sex is the most fun you can have without laughing.''',
r'''Sex on television can't hurt you unless you fall off.''',
r'''Sex takes up the least amount of time and causes the most amount of trouble.''',
r'''Shakespeare never made much money and is famous only because of his plays.''',
r'''Shakespeare thought more of the lady than of the poem.  -- F. Scott Fitzgerald''',
r'''Shakespeare was a dramatist of note who lived by writing things to quote.''',
r'''She got her good looks from her father:  He's a plastic surgeon.''',
r'''She is always late.  Her ancestors arrived on the June Flower.''',
r'''She loves you as much as she can, which is not very much.''',
r'''She walks as if balancing the family tree on her nose.''',
r'''She was a sigh to behold.  -- John Taylor''',
r'''She was all signs and no scenery.  -- John Taylor''',
r'''She was suffering from fallen archness.  -- Franklin Adams''',
r'''She's the kind of girl who climbed the ladder of success wrong by wrong.  -- West''',
r'''Should vegetarians eat animal crackers?''',
r'''Show off:  A child who is more talented than yours.''',
r'''Shower the people you love with love.  Shower with the people you love.''',
r'''Shut her down Scotty, she's sucking mud again!''',
r'''Sign at a bar:  We install and service hangovers.''',
r'''Sign at towing company:  We don't charge an arm and a leg.  We want tows.''',
r'''Sign in counselor's office:  Growing old is mandatory; growing wise is optional.''',
r'''Sign in electrician's office:  Let us remove your shorts.''',
r'''Sign in plumber's shop:  We repair what your husband fixed.''',
r'''Sign in tire shop:  Invite us to your next blowout.''',
r'''Sign in vet's office:  All unattended children will be given a free kitten.''',
r'''Sign in veterinarian's office:  Be back in five minutes.  Sit!  Stay!''',
r'''Sign on a fence:  Salesmen welcome...  Dog food is expensive.''',
r'''Sign on bank:  "FREE BOTTLE OF CHIVAS WITH EVERY MILLION-DOLLAR DEPOSIT."''',
r'''Silly is a state of mind.  Stupid is a way of life.''',
r'''Since I'm not handicapped by facts, I'm free to speculate.  -- Jim Randle''',
r'''Smile!  It is the second best thing you can do with your lips.''',
r'''Smile!  You're on Candid Camera.''',
r'''Smile, tomorrow will be worse.''',
r'''Smile...  People will wonder what you have been up to.''',
r'''Smoking is one of the leading causes of statistics.  -- Fletcher Knebel''',
r'''Snackmosphere:  The 95% air inside bags of potato chips.''',
r'''Snow and adolescence are problems that disappear if you ignore them long enough.''',
r'''So long, and thanks for all the fish.  -- Douglas Adams''',
r'''So many men, so little time.  -- Mae West''',
r'''So what if we get half what we want; we asked for twice what we needed.  -- Taylor''',
r'''So, what's the speed of dark?''',
r'''Socialism is based on the assumption that you can break even.''',
r'''Socrates died from an overdose of wedlock.''',
r'''Solipsism:  I think, therefore you are.  -- Larry Byler''',
r'''Solipsists of the world, unite!  -- Freya Harris''',
r'''Soloist:  One man falling alone.  Roped party:  Several men falling together.''',
r'''Solomon, one of David's sons, had 500 wives and 500 porcupines.''',
r'''Some are wise, and some are otherwise.''',
r'''Some circumstantial evidence is very strong, as finding a trout in the milk.''',
r'''Some days are more expensive than others.''',
r'''Some days you're the dog; some days you're the hydrant.''',
r'''Some days you're the pigeon, and some days you're the statue.''',
r'''Some is good, more is better, too much is just right.''',
r'''Some make things happen; some watch what happens; some wonder what happened.''',
r'''Some men are discovered; others are found out.''',
r'''Some mornings it's just not worth chewing through the leather straps.  -- Phillips''',
r'''Some of us quit looking for work when we find a job.''',
r'''Some of what we know is false.  The problem is figuring out what.''',
r'''Some people cause happiness wherever they go; others, whenever they go.''',
r'''Some people must get a whole lot older to become a little bit wiser.''',
r'''Some people who can, should not.''',
r'''Some people would not recognize subtlety if it hit them on the head.''',
r'''Some people wouldn't recognize diplomacy even if you rubbed their faces in it.''',
r'''Some persons are very decisive when it comes to avoiding decisions.  -- Francis''',
r'''Some prefer the happiness of pursuit to the pursuit of happiness.''',
r'''Some trails are uphill in both directions.''',
r'''Someday they'll collect our skulls and refer to us as "early man".''',
r'''Someday you will get your big chance -- or have you already had it?''',
r'''Someday you will look back on this moment and plow into a parked car.''',
r'''Someday, we'll look back on this, laugh nervously, and change the subject.''',
r'''Someone is speaking well of you.  How unusual!''',
r'''Sometimes a cigar is just a cigar.  -- Sigmund Freud''',
r'''Sometimes people don't recognize how wise you are.  -- Paul Holdeman''',
r'''Sorry about the dinosaurs...  Can I have all my iridium back?  -- David Mitchell''',
r'''Sorry, but my karma just ran over your dogma.''',
r'''Sounds like a head thing.  I don't much believe in head things.  -- Jenny Pruett''',
r'''Sounds like a personal problem to me.''',
r'''Souport publik edekasion.''',
r'''South America has cold summers and hot winters, but somehow they still manage.''',
r'''Spare no expense to save money on this one.  -- Samuel Goldwyn''',
r'''Speak softly and carry a cellular phone.''',
r'''Speaking of trade relations, almost everyone would like to.''',
r'''Specialists are people who always repeat the same mistakes.  -- Walter Gropius''',
r'''Speed is n subsittute fo accurancy.''',
r'''Speed of a tortoise breaking the sound barrier:  Mach Turtle.''',
r'''Spelling is a lossed art.''',
r'''Spending on the military doesn't increase the deficit.  -- Ronald Reagan''',
r'''Spinster:  A bachelor's wife.''',
r'''Spirobits:  The frayed bits of left-behind paper in a spiral notebook.''',
r'''Spock:  We suffered 23 casualties in that attack, Captain.''',
r'''SPQR:  What every Roman always knew:  Small Profit Quick Return!''',
r'''Stalin's grave is a communist plot.''',
r'''Standing on head makes smile of frown, but rest of face also upside down.''',
r'''Start every day off with a smile and get it over with.  -- W.C. Fields''',
r'''Statisticians do it with 95 percent confidence.''',
r'''Statistics are used as a drunk uses lampposts:  For support, not illumination.''',
r'''Stay away from flying saucers today.''',
r'''Stealing a rhinoceros should not be attempted lightly.''',
r'''Steer clear of incorrect forms of verbs that have snuck in the language.''',
r'''Stock item:  We shipped it once before and we can do it again.''',
r'''Stop committing useless mistakes.  Make your next mistake count!''',
r'''Strangers are friends you haven't bled for twenty bucks yet.''',
r'''Strategy is when you keep firing so the enemy doesn't know you're out of ammo.''',
r'''Street lights timed for 35 mph are also timed for 70 mph.  -- Jim Samuels''',
r'''Stress:  When you wake up screaming and you realize you didn't fall asleep yet.''',
r'''Stupid:  Losing $25 on the game, and $25 more on the instant replay.''',
r'''Stupidity got us into this mess -- why can't it get us out?''',
r'''Stupidity is a renewable resource.''',
r'''Stupidity is not a survival trait.''',
r'''Subject and verb always has to agree.''',
r'''Suburbia:  Where they tear out the trees and then name streets after them.''',
r'''Success always occurs in private, and failure in full view.''',
r'''Success comes in cans, failure in can'ts.''',
r'''Success is relative.  The more success the more relatives.''',
r'''Success is something I will dress for when I get there, and not until.''',
r'''Success:  The ability to go from failure to failure without being discouraged.''',
r'''Successful man:  One who makes more money than his son at college can spend.''',
r'''Successful people:  Those who think up things to keep everyone else busy.''',
r'''Suffering is not the object of adventure; it's just a byproduct.  -- Alan Silverstein''',
r'''Suicide is man's way of telling God, "You can't fire me.  I quit."  -- Bill Maher''',
r'''Suicide is the sincerest form of self-criticism.  -- Donald Kaul''',
r'''Superiority is a recessive trait.''',
r'''Support Search & Rescue:  GET LOST!''',
r'''Sure fire diet:  Swallowing pride.''',
r'''Sure it will sell product, but will it win awards?  -- advertising agency''',
r'''Sure we can laugh at ourselves, but laughing at other people is more fun.''',
r'''Surly grammarians insist that all words ending in "ly" are adverbs.''',
r'''Survivors eat anything.  Non-survivors taste a lot like chicken.  -- Papa Bear Whitmore''',
r'''Sweater:  A garment worn by a child when his parent feels chilly.''',
r'''Swimming pool:  A mob of people with water in it.''',
r'''Swiped out:  ATM or credit card rendered useless by wearing away the magstripe.''',
r'''System-independent:  Works equally poorly on all systems.''',
r'''T shirt:  I have a degree in liberal arts...  Do you want fries with that?''',
r'''Tact is the unsaid part of what you are thinking.''',
r'''Tact:  Changing the subject without changing the mind.''',
r'''Take everything in stride.  Trample anyone who gets in your way.''',
r'''Take it easy, we're in a hurry.''',
r'''Take me drunk, I'm home.  -- John Taylor''',
r'''Take the bull by the hand and avoid mixing metaphors.  -- William Safire''',
r'''Take time to stop and smell the roses, and sooner or later, you'll inhale a bee.''',
r'''Take what comfort there may be in owning a piece thereof.  -- Deteriorata''',
r'''Take your low opinion of yourself somewhere else, will you?''',
r'''Talent does what it can; genius does what it must; I do what I am paid to do.''',
r'''Talk is cheap because the supply exceeds the demand.''',
r'''Talk is cheap, unless you hire a lawyer.''',
r'''Taxation WITH representation isn't so hot, either!''',
r'''Taxes are going up so fast, the government might price itself out of the market.''',
r'''Taxes:  The one of life's two certainties for which you can get an extension.''',
r'''Taxpayers don't have to take a civil service exam to work for the government.''',
r'''Teach your kids the value of money -- borrow from them.''',
r'''Teachers are the only profession that teach our children.  -- Dan Quayle''',
r'''Teamwork is essential; it allows you to blame someone else.''',
r'''Technique:  A trick that works.''',
r'''Technological progress provides us with more efficient means of going backwards.''',
r'''Technology can be used for good or evil.  Please use only for good.''',
r'''Technology simply means finding the right wrench to pound in the correct screw.''',
r'''Teenagers are two year olds with hormones and wheels.  -- Will Limon''',
r'''Teenagers never consider that someday they'll know as little as their parents.''',
r'''Telepathy:  Knowing what people think when really they don't think at all.''',
r'''Tell a man a bench has wet paint on it and he'll have to touch to be sure.''',
r'''Tell me what you need, and I'll tell you how to get along without it.''',
r'''Terrorists blow up celluloid factory...  No film at 11.''',
r'''Texans are southerners with an attitude.''',
r'''Texas remains our largest unfrozen state.  -- Edward Abbey''',
r'''Thank God we can't prove he exists.  -- John Taylor''',
r'''Thank you for observing all safety precautions.''',
r'''Thank you for sending me a copy of your book; I'll waste no time reading it.''',
r'''Thank you.  We're all refreshed and challenged by your unique point of view.''',
r'''That man's silence is wonderful to listen to.  -- Thomas Hardy''',
r'''That must be wonderful; I don't understand it at all.  -- Moliere''',
r'''That that is is that that is not is not.''',
r'''That which does kill us makes us smell stronger, after a few days anyway.''',
r'''The 51st state of the USA is paranoia.''',
r'''The adjective is the banana peel of the parts of speech.  -- Clifton Fadiman''',
r'''The adverb always follows the verb.  -- William Safire''',
r'''The amount of sleep required by the average person is five minutes more.  -- Wilson Mizener''',
r'''The amount of work done varies inversely with the time spent in the office.''',
r'''The arrival of a baby coincides with the departure of our minds.  -- Bill Cosby''',
r'''The beatings will continue until morale improves.''',
r'''The beginning of family values is not eating dead relatives.  -- Robert Bakker''',
r'''The best car safety device is a rearview mirror with a cop in it.  -- Dudley Moore''',
r'''The best cure for insomnia is a Monday morning.  -- Sandy Cooley''',
r'''The best cure for insomnia is to get a lot of sleep.  -- W. C. Fields''',
r'''The best laid plans of mice and men are usually about equal.  -- Blair''',
r'''The best parachute folders are those who jump themselves.''',
r'''The best thing about growing older is that it takes such a long time.''',
r'''The best time to buy anything is last year.''',
r'''The best vacations are spent near the budget.''',
r'''The best way out of yourself is through someone else.  -- Norris Burkes''',
r'''The best way to get over someone is to get under someone else.''',
r'''The best way to inspire fresh thoughts is to seal the envelope.''',
r'''The bigger they are, the harder they hit.''',
r'''The biggest fish he ever caught were those that got away.  -- Eugene Field''',
r'''The blunders are all there on the chessboard waiting to be made.  -- Tartakower''',
r'''The bureaucracy expands to meet the needs of an expanding bureaucracy.''',
r'''The careful application of terror is also a form of communication.''',
r'''The cart has no place where a fifth wheel could be used.''',
r'''The celebrity is a person who is known for his well-knownness.  -- Boorstin''',
r'''The chances of being eaten by a tiger are one in a million, but once is enough.''',
r'''The chicken was the egg's idea of getting more eggs.  -- Samuel Butler''',
r'''The chief cause of problems is solutions.''',
r'''The Christmas presents of today are the garage sales of tomorrow.''',
r'''The clairvoyants meeting was canceled due to unforeseen circumstances.''',
r'''The climate of Bombay is such that its inhabitants have to live elsewhere.''',
r'''The clothes that make a woman are the clothes that break a man.''',
r'''The coldest winter I ever spent was a summer in San Francisco.  -- Mark Twain''',
r'''The cost of feathers is higher.  Down is up.''',
r'''The cost of living is going up, and the chance of living is going down.''',
r'''The covers of this book are too far apart.  -- Ambrose Bierce''',
r'''The cow is a machine that makes grass fit for us people to eat.  -- John McNulty''',
r'''The cow is of the bovine ilk; one end is moo, the other, milk.  -- Ogden Nash''',
r'''The crucial thing for a writer is the ability to make up coherent words.''',
r'''The cure for boredom is curiosity.  There is no cure for curiosity.''',
r'''The dandelion song:  I fought the lawn, and the lawn won.''',
r'''The day is the same length as anything that is the same length as it.  -- Carroll''',
r'''The day will happen whether or not you get up.  -- John Ciardi''',
r'''The days just before marriage are like a snappy introduction to a tedious book.''',
r'''The death rate on Earth is:  One per person.''',
r'''The decision does not have to be logical; it was unanimous.''',
r'''The difference between a good haircut and a bad one is seven days.''',
r'''The difference between a lady and a tramp is about three drinks.''',
r'''The difference between a wife and a mistress is night and day.  -- Dear Abby''',
r'''The difference between genius and idiocy:  Genius has its limits.  -- Darwin Awards''',
r'''The difficult we do immediately; the impossible takes a little longer.  -- USACE''',
r'''The doctor felt the patient's purse and said there was no hope.''',
r'''The dog's life is a good life, for a dog.  -- Edward Abbey''',
r'''The eager beaver works twice as hard but does not know why.''',
r'''The early bird gets the worm, but the second mouse gets the cheese.''',
r'''The early worm gets eaten first.''',
r'''The early worm gets the late bird.''',
r'''The earth is like a tiny grain of sand, only much, much heavier.''',
r'''The Earth makes one resolution every 24 hours.''',
r'''The eastern part of Asia is called Euthanasia.''',
r'''The Egyptians built the Pyramids in the shape of a huge triangular cube.''',
r'''The English spell much better than they pronounce.  -- Mark Twain''',
r'''The essence of being human is not understanding the opposite sex.''',
r'''The face of a child can say it all, especially the mouth part of the face.''',
r'''The fact that it works is immaterial.  -- Ogborn''',
r'''The facts, although interesting, are irrelevant.''',
r'''The famous politician was trying to save both his faces.''',
r'''The fastest way to discover all your bad habits is to move in with your lover.''',
r'''The fewer the data points, the smoother the curve.  -- May''',
r'''The first liar has a significant advantage.  -- Lawrence Hirsch''',
r'''The first myth about management is that it exists.  -- Robert Heller''',
r'''The first novel ever written on a typewriter was "Tom Sawyer".''',
r'''The first piece of luggage out of the chute does not belong to anyone, ever.''',
r'''The first rule of gun fighting is -- bring a gun.''',
r'''The first rule of intelligent tinkering is to save all the parts.  -- Ehrlich''',
r'''The first step in learning from your mistakes is admitting you took the course.''',
r'''The first thing I do in the morning is brush my teeth and sharpen my tongue.''',
r'''The first thing that strikes a stranger in New York is a big car.  -- Evan Esar''',
r'''The first thing we do, let's kill all the lawyers.  -- William Shakespeare''',
r'''The flush toilet is the basis of Western civilization.  -- Alan Coult''',
r'''The following statement is not true...''',
r'''The Forecaster Hall of Fame is an empty room.  -- Jane Quinn''',
r'''The four seasons are salt, pepper, mustard, and vinegar.''',
r'''The French for London is Paris.  -- Ionesco''',
r'''The future is a myth created by insurance salesmen and high school counselors.''',
r'''The future will be better tomorrow.  -- Dan Quayle''',
r'''The general direction of the Alps is straight up.''',
r'''The golfer wore two pairs of pants in case he got a hole in one.''',
r'''The grass is always greener on the other side of your sunglasses.''',
r'''The hardest thing in the world to understand is the income tax.  -- Einstein''',
r'''The hardest thing to stop is a temporary chairman.  -- Kin Hubbard''',
r'''The hardest years in life are those between ten and seventy.  -- Helen Hayes''',
r'''The heart has its reasons, and the endocrines have theirs.  -- Aldous Huxley''',
r'''The highway of life is always under construction.''',
r'''The holodeck will be society's last invention.  -- Scott Adams''',
r'''The House of Representatives is really a substitute for violence.  -- Gephardt''',
r'''The human mind is a big place and it is very easy to get lost in it.''',
r'''The idea is to die young as late as possible.  -- Ashley Montague''',
r'''The income tax has made more liars out of the American people than golf has.''',
r'''The invention of the steamboat caused a network of rivers to spring up.''',
r'''The IRS has what it takes to take what you've got.''',
r'''The key to longevity is to keep breathing.  -- Sophie Tucker''',
r'''The knack of flying is learning how to throw yourself at the ground and miss.''',
r'''The last person who said that, God rest his soul, lived to regret it.''',
r'''The law of gravity says no fair jumping up without coming back down.''',
r'''The law of gravity was enacted by the British Parliament.''',
r'''The least experienced fisherman always catches the biggest fish.''',
r'''The length of a meeting rises with the square of the number of people present.''',
r'''The light at the end of the tunnel is the headlight of an approaching train.''',
r'''The lion and the calf shall lie down together but the calf won't get much sleep.''',
r'''The locals treat the speed limits as short works of numeric fiction.  -- Robert Niland''',
r'''The longest one-syllable word in the English language is "screeched".''',
r'''The longest recorded flight of a chicken is thirteen seconds.''',
r'''The march of his intellect is like that of a crab, backward.  -- Peacock''',
r'''The meek shall inherit the Earth -- they are too weak to refuse.''',
r'''The meek shall inherit the Earth after we are done with it.''',
r'''The meek shall inherit the earth, but not its mineral rights.  -- J. Paul Getty''',
r'''The moon is a planet just like the Earth, only it is even deader.''',
r'''The more keys you have, the more likely to be you are locked out.''',
r'''The more people I meet, the more I like my dog.''',
r'''The more things change, the more they stay insane.  -- Tom Weller''',
r'''The more things change, the more they will never be the same again.''',
r'''The mosquito is the state bird of New Jersey.  -- Andy Warhol''',
r'''The most common name in the world is Mohammed.''',
r'''The most dangerous part about playing cymbals is near the nose.''',
r'''The most effective way to remember your wife's birthday is to forget it once.''',
r'''The most enjoyable form of sex education is the Braille method.''',
r'''The most popular after-dinner speech is, "Waiter, bring me the check".''',
r'''The most popular labor saving device is still a husband with money.  -- Joey Adams''',
r'''The moving finger having writ...  Gestures.''',
r'''The Navy, it's not just a job, it's an extended middle-east vacation cruise.''',
r'''The Neanderthal's brain was bigger than yours.''',
r'''The next thing I say will be true.  The last thing I said was false.''',
r'''The nice thing about standards is that there are so many of them to choose from.''',
r'''The number one thing only women understand:  Other women.''',
r'''The number watching you is proportional to the stupidity of your action.''',
r'''The number you have dialed is imaginary.  Please multiply by i and dial again.''',
r'''The older a man gets, the farther he had to walk to school as a boy.''',
r'''The older I get, the better I used to be.  -- William Keogh''',
r'''The oldest known goldfish lived to 41 years of age.  Its name was Fred.''',
r'''The one day you would sell your soul for something, souls are a glut.''',
r'''The one thing I can do better than anyone else is talk about myself.  -- Cook''',
r'''The one who says it can't be done should never interrupt the one doing it.''',
r'''The only "ism" Hollywood believes in is plagiarism.  -- Dorothy Parker''',
r'''The only bad publicity is your obituary.  -- Cynthia Typaldos''',
r'''The only easy day was yesterday.''',
r'''The only problem with poetic justice is that it doesn't know when to quit.''',
r'''The only reason I feel guilty about masturbation is because I do it so badly.  -- David Steinberg''',
r'''The only short meetings are when no one shows up.''',
r'''The only thing to do with good advice is pass it on.  -- Oscar Wilde''',
r'''The only thing worse than being talked about is not being talked about.''',
r'''The only thing wrong with doing nothing is that you never know when you're done.''',
r'''The only time people work like a horse is when the boss rides them.''',
r'''The only time the world beats a path to your door is if you're in the bathroom.''',
r'''The only tools some people are competent to use are a pen and a checkbook.''',
r'''The only way to get rid of a temptation is to yield to it.  -- Oscar Wilde''',
r'''The opera isn't over until the fat lady sings.''',
r'''The optimist invents the airplane.  The pessimist invents the parachute.''',
r'''The optimum committee has no members.  -- Norman Augustine''',
r'''The other line always moves faster.''',
r'''The overwhelming majority of people have more than the average number of legs.''',
r'''The past is another country; they do things differently there.''',
r'''The patient, be he dead or alive, needs a doctor's order to be released.''',
r'''The pen is mightier than the pencil.''',
r'''The perfect lover would turn into a pizza at 4 am.''',
r'''The person who walks alone is soon trailed by the FBI.  -- Wright Morris''',
r'''The perversity of the universe tends toward a maximum.  -- Finagle''',
r'''The phrase "working mother" is redundant.  -- Jane Sellman''',
r'''The pistol of a flower is its only protection against insects.''',
r'''The player who wins a game is the one who has made the second-to-last mistake.''',
r'''The plural of "musical instrument" is "orchestra".''',
r'''The poor are rightfully the property of the rich, because the rich made them.''',
r'''The poor ye have with ye always -- but they are not invited.  -- Addison Mizner''',
r'''The prairies are vast plains covered by treeless forests.''',
r'''The problem with the future is that it keeps turning into the present.  -- Hobbes''',
r'''The problem with the gene pool is that there is no lifeguard.''',
r'''The process of turning steam back into water again is called conversation.''',
r'''The proper basis for marriage is mutual misunderstanding.  -- Oscar Wilde''',
r'''The punishment for bigamy is two mothers-in-law.''',
r'''The purpose of the body is to carry the brain around.  -- Thomas Edison''',
r'''The Pyramids are a range of mountains between France and Spain.''',
r'''The race is not always to the swift...  But that's the way to bet.  -- Runyon''',
r'''The Ranger isn't gonna like it, Yogi.''',
r'''The rate at which a disease spreads through a corn field:  The speed of blight.''',
r'''The real thing does not advertise.''',
r'''The reason people sweat is so they won't catch fire when making love.  -- Don Rose''',
r'''The reason to have children is to give yourself immortality.  -- Bill Cosby''',
r'''The richer your friends, the more they will cost you.''',
r'''The rings of Saturn are composed entirely of lost luggage.''',
r'''The road of life is paved with flat squirrels who couldn't make a decision.''',
r'''The road to success is filled with women pushing their husbands along.  -- Dewar''',
r'''The role of culture is to enable us to talk nonsense with distinction.  -- Maugham''',
r'''The rooster may crow, but the hen delivers.''',
r'''The scenery in the play was beautiful, but the actors got in front of it.''',
r'''The Schizophrenic:  An Unauthorized Autobiography.  -- Mark Hogue''',
r'''The scientific name for an animal that doesn't fight its enemies is "lunch".''',
r'''The second best policy is dishonesty.''',
r'''The secret of being a bore is to tell everything.  -- Voltaire''',
r'''The secret of life is to look good at a distance.  -- Snoopy''',
r'''The secret of success is discovering at an early age that you are not God.''',
r'''The secret of success is sincerity.  Once you can fake that, you have it made.''',
r'''The secret told in confidence is repeated with the same discretion.  -- McKeown''',
r'''The seminar for time travel will be held two weeks ago.''',
r'''The severity of an itch is inversely proportional to your reach.''',
r'''The sex act is the funniest thing on the face of this Earth.  -- Diana Rigg''',
r'''The shortest distance between two jokes is a straight line.''',
r'''The shortest distance between two points is no fun.''',
r'''The shortest distance between two points is through hell.  -- Brian Clark''',
r'''The shortest distance between two points is under construction.  -- Altito''',
r'''The sixth sheik's sixth sheep's sick.''',
r'''The Society of Independent People has no members.''',
r'''The sooner you fall behind, the more time you have to catch up.  -- Ogden''',
r'''The stapler runs out of staples only while you are trying to staple something.''',
r'''The stock market takes the stairs up but the elevator down.''',
r'''The supernova makes Mt. St. Helens and Krakatoa look puny.  -- Time Magazine''',
r'''The theory of evolution was greatly objected to because it made men think.''',
r'''The things that interest people most are usually none of their business.''',
r'''The three most expensive cuts:  Sirloin, tenderloin, and vasectomy.''',
r'''The three stages of sex in marriage:  Tri-weekly; try-weekly; try-weakly.''',
r'''The total intelligence on the planet is a constant; the population is growing.''',
r'''The Tree of Learning bears the noblest fruit, but noble fruit tastes bad.''',
r'''The trouble with a kitten is that, when it grows up, it is always a cat.  -- Nash''',
r'''The trouble with being punctual is that no one is there to appreciate it.''',
r'''The trouble with cash flow is that the tide always seems to be going out.''',
r'''The trouble with political jokes is that they get elected.  -- Henry Cate VII''',
r'''The trouble with socialism is socialists, and with capitalism is capitalists.  -- Willi Schlamm''',
r'''The two great tragedies in life:  Not getting what one wants, and getting it.''',
r'''The two kinds of egotists:  Those who admit it, and the rest of us.''',
r'''The two most beautiful words in the English language:  "Check Enclosed".''',
r'''The two most common things in the universe are hydrogen and stupidity.''',
r'''The universe is a big place, perhaps the biggest.  -- Kilgore Trout''',
r'''The universe is surrounded by whatever it is that surrounds universes.''',
r'''The universe will soon need replacing.  It's not holding a charge.  -- Chilton''',
r'''The vast majority of the mass of the universe seems to be missing.  -- Broad''',
r'''The voices in my head tell me I'm perfectly sane.  -- Cristina Rad''',
r'''The voices in my head told me to come over and talk with you.''',
r'''The wages of sin are probably not what you're making now.  -- John Taylor''',
r'''The weather at home improves as soon as you go away.  -- Gomme''',
r'''The weather is here, I wish you were beautiful.  -- Jimmy Buffett''',
r'''The whole world is a tuxedo and you are a pair of brown shoes.''',
r'''The wind blows harder in the summer so the sun sets later.''',
r'''The winds of change aren't what they used to be.  -- Scott Adams''',
r'''The wiser and more conscious you become, the crazier you will appear to others.''',
r'''The Wonder Bra will give a cucumber a cleavage.''',
r'''The word today is legs...  Spread the word.''',
r'''The world is a toy box full of sub-optimized and feature-poor toys.  -- Adams''',
r'''The world is run by C students.''',
r'''The world isn't any worse.  It's just that the news coverage is so much better.''',
r'''The world's a stage and most of us are desperately unrehearsed.  -- Sean O'Casey''',
r'''The worst jolt most of us ever get is when we fall back on our own resources.''',
r'''The worst thing about censorship is xxxxxxxxxx.''',
r'''The worst you can say about God is that he's an underachiever.  -- Woody Allen''',
r'''The young wish to give their elders the full benefits of their inexperience.''',
r'''The zebra is chiefly used to illustrate the letter Z.''',
r'''Therapy is expensive; popping bubble wrap is cheap!  You choose.''',
r'''There are 26 vitamins in all, but some of the letters are yet to be discovered.''',
r'''There are 336 dimples on a regulation golf ball.''',
r'''There are as many grammars as there are grammarians.  -- Erasmus''',
r'''There are better things than money in this life, but it takes money to buy them.''',
r'''There are bunches of errors in this book, except this one.  -- Christer Sundqvist''',
r'''There are many excuses for being late, but there are none for being early.''',
r'''There are many experts on child raising who have no children.  -- Bill Cosby''',
r'''There are many kinds of people in the world.  Are you one of them?''',
r'''There are moments when art attains almost to the dignity of manual labor.''',
r'''There are more collect calls on Father's Day than on any other day of the year.''',
r'''There are more fish taken out of a stream than ever were in it.  -- Oliver Herford''',
r'''There are more old drunkards than old doctors.''',
r'''There are more things in heaven and Earth than anyplace else.  -- Tom Weller''',
r'''There are no bad haircuts in cyberspace.  -- Dave Barry''',
r'''There are no failures at a class reunion.''',
r'''There are no stupid questions, but there are a lot of inquisitive idiots.''',
r'''There are people who mention the word "umbrella" for no apparent reason.''',
r'''There are so many Smiths in the phone book because they all have phones.''',
r'''There are three sides to every issue:  For, Against, and "Who Cares?"''',
r'''There are two instruments worse than a clarinet:  Two clarinets.''',
r'''There cannot be a crisis next week.  My schedule is already full.  -- Kissinger''',
r'''There comes a time in every man's life, and I've had plenty of them.  -- Stengel''',
r'''There is a 20% chance of tomorrow.''',
r'''There is a fine line between courage and foolishness.  Too bad it's not a fence.''',
r'''There is a green, multi-legged creature crawling on your shoulder.  -- Spock''',
r'''There is a non-empty set in every aggregate, undoubtedly shouting something.''',
r'''There is a time and a place for everything:  8 o'clock, my place, everything.''',
r'''There is a vas deferens between men and women.''',
r'''There is a very fine line between "hobby" and "mental illness".''',
r'''There is absolutely no substitute for a genuine lack of preparation.''',
r'''There is always more hell that needs raising.  -- Lauren Leveut''',
r'''There is always one more imbecile than you counted on.''',
r'''There is an alarming increase in the number of things you know nothing about.''',
r'''There is an old proverb that says just about whatever you want it to.''',
r'''There is another advantage of being poor; a doctor will cure you faster.''',
r'''There is at least one fool in every married couple.''',
r'''There is exactly one true categorical statement.  -- John Kessenich''',
r'''There is intelligent life on Earth, but I am just visiting.''',
r'''There is life after death:  In Chicago, dead people are still allowed to vote.''',
r'''There is no bad beer.  Some kinds are better than others.  -- German Proverb''',
r'''There is no devil; it's God when he's drunk.''',
r'''There is no distinctly native American criminal class except Congress.  -- Twain''',
r'''There is no excuse for laziness, but I am working on it.''',
r'''There is no fool like an old fool, because he's experienced.''',
r'''There is no future in time travel.''',
r'''There is no problem a good miracle can't solve.  -- Shick''',
r'''There is no problem between us that cannot be solved by your departure.  -- Mark Twain''',
r'''There is no psychiatrist in the world like a puppy licking your face.  -- Williams''',
r'''There is no remedy for sex but more sex.''',
r'''There is no room in the drug world for amateurs.  -- Raoul Duke''',
r'''There is no substitute for good manners, except, perhaps, fast reflexes.''',
r'''There is no such thing as a little garlic.''',
r'''There is no time like the pleasant.''',
r'''There is no time like the present to postpone what you ought to be doing.''',
r'''There is nothing more permanent than a temporary tax.''',
r'''There is nothing wrong with sobriety in moderation.  -- John Ciardi''',
r'''There is nothing wrong with teenagers that reasoning with them won't aggravate.''',
r'''There is nothing wrong with you that Prozac and a polo mallet wouldn't fix.''',
r'''There is nothing you can do that can't be done.''',
r'''There is only one difference between a madman and me.  I am not mad.  -- Dali''',
r'''There is only one way up a mountain, but 360 ways down.''',
r'''There is so much comedy on television.  Does that cause comedy in the streets?''',
r'''There is so much to say, but your eyes keep interrupting me.''',
r'''There is something to be said for originality, but I can't remember what it is.''',
r'''There is very little future in being right when your boss is wrong.''',
r'''There isn't room enough in this dress for both of us.''',
r'''There must be more to life than sitting wondering if there is more to life.''',
r'''There's a lot to be said for denial; sit back and enjoy the ride!  -- Chidester''',
r'''There's no such thing as bad weather, only bad clothing.  -- Garrison Keillor''',
r'''There's only one alternative to getting older, so suck it up.  -- Whoopi Goldberg''',
r'''They also serve who only pay their dues.  -- The SETI League, Inc''',
r'''They also surf who only stand on waves.''',
r'''They call television a medium because it's neither rare nor well done.  -- Kovacs''',
r'''They couldn't hit an elephant at this dist...  -- last words of General Sedgwick''',
r'''They said, "Say no to drugs," so I did, but it had no effect on my aspirin.''',
r'''They took some of the Van Goghs, most of the jewels, and all of the Chivas!''',
r'''Things are going to get a lot worse before they get worse.  -- Lily Tomlin''',
r'''Things are more like they are today then they ever were before.  -- Eisenhower''',
r'''Things are more like they used to be than they are now.''',
r'''Things equal to nothing else are equal to each other.''',
r'''Things look better when they are falling down.  -- Hanif Kureshi''',
r'''Things that upset a terrier may pass virtually unnoticed by a Great Dane.''',
r'''Things to do today:  1. Get up.  2. Survive.  3. Go to bed.''',
r'''Things to do today:  1. Hunt.  2. Gather.  -- Bob Thaves''',
r'''Things will be brighter tonight.  A cop will shine a light in your face.''',
r'''Things will get better despite our efforts to improve them.  -- Will Rogers''',
r'''Things won't get any better, so get used to it.''',
r'''Things work better if you plug them in.''',
r'''Think honk if you are telepathic.''',
r'''Think how much fun you could have with the doctor's wife and a bucket of apples.''',
r'''Third marriage is the triumph of desperation over wisdom.''',
r'''This aphorism would be seven words long if it were six words shorter.''',
r'''This book fills a much-needed gap.  -- Moses Hadas''',
r'''This fellow Charles Lindbergh will never make it.  He's doomed.  -- Guggenheim''',
r'''This fortune is encrypted -- get your decoder rings ready!''',
r'''This fortune is inoperative.  Please try another.''',
r'''This fortune was brought to you by the people at Hewlett-Packard.''',
r'''This is a crude version of a more advanced joke that has never been written.''',
r'''This is a good time to punt work.''',
r'''This is a great day for France!  -- Richard Nixon, at De Gaulle's funeral''',
r'''This is a haiku.  Well, I'm not so sure it is.  Oh, wait, yes it is.''',
r'''This is a recording.''',
r'''This is as bad as it can get, but don't count on it.''',
r'''This is National Non-Dairy Creamer Week.''',
r'''This is not a novel to be tossed aside lightly, but thrown with great force.''',
r'''This is the day for firm decisions!  Or is it?''',
r'''This is the sort of English up with which I will not put.  -- Winston Churchill''',
r'''This isn't right.  This isn't even wrong.  -- Wolfgang Pauli, on physics paper''',
r'''This land is your land.  This land is my land.  So stay on your land.''',
r'''This may not be the best of all worlds, but it is certainly the most expensive.''',
r'''This prediction will not come true.''',
r'''This report is filled with omissions.''',
r'''This sentance has threee errors.''',
r'''This sentence contains ten words, eighteen syllables, and sixty-four letters.''',
r'''This sentence no verb.''',
r'''This statement is in no way to be construed as a disclaimer.''',
r'''This will be a memorable month -- no matter how hard you try to forget it.''',
r'''This won't hurt, did it?''',
r'''This won't hurt, I promise.''',
r'''Thomas Edison was afraid of the dark.''',
r'''Those are my principles.  If you don't like them, I have others.  -- Groucho Marx''',
r'''Those were the days...  And the nights weren't bad either.''',
r'''Those who can, do; those who can't, simulate.''',
r'''Those who don't mingle will die single.''',
r'''Those who flee temptation generally leave a forwarding address.  -- Olinghouse''',
r'''Those who forget this sentence are condemned to reread it.  -- Bill Yochum''',
r'''Those who know, cannot explain; those who don't know, cannot understand.''',
r'''Those who like sausages and the law had better not watch either one being made.''',
r'''Those who live by the sword get shot by those who don't.''',
r'''Three good things about school:  June, July, August.''',
r'''Three kinds of blood vessels are arteries, vanes and caterpillars.''',
r'''Three kinds of people in the world:  Those who can count and those who can't.''',
r'''Three may keep a secret, if two of them are dead.  -- Ben Franklin''',
r'''Three o'clock is always too late or too early for anything...  -- Sartre''',
r'''Thumbs Up to a Healthy Prostate!  -- Ken Tough''',
r'''Time flies like an arrow.  Fruit flies like a banana.''',
r'''Time flies when you don't know what you are doing.''',
r'''Time is an illusion perpetrated by the manufacturers of space.''',
r'''Time is an illusion; lunchtime doubly so.  -- Hitchhiker's Guide to the Galaxy''',
r'''Time is nature's way of keeping everything from happening at once.  -- Onsager''',
r'''Time is the best teacher; unfortunately, it kills all its students.''',
r'''Time may be a great healer, but it's a lousy beautician.''',
r'''Time's fun when you're having flies.  -- Kermit the Frog''',
r'''Tip the world over on its side and everything loose will land in LA.  -- Wright''',
r'''To attract a vegetarian, make a noise like a wounded vegetable.''',
r'''To be safe, make a copy of everything before you destroy it.''',
r'''To be, or not to be.  -- Shakespeare...  Oo-bee-doo-bee-doo.  -- Sinatra''',
r'''To collect fumes of sulfur, hold a deacon over a flame in a test tube.''',
r'''To discover a man's income, ask him what incomes should be exempt from taxation.''',
r'''To err is human -- but it feels divine.  -- Mae West''',
r'''To err is human; to admit it is a blunder.''',
r'''To err is human; to blame someone else for your errors is even more human.''',
r'''To err is human; To forgive is Not Company Policy.''',
r'''To err is human; to forgive is unusual.''',
r'''To err is human; to moo, bovine.''',
r'''To generalize is to be an idiot.  -- William Blake''',
r'''To get holy water, boil the hell out of it.''',
r'''To get it done:  Do it yourself, hire someone, or forbid your kids to do it.''',
r'''To hell with deep thoughts, this is the mating process.  -- Kevin Keirn''',
r'''To keep milk from turning sour, you should keep it in the cow.''',
r'''To know recursion, you must first know recursion.''',
r'''To live to be 100, give up all the things that make you want to live to be 100.  -- Woody Allen''',
r'''To make a small fortune in the commodities market, start with a large fortune.''',
r'''To make God laugh, tell him your plans.  -- Carolyn Myss''',
r'''To prevent conception when having intercourse, the male wears a condominium.''',
r'''To pull a rabbit out of a hat, ensure you put one in there first.''',
r'''To read about love and marriage, you must buy two separate books.  -- Alan King''',
r'''To remove dust from the eye, pull the eye down over the nose.''',
r'''To split is human, to infinitive, divine.  -- John Taylor''',
r'''To study a subject best, understand it thoroughly before you start.''',
r'''To succeed in politics, it is often necessary to rise above your principles.''',
r'''To vacillate or not to vacillate, that is the question...  Or is it?''',
r'''To YOU I am an atheist; to God, I'm the Loyal Opposition.  -- Woody Allen''',
r'''Toastmaster:  A guy who goes around introducing guys who need no introduction.''',
r'''Today is a good day for you to jump in a lake.''',
r'''Today is a good day to bribe a high ranking public official.''',
r'''Today is the first day of the rest of the mess.''',
r'''Today is the last day of the past of your life.''',
r'''Today is the tomorrow you worried about yesterday.''',
r'''Today is the yesterday you will be embarrassed about tomorrow.''',
r'''Toe:  A part of the foot used to find furniture in the dark.  -- Rilla May''',
r'''Tomorrow looks like a good day to sleep in.''',
r'''Tomorrow will be canceled due to lack of interest.''',
r'''Too much is not enough.''',
r'''Too much of a good thing is WONDERFUL.  -- Mae West''',
r'''Toothaches tend to start on a Saturday night.''',
r'''Toto, I don't think we're in Kansas anymore.  -- Judy Garland''',
r'''Tragedy:  A busload of lawyers driving off a cliff with three empty seats.''',
r'''Traveling through hyperspace isn't like dusting crops, boy.  -- Han Solo''',
r'''Trends are the new trend.  -- Reinier Evers''',
r'''Troglodytism does not necessarily imply a low cultural level.''',
r'''Truth is the most valuable thing we have.  Let us economize it.  -- Mark Twain''',
r'''Truthful:  Dumb and illiterate.''',
r'''Try the Moo Shu Pork.  It is especially good today.''',
r'''Try to get all of your posthumous medals in advance.''',
r'''Try to look unimportant, they might be low on ammo.''',
r'''Trying to define humor is one of the definitions of humor.  -- Saul Steinberg''',
r'''Trying to push your way through a door that doesn't open?  Connect the dots.''',
r'''Tuesday After Lunch is the cosmic time of the week.''',
r'''Turnabite is foreplay.  -- Alan Silverstein''',
r'''Twenty percent of zero is better than nothing.  -- Walt Kelly''',
r'''Two can live as cheaply as one for half as long.  -- Howard Kandel''',
r'''Two cars in every pot and a chicken in every garage.''',
r'''Two heads are more numerous than one.  -- Tom Weller''',
r'''Two is not equal to 3, not even for large values of 2.  -- Grabel''',
r'''Two kinds of people:  Those who love to talk, and those who hate to listen.''',
r'''Two thousand mockingbirds = two kilomockingbirds.''',
r'''Two wrongs are only the beginning.  -- Kohn''',
r'''Two wrongs do not make a right, but the three...  do.  -- Deteriorata''',
r'''Two wrongs don't make a right, but two Wrights made an airplane.''',
r'''UFOs are real.  The Air Force doesn't exist.''',
r'''Unauthorized fornication with this equipment is disallowed.''',
r'''Under capitalism, man exploits man.  Under communism, it is just the opposite.''',
r'''Under every stone lurks a politician.  -- Aristophanes''',
r'''Under-Achievers Anonymous has an 11-step program.''',
r'''Unfortunately there is more to life than getting enough sleep.  -- Alan Silverstein''',
r'''University:  An institution for the postponement of experience.''',
r'''Unmatched:  Almost as good as the competition.''',
r'''Unqualified superlatives are the worst of all.''',
r'''Use the newest medicines quickly before their effectiveness runs out.''',
r'''Use the word "paradigm" several times a day.  -- Scott Adams''',
r'''Using only a compass and straightedge, it's impossible to construct friends.  -- Randall Munroe''',
r'''Vacuum:  A large, empty space where the Pope lives.''',
r'''Ventis secundis, tene cursum.  (Go with the flow.)''',
r'''Verbosity leads to unclear, inarticulate things.  -- Dan Quayle''',
r'''Verbs have to agree with their subjects.  -- William Safire''',
r'''Very few profundities can be expressed in less than 80 characters.''',
r'''Very funny, Scotty.  Now beam down my clothes.''',
r'''Vescere bracis meis.  (Eat my shorts.)''',
r'''Vibration:  A motion that cannot make up its mind which way it wants to go.''',
r'''Violuminescence:  Things that glow in the dark when smashed.  -- Axel Emmermann''',
r'''Virgin wool comes from ugly sheep.''',
r'''Virginity can be cured.''',
r'''Virtual reality is its own reward.''',
r'''Virus:  A Latin medical term, meaning, "Your guess is as good as mine".''',
r'''VISA la France.  (Don't leave the chateau without it.)''',
r'''Visitors who throw litter into the crocodile pit will be asked to retrieve it.''',
r'''Vital papers demonstrate their vitality by spontaneously moving.''',
r'''Volcano:  A mountain with hiccups.''',
r'''Vote anarchist.''',
r'''Vote yes on no.''',
r'''Voting is like driving a car:  Choose R to go backward, choose D to go forward.''',
r'''Vuja De:  The feeling that none of this has happened before.''',
r'''Wagner's music is better than it sounds.  -- George Shaw''',
r'''Walk a mile in his shoes, so if he gets angry, he is barefoot and a mile away.''',
r'''Wall Street predicted nine out of the last five recessions.  -- Paul Samuelson''',
r'''Walt Disney didn't die.  He's in suspended animation.''',
r'''War is God's way of teaching us geography.  -- Paul Rodriguez''',
r'''War is menstruation envy.''',
r'''Warning:  Dates in calendar are closer than they appear.''',
r'''Warranty clauses are voided by payment of the invoice.''',
r'''Waste not, get your budget cut next year.''',
r'''Water?  I never touch the stuff:  Fish make love in it.''',
r'''We all keep busy keeping each other busy.''',
r'''We are all politicians.  Some of us are just honest enough to admit it.''',
r'''We are all self-made, but only the rich will admit it.''',
r'''We are born naked, wet and hungry.  Then things get worse.''',
r'''We are living in a golden age.  All you need is gold.  -- Robertson''',
r'''We are making progress.  Things are getting worse at a slower rate.''',
r'''We are not a loved organization, but we are a respected one.  -- John Fisher''',
r'''We are ready for any unforeseen event that may or may not occur.  -- Dan Quayle''',
r'''We are so fond of each other because our ailments are the same.  -- Jonathan Swift''',
r'''We are sorry.  We cannot complete your call as dialed.''',
r'''We are the people our parents warned us about.  -- Jimmy Buffett''',
r'''We aren't sure how clouds form.  But they know, that is what counts.''',
r'''We buy junk and sell antiques.  -- sign in country store''',
r'''We can all admit we like acronyms and leave it at that.  -- Scott Adams''',
r'''We can loan you enough money to get you completely out of debt.  -- sign in bank''',
r'''We can't all be heroes, someone has to sit on the curb and clap as they go by.''',
r'''We can't leave the haphazard to chance.  -- N. F. Simpson''',
r'''We could do that, but it would be wrong, that's for sure.  -- Richard Nixon''',
r'''We dispense with accuracy.  -- sign in pharmacy''',
r'''We don't care.  We don't have to.  We're the Phone Company.''',
r'''We don't have to protect the environment; the Second Coming is at hand.  -- Watt''',
r'''We don't really understand it, so we'll leave it for the poets.  -- John Taylor''',
r'''We don't want to go back to tomorrow, we want to go forward.  -- Dan Quayle''',
r'''We have 64 arm bones but only 62 leg bones.  The mistake is yet to be found.''',
r'''We have been through so much together, and most of it was your fault.''',
r'''We have enough youth, how about a fountain of SMART?''',
r'''We have nothing to fear about work but the work itself.''',
r'''We have the best politicians that money can buy.  -- Edward Abbey''',
r'''We have them just where they want us.  -- James Kirk''',
r'''We interrupt this fortune for an important announcement...''',
r'''We learn by making better mistakes.''',
r'''We live on one-third of what we eat, and the doctors live on the rest.''',
r'''We need either less corruption or more chance to participate in it.''',
r'''We put stamps on letters because we don't know where else to put them.''',
r'''We totally deny the allegations, and we are trying to identify the allegators.''',
r'''We will cross out that bridge when we come back to it later.''',
r'''We will get along fine as soon as you realize I am God.''',
r'''We will have solar energy when the power companies develop a sunbeam meter.''',
r'''We will sell gasoline to anyone in a glass container.  -- Sante Fe gas station''',
r'''We're all on the road to the grave, but why be in the passing lane?  -- Orben''',
r'''We're going to have the best-educated American people in the world.  -- Dan Quayle''',
r'''Wealth:  The ability to support debt.''',
r'''Weather forecaster:  One with whom the weather does not always agree.''',
r'''Wedding is destiny, and hanging likewise.  -- John Heywood''',
r'''Welcome to President Bush, Mrs. Bush, and my fellow astronauts.  -- Dan Quayle''',
r'''Welcome to the Lou Holtz Show.  Unfortunately, I'm Lou Holtz.''',
r'''Well adjusted:  Makes the same mistake twice without getting nervous.''',
r'''Well, gee, I don't know if I have mixed feelings about that or not.  -- T. Gross''',
r'''Well, if I called the wrong number, why did you answer the phone?  -- Thurber''',
r'''Well-adjusted:  Able to play bridge or golf as if they were games.''',
r'''What about an endangered animal that eats only endangered plants?''',
r'''What can't be said, can't be said.  And it can't be whistled, either.  -- Tirtha''',
r'''What did God say after creating man?  "I can do better."''',
r'''What did you bring the book I want to be read to out of about Down Under up for?''',
r'''What do Winnie the Pooh and John the Baptist have in common?  Their middle name.''',
r'''What do women want?  Nowadays mainly...  Other women.''',
r'''What do you call 10,000 lawyers at the bottom of the ocean?  A good start.''',
r'''What do you call 1000 rabbits in a row hopping backwards?  A receding hareline.''',
r'''What do you call a lawyer buried up to his neck in sand?  Not enough sand.''',
r'''What does DNA stand for?  National Dyslexia Association.''',
r'''What doesn't kill us makes us bitter.  -- Chuck Lorre''',
r'''What happens if you get scared half to death twice?''',
r'''What happens to the hole when the cheese is gone?  -- Bertolt Brecht''',
r'''What happens when you cut back the jungle?  It recedes.''',
r'''What has four legs and an arm?  A happy pit bull.''',
r'''What has reality ever done for anyone?''',
r'''What if there were no hypothetical situations?''',
r'''What is a nice person like me doing in a place like this?''',
r'''What is an atheist's favorite movie?  "Coincidence on 34th Street"''',
r'''What is another word for Thesaurus?  -- Stephen Wright''',
r'''What is Life?  It's the cereal Mikey likes.''',
r'''What is mind?  No matter.  What is matter?  Never mind.  -- Thomas Key''',
r'''What is orange and goes "click, click"?  A ball point carrot.''',
r'''What is research but a blind date with knowledge?  -- Will Harvey''',
r'''What is the difference between a duck?  One of its legs is both the same.''',
r'''What is the difference between a viola and a violin?  A violin burns faster.''',
r'''What is the difference between government bonds and men?  Bonds mature.''',
r'''What is worth doing is worth the trouble of asking someone to do.''',
r'''What orators lack in depth they make up for in length.  -- Baron de Montesquieu''',
r'''What sane person could live in this world and not be crazy?  -- Ursula LeGuin''',
r'''What scoundrel stole the cork from my lunch?  -- J. D. Farley''',
r'''What the tyrannosaurus lacked in arms he made up in other areas.  -- Brett Nelson''',
r'''What this country needs is a dime that will buy a good five cent bagel.''',
r'''What this country needs is more leaders who know what this country needs.''',
r'''What use is magic if it can't save a unicorn?  -- Peter Beagle''',
r'''What was sliced bread the greatest thing since?''',
r'''What!  Me worry?  -- Alfred E. Newman''',
r'''What's the point of being God if you can't even fulfill your own prophecies?  -- Cristina Rad''',
r'''What, after all, is a halo?  It's only one more thing to keep clean.  -- Fry''',
r'''Whatever became of eternal truth?''',
r'''Whatever is your lot in life, build on it.''',
r'''Whatever it is, I am against it.''',
r'''Whatever it is, I didn't do it!''',
r'''Whatever misfortune may be your lot, it could only be worse in Milwaukee.''',
r'''Whatever you set out to do, something else must be done first.''',
r'''When a girl goes bad -- men go right after her.  -- Mae West''',
r'''When a man tells you he got rich through hard work, ask him, "Whose?" -- Marquis''',
r'''When a man's best friend is his dog, that dog has a problem.  -- Edward Abbey''',
r'''When a person brags about his ancestors, the best part of him is underground.''',
r'''When all else fails, lower your standards.''',
r'''When all else fails, try reading the directions.''',
r'''When angry, count four; when very angry, swear.  -- Mark Twain''',
r'''When anything is used to its full potential, it will break.''',
r'''When crazy people go through the forest, they take the psycho path.''',
r'''When cryptography is outlawed, bayl bhgynjf jvyy unir cevinpl.''',
r'''When evolution is outlawed, only outlaws will evolve.''',
r'''When God created two sexes, he might have been overdoing it.  -- Charles Smith''',
r'''When God endowed human beings with brains, he did not intend to guarantee them.''',
r'''When God gives you AIDS... make lemonAIDS.  -- Sarah Silverman''',
r'''When I born I was so surprised, I didn't talk for a year and a half.  -- Allen''',
r'''When I look at my children, I often wish I had remained a virgin.  -- L. Carter''',
r'''When I played in the sandbox the cat kept covering me up.  -- Rodney Dangerfield''',
r'''When I read about the evils of drinking, I gave up reading.  -- Henny Youngman''',
r'''When I was a Brownie, I ate all the cookies.  -- Madonna''',
r'''When I'm good, I'm very good.  But when I'm bad, I'm better.  -- Mae West''',
r'''When I'm not in my right mind, my left mind gets pretty crowded.''',
r'''When in charge, ponder.  When in doubt, mumble.  When in trouble, delegate.''',
r'''When in doubt, lead trump.''',
r'''When in trouble or in doubt, run in circles, scream and shout.''',
r'''When it comes to helping you, some people stop at nothing.''',
r'''When it is a question of money, everybody is of the same religion.  -- Voltaire''',
r'''When it rains, it pours.''',
r'''When it's you against the world, bet on the world.''',
r'''When Lincoln was President, he wore only a tall silk hat.''',
r'''When management wants your opinion, they will give it to you.''',
r'''When marriage is outlawed, only outlaws will have inlaws.''',
r'''When Mozart was my age, he had been dead for two years.  -- Tom Lehrer''',
r'''When one burns one's bridges, what a very nice fire it makes.  -- Dylan Thomas''',
r'''When one door closes, another opens, but the hallways are hell.  -- Sol Wachler''',
r'''When pigs back into an electric fence, there is a short circus.''',
r'''When sign makers go on strike, is anything written on their picket signs?''',
r'''When someone says, "It ain't the money, but the principle," it's the money.''',
r'''When talking nonsense try not to be serious.''',
r'''When the going gets tough, everyone leaves.  -- Lynch''',
r'''When the going gets tough, the tough go shopping.''',
r'''When the going gets weird, the weird turn pro.  -- Hunter Thompson''',
r'''When there's a will, I want to be in it.''',
r'''When they ship styrofoam, what do they pack it in?''',
r'''When this sign is under water, this road is impassable.  -- sign on rural road''',
r'''When working hard, be sure to get up and retch every so often.''',
r'''When working on a problem, it helps to know the answer.''',
r'''When you are in it up to your ears, keep your mouth shut.''',
r'''When you breathe you inspire.  When you do not breathe you expire.''',
r'''When you can't make all of the pieces fit, throw one away.''',
r'''When you die at 72, not matter what you die of, it's natural causes. -- Chris Rock''',
r'''When you do a good deed, get a receipt, in case heaven is like the IRS.''',
r'''When you don't know what to do, walk fast and look worried.''',
r'''When you feel terrific, notify your face.  -- H. Jackson Brown''',
r'''When you finally discover all of life's answers, they'll change the questions.''',
r'''When you make your mark in the world, watch out for guys with erasers.''',
r'''When you mention something, if it's bad, it happens, if it's good, it goes away.''',
r'''When you sit too long on the ice, you get a polaroid.''',
r'''When you smell an odorless gas, it is probably carbon monoxide.''',
r'''When you've got them by the balls, their hearts and minds will follow.  -- LBJ''',
r'''When you've seen one non-sequitur, the price of tea in China.''',
r'''When your memory goes, forget it!''',
r'''When your mom is mad at your dad, don't let her brush your hair.''',
r'''Whenever anyone says, "theoretically", they really mean, "not really".  -- Parnas''',
r'''Whenever I feel like exercise, I lie down until the feeling passes.''',
r'''Where do forest rangers go to "get away from it all"?''',
r'''Where does a 300 pound gorilla sleep?  Anywhere he wants!''',
r'''Where in the world does the guy who has everything put it?''',
r'''Where is Denver?  Denver is just below the O in Colorado.''',
r'''Where there's a whip, there's a way.''',
r'''Where there's a will, there's a relative.''',
r'''Where there's a will, there's an Inheritance Tax.''',
r'''Wherever you go, there you are.''',
r'''Wherever you go, there you are.  Your luggage is another story.''',
r'''Whether you can hear it or not, the universe is laughing behind your back.''',
r'''Which came first, the chicken or the egg?  Neither, it was the rooster.''',
r'''Which is worse, ignorance or apathy?  Who knows?  Who cares?''',
r'''While in jail a man worked on his alibiography.  -- Henry Cate''',
r'''While money doesn't buy love, it puts you in a great bargaining position.''',
r'''Whining martyrs get a lot of stage time.  -- Scott Adams''',
r'''White dwarf seeks red giant for binary relationship.''',
r'''Who am I to criticize another maniac?''',
r'''Who are these children, and why are they calling me Mom?''',
r'''Who cares about procreation, as long as it tickles?''',
r'''Who dat who say "who dat" when I say "who dat"?  -- Hattie McDaniel''',
r'''Who marries for love without money has good nights and sorry days.''',
r'''Who needs astrology?  The wise man gets by on fortune cookies.  -- Edward Abbey''',
r'''Who needs companionship when you can sit alone in your room and drink?''',
r'''Who was that masked man?''',
r'''Who's on first?''',
r'''Whoever it was who told you you were wrong was right.  -- Tom von Alten''',
r'''Whoever said money can't buy happiness didn't know where to shop.''',
r'''Why are there flotation devices under airplane seats instead of parachutes?''',
r'''Why are there interstate highways in Hawaii?''',
r'''Why are they called "stands" when they are made for sitting?''',
r'''Why are today's rough times always tomorrow's good old days?''',
r'''Why argue when we both know I am right?''',
r'''Why be difficult when, with a bit of effort, you could be impossible?''',
r'''Why bother building any more nuclear warheads until we use the ones we have?''',
r'''Why can't elephants play tennis?  They don't make tennis shoes in their size.''',
r'''Why did God give us ten fingers and only two nostrils?''',
r'''Why did the chicken cross the road?  He was giving it last rites.''',
r'''Why did the chicken cross the road?  The rooster was on the other side.''',
r'''Why did the elephant cross the road?  Chicken's day off.''',
r'''Why did the politician cross the road?  To get to the middle.''',
r'''Why did the tachyon cross the road?  Because it was on the other side.''',
r'''Why didn't Noah just swat those two mosquitos?''',
r'''Why do expenses always rise to meet income?''',
r'''Why do men die before their wives?  They want to.''',
r'''Why do people who know the least know it the loudest?''',
r'''Why do we sing, "Take me out to the ball game" when we're already there?''',
r'''Why do you change your image so often?  "To entertain myself."  -- Madonna''',
r'''Why do you park on a driveway and drive on a parkway?  -- Larry Anderson''',
r'''Why does a ship carry cargo and a truck carries shipments?''',
r'''Why does bread always fall butter side down?''',
r'''Why does sour cream have an expiration date?  -- Larry Anderson''',
r'''Why does the other lane always move faster?''',
r'''Why doesn't glue stick to the inside of the bottle?''',
r'''Why doesn't life come with subtitles?''',
r'''Why don't "minimalists" find a shorter name for themselves?''',
r'''Why don't blind people bungee jump?  Because it scares hell out of their dogs.''',
r'''Why go elsewhere and be cheated when you can come here?  -- sign in store''',
r'''Why is "abbreviated" such a long word?''',
r'''Why is "palindrome" spelled "palindrome" and not "palindromeemordnilap"?''',
r'''Why is brassiere singular and panties plural?''',
r'''Why is charging ahead OK, but charging an arm and a leg is not?  -- Alan Driscoll''',
r'''Why is it called "rush hour" when nothing moves?''',
r'''Why is it called a "building" when it is already built?''',
r'''Why is it that there are so many more horses' asses than horses?  -- Liddy''',
r'''Why is the man who invests all your money called a broker?''',
r'''Why is there a "permanent press" setting on an iron?''',
r'''Why isn't "phonetic" spelled the way it's said?''',
r'''Why isn't there a special name for the tops of your feet?  -- Lily Tomlin''',
r'''Why isn't there mouse-flavored cat food?''',
r'''Why listen to reason when insanity prevails?''',
r'''Why was I born with such contemporaries?  -- Oscar Wilde''',
r'''Why would anyone want to be called Later?''',
r'''Wilderness:  A place where something might eat you.''',
r'''Willie was a chemist; Willie is no more.  What Willie thought was H20 was H2SO4.''',
r'''Wine and youth increase love.''',
r'''Winning isn't everything, but losing isn't anything.''',
r'''Wisdom is only happening to guess right.  -- Euripides''',
r'''With a rubber duck, one's never alone.''',
r'''With enough garlic, you can eat the New York Times.  -- Morley Safer''',
r'''With enough thrust, pigs fly just fine.''',
r'''With sex, who cares if practice doesn't make perfect.''',
r'''Withhold from screaming when you hear the phrase, "Let's just be friends..."''',
r'''Without ice cream life and fame are meaningless.''',
r'''Without life, biology itself would be impossible.''',
r'''Woman was God's second mistake.  -- Friedrich Nietzsche''',
r'''Women fake orgasm because men fake foreplay.''',
r'''Women like the simplest things in life...  Men.''',
r'''Women most enjoy receiving the kind of letters that should never be written.''',
r'''Women need a reason to have sex; men just need a place.  -- Billy Crystal''',
r'''Women speak in estrogen but men listen in testosterone.''',
r'''Women speak two languages, one of which is verbal.  -- Steve Rubenstein''',
r'''Women truly are better than men.  Otherwise, they'd be intolerable.  -- Edward Abbey''',
r'''Women want one man to meet every need; men want every woman to meet one need.''',
r'''Women want their men to be deep, but they don't want to hear about it.''',
r'''Women who carry a little extra weight live longer than men who notice it.''',
r'''Women who desire to be like men, lack ambition.''',
r'''Women who love only women may have a good point.  -- Edward Abbey''',
r'''Women, to make a man happy, all you must do is show up naked.''',
r'''Women:  We cannot love them all.  But we must try.  -- Edward Abbey''',
r'''Work is the curse of the drinking classes.  -- Oscar Wilde''',
r'''Work is the greatest thing in the world; always save some of it for tomorrow.''',
r'''Work off excess energy.  Steal something heavy.''',
r'''Worry kills more people than work because more people worry than work.''',
r'''Would a fly without wings be called a walk?''',
r'''Would it help if I got out and pushed?''',
r'''Wrinkled was not one of the things I wanted to be when I grew up.''',
r'''Write all adverbial forms correct.''',
r'''Writing carefully, dangling participles must be avoided.  -- William Safire''',
r'''Writing free verse is like playing tennis with the net down.''',
r'''Yale is one big party...  With a $25K cover charge.''',
r'''Yawning is an orgasm for your face.  -- Gunvar Ingeborg''',
r'''Years of development:  We finally got one to work.''',
r'''Yes, it works well in practice, but will it work in theory?''',
r'''Yesterday was the deadline on all complaints.''',
r'''Yield to temptation; it might not pass your way again.''',
r'''YKK on a zipper stands for Yoshida Kogyo Kabushikigaisha.''',
r'''Yo-yo:  Something occasionally up but normally down (see also "computer").''',
r'''You are confused; but this is your normal state.''',
r'''You are entitled to your own wrong opinion.''',
r'''You are halfway through life before you realize it's a do-it-yourself thing.''',
r'''You are here.  But you are not all there.''',
r'''You are in a maze of little twisting passages, all alike.''',
r'''You are in a maze of little twisting passages, all different.''',
r'''You are never going to fail unless you try.''',
r'''You are not abusing drugs if they're stored in a dry place and never yelled at.''',
r'''You are not as fat as you imagine.  -- Mary Schmich''',
r'''You are not fat if clothes are actually made in your size.''',
r'''You are not from Earth, are you?''',
r'''You are not overweight if you can still touch somebody's toes.''',
r'''You are not paranoid if they're really after you...''',
r'''You are still sober as lounge as you can still say your worms promperly.''',
r'''You are ugly and your mother dresses you funny.''',
r'''You are validating my inherent mistrust of strangers.''',
r'''You are warm and giving toward others.  What are you after?''',
r'''You aren't a real engineer until you make one $50,000 mistake.''',
r'''You can cage a swallow, can't you, but you can't swallow a cage, can you?''',
r'''You can drive through Wyoming at night and still see the scenery.  -- Vodall''',
r'''You can fool some of the people all of the time...  But you can't fool Mom.''',
r'''You can fool some of the people some of the time, and that is sufficient.''',
r'''You can get more with a kind word and a gun than you can with a kind word.''',
r'''You can go anywhere you want if you look serious and carry a clipboard.''',
r'''You can lead a horse to water, but if he walks on it, patent him.''',
r'''You can learn many things from children...  Like how much patience you have.''',
r'''You can never find a lost-and-found when you need one.  -- Greg Clifford''',
r'''You can observe a lot just by watchin'.  -- Yogi Berra''',
r'''You can rent this profound space for only $5 a week.''',
r'''You can tell if you're on the right track -- it's usually uphill.''',
r'''You can tell the men from the boys by the price of their toys.''',
r'''You can't belay a man who's falling in love.  -- Edward Abbey''',
r'''You can't feel as bad as you look.  Or look as bad as you feel.  -- Edward Abbey''',
r'''You can't fix stupid, but you can vote it out.''',
r'''You can't fool me -- there ain't no sanity clause.  -- Chico Marx''',
r'''You can't get there from here.''',
r'''You can't have Kate and Edith too!''',
r'''You can't hide a piece of broccoli in a glass of milk.  -- Armir, age 9''',
r'''You can't legislate against human nature.  -- Robert Reuben''',
r'''You can't see the forest if you're barking up the wrong tree.''',
r'''You cannot buy beer; you can only rent it.''',
r'''You cannot determine beforehand which side of the bread to butter.''',
r'''You cannot have everything because where would you put it?  -- Christer Sundqvist''',
r'''You could be playing a video game instead.''',
r'''You couldn't pay me to work on commission.''',
r'''You don't know what you want, and are willing to go through hell to get it.''',
r'''You don't know what you're talking about, do you?''',
r'''You don't need a parachute to skydive, only to skydive twice.  -- Darwin Awards''',
r'''You enter into a certain amount of madness when you marry a person with pets.''',
r'''You gotta break some eggs to make a real mess on the neighbor's car!''',
r'''You have a right to your opinions.  I just don't want to hear them.''',
r'''You have an important role as a negative example.''',
r'''You have been selected for a secret mission.''',
r'''You have good manners, but never carry them about you.  -- Fuller''',
r'''You have the body of a 19 year old.  Please return it before it gets wrinkled.''',
r'''You have the capacity to learn from mistakes.  You will learn a lot today.''',
r'''You keep using that word.  I do not think it means what you think it does.''',
r'''You know how happy a motorcyclist is by the bug stains on his teeth.''',
r'''You know you are a little fat if you have stretch marks on your car.  -- Cyrus''',
r'''You know you are over the hill when work is less fun and fun is more work.''',
r'''You know you have landed gear-up when it takes full power to taxi.''',
r'''You know you're getting old when you hurt yourself sleeping.  -- Billy Gardell''',
r'''You know you're old when your back goes out more than you do.''',
r'''You look like a million dollars...  All green and wrinkled.''',
r'''You made me think.  I will be wary of you in the future.''',
r'''You might get attention, but attention ain't the same thing as love.''',
r'''You never find a lost item until after you replace it.''',
r'''You never know how many friends you have until you rent a house on the beach.''',
r'''You never know who is right, but you always know who is in charge.  -- Whistler''',
r'''You never realize how short a month is until you pay alimony.  -- John Barrymore''',
r'''You never really learn to swear until you learn to drive.''',
r'''You now have Asian Flu.''',
r'''You say things with your eyes that others waste time putting into words.''',
r'''You shake milk in a big stirrer machine to make it homicidal.''',
r'''You should avoid hedging, at least that's what I think.''',
r'''You should hardly ever equivocate.''',
r'''You sound reasonable...  Must be time to up my medication.''',
r'''You were conspicuous by your absence.  -- Lord John Russell''',
r'''You will be reincarnated as a toad; and you will be much happier.''',
r'''You will be surprised by a loud noise.''',
r'''You will become rich and famous, unless you don't.''',
r'''You will experience a strong urge to do good; but it will pass.''',
r'''You will feel hungry again in another hour.''',
r'''You will live a long full life and gradually decay into a useless blob.''',
r'''You will live a long, healthy, happy life and make bags of money.''',
r'''You will never hit your finger if you hold the hammer with both hands.''',
r'''You will pay for your sins.  If you have already paid, please disregard.''',
r'''You will soon forget this.''',
r'''You will step on the night soil of many countries.''',
r'''You will wish you hadn't.''',
r'''You won't skid if you stay in a rut.  -- Frank Hubbard''',
r'''You would if you could but you can't so you won't (and probably shouldn't).''',
r'''You!  Off my planet!''',
r'''You'll find it all at Greeley Mall.  -- Radio advertisement''',
r'''You're not drunk if you can lie on the floor without holding on.  -- Dean Martin''',
r'''You're not late until you get there.''',
r'''You're only given a little spark of madness.  You mustn't lose it.  -- Robin Williams''',
r'''You're only young once, but it makes you tired for the rest of your life.''',
r'''Your boss is the biggest obstacle to workday leisure.  -- Scott Adams''',
r'''Your chance of forgetting something is directly proportional to...  uh...''',
r'''Your check is in the mail.''',
r'''Your fly might be open (but don't check it just now).''',
r'''Your intuition nearly makes up for your lack of good judgment.''',
r'''Your love life will be...  Interesting.''',
r'''Your lucky number has been disconnected.''',
r'''Your lucky number is 364958674928.  Watch for it everywhere.''',
r'''Your reasoning is silly and irrational but it is beginning to make sense.''',
r'''Your true value depends entirely on what you are compared with.''',
r'''Your weapon is made by the lowest bidder.''',
r'''Your weight is perfect for your height -- which varies.''',
r'''Youth is too good to be wasted on the young.  -- George Shaw''',
r'''Zenophobia:  The irrational fear of convergent sequences.''',
r'''Zoo:  Place devised for animals to study the habits of human beings.  -- Herford''',
r'''[He] has all the virtues I dislike and none of the vices I admire.  -- Churchill''',
r'''[Nuclear war]... may not be desirable.  -- Edwin Meese III''',
r'''"Do-so" is more important than "say-so".  -- Pete Seeger''',
r'''"Dreamt" is the only English word that ends in the letters "mt".''',
r'''"For example" is not proof.  -- Yiddish proverb''',
r'''"I really don't believe that, but I was raised that way."  -- Carolyn Myss''',
r'''"Keep the tourists out..."  As fellow tourists we heartily agree.  -- Edward Abbey''',
r'''"Know thyself"?  If I knew myself, I'd run away.  -- Johann von Goethe''',
r'''"My country right or wrong" is like saying, "My mother drunk or sober."''',
r'''"Things" are thieves of time.''',
r'''...context...  -- Manny Farber''',
r'''1. Thought is creative.  2. Fear attracts like energy.  3. Love is all there is.''',
r'''A "jiffy" is an actual unit of time for 1/100th of a second.''',
r'''A baby is God's opinion that the world should go on.  -- Carl Sandburg''',
r'''A beggar can never be bankrupt.  -- John Ray''',
r'''A billion hours ago man had not yet walked on earth.''',
r'''A bird in the hand is worth two in the bush.''',
r'''A boss says, "Go!"  A leader says, "Let's go!"  -- E.M. Kelley''',
r'''A boy gets to be a man when a man is needed.  -- John Steinbeck''',
r'''A business without a path to profit isn't a business, it's a hobby.  -- Jason Fried''',
r'''A candle loses nothing by lighting another candle.''',
r'''A chain is no stronger than its weakest link.''',
r'''A child does not need to be parented.  He needs to be mothered and fathered.''',
r'''A city is a large community where people are lonesome together.  -- Prochnow''',
r'''A civilized society makes swords into decoration.  -- Danny Low''',
r'''A clash of doctrine is not a disaster; it is an opportunity.''',
r'''A clever prophet makes sure of the event first.''',
r'''A closed mouth gathers no foot.''',
r'''A collection of facts not necessarily science.  -- Henri Poincar''',
r'''A company is known by the people it keeps.''',
r'''A compliment is something like a kiss through a veil.  -- Victor Hugo''',
r'''A confusion of the real with the ideal never goes unpunished.  -- Johann von Goethe''',
r'''A conspiracy of silence speaks louder than words.''',
r'''A continuing flow of paper is sufficient to continue the flow of paper.  -- Dyer''',
r'''A coward dies a thousand deaths, a brave man dies but once.''',
r'''A critic is a man who knows the way but can't drive the car.  -- Kenneth Tynan''',
r'''A critic is to an author as a fungus to an oak.  -- Edward Abbey''',
r'''A crocodile cannot stick out its tongue.''',
r'''A cult becomes a religion when it begins to kill those outside its membership.''',
r'''A culture can be no stronger than its strongest myths.  -- James Carse''',
r'''A cynic is a disappointed lover.''',
r'''A cynic is a man who knows the price of everything and the value of nothing.''',
r'''A day without fear changes your life forever.  -- Jerry Stocking''',
r'''A deceased body harms the mind.''',
r'''A dime has 118 ridges around the edge.''',
r'''A disease known is half cured.''',
r'''A doctor gets no pleasure out of the health of his friends.  -- de Montaigne''',
r'''A donkey raised among horses is still a donkey.''',
r'''A drastic change to stay where you are always puts you in a different place.''',
r'''A dream that is not interpreted is like a letter that is not read.  -- Talmud''',
r'''A drill is a tool.  A hole is a solution.''',
r'''A dry cough is the trumpeter of death.''',
r'''A dying man can do nothing easy.  -- Benjamin Franklin''',
r'''A fair exterior is a silent recommendation.''',
r'''A family is the difference between a house and a home.''',
r'''A fault recognized is half corrected.''',
r'''A feather in hand is better than a bird in the air.  -- George Herbert''',
r'''A fellow with a closed mind often has an open mouth.''',
r'''A flood of words over a desert of thought.  -- Simon Bolivar''',
r'''A fool and his money are soon parted.''',
r'''A fool and his words are soon parted.  -- William Shenstone''',
r'''A fool with tool is still a fool.''',
r'''A foolish consistency is the hobgoblin of little minds.  -- Ralph Emerson''',
r'''A free society is one where it is safe to be unpopular.  -- Adlai Stevenson''',
r'''A friend in need is a friend indeed.''',
r'''A friend is one with whom you dare to be yourself.''',
r'''A friend to everyone is a friend to no one.''',
r'''A full belly makes a dull brain.''',
r'''A full heart should not go where an empty mind leads.''',
r'''A genius is always on duty; even his dreams are tax deductible.  -- Edward Abbey''',
r'''A goal is a dream with a deadline.  (But do you really need a deadline?)''',
r'''A god can create a world only by listening.  -- James Carse''',
r'''A goldfish has a memory span of three seconds.''',
r'''A good example is the best sermon.  -- H. Jackson Brown''',
r'''A good memory does not equal pale ink.''',
r'''A good painter can draw a devil as well as an angel.  -- G. Delamothe''',
r'''A good philosopher is one who does not take ideas seriously.  -- Edward Abbey''',
r'''A good plan today is better than a perfect plan tomorrow.  -- Patton''',
r'''A good supervisor can step on your toes without messing up your shine.''',
r'''A good tale cannot too often be told.  -- Sir T. More''',
r'''A good tongue is a good weapon.  -- James Kelly''',
r'''A good word costs no more than a bad one.  -- B. Googe''',
r'''A good workman is known by his tools.''',
r'''A government able to give you all you want can also take away all you have.''',
r'''A government that robs Peter to pay Paul can always depend on Paul's support.''',
r'''A grasshopper has 100 more distinct muscles than a human.''',
r'''A great idea needs landing gear, not just wings.''',
r'''A great person never reminds us of others.''',
r'''A great ship asks deep waters.  -- George Herbert''',
r'''A half-truth is closer to falsehood than to veracity.  -- Abba Eban''',
r'''A hammer sometimes misses its mark; a bouquet, never.''',
r'''A handful of friends is worth more than a wagon of gold.''',
r'''A handful of sand is an anthology of the universe.  -- David McCord''',
r'''A hard life is a free lesson in poetry.  -- John Taylor''',
r'''A hard-working farmer has plenty to eat.  -- Solomon''',
r'''A heavy purse makes a light heart.''',
r'''A hen is only an egg's way of making another egg.  -- Samuel Butler II''',
r'''A hermit is a deserter from the army of humanity.''',
r'''A hero is a man who does what he can.  -- Romain Rolland''',
r'''A highbrow is a person educated beyond his intelligence.  -- Brander Matthews''',
r'''A house without books is like a room without windows.  -- Horace Mann''',
r'''A joke breaks no bones.''',
r'''A journey of a thousand miles must begin with a single step.  -- Lao Tzu''',
r'''A learned fool is more foolish than an ignorant fool.  -- Molire''',
r'''A learned man always has wealth within himself.''',
r'''A leopard cannot change his spots.  -- William Shakespeare''',
r'''A liar is not believed when he speaks the truth.  -- Cicero''',
r'''A liar needs a good memory.  -- Quintilian''',
r'''A lie has a short life, but truth lives on for ever.  -- Solomon''',
r'''A life without tragedy would not be worth living.  -- Edward Abbey''',
r'''A likely impossibility is always preferable to an unconvincing possibility.''',
r'''A little experience often upsets a lot of theory.''',
r'''A little fire consumes a great wood.  -- Roger Edgeworth''',
r'''A little inaccuracy saves a world of explanation.  -- C. E. Ayres''',
r'''A little knowledge can be a ridiculous thing.  -- Scott Adams''',
r'''A little sunlight is the best disinfectant.  -- Justice Louis Brandeis''',
r'''A living dog is better than a dead lion.  -- Old Testament''',
r'''A log may float in a river, but that does not make it a crocodile.''',
r'''A long life deprives man of his optimism.  -- Ernest Hemingway''',
r'''A long tongue is a sign of a short hand.  -- George Herbert''',
r'''A lost ounce of gold may be found, a lost moment of time never.''',
r'''A love for the land does not necessarily equate with good care of the land.''',
r'''A loving mate can see the good in you even when you cannot.''',
r'''A man can do everything with a sword except sit on it.  -- Talleyrand''',
r'''A man can do no more than he can.''',
r'''A man can only be young once, but he can be immature forever.  -- Catherine Aird''',
r'''A man cannot be in two places at the same time.''',
r'''A man does not look behind the door unless he has stood there himself.''',
r'''A man doesn't become a failure until he is satisfied with being one.  -- Henry Cate''',
r'''A man is a lion in his own cause.''',
r'''A man is known to be mortal by two things, sleep and lust.  -- Francis Bacon''',
r'''A man is not old until regrets take the place of dreams.  -- John Barrymore''',
r'''A man is not so soon healed as hurt.  -- Porter''',
r'''A man may lose his goods for want of demanding them.  -- Thomas Draxe''',
r'''A man may lose more in an hour than he can get in seven.''',
r'''A man must not swallow more beliefs than he can digest.  -- Havelock Ellis''',
r'''A man never becomes an orator if he has anything to say.  -- Finley Dunne''',
r'''A man who cannot seduce men cannot save them either.  -- Soren Kierkegaard''',
r'''A man who fears suffering is already suffering from what he fears.  -- Montaigne''',
r'''A man will never change his mind if he has no mind to change.  -- Trench''',
r'''A man with two clocks never knows exactly what is the time.''',
r'''A man without reason is a beast in season.  -- Howell''',
r'''A man without religion is like a horse without a bridle.''',
r'''A man wrapped up in himself makes a very small package.''',
r'''A man's envy alludes to where his ambition fails.  -- William Wall''',
r'''A man's home is his castle.''',
r'''A man's library is his map drawn to scale.  -- John Taylor''',
r'''A man's praise in his own mouth stinks.''',
r'''A man's soul may be buried under a pile of money.  -- Nathaniel Hawthorne''',
r'''A mantra is a training device to break you out of your attachments.  -- Ram Dass''',
r'''A mask tells us more than the face.  -- Oscar Wilde''',
r'''A mathematician knows how to solve a problem, but can't do it.  -- Milne''',
r'''A memorandum is written not to inform the reader but to protect the writer.''',
r'''A mind that is stretched by an idea will never return to its original size.''',
r'''A mink is just a high-budget weasel.''',
r'''A miracle is not an event that heals the physical body, but the mind and spirit.''',
r'''A moment's insight is sometimes worth a life's experience.  -- Oliver Holmes''',
r'''A moneyless man goes fast through the market.  -- Fuller''',
r'''A museum is a collection of labels, illustrated by specimens.  -- George Goode''',
r'''A mushroom cloud has no silver lining.''',
r'''A nerd is simply someone who thinks exceedingly inside the box.  -- Nassim Taleb''',
r'''A nuclear war cannot be won and must never be fought.  -- Ronald Reagan''',
r'''A page of history is worth a volume of logic.''',
r'''A peaceful man is the first criterion if you want to have a peaceful universe.''',
r'''A pedestal is as much a prison as any small, confined space.  -- Gloria Steinem''',
r'''A penalty for hubris is always exacted.  -- Jon Bayh''',
r'''A pencil with no point needs no eraser.''',
r'''A person before birth knows exactly what they're buying into.  -- Ram Dass''',
r'''A person forgives only when he is in the wrong.''',
r'''A person is just about as big as the things that make him angry.''',
r'''A person paints with his brains and not with his hands.''',
r'''A physicist is an atom's way of knowing about atoms.  -- George Wald''',
r'''A pious man is one who would be an atheist if the king were.  -- la Bruyere''',
r'''A plagiarist steals a writer's mental children.  -- Isaac Asimov''',
r'''A plucked goose doesn't lay golden eggs.''',
r'''A poet is born not made.''',
r'''A political career brings out the basest qualities in human nature.  -- Bryce''',
r'''A poor man sells his saucepan to buy something to put in it.''',
r'''A pound of salt will not sweeten a single cup of tea.''',
r'''A pragmatist is one who's ideology/theology has failed.  -- Herbert Schlossberg''',
r'''A prediction is but an explanation in advance.  -- James Carse''',
r'''A President is impeachable if he attempts to subvert the Constitution.  -- Madison''',
r'''A private sin is not so prejudicial in the world as a public indecency.''',
r'''A problem found by appraisal must be found and fixed each time it occurs.''',
r'''A problem found by solution is gone forever.''',
r'''A problem is nothing more than a solution in disguise.  -- John Taylor''',
r'''A productive drunk is the bane of moralists.''',
r'''A professorship of theology should have no place in our institution.  -- Thomas Jefferson''',
r'''A project not worth doing at all is not worth doing well.''',
r'''A proliferation of theories is a symptom of a lack of data.  -- Eddington''',
r'''A prophet is not without honor save in his own country.  -- New Testament''',
r'''A prosperous fool is a grievous burden.  -- Aeschylus''',
r'''A proverb is a short sentence based on long experience.  --  Miguel de Cervantes''',
r'''A prudent question is one-half of wisdom.  -- Bacon''',
r'''A quiet conscience sleeps in thunder.''',
r'''A real friend walks in when the rest of the world walks out.''',
r'''A relationship cannot be healthier than both people.''',
r'''A Renaissance man refuses to define himself.''',
r'''A rich person is not one who has the most, but one who needs the least.''',
r'''A ringing telephone is a request, not an order.''',
r'''A rising tide lifts all boats.  -- Sean Lemass''',
r'''A rolling stone gathers no moss.  -- Publilius Syrus''',
r'''A scientist looking at nonscientific problems is just as dumb as the next guy.''',
r'''A scientist must be successful and not a success-fool.  -- Gerhard Uhlenbruck''',
r'''A second class effort is a first class mistake.''',
r'''A second fault ought not to be pardoned.  -- G. Delamothe''',
r'''A secret is too little for one, enough for two, too much for three.''',
r'''A sense of humor is just common sense, dancing.  -- Clive James''',
r'''A serious work in philosophy could be written that consisted entirely of jokes.''',
r'''A ship on the beach is a lighthouse to the sea.  -- Dutch proverb''',
r'''A short prayer penetrates heaven.''',
r'''A single death is a tragedy, a million deaths is a statistic.  -- Joseph Stalin''',
r'''A slave is one who waits for someone to come and free him.  -- Ezra Pound''',
r'''A small fire makes often a great smoke.  -- G. Delamothe''',
r'''A small leak will sink a great ship.  -- Benjamin Franklin''',
r'''A snowflake near lightspeed completely obliterates a planet, even Jupiter.  -- Axel Emmermann''',
r'''A standard that no one follows is worse than useless; it is a waste of time.''',
r'''A stitch in time saves nine.''',
r'''A straight stick is crooked in the water.''',
r'''A straw vote only shows which way the hot air blows.  -- O'Henry''',
r'''A stupid person cannot be advised.  -- Lawrence Hirsch''',
r'''A system meant for common use should rarely need uncommon knowledge.  -- Redford''',
r'''A tale never loses in the telling.''',
r'''A teacher affects eternity.  -- Henry Adams''',
r'''A thief passes for a gentleman when stealing has made him rich.  -- Fuller''',
r'''A thing is not necessarily true because a man dies for it.''',
r'''A thing is not true for you until it is true in thought, word, and deed.  -- God?''',
r'''A third party cannot mediate a dispute if they are even subtley involved.''',
r'''A thought is often original, though you have uttered it a hundred times.''',
r'''A tree is known by its fruit.  -- New Testament''',
r'''A tribe is a group of people who honor the same perceptions.  -- Carolyn Myss''',
r'''A true leader cannot make anyone do something they do not want to do.  -- Sir Chris Bonington''',
r'''A true sign of wealth is free time -- freedom from drudgery.  -- Daniel Newman''',
r'''A truth that's told with bad intent beats all the lies you can invent.  -- Blake''',
r'''A violent man will die a violent death.  -- Lao Tsu''',
r'''A vision is only as good as the clarity of the image presented.  -- TWendle''',
r'''A wealth of information creates a poverty of attention.  -- Herbert Simon''',
r'''A weed is a plant whose virtues have not been discovered.  -- Ralph Emerson''',
r'''A wise lover values not so much the gift of the lover as the love of the giver.''',
r'''A wise man cares not for what he cannot have.  -- George Herbert''',
r'''A wise man is never surprised.  -- Horace''',
r'''A wise person makes his own decisions, a weak one obeys public opinion.''',
r'''A witty saying proves nothing.  -- Voltaire''',
r'''A woman is as old as she looks before breakfast.  -- E. W. Howe''',
r'''A woman is as old as she looks to a man who likes to look at her.  -- Finley Dunne''',
r'''A woman is as young as she feels like telling you she is.''',
r'''A woman never forgets the men she could have had; a man, the women he couldn't.''',
r'''A woman without a man is like a fish without a bicycle.  -- Gloria Steinem''',
r'''A word in time is worth two afterwards.  -- James Carmichaell''',
r'''A word to the wise is enough.  -- Miguel de Cervantes''',
r'''A writer must not shift your point of view.  -- William Safire''',
r'''A writer without an audience is a writer; a writer with an audience, very lucky.''',
r'''A yawn is a silent shout.  -- G. K. Chesterton''',
r'''A young man might have more money than brains -- but not for long!''',
r'''A [person] without religion is like a fish without pajamas.  -- J. Powers''',
r'''Ability has nothing to do with opportunity.  -- Napoleon''',
r'''Above all things, reverence yourself.''',
r'''Absence makes the heart grow fonder.  -- Sextus Propertius''',
r'''Absence of evidence is not evidence of absence.''',
r'''Absence sharpens love.  Presence strengthens it.  -- Thomas Fuller''',
r'''Absence works wonders.  -- Tottel''',
r'''Abstraction is representing the whole by a part of the whole.''',
r'''Accept forgiveness as a way of life.''',
r'''Accept loneliness as normal, merely a sign that action is required.  -- Limon''',
r'''Accept your ordination.  -- Carolyn Myss''',
r'''Achilles cannot defeat the tortoise if he thinks of space and time.  -- Valery''',
r'''Action is what separates an opinion from a belief.  -- Patel''',
r'''Action makes more fortune than caution.''',
r'''Action may not always bring happiness, but there is no happiness without action.''',
r'''Actions speak louder than words.  -- Confucius''',
r'''Ad astra per aspera.  (To the stars through hardships.)''',
r'''Adaptation precludes adaptivity.  -- Carl White''',
r'''Adde parvum parvo magnus acervus erit.  (Add little to little, get big pile.)''',
r'''Addiction is an adaptation.  It's not you.  It's your cage.  -- Bruce Alexander''',
r'''Admit it, unplug, and get it over with.  -- Carolyn Myss''',
r'''Adolf Hitler made a mistake admiring Napoleon's strategy.''',
r'''Adversity introduces man to himself.''',
r'''Adversity makes a man wise, not rich.  -- John Ray''',
r'''Advice from an old carpenter:  Measure twice, saw once.''',
r'''Advice is a dangerous gift; be cautious about giving and receiving it.''',
r'''Advice is a form of nostalgia.  -- Mary Schmich''',
r'''Advice is least heeded when most needed.''',
r'''Advice only works for the people that give it.  -- Scott Adams''',
r'''Advocacy addiction limits our ability to learn from others; use inquiry instead.''',
r'''Affection blinds reason.  -- J. Howell''',
r'''Affection makes a fool of any man.  -- Ben Jonson''',
r'''After a calm comes a storm.  -- Thomas Draxe''',
r'''After a storm comes a calm.''',
r'''After age 30, we are all in extra innings.  -- Alan Silverstein''',
r'''After dinner sit awhile, after supper walk a mile.  -- Whetstone''',
r'''After enlightenment, do the laundry.  -- Zen proverb''',
r'''After pleasure comes pain.  -- J. C. Bridge''',
r'''After the game, the king and the pawn go in the same box.  -- Italian proverb''',
r'''Age before beauty; and pearls before swine.  -- Dorothy Parker''',
r'''Age does not protect you from love, but love somewhat protects you from age.''',
r'''Age doesn't always bring wisdom.  Sometimes age comes alone.''',
r'''Age is a high price to pay for maturity.''',
r'''Age is like love, it cannot be hid.  -- Dekker''',
r'''All are given the key to heaven's gates; the same key opens the gates of hell.''',
r'''All are not merry that dance lightly.''',
r'''All are not thieves that dogs bark at.''',
r'''All art is but imitation of nature.  -- Seneca''',
r'''All clouds bring not rain.''',
r'''All dreams are possible until proven otherwise.  -- Kenny Loggins''',
r'''All education is accompanied by pain.  -- Aristotle''',
r'''All finite play is play against itself.  -- James Carse''',
r'''All forms of government are pernicious, including good government.  -- Edward Abbey''',
r'''All generalizations are dangerous, even this one.  -- Dumas''',
r'''All gold is fool's gold.  -- Edward Abbey''',
r'''All good work is done in defiance of management.  -- Tom Peters''',
r'''All governments need enemies.  How else to justify their existence?  -- Edward Abbey''',
r'''All great discoveries are made by mistake.  -- Young''',
r'''All great discoveries have been made from a willingness to not be right.  -- God?''',
r'''All great ideas are controversial, or have been at one time.''',
r'''All great truths begin as blasphemies.  -- George Shaw''',
r'''All hope abandon, ye who enter here!  -- Dante Alighieri''',
r'''All I ask of you is forever to remember me as loving you.''',
r'''All I know is, I will get guidance when I need it.  -- Carolyn Myss''',
r'''All I need to do is change one attitude and that is enough to change my world.''',
r'''All I want from you is your joyful sharing.  -- Lee Coit''',
r'''All in all, it's just another brick in the wall.''',
r'''All is fair in love and war.''',
r'''All is not gold that glitters.''',
r'''All is not lost that is delayed.  -- A. Boyer''',
r'''All is well that ends well.  -- John Heywood''',
r'''All laws are simulations of reality.  -- John C. Lilly''',
r'''All life evolves by the differential survival of replicating entities.  -- Richard Dawkins''',
r'''All limits must be zero, one, or infinite.''',
r'''All machines are amplifiers.''',
r'''All may begin a war, few can end it.''',
r'''All men are mortal.  -- Haughton''',
r'''All men know the utility of useful things, but know not the utility of futility.''',
r'''All modern thought is permeated by the idea of thinking the unthinkable.''',
r'''All my life I wanted to be someone; I should have been more specific.  -- Wagner''',
r'''All obstacles not foreseen will be tripped over.''',
r'''All people smile in the same language.''',
r'''All philosophy lies in two words:  Sustain and abstain.  -- Epictetus''',
r'''All professions are organized conspiracies against the laity.  -- Russell''',
r'''All progress depends on the unreasonable man.  -- George Shaw''',
r'''All relationship is a mirror of your relationship with yourself.  -- Deepak Chopra''',
r'''All roads in the Middle East lead to the bizarre.  -- John Chanselor''',
r'''All roads lead to Rome.  -- La Fontaine''',
r'''All that is said in the kitchen should not be heard in the hall.''',
r'''All that we may see or seem, is but a dream within a dream.  -- Edgar Allan Poe''',
r'''All the world's churchyards are full with irreplaceable people.''',
r'''All things are good untried.  -- James Carmichaell''',
r'''All things come to he who waits.''',
r'''All things excellent are as difficult as they are rare.''',
r'''All things merge into one, and a river runs through it.  -- Norman McLain''',
r'''All things obey money.  -- Guazzo''',
r'''All truth, like love, is eternal -- while it lasts.  -- William Etkin''',
r'''All wars are civil wars, because all men are brothers...  -- Francois Fenelon''',
r'''All we learn from history is that we learn nothing from history.  -- Hegel''',
r'''All you accomplish by defending someone is to concede that he needs a defense.''',
r'''All you have to offer another human being, ever, is your own state of being.''',
r'''All you need in this life is ignorance and confidence, and then success is sure.''',
r'''All your fears must be embraced, entertained, honored, and you go on with them.''',
r'''Allow each soul to walk its path.  -- Conversations with God''',
r'''Allow others to make educational mistakes.''',
r'''Allow your children to face the consequences of their actions.  -- Brown''',
r'''Almost everything is easier to get into than out of.''',
r'''Almost everything looks better after a good night's sleep.  -- H. Jackson Brown''',
r'''Almost was never hanged.  -- Roger Edgeworth''',
r'''Alternatives exclude.  Saying "yes" to one thing says "no" to another.  -- Neifert''',
r'''Always be careful to make a bad impression on undesirables.''',
r'''Always do what you are afraid to do.  -- Emerson''',
r'''Always the dullness of the fool is the whetstone of the wits.''',
r'''Amateurs talk strategy while generals talk logistics.''',
r'''Ambition is the last refuge of the failure.  -- Oscar Wilde''',
r'''America's best buy for a nickel is a telephone call to the right person.''',
r'''Americans are people who insist on living in the present, tense.''',
r'''Americans do the right thing, but only after exhausting all other possibilities.  -- Winston Churchill''',
r'''An addict bonds with heroin because he can't bond as fully with anything else.''',
r'''An American is a man with two arms and four wheels.  -- A Chinese child''',
r'''An aphorism is a one-line novel.  -- Leonid Sukhorukov''',
r'''An apple a day keeps the doctor away.''',
r'''An argument is the longest distance between two points.''',
r'''An armed society is a polite society.''',
r'''An army is nothing but a well-organized lynch mob.  -- Edward Abbey''',
r'''An army marches on its stomach.  -- Napoleon''',
r'''An artist who is self-taught is taught by a very ignorant person indeed.''',
r'''An atheist is one point beyond the devil.  -- Fuller''',
r'''An atom-blaster is a good weapon, but it can point both ways.''',
r'''An average person laughs about 15 times a day.''',
r'''An easy answer to every human problem:  Neat, plausible, and wrong.  -- Mencken''',
r'''An efficient bureaucracy is the greatest threat to liberty.  -- Eugene McCarthy''',
r'''An egg today is better than a hen tomorrow.  -- Benjamin Franklin''',
r'''An ego trip takes you nowhere.''',
r'''An emotionless life is biologically impossible.  -- Lawrence Hirsch''',
r'''An empty man is full of himself.  -- Edward Abbey''',
r'''An empty purse fills the face with wrinkles.  -- Thomas Draxe''',
r'''An empty stomach is not a good political advisor.  -- Albert Einstein''',
r'''An enduring paradox of the human mind is that it doesn't know itself very well.''',
r'''An era can be said to end when its basic illusions are exhausted.  -- Miller''',
r'''An expert is a person who knows his limitations.''',
r'''An expert is an ordinary guy 50 miles from home.''',
r'''An expert knows no more than you do, but has it better organized.''',
r'''An eye for an eye, a tooth for a tooth.''',
r'''An honest answer is a sign of true friendship.  -- Solomon''',
r'''An honest man's the noblest work of God.  -- Alexander Pope''',
r'''An honest tale speeds best being plainly told.''',
r'''An idea is not responsible for the people who believe in it.''',
r'''An idea is only as good as its execution.''',
r'''An idea well-expressed is like a design of gold, set in silver.  -- Solomon''',
r'''An idealist is a person who helps other people to be prosperous.  -- Henry Ford''',
r'''An idle brain is the devil's shop.  -- W. Perkins''',
r'''An incorrect belief may still benefit its believer.''',
r'''An intellectual is someone whose mind watches itself.  -- Albert Camus''',
r'''An investment in knowledge always pays the best interest.  -- Benjamin Franklin''',
r'''An occasion lost cannot be redeemed.  -- John Ray''',
r'''An open auction extracts the highest price from any buyer.''',
r'''An optimist laughs to forget; a pessimist forgets to laugh.''',
r'''An ounce of application is worth a ton of abstraction.  -- Booker''',
r'''An ounce of clear truth is worth a pound of obfuscation.''',
r'''An ounce of emotion equals a ton of facts.''',
r'''An ounce of good fortune is worth a pound of forecast.  -- Fuller''',
r'''An ounce of vanity can ruin a ton of merit.''',
r'''An owl is the king of the night.  -- Thomas Draxe''',
r'''An ox is taken by the horns, and a man by the tongue.''',
r'''Analogies prove nothing...  But they can make one feel at home.  -- Freud''',
r'''And malt does more than Milton can to justify God's ways to man.  -- Housman''',
r'''And only the good die young.  -- Billy Joel''',
r'''And that's the way it is...  -- Walter Cronkite''',
r'''And tomorrow will be like today, only more so.  -- Isaiah 56:12 [NSV]''',
r'''Angels do not support BS.  -- Carolyn Myss''',
r'''Anger goes after the first available target.  -- Reggie Rivers''',
r'''Anger is a short madness.  -- Taverner''',
r'''Anger kills as surely as the other vices.''',
r'''Animals cannot be harvested.  They mature, but they do not ripen.  -- Carse''',
r'''Another such victory over the Romans, and we are undone.  -- Pyrrhus''',
r'''Answers almost never fulfill the promise of our questions.  -- John Taylor''',
r'''Anxiety is a condition of the privileged.''',
r'''Any clod can have the facts, but having opinions is an art.  -- Charles McCabe''',
r'''Any difference that makes a difference is information.  -- Gregory Bateson''',
r'''Any difference that makes no difference is noise.''',
r'''Any doom that can be predicted won't happen.  -- Scott Adams''',
r'''Any excuse will serve a tyrant.  -- Aesop''',
r'''Any fool can criticize, condemn, and complain -- and most fools do.  -- Carnegie''',
r'''Any fool can make a rule and every fool will mind it.  -- Thoreau''',
r'''Any fool can paint a picture, but it takes a wise person to be able to sell it.''',
r'''Any illusion requires both time and space to be experienced.''',
r'''Any man who thinks of himself as therapy should not have a license to practice.''',
r'''Any negativity can make you sick.  -- Carolyn Myss''',
r'''Any new tax law must exempt enough voters to win the next election.''',
r'''Any philosophy that can be put in a nutshell belongs there.  -- Harris''',
r'''Any reality that you get stuck in is the wrong one.  -- Ram Dass''',
r'''Any sufficiently advanced technology is indistinguishable from magic.  -- Arthur Clarke''',
r'''Any system that depends on reliability is unreliable.''',
r'''Any technology distinguishable from magic is insufficiently advanced.  -- Gehm's corollary''',
r'''Any time that you crave, there is always going to be suffering built right in.''',
r'''Anyone can hold the helm when the sea is calm.  -- Publilius Syrus''',
r'''Anyone can make history.  Only a great man can write it.  -- Oscar Wilde''',
r'''Anyone can make mistakes, but only an idiot persists in his error.  -- Cicero''',
r'''Anyone who wants to rule, should, ipso facto, not be allowed to do so.''',
r'''Anyone without a sense of humor is at the mercy of everyone else.  -- Rotsler''',
r'''Anything free comes with no guarantee.''',
r'''Anything free is worth what you pay for it.''',
r'''Anything is easy if someone else does it for you.''',
r'''Anything is easy if you can assimilate it to your collection of models.  -- Papert''',
r'''Anything is possible if you don't know what you're talking about.''',
r'''Anything is possible, but only a few things actually happen.  -- Rich Rosen''',
r'''Anything is possible, unless it is not.''',
r'''Anything that sticks out usually gets hammered back in.''',
r'''Apparently there are multiple way sto invoke multiple universes.''',
r'''Appearance VERSUS reality?  Appearance IS reality...  -- Edward Abbey''',
r'''Appearances often are deceiving.  -- Aesop''',
r'''Apply good consumerism to your love relationships.  -- Will Limon''',
r'''Approach your limits from the safe side.  -- Volker Hetzer''',
r'''Architecture is frozen music.  -- Hegel''',
r'''Argue for your limitations and sure enough, they are yours.  -- Richard Bach''',
r'''Armed with these patterns, we go forward and brilliantly predict... the past. -- Allan Roth''',
r'''Art has no enemy but ignorance.  -- Ben Jonson''',
r'''Art is a lie that makes us realize the truth.  -- Picasso''',
r'''Art is never finished, only abandoned.  -- Leonardo da Vinci''',
r'''Artistic temperament is a disease that afflicts amateurs.  -- G. K. Chesterton''',
r'''As a man lives, so shall he die; as a tree falls, so shall it lie.''',
r'''As a rule, pantheism is only a respectful variety of atheism.  -- Schopenhauer''',
r'''As average skill increases, it's more difficult to outperform by large margins.  -- Larry Swedroe''',
r'''As far as the question of Martian life, if we don't go, we won't know.  -- Robert Zubrin''',
r'''As for the future, your task is not to foresee, but to enable it.''',
r'''As goatherd learns his trade by goat, so writer learns his trade by wrote.''',
r'''As is the mother, so is her daughter.  -- Old Testament''',
r'''As life is to live, so love is to give.  -- Patricia Barc''',
r'''As others hurt and betray us, so are we the perpetrators of pain.  -- Limon''',
r'''As silent as the grave.  -- Robert Stevenson''',
r'''As soon as man is born he begins to die.''',
r'''As the body becomes more limited, the soul expands.  -- Dustin Hoffman''',
r'''As the question, so the answer.  -- Torriano''',
r'''As the radius of knowledge increases, so does the circumference of ignorance.''',
r'''As we let our own light shine, we give others permission to do the same.''',
r'''As we migrated into Europe we discovered something new, called winter.  -- Paul Stamets''',
r'''Ashes to ashes, dust to dust; if God won't have you, the devil must.''',
r'''Ask a self-answering question; get a self-questioning answer.  -- John Flagg''',
r'''Ask much to have little.''',
r'''Ask no questions and you will be told no lies.  -- Charles Dickens''',
r'''Ask not for whom the bell tolls; it tolls for thee.  -- John Donne''',
r'''Ask not what's inside your head, but what your head's inside of.  -- Gibson''',
r'''Ask yourself whether you are happy and you cease to be so.  -- John Mill''',
r'''Assertiveness is essential to a healthy relationship.''',
r'''Assume the worst, hope for the best, accept reality.  -- Morgan Housel''',
r'''Assumption is the mother of all screw-ups.  -- Wethern''',
r'''Asteroids are nature's way of asking, "How's that space program coming along?"''',
r'''Astrology is true, but the astrologers cannot find it.  -- George Herbert''',
r'''At 50, everyone has the face he deserves.  -- George Orwell''',
r'''At either end of the social spectrum there lies a leisure class.  -- Beck''',
r'''At four we know all the questions.  At eighteen we know all the answers.''',
r'''At retirement, human capital falls to zero.  -- Pfau and Kitces''',
r'''At the feast of ego, everyone leaves hungry.''',
r'''At the moment of meeting, the parting begins.''',
r'''Attachments fall away like a snake sheds its skin.  -- Ram Dass''',
r'''Attack the problem, not each other.  -- Limon''',
r'''Auribus teneo lupum.  (I hold a wolf by the ears.)''',
r'''Authority should command respect, not demand respect.''',
r'''Autocracy is based on the theorem that one man is smarter than many.''',
r'''Autograph your work with quality.''',
r'''Avert misunderstanding by calm, poise, and balance.''',
r'''Avoid unnecessary dependency on large scale, harmful predictions.  -- Nassim Taleb''',
r'''Avoidable complexity should indeed be avoided.''',
r'''Avoiding danger is no safer in the long run than outright exposure to it.''',
r'''Bad is never good until worse happens.  -- Danish proverb''',
r'''Bad money drives out good money; new love drives out old love.''',
r'''Barbarian:  Thinks the customs of his tribe and island are laws of nature.''',
r'''Barking dogs seldom bite.''',
r'''Be a Fundamentalist -- ensure the Fun always comes before the mental.  -- Bhaerman''',
r'''Be a good listener 'cause you never learn much from talking.  -- Will Rogers''',
r'''Be a light unto the darkness, and curse it not.  -- Conversations with God''',
r'''Be agreeable in manner, and resolute in action.  -- Lord Chesterfield''',
r'''Be an expert on what's strong, not on what's wrong.  -- Will Limon''',
r'''Be ashamed to die until you have won one victory for humanity.  -- Horace Mann''',
r'''Be bold in what you stand for and careful what you fall for.  -- Mary Webb''',
r'''Be both a speaker of words and a doer of deeds.  -- Homer''',
r'''Be careful about what you teach your children.  They might believe you.''',
r'''Be careful what you plug yourself into.  -- Carolyn Myss''',
r'''Be careful whose advice you buy, but be patient with those who supply it.''',
r'''Be cheerful while you are alive.''',
r'''Be conservative in what you generate, but liberal in what you accept.''',
r'''Be emotionally prepared to walk away from any deal that doesn't work for you.''',
r'''Be faithful to that which exists nowhere but in yourself.  -- Andre Gide''',
r'''Be fearful when others are greedy, and greedy when others are fearful.  -- Warren Buffett''',
r'''Be good and you will be lonesome.  -- Mark Twain''',
r'''Be happy with the real pleasures in life.''',
r'''Be humble or you will stumble.''',
r'''Be in the world but not of it.  -- Meher Baba''',
r'''Be kind and courteous to everyone.  -- Peter Chantilis''',
r'''Be moderate where pleasure is concerned, avoid fatigue.''',
r'''Be nice to people on your way up; you'll meet them on your way down.  -- Mizner''',
r'''Be not anxious about what you have, but about what you are.  -- St. Gregory I''',
r'''Be not simply good -- be good for something.  -- Henry Thoreau''',
r'''Be organized:  This is a euphemism for being efficiently lazy.  -- Isaac Asimov''',
r'''Be self-reliant and your success is assured.''',
r'''Be spontaneous!''',
r'''Be sure your ladder of success is leaning against the right wall.  -- Dobson''',
r'''Be thou familiar, but by no means vulgar.  -- William Shakespeare''',
r'''Be to friends' virtues very kind; be to their faults a little blind.''',
r'''Be willing to lead your life, not just follow it.''',
r'''Beauty and chastity seldom agree.''',
r'''Beauty fades like a flower.''',
r'''Beauty has nothing to do with the package I come in; it is just what I radiate.''',
r'''Beauty is in the eye of the beholder.''',
r'''Beauty is one of the rare things which do not lead to doubt of God.  -- Anouilh''',
r'''Beauty is potent but money is omnipotent.''',
r'''Beauty may have fair leaves, yet bitter fruit.  -- Lyly''',
r'''Beauty that doesn't make a woman vain makes her very beautiful.  -- Josh Billings''',
r'''Because we don't think about future generations, they will never forget us.''',
r'''Become famous for finishing important, difficult tasks.  -- H. Jackson Brown''',
r'''Becoming number one is easier than remaining number one.  -- Senator Bill Bradley''',
r'''Before borrowing money from a friend, decide which you need more.  -- Hallock''',
r'''Before buying a piece of property, walk around its perimeter.''',
r'''Before thirty, men seek disease; after thirty, diseases seek men.  -- Chinese''',
r'''Before Xerox, five carbons were the maximum extension of anyone's ego.''',
r'''Before you accuse, walk a mile in their shoes.''',
r'''Before you kill the cat, make arrangements for the mice.  -- Sufi proverb''',
r'''Beg from beggars and you will never be rich.''',
r'''Beggars cannot be choosers.''',
r'''Begin a lesson with a humorous illustration.  -- the Talmud''',
r'''Begin well, end badly; begin badly, end worse.''',
r'''Behaviors don't continue unless we get something for them, even just attention.''',
r'''Behind all individual differences there turns out to be only one of us.''',
r'''Behind every argument is someone's ignorance.''',
r'''Being brave does not mean going out looking for trouble.''',
r'''Being consistent is less important than being happy.  -- Marlo Thomas''',
r'''Being defeated is often a temporary condition.  Giving up makes it permanent.''',
r'''Being deserving of praise blinds us to flattery.  -- William Wall''',
r'''Being flexible is how you exercise your adult part.''',
r'''Being human involves becoming a burden.  -- Roy Bonisteel''',
r'''Being lazy will make you poor, but hard work will make you rich.  -- Solomon''',
r'''Being on sea, sail; being on land, settle.  -- George Herbert''',
r'''Being part of the tribal mind is part of your evolution.  -- Carolyn Myss''',
r'''Being predictable in your style puts you at the mercy of your adversary.''',
r'''Being right is seldom enough.  Even the best ideas must be packaged and sold.''',
r'''Belief in God?  An afterlife?  I believe in rock...  -- Edward Abbey''',
r'''Belief in the supernatural reflects a failure of the imagination.  -- Edward Abbey''',
r'''Belief is not the beginning but the end of all knowledge.  -- Johann von Goethe''',
r'''Believe and ye shall receive.''',
r'''Believe only half of what you see, and nothing that you hear.  -- Mulock''',
r'''Believe that life is worth living and your belief will help create the fact.''',
r'''Believing God created it all is religion.  Wondering how it works is science.''',
r'''Best is best cheap.  -- Wolcot''',
r'''Best to bend it while it is a twig.''',
r'''Better a cruel truth than a comfortable delusion.  -- Edward Abbey''',
r'''Better a diamond with a flaw than a pebble without.  -- Chinese proverb''',
r'''Better a lean peace than a fat victory.  -- Sanford''',
r'''Better a little loss than a long sorrow.  -- Langland''',
r'''Better an open enemy than a false friend.''',
r'''Better clean death than dirty life.  -- Frank Herbert''',
r'''Better late than never.  -- Titus Livius''',
r'''Better living a beggar than buried an emperor.''',
r'''Better safe than sorry.''',
r'''Better some of a pudding than none of a pie.  -- John Ray''',
r'''Better the devil you know than the devil you don't know.''',
r'''Better the foot slip than the tongue.  -- Sanford''',
r'''Better to be ignorant of a matter than half know it.  -- Publilius Syrus''',
r'''Better to be patient on the road than a patient in the hospital.  -- C. Jenkins''',
r'''Better to be poor and fear the Lord than to be rich and in trouble.  -- Solomon''',
r'''Better to be the head of an ass than the tail of a horse.  -- Clarke''',
r'''Better to reign in Hell then serve in Heaven.  -- Milton''',
r'''Better to remain silent and be thought a fool than speak and remove all doubt.''',
r'''Better to understand a little than to misunderstand a lot.''',
r'''Better untaught than ill taught.  -- John Ray''',
r'''Between a good reputation and great wealth, choose a good reputation.  -- Solomon''',
r'''Beware of all enterprises that require new clothes...  -- Henry Thoreau''',
r'''Beware of the man of one book.  -- George Herbert''',
r'''Beware of the man who has no enemies.  -- Edward Abbey''',
r'''Beware of the man who knows the answer before he understands the question.''',
r'''Beware of your wishes:  They will probably come true.  -- Edward Abbey''',
r'''Beware substantiation of abstracta, which leads to fallacies.''',
r'''Beware temptation -- the more of it you see, the better it looks.''',
r'''Beware the legless man who teaches running.''',
r'''Beware the wrath of a patient person.''',
r'''Big brother isn't watching you, you're watching big brother -- all 181 channels.''',
r'''Bigger isn't always better, but better will always get bigger.  -- Kevin Jones''',
r'''Biochemistry is the study of carbon compounds that crawl.  -- Mike Adams''',
r'''Birds of a feather flock together.''',
r'''Bizarreness is the essence of the exotic.''',
r'''Blessed is he who expects nothing, for he shall never be disappointed.  -- Pope''',
r'''Blessings on him that invented sleep!  -- Cervantes''',
r'''Blinding speed can compensate for a lot of deficiencies.  -- David Nichols''',
r'''Blood is thicker than water.''',
r'''Boldness has genius, power, and magic in it.''',
r'''Books as well as food nourish and warm people.  Books make connections.  -- Sarton''',
r'''Boredom:  The desire for desires.  -- Leo Tolstoi''',
r'''Borrowed garments never fit well.  -- Fuller''',
r'''Boys will be boys.''',
r'''Break a few rules.''',
r'''Brevity is the soul of wit.''',
r'''Build a better mousetrap and the world will beat a path to your door.''',
r'''Build a system any fool can use, and only a fool will want to use it.''',
r'''Build something foolproof and every fool will use it.''',
r'''Building a better mousetrap merely results in smarter mice.''',
r'''Bumper sticker:  My politics don't fit on a bumper sticker.  -- John Shelton''',
r'''Bureaucracy:  A giant mechanism operated by pygmies.  -- Honor de Balzac''',
r'''Business first and pleasure afterwards.  -- Surtees''',
r'''Business is a combination of war and sport.  -- Andre Maurois''',
r'''Busy souls have no time to be busybodies.  -- Austin O'Malley''',
r'''But "yes" can mean so many things.  -- John Taylor''',
r'''But how can fame and profit concern a man of genius?  -- Li Ch'i''',
r'''But in this world nothing is certain but death and taxes.  -- Benjamin Franklin''',
r'''But it does move!  -- Galileo Galilei''',
r'''Buy low, sell high.''',
r'''By allowing her to be totally herself...  She frees me to to be totally myself.''',
r'''By failing to prepare, you are preparing to fail.''',
r'''By nature, men are nearly alike; by practice, they get to be far apart.''',
r'''By protracting life, we do not deduct one jot from the duration of death.''',
r'''By the time everyone agrees, it is too late.''',
r'''By the yard, life is hard.  By the inch, it's a cinch.''',
r'''By their fruit you will recognize them. (By their works ye shall know them.)  -- Matthew 7:16''',
r'''Cabbage has a higher yield per acre than any other vegetable.''',
r'''Call on God, but row away from the rocks.  -- Indian proverb''',
r'''Calling religion a mental illness is really insulting to mentally ill people.  -- Cristina Rad''',
r'''Can anyone remember when the times were not hard and money not scarce?  -- Ralph Emerson''',
r'''Can anything be sadder than work left unfinished?  Yes, work never begun.''',
r'''Cancer cures smoking.''',
r'''Capability does not imply intent.''',
r'''Capitalism is the exploitation of one man by another; socialism is the reverse.''',
r'''Capitalists will sell themselves the rope to hang themselves with.''',
r'''Care is no cure.  -- Greene''',
r'''Carrying resentment is like drinking poison and waiting for someone else to die.''',
r'''Cast not out the foul water till you bring in the clean.  -- James Carmichaell''',
r'''Cats, no less liquid than their shadows, offer no angles to the wind.''',
r'''Celebrity isn't an achievement in itself.  -- Carol Loomis''',
r'''Certain actors in history change the world by staging their own defeat.  -- Wolf''',
r'''Chance favors the prepared mind.  -- Louis Pasteur''',
r'''Chance is perhaps the pseudonym of God when He did not want to sign.  -- France''',
r'''Change your mind as often as the facts change.  -- Morgan Housel''',
r'''Change your thoughts and you change your world.''',
r'''Character consists of what you do on the third and fourth tries.  -- Michener''',
r'''Character is not made in a crisis -- it is only exhibited.  -- Robert Freeman''',
r'''Character is the power to change the face of things.''',
r'''Character is what you are in the dark.  --  Dwight Moody''',
r'''Charity begins at home.''',
r'''Charity should be spontaneous.  Calculated altruism is an affront.  -- Edward Abbey''',
r'''Charm is the quality in others that makes us more satisfied with ourselves.''',
r'''Chastity and virtue are their own punishment.''',
r'''Chastity is more a state of mind than of anatomy.  -- Edward Abbey''',
r'''Chastity is no more a virtue than malnutrition.  -- Alex Comfort''',
r'''Cheap things are of no value, valuable things are not cheap.''',
r'''Check again to ensure it's not loaded.''',
r'''Children are poor men's riches.''',
r'''Children become ready for toilet training and independence at the same time.''',
r'''Children have more need of models than of critics.''',
r'''Children need love, especially when they do not deserve it.''',
r'''Choice is a terrifying power.  -- Carolyn Myss''',
r'''Choice of words is spontaneous but no accident.  -- NLP''',
r'''Choice within constraint is essential; choice without constraint is paralyzing.  -- Barry Schwartz''',
r'''Choose happiness for yourself regardless of what others do.''',
r'''Choose not a spouse by the eye only.''',
r'''Christianity might be a good thing if anyone ever tried it.  -- George Shaw''',
r'''Circumstances rule men; men do not rule circumstances.  -- Herodotus''',
r'''Citizens want honest politicians until they want something fixed.''',
r'''Civility is a sign of strength, not weakness.  -- Peter Chantilis''',
r'''Civility means obeying the unenforceable.''',
r'''Civilization is limitless multiplication of unnecessary necessities.  -- Twain''',
r'''Civilization is what the neutron bombs are supposed to leave intact.  -- Enright''',
r'''Civilization remains a remote ideal.  -- Edward Abbey''',
r'''Clarity is power.  -- Buckminster Fuller''',
r'''Classy:  You have a lot to say, but remain silent in front of fools.''',
r'''Cleanliness is next to Godliness.''',
r'''Clear thinking requires courage rather than intelligence.  -- Thomas Szasz''',
r'''Cleopatra lived closer in time to WWII than the building of the Great Pyramid.''',
r'''Cleverness is not wisdom.  -- Euripides''',
r'''Cloning is unnatural, but unnatural isn't... a synonym for bad.  -- Richard Dawkins''',
r'''Clothes make the man.''',
r'''Cogito ergo sum.  (I think, therefore I am.)  -- Rene Descartes''',
r'''Collective responsibility brings a lowering of moral standards.  -- Freeman Dyson''',
r'''College is a refuge from hasty judgment.  -- Robert Frost''',
r'''Comedy is tragedy plus time.  -- Steve Allen''',
r'''Comfort zones are most often expanded through discomfort.  -- McWilliams''',
r'''Coming events cast their shadows before.''',
r'''Command yourself to feel good about yourself.  -- Carolyn Myss''',
r'''Commitment is making time when there is none.''',
r'''Commitment is the stuff character is made of.''',
r'''Commitment is what transforms a promise into reality.''',
r'''Common minds discuss people; moderate minds, events; great minds, ideas.''',
r'''Common sense is instinct, and enough of it is genius.  -- Josh Billings''',
r'''Common sense is not so common.  -- Voltaire''',
r'''Common sense, in an uncommon degree, is what the world calls wisdom.  -- Coleridge''',
r'''Communication is next to impossible with someone who has no doubts.  -- Limon''',
r'''Communications are the lifeblood of a relationship, carrying the nutrients.''',
r'''Companionship is often shared loneliness.  -- Herbert Salzer''',
r'''Compensate complexity with simplicity.  -- Nassim Taleb''',
r'''Competence always contains the seeds of incompetence.''',
r'''Conceit causes more conversation than wit.  -- LaRouchefoucauld''',
r'''Concepts without words have no existence, and words without concepts no meaning.''',
r'''Concrete is heavy; iron is hard -- but the grass will prevail.  -- Edward Abbey''',
r'''Conflict is inevitable but not necessarily bad.  -- Paul Gillette''',
r'''Conflict is not possible without communication.  -- Fred Jandt''',
r'''Confusion can be both pleasant and helpful.''',
r'''Conquer yourself instead of the world.  -- Rene Descartes''',
r'''Conscience is God's presence in man.  -- Swedenborg''',
r'''Conscience makes egotists of us all.  -- Oscar Wilde''',
r'''Consciousness is a full-time job.  -- Carolyn Myss''',
r'''Consciousness is not an emergent property of the universe, but fundamental.  -- Christof Koch''',
r'''Consciousness means freedom from attachment.  -- Ram Dass''',
r'''Consensus is no substitute for leadership; it is the result of leadership.''',
r'''Consider all outcomes before taking a step, and spend your life on one leg.''',
r'''Consistency is always easier to defend than correctness.''',
r'''Consistency is the last refuge of the unimaginative.  -- Oscar Wilde''',
r'''Consistency is the quality of a stagnant mind.  -- John Sloan''',
r'''Consistency requires you to be as ignorant today as you were a year ago.''',
r'''Constant reorganization is the hallmark of a dynamic organization.''',
r'''Contentment is the smother of invention.  -- Laura Watson''',
r'''Contexts serve as (mental) primers.  -- Ellen Langer''',
r'''Conversation enriches the understanding, but solitude is the school of genius.''',
r'''Convincing yourself that a bad idea is a good idea is a bad idea.''',
r'''Cooler heads will prevail.''',
r'''Cooperation:  Doing with a smile what you are forced to do.''',
r'''Corporations as persons, not property, let them deny the rights of real persons.''',
r'''Correlation does not imply causation.''',
r'''Counsel must be followed, not praised.  -- Lyly''',
r'''Courage is grace under pressure.''',
r'''Courage is not the absence of fear but the conquest of it.  -- Scott Cochran''',
r'''Courage is the price life exacts for granting peace.  -- Amelia Earhart''',
r'''Covetousness brings nothing home.''',
r'''Cowards are cruel but the brave love mercy.  -- Gay''',
r'''Cream rises to the top, but so does scum.''',
r'''Creation is a mighty joke, but the laugh is at my own expense.  -- Meher Baba''',
r'''Creativity is allowing oneself to make mistakes.  Art is knowing which to keep.''',
r'''Creativity is no substitute for knowing what you are doing.''',
r'''Creativity, like love, should be diagnosed retrospectively.  -- John Schimel''',
r'''Credible people sign their work.''',
r'''Creditors have much better memories than debtors.''',
r'''Crisis is a motivator for change.''',
r'''Criticism comes easier than craftsmanship.  -- Zeuxis''',
r'''Cult:  A small, unpopular religion.  Religion:  A large, popular cult.''',
r'''Cultivate happiness and it becomes a habit.''',
r'''Culture is the habit of being pleased with the best and knowing why.''',
r'''Curiosity is ill manners in another's house.  -- Oudin''',
r'''Curiosity will conquer fear even more than bravery will.  -- James Stephens''',
r'''Cynicism is an unpleasant way of saying the truth.  -- Lillian Hellman''',
r'''Darkness is cheap.  -- Charles Dickens''',
r'''Data isn't information; information isn't knowledge; knowledge isn't wisdom.''',
r'''De gustibus non es disputandum. (In matters of taste there can be no disputes.)  -- old Roman axiom''',
r'''Dead men tell no tales.''',
r'''Deal with reality, or reality will deal with you.''',
r'''Death and taxes may be inevitable, but they should not be simultaneous.  -- Mack''',
r'''Death is a self-fulfilling prophecy.  You just don't dwell on it.  -- Nance''',
r'''Death is every man's final critic.  To die well you must live bravely.  -- Edward Abbey''',
r'''Death is just nature's way of telling you to slow down.''',
r'''Death is the one experience that we cannot put in perspective afterwards.''',
r'''Death is the ultimate low, from which we do not recover.''',
r'''Death keeps no calendar.  -- George Herbert''',
r'''Death pays all debts.''',
r'''Decisions terminate panic.''',
r'''Deeds are fruits, words are but leaves.  -- Thomas Draxe''',
r'''Deeds are males, and words are females.  -- Sanford''',
r'''Defeat is worse than death because you have to live with defeat.''',
r'''Degrees and credentials are primarily badges of compliance.  -- Bruce Levine''',
r'''Delay is preferable to error.  -- Thomas Jefferson''',
r'''Delay is the deadliest form of denial.  -- Parkinson''',
r'''Delusion fends off disillusion.  -- Ben Staub''',
r'''Democracy is good.  I say this because other systems are worse.  -- Nehru''',
r'''Democracy is the art of running the circus from the monkey cage.  -- Mencken''',
r'''Democracy is the worst form of government -- except for all the others.''',
r'''Democracy is where you can say what you think even if you don't think.''',
r'''Democracy means only that people are sovereign; not that they are infallible.  -- Rod Dreher''',
r'''Dependable is not the same as accurate.  -- Frederick Brooks''',
r'''Depression is anger without enthusiasm.''',
r'''Deprive a mirror of its silver and even the Czar won't see his face.''',
r'''Desire for greatness prevents its achievement.''',
r'''Desire has no rest.''',
r'''Desire unacted is corruption.  -- Ursula LeGuin''',
r'''Desires and longings are the root cause of all suffering.  -- Meher Baba''',
r'''Desires are nourished by delays.''',
r'''Despair is the necessary prerequisite for the next level of consciousness.''',
r'''Desperate diseases must have desperate cures.''',
r'''Details call things into being.  -- Leonard Bernstein''',
r'''Determine that the thing can and shall be done, and then we will find the way.''',
r'''Devil's advocacy is an honorable profession.''',
r'''Did God the designer choose a method designed precisely as if he wasn't there?  -- Richard Dawkins''',
r'''Difficult to find a black cat in a dark room, especially if there is no cat.  -- Confucius''',
r'''Discontent is the first step in the progress of a man or a nation.  -- Oscar Wilde''',
r'''Discouragement is simply the despair of wounded self-love.  -- De Fenelon''',
r'''Discussions of morality must inevitably lead to immoral statements.  -- Bradshaw''',
r'''Disengage from consumerism as the main avenue of experience.''',
r'''Dishonor will not trouble me, once I am dead.''',
r'''Divine justice, and how it plays out, is perfect.  -- Carolyn Myss''',
r'''Divorce can be a creative experience.  -- Will Limon''',
r'''DNA is not really a thing, it is a memory.  -- Deepak Chopra''',
r'''Do more than anyone expects, and pretty soon everyone will expect more.''',
r'''Do not ask for what you will wish you had not got.  -- Seneca''',
r'''Do not be angry with me if I tell you the truth.  -- Socrates''',
r'''Do not be intimidated by reality.''',
r'''Do not be overly suspicious where it is not warranted.''',
r'''Do not beg trouble from the future.  -- Nancy Kirkwood''',
r'''Do not believe everything you hear or anything you say.''',
r'''Do not clog intellect's sluices with bits of knowledge of questionable uses.''',
r'''Do not count your chickens before they are hatched.  -- Aesop''',
r'''Do not cross a river if it is four feet deep on average.  -- Nassim Taleb''',
r'''Do not handicap your children by making their lives easy.  -- Robert Heinlein''',
r'''Do not judge a book by its cover.''',
r'''Do not learn the tricks of the trade; learn the trade.''',
r'''Do not seek answers that cannot be given; you would not be able to live them.''',
r'''Do not stoop to tie your laces in your neighbor's melon patch.''',
r'''Do not think by infection, catching an opinion like a cold.''',
r'''Do not triumph before the victory.''',
r'''Do not try to live forever.  You will not succeed.  -- George Shaw''',
r'''Do not worry about which side your bread is buttered on:  You eat BOTH sides.''',
r'''Do one thing every day that scares you.  -- Mary Schmich''',
r'''Do the thing and have the power.  -- Ralph Emerson''',
r'''Do to others as you would have them do unto you.''',
r'''Do unto others as they would have you do unto them.  -- Haley''',
r'''Do unto yourself as you would have others do unto you.''',
r'''Do what you love, and follow your passion.  -- Jim and June Spencer''',
r'''Do what you want -- but KNOW what you are doing.  -- Kenny Washington''',
r'''Do you ever just seem to not be able to get around to procrastinating?''',
r'''Do you wish people to think well of you?  Don't speak well of yourself.  -- Pascal''',
r'''Doctors do not cry but men do.  -- Harry Weiss''',
r'''Doctors think many patients are cured who have simply quit in disgust.  -- Herold''',
r'''Does this path have a heart?  -- Carlos Castaneda''',
r'''Dog wisdom:  Avoid biting when a simple growl will do.''',
r'''Dog wisdom:  Eat with gusto and enthusiasm.''',
r'''Dog wisdom:  If what you want lies buried, dig until you find it.''',
r'''Dog wisdom:  Let others know when they have invaded your territory.''',
r'''Dog wisdom:  Take naps and stretch before rising.''',
r'''Dog wisdom:  Thrive on attention and let people touch you.''',
r'''Dogma takes over when facts fail.''',
r'''Dogs that bark at a distance bite not at hand.  -- Camden''',
r'''Doing gets it done.''',
r'''Doing is demonstrating that you know something.''',
r'''Doing what you love is freedom.  Loving what you do is happiness.''',
r'''Doing your best is more important than being the best.  -- Cathy Rigby's mom''',
r'''Dollar-cost average your entire life, you'll beat almost everyone who doesn't.  -- Morgan Housel''',
r'''Don't be ashamed to say what you are not afraid to think.  -- Montaigne''',
r'''Don't be mad about growing old.  Some aren't that lucky.''',
r'''Don't be reckless with other people's hearts.  -- Mary Schmich''',
r'''Don't be so afraid of making a mistake that you can't make a decision.''',
r'''Don't believe all you hear, spend all you have, or sleep all you want.  -- Brown''',
r'''Don't burn any bridges you might need to cross again later.''',
r'''Don't change a hair for me, not if you care for me.  -- Lee Coit''',
r'''Don't compare your insides with other people's outsides.''',
r'''Don't confuse mere inconveniences with real problems.  -- H. Jackson Brown''',
r'''Don't confuse motion with progress (or effort with results).''',
r'''Don't confuse things that need action with those that take care of themselves.''',
r'''Don't congratulate yourself too much, or berate yourself either.  -- Mary Schmich''',
r'''Don't count the days.  Make the days count.  -- Muhammed Ali''',
r'''Don't cross the bridge till you get to it.  -- Longfellow''',
r'''Don't die until you're dead.  -- Billy Connolly''',
r'''Don't do something.  Just stand there.  -- Vanguard founder Jack Bogle''',
r'''Don't ever slam a door; you might want to go back.''',
r'''Don't expect drastic changes fast.  Good practices require practice.  -- Hanson''',
r'''Don't find fault, find a remedy; anyone can complain.''',
r'''Don't get even -- get better.  -- Carolyn Myss''',
r'''Don't have good ideas if you aren't willing to be responsible for them.''',
r'''Don't judge a man until you have walked a mile in his shoes.  -- Confucius''',
r'''Don't judge your insides by other peoples' outsides.''',
r'''Don't just adopt opinions; develop them.''',
r'''Don't keep going to the well when the well is dry.''',
r'''Don't kid yourself.  Little is relevant, and nothing lasts forever.''',
r'''Don't let editors edit the life out of your sentences!  -- Isaac Asimov''',
r'''Don't let God laugh alone.  -- Josef Engressia''',
r'''Don't let what you can't do stop you from doing what you can do.''',
r'''Don't look a gift horse in the mouth.''',
r'''Don't look for the right person; be the right person.  -- Will Limon''',
r'''Don't make a big deal out of everything; just deal with everything.''',
r'''Don't make it a project.  Much of the joy of things lies in their serendipity.''',
r'''Don't meet troubles half-way.  -- Christer Sundqvist''',
r'''Don't outlive your money.  -- H. Jackson Brown''',
r'''Don't panic; calmness attracts answers.''',
r'''Don't pet a dog you have just kicked.''',
r'''Don't pick a fight with an old man.  If too old to fight, he'll just kill you.''',
r'''Don't put all of your eggs in one basket.''',
r'''Don't put anything in writing that you wouldn't want to see in print.  -- Young''',
r'''Don't run from love.  There is no other direction.''',
r'''Don't send your spirit on missions of destruction.  -- Carolyn Myss''',
r'''Don't speak about Time, until you have spoken to him.''',
r'''Don't stop along the way at all.  That's illusion too.  -- Ram Dass''',
r'''Don't stop to step on the ants when the elephants are stampeding.''',
r'''Don't take anything seriously except happiness.  -- Albert Camus''',
r'''Don't teach your children what to think; just teach them to think.  -- Tannenbaum''',
r'''Don't think that a house covered with snow has no fire in it.  -- George Shaw''',
r'''Don't try to have the last word -- you might get it.  -- Lazarus Long''',
r'''Don't try to pitch from third base.''',
r'''Don't use big words for little matters.  -- Samuel Johnson''',
r'''Don't use yesterday as an excuse for not being fine.  -- Carolyn Myss''',
r'''Don't use your powers, let them go.  -- Ram Dass''',
r'''Don't Worry, Be Happy.  -- Meher Baba''',
r'''Doubt is humble, and that's what man needs to be.  -- Bill Maher''',
r'''Draw a circle around your love and hate will walk the line.  -- Hugh Prather''',
r'''Draw your salary before spending it.''',
r'''Drawing on my fine command of language, I said nothing.  -- Robert Benchley''',
r'''Dream as if you'll live forever.  Live as if you'll die tomorrow.  -- James Dean''',
r'''Dry bread at home is better than roast meat abroad.  -- George Herbert''',
r'''Dry socks are far more important than clean underwear.  -- Len McDougall''',
r'''During depressions, assets return to their rightful owners.  -- Andrew Mellon''',
r'''During the lows I find hope in knowing another high will come along.  -- Keirn''',
r'''Duty is what one expects from others.''',
r'''Each bird loves to hear himself sing.  -- Howell''',
r'''Each circumstance is a gift, and in each experience is hidden a treasure.  -- God?''',
r'''Each day can be whatever it is, and it's all right.  -- Ram Dass''',
r'''Each man is his own prisoner, in solitary confinement for life.''',
r'''Each of us bears his own Hell.  -- Publius Maro''',
r'''Each one of us is an experiment-of-one.  -- George Sheehan''',
r'''Each one of us is plugged into a schemata of archetypal patterns.  -- Carolyn Myss''',
r'''Each person's journey into consciousness recapitulates all of man's journey.''',
r'''Each problem solved introduces a new unsolved problem.''',
r'''Early to bed and early to rise, makes a man healthy, wealthy, and wise.''',
r'''Earth is the cradle of reason, but it's impossible to live eternally in cradles.  -- Konstantin Tsiolkovsky''',
r'''Earth is the insane asylum of the universe.''',
r'''Easy come, easy go.''',
r'''Eat to live, and not live to eat.  -- Benjamin Franklin''',
r'''Eat, drink, and be merry.''',
r'''Eclipses clearly illuminate numerous features of society.  -- David Daye''',
r'''Economic compulsion determines ethical perspective.  -- Lawrence Hirsch''',
r'''Economy makes men independent.''',
r'''Educated:  Can hear almost anything without losing temper or self-confidence.''',
r'''Education consists of pounding abstract ideas into concrete heads.''',
r'''Education is a method whereby one acquires a higher grade of prejudice.  -- Peter''',
r'''Education is a progressive discovery of our own ignorance.  -- Will Durant''',
r'''Education is a weapon.  -- Josef Stalin''',
r'''Education is the process of casting false pearls before real swine.  -- Edman''',
r'''Education is what survives when what has been learnt has been forgotten.''',
r'''Education makes a straight cut ditch of a free meandering brook.  -- Thoreau''',
r'''Eighty percent of success is showing up.  -- Woody Allen''',
r'''Eliminate any artificial "creativity" processes in the company.  -- Scott Adams''',
r'''Emotion:  Energy in motion.''',
r'''Emotions honestly tell what is your investment and what are your expectations.''',
r'''Empowering your child does not depower you.  -- Barbara Coloroso''',
r'''Endurance is not toleration.''',
r'''Energy flowing through a system organizes that system into greater complexity. -- Alan MacRobert''',
r'''Energy flows where attention goes.  -- Christiane Turner''',
r'''Engineering is the art of knowing how to avoid difficult issues.  -- Dr. Budak''',
r'''Engineering is the art of making the impossible possible.  -- Robert Zubrin''',
r'''Engineers are the natural enemies of marketing people.  -- Scott Adams''',
r'''Enjoy your body.  Use it every way you can.  -- Mary Schmich''',
r'''Enjoy yourself, it's later than you think.  -- Rasmus Petersen''',
r'''Ensure your mind makes contracts your body can meet.''',
r'''Envy and mediocrity are an explosive mixture.  -- Irvine Page''',
r'''Envy is a pain of mind that successful men cause their neighbors.''',
r'''Envy provides the mud that failure throws at success.''',
r'''Established technology tends to persist in spite of new technology.  -- Blaauw''',
r'''Eternity is a mere moment, just long enough for a joke.  -- Hermann Hesse''',
r'''Eureka!  -- Archimedes''',
r'''Even a cabbage can look at a king.''',
r'''Even a hawk is an eagle among crows.''',
r'''Even a straight line is art in someone's eyes.''',
r'''Even God lends a hand to honest boldness.''',
r'''Even if a marriage is made in heaven the maintenance must be done on Earth.''',
r'''Even if we fail, we'll learn.  -- Hachiro Shimanuki''',
r'''Even if you win the rat race, you're still a rat.''',
r'''Even the best of friends cannot attend each other's funeral.  -- Kehlog Albran''',
r'''Even the boldest zebra fears the hungry lion.''',
r'''Even the finest of cookbooks is no substitute for the poorest of dinners.''',
r'''Even the smallest candle burns brighter in the dark.''',
r'''Every 5-7 years, people forget that recessions occur every 5-7 years.  -- Morgan Housel''',
r'''Every absurdity has a champion to defend it.''',
r'''Every activity takes more time than you have.''',
r'''Every blessing ignored becomes a curse.  -- Paulo Coelho''',
r'''Every child is gifted and talented.  You just have to pull it out.''',
r'''Every clarification breeds new questions.''',
r'''Every cloud engenders not a storm.''',
r'''Every cloud has a silver lining.  -- Gilbert''',
r'''Every cubic inch in space is a miracle.  -- Walt Whitman''',
r'''Every day you add one more day to your history.  -- Carolyn Myss''',
r'''Every erroneous inference involves admitting insufficient evidence as data.''',
r'''Every exit is an entry somewhere else.  -- Tom Stoppard''',
r'''Every fool aspired to be a knave.  -- Mackay, of the South Sea Bubble''',
r'''Every generation laughs at the old fashions, but follows religiously the new.''',
r'''Every genius is a child, every child is a genius.''',
r'''Every good idea started out as a bad idea.  -- Doug Baskins''',
r'''Every horse thinks his own pack the heaviest.''',
r'''Every human is... that profound secret and mystery to every other.  -- Dickens''',
r'''Every intelligent conversation is punctuated by periods of silence.''',
r'''Every job is a self-portrait of the person who did it.''',
r'''Every man a little beyond himself is a fool.''',
r'''Every man dies...  Not every man truly lives.  -- William Wallace''',
r'''Every man has a right to be conceited until he is successful.  -- Disraeli''',
r'''Every man has a scheme that absolutely will not work.''',
r'''Every man has his price.  Every price has its man.''',
r'''Every man has two vocations:  His own and philosophy.  -- Edward Abbey''',
r'''Every man is a fool sometimes, and none at all times.  -- George Herbert''',
r'''Every man is a king in his own house.''',
r'''Every man is all of man.  -- Jean-Paul Sartre''',
r'''Every man is as God made him, ay, and often worse.  -- Miguel de Cervantes''',
r'''Every man is best known to himself.  -- Thomas Draxe''',
r'''Every man is mad on some point.''',
r'''Every man is the architect of his own fortune.''',
r'''Every man is working out his destiny in his own way and no one can be of help.''',
r'''Every man likes his own thing best.''',
r'''Every man loves what he is good at.  -- Shadwell''',
r'''Every man who takes office in Washington either grows or swells.  -- Wilson''',
r'''Every medal has its reverse.''',
r'''Every mile is two in winter.  -- George Herbert''',
r'''Every minority group in order to survive works harder than usual.  -- Katchalski''',
r'''Every moment is precious.  And precarious.  -- Edward Abbey''',
r'''Every nation has the government it deserves.  -- Joseph De Maistre''',
r'''Every new generation is a fresh invasion of savages.  -- Harvey Allen''',
r'''Every now and then, bite off more than you can chew.  -- H. Jackson Brown''',
r'''Every oak has been an acorn.''',
r'''Every patient is a doctor after they are cured.''',
r'''Every pawn move loosens the position.  -- Siegbert Tarrasch''',
r'''Every person has a unique tongue print.''',
r'''Every person on earth plays a central role in the history of the world.  -- Coelho''',
r'''Every purchase has its price.''',
r'''Every revolution was first a thought in one man's mind.  -- Emerson''',
r'''Every saint has a past and every sinner has a future.  -- Oscar Wilde''',
r'''Every single person has his or her divine purpose for being here.  -- Carolyn Myss''',
r'''Every single person you relate to has a completely different culture.  -- Coit''',
r'''Every truth starts life as a heresy and ends life as an orthodoxy.  -- Huxley''',
r'''Every truth that finally wakes up in you changes the rules of your life.  -- Carolyn Myss''',
r'''Every why hath a wherefore.''',
r'''Every word is like an unnecessary stain on silence and nothingness.  -- Beckett''',
r'''Everybody has something to conceal.  -- Humphrey Bogart''',
r'''Everybody is somebody else's weirdo.  -- Dykstra''',
r'''Everybody ought to have a friend.''',
r'''Everybody wants to go to heaven, but nobody wants to die.''',
r'''Everyone complains of his memory, no one of his judgement.''',
r'''Everyone does better when everyone does better.  -- Hightower''',
r'''Everyone in favor of birth control has already been born.  -- Laurence Peter''',
r'''Everyone is born a king, and most people die in exile.''',
r'''Everyone is entitled to his own opinion, but not his own facts.  -- Daniel Moynihan''',
r'''Everyone is ignorant -- only on different subjects.  -- Will Rogers''',
r'''Everyone is in the best seat.  -- John Cage''',
r'''Everyone is partly man and partly woman.  -- Virginia Woolf''',
r'''Everyone is someone's fool.''',
r'''Everyone knows what ought to be done with everyone else's children.''',
r'''Everyone loves praise.  Look hard for ways to give it to them.  -- Brown''',
r'''Everyone stays busy keeping other people busy.''',
r'''Everyone thinks of changing mankind, but no one thinks of changing himself.''',
r'''Everyone wants to change the world, but no one wants to change their mind.''',
r'''Everyone you meet is fighting a battle you know nothing about.  -- Ian Maclaren''',
r'''Everyone's faults are written in their foreheads.''',
r'''Everyone, when they are young, knows what their destiny is.  -- Paulo Coelho''',
r'''Everything bows to success, even grammar.  -- Victor Hugo''',
r'''Everything changes but change itself.  -- John F. Kennedy''',
r'''Everything expands to fill the available space.''',
r'''Everything goes wrong at once.''',
r'''Everything has an end.''',
r'''Everything has beauty, but not everyone sees it.  -- Confucius''',
r'''Everything has some value -- if you use the right currency.''',
r'''Everything I did in my life that was worthwhile I caught hell for.  -- Warren''',
r'''Everything in excess!  To enjoy the flavor of life, take big bites.  -- Robert Heinlein''',
r'''Everything in the world may be endured except continual prosperity.  -- Johann von Goethe''',
r'''Everything in war is very simple, but the simplest thing is difficult.  -- Carl von Clausewitz''',
r'''Everything in your universe becomes your teacher.  -- Ram Dass''',
r'''Everything is negotiable.''',
r'''Everything is written in the Soul of the World, and there it will stay forever.''',
r'''Everything must have a beginning.''',
r'''Everything should be built top-down, except the first time.''',
r'''Everything should be made as simple as possible, but not simpler.  -- Einstein''',
r'''Everything takes longer than you think it will.  -- Murphy''',
r'''Everything tends toward chaos.  -- John Quill Taylor''',
r'''Everything that goes up must come down.''',
r'''Everything that used to be a sin is now a disease.  -- Bill Maher''',
r'''Everything will kill you, but without it you would be nothing.''',
r'''Evil is never intended as evil.  -- James Carse''',
r'''Evil is the termination of infinite play.  -- James Carse''',
r'''Evil is... the restriction of all play to one or another finite game.  -- Carse''',
r'''Evolution is a theory that accounts for variety, not superiority.  -- Joan Pontius''',
r'''Examine what is said, not him who speaks.  -- Arab proverb''',
r'''Example has more followers than reason.  -- Christian Bovee''',
r'''Example is not the main thing in influencing others.  It is the only thing.''',
r'''Excellence is not an act but a habit.  -- Aristotle''',
r'''Excellent things are hard to come by.  -- Clarke''',
r'''Exceptions are pernicious because they conceal laws.  -- Henri Poincar''',
r'''Execute every act of thy life as though it were thy last.  -- Marcus Aurelius''',
r'''Executives count their beans instead of feeling passion about customers.''',
r'''Exotic foreign places don't seem exotic to the people who live there.''',
r'''Expansion means complexity; and complexity decay.''',
r'''Expectations are resentment in training.  -- Cindy Ryk''',
r'''Experience is a hard teacher for it gives the test first and the lesson later.''',
r'''Experience is sometimes dangerous.  -- Florio''',
r'''Experience is the father of knowledge and the mother of wisdom.''',
r'''Experience is the name everyone gives to their mistakes.  -- Oscar Wilde''',
r'''Experience is what you get when you don't get what you want.''',
r'''Experience keeps a dear school, but fools will learn in no other.  -- Franklin''',
r'''Experience should be a guide post, not a hitching post.''',
r'''Experience without learning is better than learning without experience.''',
r'''Expert advice is a great comfort, even when it is wrong.  -- Ellen Currie''',
r'''Explanation is an antagonistic encounter.  -- James Carse''',
r'''Express an opinion, but send advice by freight.''',
r'''Expressing anger is a form of public littering.  -- Willard Gaylin''',
r'''Expressing negative emotions contributes to recovery from hurts.''',
r'''Extraordinary claims require extraordinary evidence.  -- Carl Sagan''',
r'''Extraordinary people use their wisdom to avoid the need for their skill.''',
r'''Extreme fear can neither fight nor fly.''',
r'''Extroverts must talk to think; introverts must think to talk.''',
r'''e^(i*pi) + 1 = 0''',
r'''Face reality:  Consistently adequate is good enough.  -- Marianne Neifert''',
r'''Facts are meaningless except as part of a system.  -- Morris Cohen''',
r'''Facts are stubborn things.  -- Tobias Smollett''',
r'''Facts do not cease to exist because they are ignored.  -- Aldous Huxley''',
r'''Facts, apart from their relationships, are like labels on empty bottles.''',
r'''FAIL = First Attempt In Learning.''',
r'''Failure is falling down.  Success is getting back up.''',
r'''Failure is more frequently from want of energy than want of capital.''',
r'''Failure is the path of least persistence.''',
r'''Failure teaches success.''',
r'''Fain would I climb, yet fear I to fall.''',
r'''Fair words and foul play cheat both young and old.  -- Mapletoft''',
r'''Fair words hurt not the mouth.''',
r'''Fair words make me look to my purse.  -- George Herbert''',
r'''Faith goes out through the window when beauty comes in at the door.''',
r'''Faith is believing what you know ain't so.''',
r'''Faith means making a virtue out of not thinking.  -- Bill Maher''',
r'''Faith without works is dead.  -- New Testament''',
r'''Fake news has real consequences! -- John Martin''',
r'''False hope is better than no hope at all.''',
r'''False modesty is the refuge of the incompetent.''',
r'''Fame is a magnifying glass.''',
r'''Fame is but the breath of the people.''',
r'''Fame is proof that people are gullible.  -- Ralph Emerson''',
r'''Fame is the perfume of heroic deeds.  -- Socrates''',
r'''Familiarity breeds contempt.  -- Augustinus''',
r'''Fancy gizmos don't work.''',
r'''Far duller than a serpent's tooth it is to spend a quiet youth.''',
r'''Fashion:  A despot whom the wise ridicule and obey.  -- Ambrose Bierce''',
r'''Fate knows best sometimes.  -- John Taylor''',
r'''Fatigue is the best pillow.''',
r'''Fear is interest paid on a debt you may not owe.  -- McWilliams''',
r'''Fear is the result of impurity.  -- Ram Dass''',
r'''Fear of death is worse than death itself.''',
r'''Fear teaches us in the most graphic terms just what it is we value.  -- Limon''',
r'''Fear:  False Expectations About Reality.''',
r'''February 1865 is the only month in recorded history not to have a full moon.''',
r'''Feelings are neither good nor bad; they are just indicators.  -- Will Limon''',
r'''Few lawyers die well; few physicians live well.''',
r'''Few men have the ambition to be great, although many aspire to be thought so.''',
r'''Few of us seem to realize that pleasure is not the same as happiness.  -- Highet''',
r'''Few people recover from having had a childhood.  -- Robert Niland''',
r'''Few things in life are as kind as forgetfulness.''',
r'''Few words and many deeds.''',
r'''Few, if any, survive their teens.  -- Maya Angelou''',
r'''Fields with the word "Science" in their names usually aren't.''',
r'''Fifty percent of something is better than 100 percent of nothing.  -- Suze Orman''',
r'''Fighting for peace is like making love for virginity.''',
r'''Figures won't lie, but liars will figure.  -- C. H. Grosvenor''',
r'''Financial diversification means always having to say you are sorry.  -- Brian Portnoy''',
r'''Find a job you love, and you will never have to work again.''',
r'''Find an aim in life before you run out of ammunition.  -- Arnold Glasow''',
r'''Find time to work smarter.''',
r'''Find ways to be wealthy that don't depend on earning cash or buying things.''',
r'''Fine words dress ill deeds.''',
r'''Fingers were made before forks, and hands before knives.''',
r'''Finite play is inherently contradictory; infinite play is paradoxical.  -- Carse''',
r'''Finite players play within boundaries; infinite players play with boundaries.''',
r'''Fire is a low-temperature phenomenon...  in the universe.  -- Arthur Clarke''',
r'''Fire, water, and money are good servants but terrible masters.''',
r'''Firmness of delivery dates is inversely proportional to tightness of schedule.''',
r'''First come, first served.''',
r'''First deserve, and then desire.''',
r'''First in time, first in right.  -- Colorado water law''',
r'''First step to getting what you want:  Courage to get rid of what you don't want.''',
r'''First think, and then speak.''',
r'''Fish and visitors smell in three days.''',
r'''Fish or cut bait.''',
r'''Fix the problem, not the blame.''',
r'''Flattery is like cologne:  To be smelled, but not swallowed.  -- Josh Billings''',
r'''Float like a butterfly, sting like a bee.  -- Muhammed Ali''',
r'''Focused action beats brilliance any day.  -- Art Turock''',
r'''Follow the good side right to the fire, but not into it.''',
r'''Follow the river and you will get to the sea.''',
r'''Follow your bliss.  -- Joseph Campbell''',
r'''Folly grows without watering.  -- George Herbert''',
r'''Fond of the game, but no fool -- a real man.  -- Louis-Ferdinand Celine''',
r'''Food for thought is no substitute for the real thing.  -- Walt Kelly''',
r'''Fool me once, shame on you.  Fool me twice, shame on me.  -- Scotti''',
r'''Fools are always at the bottom of the food chain.  -- Cesare''',
r'''Fools don't attempt suicide; rather, they succeed at it.  -- John Taylor''',
r'''Fools rush in where angels fear to tread.''',
r'''For best results, authority and responsibility should be commensurate.''',
r'''For courage mounteth with occasion.''',
r'''For every credibility gap, there is a gullibility fill.  -- R. Clopton''',
r'''For fast-acting relief, try slowing down.''',
r'''For God's sake, stop researching for a while and begin to think.  -- Moberly''',
r'''For humans, honest is a matter of degree.  -- Scott Adams''',
r'''For life to have meaning, one must have something significant yet to do.''',
r'''For the love of lust is the root of all evil...  Lust came before money.''',
r'''For the love of money is the root of all evil.  -- New Testament''',
r'''For the unlearned, old age is winter.  For the learned, it's the harvest season.''',
r'''For thee the wonder-working Earth puts forth sweet flowers.  -- Titus Carus''',
r'''For us there is only the trying.  -- T. S. Eliot''',
r'''Forbidden fruit is sweet.  -- Old Testament''',
r'''Force has no place where there is need of skill.  -- Herodotus''',
r'''Forget what you know and learn.  -- Roger von Oech''',
r'''Forget your troubles as easily as you do your blessings.  -- NRTA Journal''',
r'''Forgive us, for we also know not what we don't.  -- John Taylor''',
r'''Forgive your enemies, but never forget their names.  -- John F. Kennedy''',
r'''Forgiveness is the attribute of the strong.  -- Mohandas Gandhi''',
r'''Forgiveness means giving up your right to punish another.''',
r'''Forgiveness of another is a gift you give to yourself.''',
r'''Fortune can take from us nothing but what she gave us.''',
r'''Fortune favors the brave.''',
r'''Fortune knocks at least once at every man's gate.''',
r'''Fortune never seems so blind as to those upon whom she has bestowed no favors.''',
r'''Freedom begins between the ears.  -- Edward Abbey''',
r'''Freedom is its own punishment.  -- P.J. O'Rourke''',
r'''Freedom is nothing else but the chance to do better.  -- Albert Camus''',
r'''Freedom is slavery.  Ignorance is strength.  War is peace.  -- George Orwell''',
r'''Freedom is the recognition of necessity.  -- Spinoza''',
r'''Freedom is the right to be wrong, not the right to do wrong.  -- John Diefenbaker''',
r'''Freedom isn't free; it is purchased by respecting the liberties of others.''',
r'''Freedom of the press belongs to he who owns one.''',
r'''Freedom, not safety, is the highest good.  -- Edward Abbey''',
r'''Friends agree best at a distance.''',
r'''Friends are people you can be quiet with.''',
r'''Friends are thieves of time.''',
r'''Friends listen to what you say.  Best friends listen to what you don't say.''',
r'''Friends may come and go, but enemies accumulate.  -- Jones''',
r'''Friendship cannot stand always on one side.''',
r'''Friendship is forgetting what you give and remembering what you receive.''',
r'''Friendship is one mind in two bodies.  -- Mencius''',
r'''From each according to his abilities, to each according to his needs.  -- Marx''',
r'''From error to error, one discovers the entire truth.  -- Sigmund Freud''',
r'''From fanaticism to barbarism is only one step.  -- Denis Diderot''',
r'''From hearing comes wisdom; from speaking, repentance.  -- Mapletoft''',
r'''Fruit ripens not well in the shade.  -- Fuller''',
r'''Furious activity is no substitute for understanding.  -- H. H. Williams''',
r'''Fuzzy project goals avoid the embarrassment of estimating the costs.''',
r'''Genius is 1% inspiration and 99% perspiration.  -- Thomas Edison''',
r'''Genius is born, not paid.  -- Oscar Wilde''',
r'''Genius is seeing origins.''',
r'''Genius is the talent of a person who is dead.''',
r'''Genius might have its limitations, but stupidity is not thus handicapped.''',
r'''Genuine travel has no destination.  -- James Carse''',
r'''Genuine travelers travel not to overcome distance but to discover distance.''',
r'''Geologic time is measured by mass extinctions.  -- Charlene Anderson''',
r'''Get even...  With the people who have helped you.''',
r'''Get up one time more than you are knocked down.  -- Peter''',
r'''Ghosts are the insomniacs among the dead.  -- Louis Jenkins''',
r'''Gifts blind the eyes.''',
r'''Give a lie twenty-four hours' start, and you can never overtake it.''',
r'''Give me a fish and I will eat today.  Teach me to fish and I will eat forever.''',
r'''Give me enough medals, and I'll win any war.  -- Napolean''',
r'''Give religion privilege, and it gets corrupted.  -- Martin Marty''',
r'''Give the Devil his due, but be careful that there ain't much due him.''',
r'''Given a choice between grief and nothing, I'd choose grief.  -- William Faulkner''',
r'''Given enough time, almost everything will occur.''',
r'''Given sufficient time, what you put off doing today will get done by itself.''',
r'''Giving away your personal power is an explosive fuel for power struggles.''',
r'''Giving leadership to those incapable of governing themselves is foolishness.''',
r'''Giving to the poor insures their predicament.''',
r'''Glory is fleeting, but obscurity is forever.  -- Napoleon Bonaparte''',
r'''Glory to the pattern finders.  They make sense out of apparent chaos.  -- Raham''',
r'''Goals...  Plans...  They're fantasies, part of a dream world...  -- Wally Shawn''',
r'''God came to the United States in the form of LSD.  -- Ram Dass''',
r'''God can make an ass with three tails, but not a triangle with four sides.''',
r'''God comes to see without a bell.''',
r'''God complains not, but does what is fitting.  -- George Herbert''',
r'''God does not play dice with the universe.  -- Albert Einstein''',
r'''God gives burdens; also shoulders.''',
r'''God gives us the nuts, but he does not crack them.  -- German proverb''',
r'''God has no intention of setting a limit to the efforts of man to conquer space.''',
r'''God heals and the doctor takes the fee.  -- Benjamin Franklin''',
r'''God is a comic playing to an audience afraid to laugh, with no front row.''',
r'''God is an artist who paints with broad strokes.''',
r'''God is great, too great for me.  -- Kurt Tucholsky''',
r'''God is not all-powerful as he cannot build a wall he cannot jump.  -- Pascal''',
r'''God is the tangential point between zero and infinity.  -- Alfred Jarry''',
r'''God loves everyone in the world who doesn't love himself.  Does God love God?''',
r'''God made man, but Samuel Colt made men equal.''',
r'''God made the country, and man made the town.''',
r'''God made the integers; all else is the work of Man.  -- Kronecker''',
r'''God made us plain and simple, but we have made ourselves very complicated.''',
r'''God makes and man shapes.''',
r'''God may be subtle, but he isn't plain mean.  -- Albert Einstein''',
r'''God meditates in geniuses, dreams in poets, and sleeps in other people.''',
r'''God offers to every mind its choice between truth and repose.  -- Emerson''',
r'''God sends cold after clothes.''',
r'''God sends meat and the devil sends cooks.  -- Thomas Deloney''',
r'''God strikes with his finger, and not with all his arm.  -- Delamothe''',
r'''God walking on Earth is more important than man walking on the Moon.  -- Jim Irwin''',
r'''God will not look you over for medals, degrees or diplomas, but for scars.''',
r'''God works with you, not for you.''',
r'''God's career would end tomorrow were there no more problems.  -- Neale Walsch''',
r'''God's mill grinds slow but exceedingly fine.''',
r'''God, it looks like it's going to be you and me for the rest of my life.  -- Coit''',
r'''Gold that's put to use more gold begets.  -- William Shakespeare''',
r'''Good artists borrow.  Great artists steal.  -- Steven Jobs''',
r'''Good beginning makes a good ending.''',
r'''Good behavior is the last refuge of mediocrity.  -- Henry Haskins''',
r'''Good counsel never comes too late.''',
r'''Good fortune will find you, providing you gave directions.''',
r'''Good gift: Someone really wants it, but feels guilty buying it for themselves.  -- Dan Ariely''',
r'''Good humor is the health of the soul, sadness the poison.''',
r'''Good judgement comes from experience, which comes from bad judgement.''',
r'''Good leaders being scarce, following yourself is allowed.''',
r'''Good listeners make good lovers.''',
r'''Good management is knowing what's fundamental to success and what's not.  -- Adams''',
r'''Good manuals are not written...  They are rewritten.''',
r'''Good memories have ill judgements.  -- James Kelly''',
r'''Good men are scanty, make much of one.  -- Fletcher''',
r'''Good nature and good sense must ever join; to err is human, to forgive, divine.''',
r'''Good poetry and bad poetry look pretty much the same at fifty yards.  -- Taylor''',
r'''Good teaching is one-fourth preparation and three-fourths theater.  -- Godwin''',
r'''Good that the teeth guard the tongue.''',
r'''Good things come in small packages.''',
r'''Good to begin well, better to end well.''',
r'''Good words are worth much, and cost little.  -- George Herbert''',
r'''Good, to forgive; best, to forget.  -- Robert Browning''',
r'''Gossip is so tasty, how we love to swallow it!  -- Solomon''',
r'''Government is the last solution but the first suggestion for many problems.''',
r'''Governments lie; newspapers lie; but in a democracy they are different lies.''',
r'''Grace is more beautiful than beauty.  -- Ralph Waldo Emerson''',
r'''Gratitude is a lively sense of future favors.  -- Sir Robert Walpole''',
r'''Gratitude is the memory of the heart.  -- J. B. Massieu''',
r'''Great achievements require relatively few ideas and even less men.  -- Uhrin''',
r'''Great acts are made up of small deeds.  -- Lao Tsu''',
r'''Great art is indefinable but that's all right; it exists anyway.  -- Edward Abbey''',
r'''Great art is never perfect; perfect art is never great.  -- Edward Abbey''',
r'''Great blunders are often made, like large ropes, of a multitude of fibers.  -- Victor Hugo''',
r'''Great businesses must survive bad managers because eventually they'll have to.''',
r'''Great expectations lead to great disappointments.''',
r'''Great intellects are skeptical.  -- Friedrich Nietzsche''',
r'''Great love and great achievements involve great risk.  -- H. Jackson Brown''',
r'''Great men have great faults.  -- Thomas Draxe''',
r'''Great minds have purposes; others have wishes.  -- Washington Irving''',
r'''Great opportunities to help others seldom come; small ones surround us every day.''',
r'''Great spirits have always encountered violent opposition from mediocre minds.''',
r'''Greater qualities are necessary to bear good fortune than bad.  -- La Rochefoucald''',
r'''Greatness is a transitory experience.  It is never consistent.''',
r'''Grown men do not need leaders.  -- Edward Abbey''',
r'''Growth for the sake of growth is the ideology of the cancer cell.  -- Edward Abbey''',
r'''Half of being smart is knowing what you are dumb at.''',
r'''Half the truth is often a great lie.  -- Benjamin Franklin''',
r'''Half the world knows not how the other half lives.  -- J. Hall''',
r'''Handle yourself with your head, handle others with your heart.''',
r'''Happiness adds and multiplies as we divide it with others.''',
r'''Happiness equals reality minus expectations.  -- Tom Magliozzi''',
r'''Happiness is a perpetual possession of being well deceived.  -- Jonathan Swift''',
r'''Happiness is just an illusion, filled with sadness and confusion.''',
r'''Happiness isn't something you experience; it's something you remember.  -- Levant''',
r'''Happy folks do not make history.  -- French proverb''',
r'''Happy is he that is happy in his children.  -- Fuller''',
r'''Happy is the man who becomes wise, who gains understanding.  -- Solomon''',
r'''Happy-go-lucky people can only be happy when they are lucky.''',
r'''Hard facts are hard to beat.''',
r'''Hard reality has a way of cramping your style.  -- Daniel Dennett''',
r'''Haste makes waste.  -- R. C. Trench''',
r'''Hasten slowly.  -- Suetonius''',
r'''Hate is a disease, and tolerance is the cure.  -- Dennis Shepard''',
r'''Hate stirs up trouble, but love overlooks all offenses.  -- Solomon''',
r'''Hate the sin and love the sinner.  -- Mohandas Gandhi''',
r'''Hating people is like burning down your own house to get rid of a rat.  -- Fosdick''',
r'''Hatred is blind, as well as love.  -- Fuller''',
r'''Hatred is never ended by hatred but by love.  -- Buddhism''',
r'''Have no fear of perfection -- you'll never reach it.  -- Salvador Dali''',
r'''Have no friends not equal to yourself.  -- Confucius''',
r'''Have preferences, not expectations; make choices, not demands.''',
r'''Have the courage to be honest with yourself.  -- Carolyn Myss''',
r'''Have you ever gone out to see how much fun you'd be to be with?  -- Lee Coit''',
r'''Have you tried on your smile today?''',
r'''Having a mind of one's own doesn't necessarily imply having any mind as such.''',
r'''Having been poor is no shame, but being ashamed of it, is.  -- Benjamin Franklin''',
r'''Having made one lie, he is fain to make more to maintain it.  -- Fuller''',
r'''Having no security is better than thinking you have security when you don't.''',
r'''Having nothing, nothing can he lose.  -- William Shakespeare''',
r'''Having the fewest wants, I am nearest to the gods.  -- Socrates''',
r'''He bears misery best that hides it most.  -- Harvey''',
r'''He cannot be good that knows not why he is good.  -- I. Sidney''',
r'''He cannot speak well that cannot hold his tongue.''',
r'''He cries wine and sells vinegar.  -- Howell''',
r'''He gets a double victory who conquers himself.''',
r'''He has not acquired a fortune; the fortune has acquired him.  -- Bion''',
r'''He has slept well that remembers not he has slept ill.  -- Fuller''',
r'''He is a good friend that speaks well of us behind our backs.''',
r'''He is a good orator who convinces himself.  -- Mapletoft''',
r'''He is at ease who has enough.''',
r'''He is lifeless that is faultless.''',
r'''He is not laughed at that laughs at himself first.''',
r'''He is now rising from affluence to poverty.  -- Mark Twain''',
r'''He is poor indeed that can promise nothing.  -- Thomas Draxe''',
r'''He is rich enough that wants nothing.''',
r'''He is the best of men who dislikes power.  -- Mohammed''',
r'''He is the kind of man for the times that need the kind of man he is.''',
r'''He is truly wise who gains wisdom from another's mishap.''',
r'''He is wise that knows when he is well enough.''',
r'''He jests at scars who never felt a wound.  -- William Shakespeare''',
r'''He knows not how to know who knows not also how to unknow.  -- Richard Burton''',
r'''He knows not what good is who has not tried what evil is.  -- Torriano''',
r'''He laughs best that laughs last.  -- Sir J. Vanbrugh''',
r'''He lives long that lives well.''',
r'''He loses his thanks who promises and delays.  -- Thomas Draxe''',
r'''He loses indeed that loses at last.  -- Fuller''',
r'''He loses nothing who keeps God for his friend.  -- Cotgrave''',
r'''He or she who would gather roses must not fear thorns.  -- Dutch proverb''',
r'''He played the king as if afraid someone else would play the ace.  -- John Brown''',
r'''He praises who wishes to sell.''',
r'''He sits not sure that sits too high.  -- Cotgrave''',
r'''He spent his last shilling on a purse.''',
r'''He teaches ill who teaches all.''',
r'''He that bringeth a present, findeth the door open.  -- Scottish proverb''',
r'''He that brings good news knocks hard.  -- Cotgrave''',
r'''He that can have patience can have what he will.''',
r'''He that cannot abide a bad market deserves not a good one.  -- John Ray''',
r'''He that cannot pay let him pray.  -- John Ray''',
r'''He that counts all costs will never put plow in the earth.  -- Carmichaell''',
r'''He that does what he will, does not what he ought.''',
r'''He that eats least eats most.''',
r'''He that falls in love with himself, will have no rivals.  -- Franklin''',
r'''He that falls today may rise tomorrow.''',
r'''He that fears you present will hate you absent.  -- Fuller''',
r'''He that goes barefoot must not plant thorns.''',
r'''He that has a full purse never wanted a friend.  -- James Kelly''',
r'''He that has a great nose, thinks everyone is speaking of it.''',
r'''He that has lost his credit is dead to the world.''',
r'''He that has money has what he wants.''',
r'''He that has no money needs no purse.  -- Thomas Draxe''',
r'''He that has not silver in his purse, should have silk on his tongue.''',
r'''He that has time has life.''',
r'''He that hurts another hurts himself.  -- Sanford''',
r'''He that is born a fool is never cured.  -- Harward''',
r'''He that is carried down the stream need not row.  -- Fuller''',
r'''He that is fallen cannot help him that is down.  -- George Herbert''',
r'''He that is giddy thinks the world turns round.  -- William Shakespeare''',
r'''He that is his own counsel has a fool for a client.''',
r'''He that is not sensible of his loss has lost nothing.''',
r'''He that kills a man when he is drunk, shall be hanged when he is sober.''',
r'''He that knows little soon repeats it.  -- John Ray''',
r'''He that knows nothing doubts nothing.  -- Cotgrave''',
r'''He that lends, gives.  -- George Herbert''',
r'''He that lies upon the ground can fall no lower.  -- Alain de Lille''',
r'''He that lives in hope dances without music.''',
r'''He that lives long suffers much.''',
r'''He that lives most, dies most.  -- George Herbert''',
r'''He that lives upon hope will die fasting.''',
r'''He that lives well is learned enough.  -- Cotgrave''',
r'''He that lives wickedly can hardly die honestly.  -- Thomas Draxe''',
r'''He that loves well sees afar off.  -- George Herbert''',
r'''He that makes a good war makes a good peace.''',
r'''He that makes a thing too fine, breaks it.  -- George Herbert''',
r'''He that marries for wealth sells his liberty.''',
r'''He that nothing questions, nothing learns.''',
r'''He that pays last never pays twice.''',
r'''He that plants a tree plants for posterity.''',
r'''He that seeks finds.  -- New Testament''',
r'''He that seeks trouble, never misses.''',
r'''He that sleeps with dogs must rise up with fleas.  -- Seneca''',
r'''He that sows good seed shall reap good corn.''',
r'''He that speaks to a fool, talks to himself.  -- James Kelly''',
r'''He that stays in the valley shall never get over the hill.  -- Thomas Draxe''',
r'''He that steals honey should beware of the sting.  -- James Kelly''',
r'''He that will be served, must be patient.  -- George Herbert''',
r'''He that will eat the kernel must crack the nut.''',
r'''He that will enter into Paradise must have a good key.  -- Thomas Draxe''',
r'''He that will lie will steal.''',
r'''He that would govern others, first should be the master of himself.''',
r'''He was meant for a gentleman, but was spoilt in the making.  -- Jonathan Swift''',
r'''He who angers you, conquers you.  -- Elisabeth Kenny''',
r'''He who asks is a fool for five minutes; he who does not remains a fool forever.''',
r'''He who begins many things finishes but few.''',
r'''He who can, does.  He who cannot, teaches.  -- Bernard Shaw''',
r'''He who dares knows adventure.''',
r'''He who defines the terms wins the argument.  -- Chinese proverb''',
r'''He who despises himself nevertheless esteems himself as a self-despiser.''',
r'''He who dies with the most peace of mind wins.''',
r'''He who dies with the most toys has missed the point of the game.''',
r'''He who fears the unknown may one day flee from his own backside.  -- Sinbad''',
r'''He who fights and runs away lives to fight another day.  -- Leng-Tzu''',
r'''He who foresees calamities suffers them twice over.''',
r'''He who gives promptly gives twice.  -- Miguel de Cervantes''',
r'''He who goes into the conclave a pope comes out a cardinal.''',
r'''He who has a fair wife needs more than two eyes.''',
r'''He who has a WHY to live for can bear with almost any HOW.  -- Friedrich Nietzsche''',
r'''He who has imagination without learning has wings but no feet.''',
r'''He who has no poetry in himself will find poetry in nothing.''',
r'''He who has the gold makes the rules.''',
r'''He who hates vices hates mankind.''',
r'''He who hesitates is lost.  -- Leng-Tzu''',
r'''He who hesitates is sometimes saved.  -- James Thurber''',
r'''He who is good for making excuses is seldom good for anything else.''',
r'''He who knows others is wise.  He who knows himself is enlightened.  -- Lao Tsu''',
r'''He who knows that enough is enough will always have enough.  -- Lao Tsu''',
r'''He who knows, does not speak.  He who speaks, does not know.  -- Lao Tsu''',
r'''He who laughs, lasts.''',
r'''He who lives without folly is less wise than he believes.''',
r'''He who makes no mistakes makes nothing.''',
r'''He who opens a school door, closes a prison.  -- Victor Hugo''',
r'''He who owes is in all wrong.  -- Torriano''',
r'''He who sees much can endure much.  -- Emanuel Lasker''',
r'''He who slings mud generally loses ground.  -- Adlai Stevenson''',
r'''He who tells you how great he is usually isn't.''',
r'''He who thinks he is raising a mound might only in reality be digging a pit.''',
r'''He who wonders discovers that this in itself is wonder.  -- Escher''',
r'''He who would climb the ladder must begin at the bottom.  -- Palmer''',
r'''He's poor as Job, and not so patient.  -- Byron''',
r'''Health follows a change in mindset, just as in the case for placebos.  -- Ellen Langer''',
r'''Health is better than wealth.''',
r'''Health is not valued till sickness comes.''',
r'''Health:  The capacity to completely accept with joy the fact that you are alive.''',
r'''Hearts may agree, though heads differ.  -- Fuller''',
r'''Heaven does not worth according to human justice.  -- Carolyn Myss''',
r'''Heaven has no regard for physical comfort.  -- Carolyn Myss''',
r'''Heaven is a space where you can get whatever you want, and then it isn't enough.''',
r'''Heaven is to be at peace with all things.  -- George Santayana''',
r'''Heaven is under our feet as well as over our heads.  -- Thoreau''',
r'''Heaven takes care of children, sailors, and drunken men.''',
r'''Hell is a place where you have nothing to do but amuse yourself.''',
r'''Hell is always open.  -- Vergil''',
r'''Hell is not a place you go, it's a way you live.  Same with heaven.''',
r'''Hell is wherever heaven is not.  -- Delamothe''',
r'''Help can come any which way -- anything is possible.  -- Carolyn Myss''',
r'''Henry Ford didn't make a penny until he was forty.''',
r'''Her head looks as if it had worn out two bodies.  -- Vermont saying''',
r'''Here comes the orator, with his flood of words and his drop of reason.''',
r'''Here it is standing:  Atoms with consciousness; matter with curiosity.  -- Feynman''',
r'''Here lies a good fellow who spent his life while he had it.  -- Horatio Alger''',
r'''Hey, everything goes wrong every minute.  What you do is fix it.  -- Gus Pagnois''',
r'''Higher technology does not necessarily equate to higher anything else.  -- Donovan''',
r'''Hindsight is an exact science.''',
r'''His bark is worse than his bite.''',
r'''Historians are gossips who tease the dead.  -- Voltaire''',
r'''History books that contain no lies are extremely dull.''',
r'''History develops, art stands still.  -- E. M. Forster''',
r'''History illuminates the actions of men, primatology those of women.''',
r'''History is a spectator sport.''',
r'''History is any succession of events seen with the effect of posteriority.  -- Nassim Taleb''',
r'''History is not a spectator sport.  -- Robert Zubrin''',
r'''History is written by the survivors.  -- Max Lerner''',
r'''History knows no resting places and no plateaus.  -- Henry Kissinger''',
r'''History may not repeat but sometimes it rhymes.  -- Mark Twain''',
r'''History usually clarifies stupidity.''',
r'''History will be kind to me for I intend to write it.  -- Winston Churchill''',
r'''Holding on to the past interferes with what the divine is doing in the present.''',
r'''Home is home, though it be never so homely.  -- James Kelly''',
r'''Home is the nicest place you will ever go.''',
r'''Home is the sailor, home from the sea...  -- Kipling''',
r'''Home is where I want to be, but I guess I'm already there.  -- David Byrnes''',
r'''Home is where the heart is.''',
r'''Homo sapiens is the greatest catastrophe since the Cretaceous extinction.''',
r'''Honest, smart, effective:  Choose at most one.''',
r'''Honesty is better than lying.''',
r'''Honesty is the best policy.''',
r'''Honey is sweet, but the bee stings.''',
r'''Honor lies in honest toil.  -- Grover Cleveland''',
r'''Hope is a good breakfast, but it is a bad supper.''',
r'''Hope is a waking dream.''',
r'''Hope is most powerful when backed up by action.''',
r'''Hope is not a great investment strategy.  -- John Waggoner''',
r'''Hope is the poor man's bread.  -- George Herbert''',
r'''Hope keeps man alive.  -- Withals''',
r'''Hope springs eternal in the human mind.''',
r'''Hot love is soon cold.  -- Lyly''',
r'''Hot tempers cause arguments, but patience brings peace.  -- Solomon''',
r'''Houston, Tranquillity Base here.  The Eagle has landed.  -- Neil Armstrong''',
r'''How apt the poor are to be proud.''',
r'''How are you going to shape the future if you don't know the past?  -- Billie Jean King''',
r'''How beautiful it is to do nothing, and then rest afterward.  -- Spanish proverb''',
r'''How bitter a thing it is to look into happiness through another man's eyes.''',
r'''How can I know what I think until I see what I say?  -- E. M. Forster''',
r'''How can so many take The Amazing Journey and not be amazed?  -- Steve Hug''',
r'''How can you avoid hurting someone's feelings without being a liar?''',
r'''How can you tell the dance from the dancer?''',
r'''How complete is the delusion that beauty is goodness.''',
r'''How do we acquire wisdom along with all these shiny things?  -- David Brin''',
r'''How does a project get to be a year late?  One day at a time.  -- Frederick Brooks''',
r'''How happy we would be if we lost all we had -- and then regained it.  -- Seneca''',
r'''How high I am, how much I see, how far I reach, depends on me.''',
r'''How long does it take to learn that violence begets violence?  -- Marc Salkin''',
r'''How much more money does a millionaire need?  Just one more dollar.''',
r'''How old would you feel if you didn't know how old you were?''',
r'''How vast the realm is our current oblivion.''',
r'''How you look depends on where you go.''',
r'''Human beings are omnivores.  We eat everything, and the box it came in.''',
r'''Human beings live longer and better when they enjoy what they do.  -- J. Asimov''',
r'''Human birth is precious because of the degree of awareness of one's predicament.''',
r'''Human nature is not only about as bad as it can be, but a great deal worse.''',
r'''Human rationality isn't a scientist, it's a lawyer.  -- Jonah Lehrer''',
r'''Humankind's greatest experiences still lie ahead of us.''',
r'''Humans are communications junkies.  We just can't get enough.  -- Alan Kay''',
r'''Humans are motivated by what has been done for them lately.  -- Daniel Koshland''',
r'''Humans are not rational beings; they are rationalizing beings.''',
r'''Humans can't think randomly.  -- Allan Roth''',
r'''Humans need simple answers for complex problems.  -- Lawrence Hirsch''',
r'''Humble hearts have humble desires.  -- Cotgrave''',
r'''Humility is a virtue when you have no other.  -- Edward Abbey''',
r'''Humility is not a state of mind conducive to the advancement of learning.''',
r'''Humility to genius is as an extinguisher to a candle.  -- Shenstone''',
r'''Humor is a drug which it's the fashion to abuse.  -- William Gilbert''',
r'''Humor is by far the most significant activity of the human brain.  -- de Bono''',
r'''Hunger finds no fault with the cookery.''',
r'''Hunger is not caused by scarcity of food but scarcity of democracy.  -- Lappe''',
r'''Hunger is the best sauce.  -- Cicero''',
r'''Hunger knows no friend.  -- Daniel Defoe''',
r'''Hurt people hurt people.  -- Will Bowen''',
r'''Hurting yourself is not sinful -- just stupid.  -- Robert Heinlein''',
r'''Hypocrites are real atheists.  -- Francis Bacon''',
r'''I am a deeply religious non-believer.  This is a somewhat new kind of religion.  -- Albert Einstein''',
r'''I am a man; nothing human is alien to me.''',
r'''I am an enemy of the State.  But isn't everyone?  -- Edward Abbey''',
r'''I am becoming more energy than matter.  -- Carolyn Myss''',
r'''I am convinced the desire to formulate truths is a virulent disease.  -- James''',
r'''I am cured of my illness; I am healed with my illness.  -- James Carse''',
r'''I am exactly where I am supposed to be.  -- Carolyn Myss''',
r'''I am glad I will not be young in a future without wilderness.  -- Aldo Leopold''',
r'''I am looking for an honest man.  -- Diogenes the Cynic''',
r'''I am not afraid of tomorrow, for I have seen yesterday and I love today.''',
r'''I am not this thought.  -- Ram Dass''',
r'''I am the story I tell myself.  -- Greg Wait''',
r'''I am two fools, I know, for loving, and for saying so.  -- John Donne''',
r'''I believe in getting into hot water; it keeps you clean.  -- G. K. Chesterton''',
r'''I believe in nothing that I cannot touch, kiss, embrace...  -- Edward Abbey''',
r'''I can believe anything, provided it is incredible.  -- Oscar Wilde''',
r'''I can explain it for you, but I can't understand it for you.''',
r'''I can't afford to waste my time making money.  -- Jean Agassiz''',
r'''I can't complain, but sometimes I still do.  -- Joe Walsh''',
r'''I cannot and will not cut my conscience to fit this year's fashions.  -- Hellman''',
r'''I cannot be alone; it's not possible.  -- Carolyn Myss''',
r'''I cannot prove this statement is true.  -- Bo Curry''',
r'''I cannot tell you my truth until you stop telling me yours.  -- God?''',
r'''I couldn't possibly fail to disagree with you less.  -- John Taylor''',
r'''I cried because I had no socks, until I met a man who had no shoes.''',
r'''I do not believe in personal immortality; it seems so unnecessary.  -- Edward Abbey''',
r'''I do not know myself and God forbid that I should.  -- Johann von Goethe''',
r'''I do not take drugs -- I am drugs.  -- Salvador Dali''',
r'''I don't gamble.  There are other ways to win at life.  -- Mike Moxcey''',
r'''I don't know, I don't care, and it doesn't make any difference.  -- Jack Kerouac''',
r'''I don't make much sense because the rest of the world doesn't either.''',
r'''I don't make the rules, Gil, I only play the game.  -- Cash McCall''',
r'''I don't mind going nowhere as long as it's an interesting path.''',
r'''I don't see why any system of beliefs deserves respect simply because it exists.  -- Cristina Rad''',
r'''I don't speak for others and they don't speak for me.''',
r'''I don't think comedy is an escape from tragedy.  They are both life.  -- Nichols''',
r'''I don't want to make money.  I just want to be wonderful.  -- Marilyn Monroe''',
r'''I dream things that never were; and I say "Why not?"  -- George Shaw''',
r'''I fear explanations explanatory of things explained.  -- Abraham Lincoln''',
r'''I find great humor in the fact that we ever take ourselves seriously.  -- Adams''',
r'''I forgive and quite forget old faults.  -- William Shakespeare''',
r'''I found Rome a city of bricks and left it a city of marble.  -- Augustus Caesar''',
r'''I have become me without my consent.''',
r'''I have been a lucky man.  But someone has to be.  -- Edward Abbey''',
r'''I have lost all and found myself.  -- Clarke''',
r'''I have met my hero, and he is me.  -- George Sheehan''',
r'''I have never been hurt by anything I didn't say.  -- Calvin Coolidge''',
r'''I have never let my schooling interfere with my education.  -- Mark Twain''',
r'''I have never, ever seen God come through the front door.  -- Carolyn Myss''',
r'''I have no special talents.  I am only passionately curious.  -- Albert Einstein''',
r'''I have nothing to say, and I am saying it.  -- John Cage''',
r'''I have often regretted my speech, never my silence.  -- Publilius Syrus''',
r'''I have promises to keep, and miles to go before I sleep.  -- Robert Frost''',
r'''I have with me two gods, Persuasion and Compulsion.  -- Themistocles''',
r'''I know what I know, but I will keep it to myself.  -- Howell''',
r'''I like a state of continual becoming, with a goal in front and not behind.''',
r'''I like being single.  I am always there when I need me.  -- Art Leo''',
r'''I love treason but hate a traitor.''',
r'''I might make you feel, but I can't make you think.  -- Gerald Bostock''',
r'''I never know how much of what I say is true.  -- Bette Midler''',
r'''I never think of the future.  It comes soon enough.  -- Albert Einstein''',
r'''I never tried quitting, and I never quit trying.  -- Dolly Parton''',
r'''I never wish for anyone's death, but read a few obituaries with a chuckle.  -- Mark Zimmerer''',
r'''I only know that I do not know, but that is something after all.''',
r'''I only know what I read in the papers.  -- Will Rogers''',
r'''I prefer rogues to imbeciles, because they sometimes take a rest.  -- Dumas''',
r'''I put up my thumb...  And it blotted out the planet Earth.  -- Neil Armstrong''',
r'''I realized something about perfection...  It comes only with time.  -- Collymore''',
r'''I respect faith, but doubt is what gets you an education.  -- Wilson Mizner''',
r'''I saw that, finally, my responsibility was to work on myself.  -- Ram Dass''',
r'''I say little but think the more.  -- William Shakespeare''',
r'''I seem to be a verb.  -- Buckminster Fuller''',
r'''I slept and dreamed that life was Beauty; I woke, and found that life was Duty.''',
r'''I strive to be brief but I become obscure.  -- Horace''',
r'''I think time is a merciless thing.  -- Tennessee Williams''',
r'''I touch the future.  I teach.  -- Christa McAuliffe''',
r'''I tremble for my country when I reflect that God is just.  -- Thomas Jefferson''',
r'''I try not to break the rules but merely to test their elasticity.  -- Bill Veeck''',
r'''I understand why you are confused.  You're thinking too much.  -- Carole Wallach''',
r'''I used to be disgusted, now I find I am just amused.  -- Costello''',
r'''I wanted to do it just as he did; so I began to learn.  -- Cesar Chavez''',
r'''I wasted time and now doth time waste me.  -- William Shakespeare''',
r'''I will do nothing for you that you will not do for your Self.  -- God?''',
r'''I wish I didn't know now what I didn't know then.  -- Bob Seeger''',
r'''I wish I were as certain about anything as some people are about everything.''',
r'''I would consider it an honor to be fossilized.  -- famous anthropologist''',
r'''I would like to know what I was fencing in and what I was fencing out.  -- Frost''',
r'''I would rather be defeated with love in my heart than be victorious without it.''',
r'''I would rather be the first man here than the second in Rome.  -- Julius Caesar''',
r'''I would sooner be notorious than unknown.''',
r'''I [am] a channel through which music emerges from the chaos of noise.  -- Vangelis''',
r'''I'd much rather see lube oil running out of a bearing than metal particles.  -- Jim Potterf''',
r'''I'll meet you... on the dark side... of the moon...  -- Pink Floyd''',
r'''I'm against a homogenized society because I want the cream to rise.  -- Frost''',
r'''I'm always doing that which I cannot do, in order that I may learn how to do it.  -- Pablo Picasso''',
r'''I'm an idealist.  I don't know where I'm going, but I'm on my way!  -- Sandberg''',
r'''I'm running out of cheeks to turn.  -- John Taylor''',
r'''I've finally become what I had merely intended to seem.  -- Ludwig von Humboldt''',
r'''Idealism increases in direct proportion to your distance from the problem.''',
r'''Ideals are like the stars; we never reach them, but chart our course by them.''',
r'''Ideas:  Funny little things that don't work unless you do.''',
r'''Idle hands are the devil's playground.''',
r'''Idleness is leisure gone to seed.''',
r'''Idleness is the holiday of fools.''',
r'''If a camel flies, no one laughs if it doesn't get very far.  -- Paul White''',
r'''If a cat has nine lives, a lie has ninety-nine.  -- Blackmore''',
r'''If a document is over two pages long, few people will ever read it.  -- Adams''',
r'''If a fool persists in his folly he shall become wise.  -- William Blake''',
r'''If a guy is over 25% jerk, he's in trouble.  -- Lee Iacocca''',
r'''If a man has talent and cannot use it, he has failed.  -- Thomas Wolfe''',
r'''If a man hasn't discovered something that he will die for, he isn't fit to live.''',
r'''If a man hears much that a woman says, she is not beautiful.  -- Haskins''',
r'''If a person can't communicate, the very least he can do is to shut up!  -- Lehrer''',
r'''If a plant grows in abundance, it is a plant of virtue.  -- old Gypsy proverb''',
r'''If a string has one end, then it has another end.  -- Miksch''',
r'''If a thing's worth doing, it is worth doing badly.  -- G. K. Chesterton''',
r'''If an ad leaves off the price, it means if you knew it, you wouldn't pay it.''',
r'''If an inch represents one AU, then a light year is one mile, within 1%.''',
r'''If anything can go wrong, it will.  -- Murphy''',
r'''If anything is sacred, the human body is sacred.  -- Walt Whitman''',
r'''If at first you don't succeed, try, try again.  -- Confucius''',
r'''If blame can be shifted, it will be.''',
r'''If Christ were here now there is one thing he would not be -- a Christian.''',
r'''If either religion or science were infallible, it would incorporate the other.''',
r'''If everybody was satisfied with himself, there would be no heroes.  -- Mark Twain''',
r'''If fifty million people say a foolish thing, it is still a foolish thing.''',
r'''If God did not exist, it would be necessary to invent him.  -- Voltaire''',
r'''If God exists only in the gaps, then God is diminished with each new discovery.''',
r'''If God made us in His image, we have certainly returned the compliment.''',
r'''If God wanted us to have a president, he would have sent us a candidate.''',
r'''If guns are outlawed, only the government will have guns.  -- Edward Abbey''',
r'''If happiness is in your destiny, you need not be in a hurry.  -- Chinese proverb''',
r'''If he works for you, you work for him.  -- Japanese proverb''',
r'''If I cannot bend Heaven, I shall move Hell.  -- Virgil''',
r'''If I had finished this sentence.  -- Hofstadter''',
r'''If I have seen further, it is by standing on the shoulders of giants.  -- Newton''',
r'''If it can't bite you, it can't kiss you.''',
r'''If it doesn't matter, it doesn't matter.''',
r'''If it happens, it must be possible.''',
r'''If it is to be, it is up to me.''',
r'''If it still works for you, it's not obsolete.''',
r'''If it works, don't fix it.  -- Sam Rayburn''',
r'''If it's not necessary to make a decision, it's necessary not to make a decision.''',
r'''If life gives you lemons, make lemonade.''',
r'''If life is merely a joke, the question still remains:  For whose amusement?''',
r'''If love is blind, it best agrees with night.  -- William Shakespeare''',
r'''If men could become pregnant, abortion would be a sacrament.''',
r'''If money is a means to an end, then inflation is an end to the means.  -- Seitler''',
r'''If N=1, all bets are off.  -- Chuck Forsberg''',
r'''If no one measures up, check your yardstick.''',
r'''If no one uses it, there is a reason.''',
r'''If not controlled, work flows to the competent person until he is submerged.''',
r'''If one tells the truth, one is sure sooner or later, to be found out.  -- Oscar Wilde''',
r'''If only I had known, I should have become a watchmaker.  -- Albert Einstein''',
r'''If peace cannot be maintained with honor, it is no longer peace.  -- John Russell''',
r'''If people behaved like governments, you'd call the cops.  -- Kelvin Throop''',
r'''If plugged into tribal thought forms, you're also plugged into tribal diseases.  -- Carolyn Myss''',
r'''If religion remains unchallenged, so are the social problems that come with it.  -- Cristina Rad''',
r'''If slavery is not wrong, nothing is wrong.  -- Lincoln''',
r'''If someone truly loves you, they ask how to make you happy; they don't guess.''',
r'''If stock market experts were so expert, they would buy stock, not sell advice.''',
r'''If the bed could tell all it knows it would put many to the blush.  -- Overbury''',
r'''If the end does not justify the means -- what can?  -- Edward Abbey''',
r'''If the enemy is in range, so are you.''',
r'''If the master dies and the disciple grieves, the lives of both have been wasted.''',
r'''If the poor cannot always get meat, the rich cannot always digest it.''',
r'''If the solution is too complex you haven't stated the problem right.  -- Baskins''',
r'''If the thought is not the thinker then the thinker can choose the thought.''',
r'''If the universe is the answer, what is the question?  -- Leon Lederman''',
r'''If the Universe were fair, we would deserve all the pain that we suffer.''',
r'''If there are epigrams, there must be meta-epigrams.''',
r'''If there is a wrong way to do something, then someone will do it.  -- Murphy''',
r'''If there is no wind, row.  -- Polish proverb''',
r'''If war is the answer, then it's a stupid question.''',
r'''If we could love our enemies we would have none.  -- Thomas McKeown''',
r'''If we crave some cosmic purpose, let us find ourselves a worthy goal.  -- Carl Sagan''',
r'''If we don't survive, we don't do anything else.  -- John Sinclair''',
r'''If we look for the good in others, we discover the best in ourselves.  -- Walsh''',
r'''If we stop trying to understand things, we'll all be sunk.  -- Frank Oppenheimer''',
r'''If what you're doing doesn't work, try something different.''',
r'''If wilderness is outlawed, only outlaws can save wilderness.  -- Edward Abbey''',
r'''If ye sow the wind, ye shall reap the whirlwind.  -- Old Testament''',
r'''If you accept yesterday and love today, you will not be afraid of tomorrow.''',
r'''If you aim at nothing, you are bound to hit it.''',
r'''If you always postpone pleasure you will never have it.''',
r'''If you are afraid of loneliness, don't marry.  -- Chekhov''',
r'''If you are at the poker table wondering who the patsy is, it's probably you.  -- William Bernstein''',
r'''If you are careful enough, nothing bad or good will ever happen to you.''',
r'''If you are going to make rubbish, be the best rubbish in it.  -- Richard Burton''',
r'''If you are short of everything but the enemy, you're in a combat zone.''',
r'''If you are too busy to read, then you are too busy.''',
r'''If you are wise, you will keep quiet.  -- Solomon''',
r'''If you aren't going all the way, why go at all?''',
r'''If you argue with a fool, chances are he's doing the same thing.''',
r'''If you brutalize the world around you, you also brutalize yourself.  -- Flanders''',
r'''If you can afford to do the right thing, you cannot afford to do otherwise.''',
r'''If you can distinguish between good and bad advice, you don't need advice.''',
r'''If you can dream it, you can do it.  -- Walt Disney''',
r'''If you can't be right, at least be consistent.  -- Allan Roth''',
r'''If you can't explain it simply, you don't understand it.''',
r'''If you can't feed 'em, don't breed 'em.''',
r'''If you can't lick 'em, join 'em.''',
r'''If you can't stand the heat, get out of the kitchen.''',
r'''If you can't tell the difference, there is no difference.''',
r'''If you can't write it right, you can't think it right.''',
r'''If you carry enough gear for every emergency, you'll eventually need to use it.''',
r'''If you choose not to decide you still have made a choice.  -- Rush''',
r'''If you continually give you will continually have.''',
r'''If you detect a problem in communicating, it is your problem.''',
r'''If you dig a pit, you will fall in it.  -- Old Testament''',
r'''If you do not change your direction, you might end up where you are headed.''',
r'''If you do not go within, you go without.  -- Conversations with God''',
r'''If you do not think about the future, you cannot have one.  -- John Galsworthy''',
r'''If you do what you've always done, you'll get what you've always gotten.''',
r'''If you don't deal with anger, it will deal with you.  -- Will Limon''',
r'''If you don't get it, don't worry about it, it will come back bigger.''',
r'''If you don't know where you are going, any road will take you there.  -- Carroll''',
r'''If you don't like a job, don't get good at it.  -- Jon Cohen''',
r'''If you don't like change, you're going to like irrelevance even less.  -- Shinseki''',
r'''If you don't make mistakes, you aren't really trying.  -- Coleman Hawkins''',
r'''If you don't scale the mountain, you can't see the plain.  -- Chinese proverb''',
r'''If you don't strike oil in twenty minutes, stop boring.  -- Andrew Carnegie''',
r'''If you don't take care of your body, where will you live?''',
r'''If you don't understand my silence, you will never understand my words.  -- Taylor''',
r'''If you don't visit a bad neighborhood, it will visit you.  -- Thomas Friedman''',
r'''If you dress like you know what you're doing, people will think you do.  -- Duggan''',
r'''If you ever need a helping hand, you will find one at the end of your arm.''',
r'''If you explain a joke, it ceases to be funny.''',
r'''If you fall in a pond, check your pockets for fish.  -- Darrell Royal''',
r'''If you find a path with no obstacles, it probably doesn't go anywhere.''',
r'''If you find your foot in your mouth, floss with your shoelaces and move on.''',
r'''If you flatter your friends, you set a trap for yourself.  -- Solomon''',
r'''If you get the feeling I don't love you, feel again.''',
r'''If you give love, it has to be unconditional; there is no other kind.  -- Coit''',
r'''If you have a job without aggravations, you don't have a job.''',
r'''If you have no enemies, it's a sign fortune has forgot you.''',
r'''If you have the right attitude, interesting problems will find you.  -- Raymond''',
r'''If you have to ask what jazz is, you will never know.  -- Louis Armstrong''',
r'''If you have to ask you will never know.''',
r'''If you have to walk on thin ice...  You might as well dance!''',
r'''If you haven't got a sense of humor, you haven't got any sense at all.''',
r'''If you haven't time to do it right now, how will you redo it right later?''',
r'''If you itch for it, scratch for it.''',
r'''If you keep an open mind people will throw a lot of garbage in it.''',
r'''If you keep people awake long enough, you can make them believe anything.  -- Chuck Dederich''',
r'''If you knew what you were doing you would probably be bored.  -- Fresco''',
r'''If you know your best, it's easier to say no to the merely good.  -- Neifert''',
r'''If you lend money in close friendship, it is sure to close friendship.  -- Murthy''',
r'''If you lie upon roses when young, you'll lie upon thorns when old.  -- Quarles''',
r'''If you love life it will love you back.''',
r'''If you make demands, you are trapped in others's actions.  -- Limon''',
r'''If you must fail, fail early.''',
r'''If you must fly, fly well.  -- George Herbert''',
r'''If you must hate, hate gently.''',
r'''If you must say something anonymously, it's probably not worth saying.''',
r'''If you obey all the rules, you miss all the fun.''',
r'''If you only have a hammer, you tend to see every problem as a nail.  -- Maslow''',
r'''If you reach the endzone, act like you've been there before.  -- Joe Paterno''',
r'''If you refuse to accept anything but the best, you very often get it.''',
r'''If you see fraud and don't shout fraud, you are a fraud.  -- Nassim Taleb''',
r'''If you seem to know what you are doing, you will be given more to do.''',
r'''If you share less, you will find you have less to share.  -- Dave Mata''',
r'''If you smile at someone, they might smile back.''',
r'''If you steal for others you shall be hanged yourself.  -- Torriano''',
r'''If you struggle with money, you will struggle in life.  -- Peter Dunn''',
r'''If you suspect a person, don't employ him.''',
r'''If you take care of the future, you take care of yourself.  -- Oren Lyons''',
r'''If you tell the truth, you don't have to remember anything.  -- Mark Twain''',
r'''If you think education is expensive, try ignorance.  -- Derek Bok''',
r'''If you think you are above other people, you might really be standing all alone.''',
r'''If you think you have no faults, that makes one.''',
r'''If you think you're free, there's no escape possible.  -- Ram Dass''',
r'''If you treat people right they will treat you right -- 90% of the time.''',
r'''If you trim yourself to suit others, soon you will whittle yourself away.''',
r'''If you try to please everyone, someone will be displeased.''',
r'''If you wait long enough, all your neighbors will build your fence.''',
r'''If you want a place in the sun, you must leave the shade of the family tree.''',
r'''If you want a quality, act as if you already had it.  -- William James''',
r'''If you want divine justice, die.  -- Nick Seldon''',
r'''If you want people to think you wise, just agree with them.''',
r'''If you want something different, do something different.  -- Chris Bouten''',
r'''If you want to annoy your neighbors, tell the truth about them.  -- Pietro Aretino''',
r'''If you want to know what God thinks of money, look at the people he gives it to.''',
r'''If you want to test a man's character, give him power.  -- Abraham Lincoln''',
r'''If you want unconditional enthusiasm and love, get a dog.  -- Clara Thompson''',
r'''If you wish to succeed, consult three old people.''',
r'''If you won't bring your power into the light you'll maneuver it in the darkness.''',
r'''If you work on your mind with your mind, how can you avoid immense confusion?''',
r'''If you would be at ease, all the world is not.  -- George Herbert''',
r'''If you would keep a secret from an enemy, tell it not to a friend.''',
r'''If you would know the value of money, go try to borrow some.  -- Ben Franklin''',
r'''If you would make an enemy, lend a man money, and ask it of him again.  -- Ray''',
r'''If you wouldn't shoot your mother for it, it's not worth taxing.  -- O'Rourke''',
r'''If you're going to be thinking anything, you might as well think big.  -- Trump''',
r'''If you're gonna be dumb, you'd better be tough.  -- Johnny Cash''',
r'''If you're happy, you're successful.''',
r'''If you're in debt, you can't say no.  -- Tom Hanks''',
r'''If you're not allowed to laugh in heaven, I don't want to go there.  -- Luther''',
r'''If your bread is stale, make toast.''',
r'''If your friends all jumped off a bridge, would you?''',
r'''If your riches are yours, why can't you take them with you to the next world?''',
r'''If youth but knew, if old age but could.  -- Henri Estienne''',
r'''Ignorance doesn't kill you, but it makes you sweat a lot.  -- Haitian proverb''',
r'''Ignorance is bliss.''',
r'''Ignorance is easier to cure than arrogance.''',
r'''Ignorance is the first guarantee of poverty and peonage.  -- Pancho Villa''',
r'''Ignorance is the mother of adventure.''',
r'''Ignorance, like faith and love, often blinds men.  -- Michael Uhrin''',
r'''Ignore people who refuse to change their mind when the facts change.  -- Morgan Housel''',
r'''Ill agreement is better than good judgement.''',
r'''Ill news comes often on the back of worse.''',
r'''Illness is nothing more than yet another form of neutral experience.  -- Carolyn Myss''',
r'''Illusion is the first of all pleasures.  -- Voltaire''',
r'''Imagination is more important than knowledge.  -- Albert Einstein''',
r'''Imagination is the one weapon in the war against reality.  -- Jules de Gaultier''',
r'''Imagine there's no heaven...  It's easy if you try.  -- John Lennon''',
r'''Imitation is the sincerest flattery.  -- Colton''',
r'''Immortality can always be assured by spectacular error.  -- John Galbraith''',
r'''Importance is one of the most important of our illusions.  -- Herbert Salzer''',
r'''Important if true.  -- A.W. Kinglake (proposed warning label on churches)''',
r'''Improvement requires change.  But change is not necessarily improvement.''',
r'''Impurity means thoughts which define oneself as separate.  -- Ram Dass''',
r'''In a hierarchical organization, the higher the level, the greater the confusion.''',
r'''In a hierarchy every employee rises to his level of incompetence.  -- Dr. Peter''',
r'''In a leopard the spots are not observed.  -- George Herbert''',
r'''In a nation of sheep, one brave man forms a majority.  -- Edward Abbey''',
r'''In a philosophical dispute, he gains most who is defeated, since he learns most.''',
r'''In a time of universal deceit, telling the truth is a revolutionary act.  -- George Orwell''',
r'''In a world without sorrow, nightingales would burp.  -- E. M. Cioran''',
r'''In all labor there is profit, but mere talk leads only to poverty.  -- Proverbs''',
r'''In America the typewriters sleep with the good plumbing.''',
r'''In America, sex is an obsession, in other parts of the world it is a fact.''',
r'''In any human endeavor, work seeks the lowest hierarchical level.''',
r'''In art as in life, form and subject, body and soul, are one.  -- Edward Abbey''',
r'''In calm waters, every ship has a good captain.  -- Swedish proverb''',
r'''In charity there is no excess.  -- Francis Bacon''',
r'''In defeat, unbeatable; in victory, unbearable.  -- Churchill, on Montgomery''',
r'''In every country the sun rises in the morning.  -- George Herbert''',
r'''In every fault there is folly.''',
r'''In expressing love we belong among the undeveloped countries.  -- Saul Bellow''',
r'''In giving advice seek to help, not to please your friend.  -- Solon''',
r'''In God we trust; all others pay cash.''',
r'''In her dealings with man Destiny never closes her accounts.  -- Oscar Wilde''',
r'''In high school, you teach subjects.  In grade school, you teach children.''',
r'''In investing, a sign you are doing the right thing is that it hurts.  -- Allan Roth''',
r'''In investing, moderation in all things is preferred to excess in any one thing.''',
r'''In life, some people get "shipped and handled" more than others.  -- Will Limon''',
r'''In loosing time, a man gets no money.  -- Thomas Draxe''',
r'''In Los Angeles there are fewer people than there are automobiles.''',
r'''In love's wars he who flies is conqueror.  -- Torriano''',
r'''In medicine, sins of commission are mortal, sins of omission venial.  -- Tronchin''',
r'''In modern life nothing produces such an effect as a good platitude.  -- Oscar Wilde''',
r'''In most instances, all an argument proves is that two people are present.''',
r'''In my end is my beginning.''',
r'''In nature there are no rewards or punishments, only actions and consequences.''',
r'''In order to be it you've got to give up knowing you know.  -- Ram Dass''',
r'''In order to progress we must recognize our ignorance and leave room for doubt.''',
r'''In our lives, death is both more removed and with us constantly.  -- Marc Salkin''',
r'''In painting you must give the idea of the true by means of the false.  -- Degas''',
r'''In science the difficulty is not the discovery, but realizing one has made it.''',
r'''In sickness health is known.  -- Torriano''',
r'''In silence also there's a worth that brings no risk.  -- Simonides of Ceos''',
r'''In success there's a tendency to keep on doing what you were doing.  -- Alan Kay''',
r'''In the absence of that which is not, that which IS, is NOT.  -- God?''',
r'''In the beginner's mind are many possibilities, but in the expert's mind, few.''',
r'''In the country of the blind, the one eye'd man is king.''',
r'''In the deepest water is the best fishing.  -- Thomas Draxe''',
r'''In the kingdom of blind men the one-eyed is king.''',
r'''In the kingdom of blind men the one-eyed must be mad.''',
r'''In the last 4000 years no new animals have been domesticated.''',
r'''In the long run we're all dead.  -- John Keynes''',
r'''In the matter of taxation, every privilege is an injustice.  -- Voltaire''',
r'''In the middle of difficulty lies opportunity.  -- Albert Einstein''',
r'''In the midst of movement and activity, carry your stillness within you.  -- Deepak Chopra''',
r'''In the moment you pledge your highest love, you greet your greatest fear.  -- God?''',
r'''In time of peace, prepare for war.''',
r'''In time, the mask becomes the face.''',
r'''In too much dispute truth is lost.''',
r'''In trying times, keep trying.''',
r'''In vino veritas.  (In wine there is truth.)  -- Pliny''',
r'''In war it is not permitted twice to err.''',
r'''In war, truth is the first casualty.  -- U Thant''',
r'''In Washington (DC), the urgent overwhelms the important.  -- Tony Snow''',
r'''In writing, fidelity to fact leads eventually to the poetry of truth.  -- Edward Abbey''',
r'''Income almost always summons expenses. -- Peter Dunn''',
r'''Incompetence knows no barriers of time or place.''',
r'''Incompetence plus incompetence equals incompetence.''',
r'''Individuals often forget and forgive, but societies never do.  -- Averbury''',
r'''Individuals resist factual information that threatens their defining values.  -- Dan Kahan''',
r'''Indomitable in retreat; invincible in advance; insufferable in victory.''',
r'''Infinite speech has the form of listening.  -- James Carse''',
r'''Infinite speech is not ABOUT anything; it is always TO someone.  -- James Carse''',
r'''Information deteriorates upward through bureaucracies.''',
r'''Information in the present can change the past.  -- Scott Adams''',
r'''Information is the inverse of entropy.''',
r'''Information that is hard to access is worth less than none at all.''',
r'''Injustice anywhere is a threat to justice everywhere.  -- Martin King Jr''',
r'''Innocence is no protection.  -- Jonson''',
r'''Innovation is hard to schedule.  -- Dan Fylstra''',
r'''Insanity is expecting different results from repeating the same behavior.''',
r'''Inside every large problem is a small problem struggling to get out.  -- Hoare''',
r'''Instead of loving your enemies, treat your friends a little better.  -- Howe''',
r'''Instead of panicking, detach like Buddha.  -- Carolyn Myss''',
r'''Institutions are devoid of humanity; they are established for productivity.''',
r'''Insulting those who don't already hold your point of view isn't persuasive.  -- Bob Moore''',
r'''Integrity costs so very little.''',
r'''Integrity has no need of rules.  -- Albert Camus''',
r'''Intellect annuls Fate.  So far as a man thinks, he is free.  -- Ralph Emerson''',
r'''Intellectual assets, unlike physical assets, increase in value with use.''',
r'''Intellectual objectivity is often seduced by semantic skullduggery.  -- Hirsch''',
r'''Intelligence is more often than not misused.''',
r'''Intelligence is the art of good guessing.  -- Horace Barlow''',
r'''Intelligence without character is a dangerous thing.  -- Gloria Steinem''',
r'''Intelligent people think before they speak.  -- Solomon''',
r'''Intention is not action.''',
r'''Internal consistency is valued more than efficient service.''',
r'''Internalized oppression is the part of us that believes we're less than perfect.''',
r'''Intimacy comes from the resolution of conflict, not the lack of it.  -- Limon''',
r'''Intimacy is the exchange of vulnerabilities.  -- Masters and Johnson''',
r'''Intimacy:  Two trees growing close together, but not in each other's shadow.''',
r'''Into every life a bit of rain must fall.''',
r'''Intolerance is a state no tolerant man can tolerate.  -- McGinley''',
r'''Intolerance is the last defense of the insecure.''',
r'''Intuitive insight is not a gift, it is a skill.  -- Carolyn Myss''',
r'''Invest in the past.  It will always be with you.''',
r'''Investing is simple, but not easy.  -- Warren Buffett''',
r'''Investing is taking a risk only when you expect a positive return.  -- Allan Roth''',
r'''Investing isn't a game, and doing it right really isn't any fun.  -- Allan Roth''',
r'''Investors should remember that excitement and expenses are their enemies.  -- Warren Buffett''',
r'''Irritation is one of the great gifts we give each other.  -- Lee Coit''',
r'''Is a mirage real?  Well, it's a real mirage.  -- Edward Abbey''',
r'''Is no one inspired by our present picture of the universe?  -- Richard Feynman''',
r'''Is there anyone so wise as to learn by the experience of others?  -- Voltaire''',
r'''Is this true or only clever?  -- Augustine Birrell''',
r'''Isn't fun the best thing to have?''',
r'''It ain't creative if it don't sell.''',
r'''It ain't over till it's over.  -- Yogi Berra''',
r'''It costs more to do ill than to do well.  -- George Herbert''',
r'''It doesn't matter who you marry; next morning you will find it was someone else.''',
r'''It has yet to be proven that intelligence has any survival value.  -- Clarke''',
r'''It is a fundamental law of nature that nothing ever quite works out.''',
r'''It is a great point of wisdom to find out one's own folly.''',
r'''It is a great victory that comes without blood.''',
r'''It is a miracle that curiosity survives formal education.  -- Albert Einstein''',
r'''It is a poor judge who cannot award a prize.''',
r'''It is a poor workman who blames his tools.''',
r'''It is a principle function of society to validate titles.  -- James Carse''',
r'''It is a principle of human nature to hate those whom you have injured.  -- Tacitus''',
r'''It is a profitable thing, if one is wise, to seem foolish.  -- Aeschylus''',
r'''It is a rare problem that can't be solved by fewer people or less government.''',
r'''It is a short way from the penthouse to the outhouse.  -- (coach) Dan Reeves''',
r'''It is a silly fish that is caught twice with the same bait.''',
r'''It is a very sad thing that nowadays there is so little useless information.''',
r'''It is a wise father that knows his own child.''',
r'''It is all a game; play it to have fun.  -- Price''',
r'''It is always best to do a thing wrong the first time.  -- Osler''',
r'''It is always with the best intentions that the worst work is done.  -- Oscar Wilde''',
r'''It is amazing how much "mature wisdom" resembles being too tired.  -- Robert Heinlein''',
r'''It is amazing how much one person can do, little by little, over time.''',
r'''It is amusing that a virtue is made of the vice of chastity...  -- Voltaire''',
r'''It is annoying to be honest to no purpose.  -- Ovid''',
r'''It is as cheap sitting as standing.  -- Torriano''',
r'''It is as good to be in the dark as without light.  -- John Ray''',
r'''It is as natural to die as to be born.''',
r'''It is bad not to do any research, but badly done research is even worse.''',
r'''It is best to be off with the old love before you are on with the new.''',
r'''It is better never to begin than never to make an end.  -- Alexander Barclay''',
r'''It is better to be a beggar than a fool.  -- Torriano''',
r'''It is better to be a coward for a minute than dead the rest of your life.''',
r'''It is better to be a martyr than a confessor.  -- Sanford''',
r'''It is better to be alone than in bad company.''',
r'''It is better to be deceived by a friend than to suspect him.''',
r'''It is better to be deceived than to be undeceived by those we love.''',
r'''It is better to be happy than wise.  -- W. Alley''',
r'''It is better to be wanted for murder that not to be wanted at all.  -- Marty Winch''',
r'''It is better to be wise than smart.''',
r'''It is better to beg than to steal.''',
r'''It is better to buy than borrow.  -- Taverner''',
r'''It is better to die on your feet than to live on your knees.''',
r'''It is better to die with honor than live with shame.''',
r'''It is better to divorce than to murder.''',
r'''It is better to eat than to be eaten.''',
r'''It is better to give than receive.''',
r'''It is better to go by your enemy's grave than his gate.  -- Robinson''',
r'''It is better to go to heaven in rags than to hell in embroidery.  -- Fuller''',
r'''It is better to have men ask why you have no statue than why you have one.''',
r'''It is better to have than to hear of a good thing.  -- John Ray''',
r'''It is better to keep the devil at the door than turn him out of the house.''',
r'''It is better to know nothing than to know what ain't so.  -- Josh Billings''',
r'''It is better to know some of the questions than all of the answers.  -- Thurber''',
r'''It is better to know, than not to know.  -- Paul Harvey''',
r'''It is better to live rich than to die rich.''',
r'''It is better to pass a danger once than be always in fear.  -- Julius Caesar''',
r'''It is better to say, "here it is" than, "here it was."  -- James Carmichaell''',
r'''It is better to speak truth rudely than lie covertly.  -- George Herbert''',
r'''It is better to suffer ill than do ill.''',
r'''It is better to travel in hope than arrive in despair.  -- Tom Magliozzi''',
r'''It is better to wear out than to rust out.  -- Richard Cumberland''',
r'''It is better to win control over yourself than over whole cities.  -- Solomon''',
r'''It is dangerous to be a farsighted midget in a land of nearsighted giants.''',
r'''It is dangerous to be right when the government is wrong.  -- Voltaire''',
r'''It is dangerous to be sincere unless you are also stupid.  -- George Shaw''',
r'''It is difficult to be depressed while you are doing something.''',
r'''It is difficult to see the picture when you are inside the frame.''',
r'''It is easier to be a result of the past than a cause of the future.''',
r'''It is easier to be wise for others than for oneself.  -- La Rochefoucald''',
r'''It is easier to do good than be good.''',
r'''It is easier to fight for principles than live up to them.  -- Alfred Adler''',
r'''It is easier to get forgiveness than permission.  -- Stewart''',
r'''It is easier to praise poverty than to bear it.''',
r'''It is easier to pull down than to build up.''',
r'''It is easier to resist at the beginning than at the end.  -- Leonardo da Vinci''',
r'''It is easier to run down a hill than up one.''',
r'''It is easy to be brave from a safe distance.  -- Aesop''',
r'''It is evil to act as though the past is bringing us to a specifiable end.''',
r'''It is extraordinary how extraordinary the ordinary person is.  -- George Will''',
r'''It is good to have some friends both in heaven and hell.  -- G. Delamothe''',
r'''It is good to marry late or never.  -- Thomas Draxe''',
r'''It is hard having a hierarchical mind in a serial world.  -- Alan Silverstein''',
r'''It is hard to be graceful getting off a high horse.''',
r'''It is hard to fight an enemy who has outposts in your head.  -- Sally Kempton''',
r'''It is hard to write even a bad book.''',
r'''It is impolite to silence a fool and cruel to let him go on.''',
r'''It is impossible for a man to learn what he thinks he already knows.  -- Epictetus''',
r'''It is impossible for an optimist to be pleasantly surprised.''',
r'''It is impossible to enjoy idling thoroughly unless one has plenty of work to do.''',
r'''It is impossible to make anything foolproof because fools are so ingenious.''',
r'''It is in surrendering that the victory is won.  -- Conversations with God''',
r'''It is incumbent on every generation to pay its own debts.  -- Thomas Jefferson''',
r'''It is just as easy to make a dollar today as it will be next year.  -- Packard''',
r'''It is least productive to make more efficient what need not be done at all.''',
r'''It is lost that is unsought.  -- John Heywood''',
r'''It is misery enough to have once been happy.''',
r'''It is more important to get in the first thought than the last word.''',
r'''It is more pain to do nothing than something.  -- George Herbert''',
r'''It is much better to become the saint, rather than to go and have his visit.''',
r'''It is much easier and much faster to destroy than to build.  -- Nassim Taleb''',
r'''It is much easier to be critical than to be correct.  -- Benjamin Disraeli''',
r'''It is much easier to change what you are doing than what another is doing.''',
r'''It is much harder to find a job than to keep one.  -- Jules Becker''',
r'''It is necessary to think even to decide which facts to collect.  -- Hutchins''',
r'''It is never too late to be what you might have been.  -- George Eliot''',
r'''It is never too late to have a happy childhood.''',
r'''It is never too late to learn.''',
r'''It is no good trying to teach people who need to be taught.  -- Aleister Crowley''',
r'''It is not a bad little planet, if you know the right people.''',
r'''It is not easy to play the clown when you have to run the whole circus.''',
r'''It is not enlightened to shrink so others won't feel insecure around you.''',
r'''It is not enough to be a market-focused company.  You must be customer-centered.''',
r'''It is not enough to be a strong player, one must also play well.  -- Tarrasch''',
r'''It is not enough to succeed.  Others must fail.  -- Gore Vidal''',
r'''It is not every question that deserves an answer.  -- Publilius Syrus''',
r'''It is not granted to man to love and to be wise.  -- Francis Bacon''',
r'''It is not honest to be tactful.  -- Robert Taft''',
r'''It is not how long but how well we live.''',
r'''It is not necessary to appreciate fine wine to drink it.  -- Henry Gay''',
r'''It is not possible to step in the same river twice.  -- Heraclitus''',
r'''It is not reality that is important, but how you perceive things.''',
r'''It is not the beard that makes the philosopher.  -- E. Gayton''',
r'''It is not the man who has too little, but the man who craves more, that is poor.''',
r'''It is not the perfect but the imperfect who have need of love.  -- Oscar Wilde''',
r'''It is not the size of the army, it's the frenzy of the attack.''',
r'''It is not who you know, it's what you are.  -- John Taylor''',
r'''It is not wise to show one's heart to the world.  -- Oscar Wilde''',
r'''It is not work that kills, but worry.''',
r'''It is one thing to praise discipline, and another to submit to it.  -- Cervantes''',
r'''It is only shallow people who do not judge by appearances.''',
r'''It is personalities, not principles, that move the age.  -- Oscar Wilde''',
r'''It is possible to love a human being if you don't know them too well.''',
r'''It is simple to make things complex, but complex to make them simple.''',
r'''It is sin to think evil of others, but it is seldom a mistake.  -- H. L. Mencken''',
r'''It is smart to pick your friends -- but not to pieces.''',
r'''It is so much easier to be together when we drop our masks.  -- Liv Ullman''',
r'''It is so very difficult for a sick man not to be a scoundrel.  -- Samuel Johnson''',
r'''It is sometimes necessary to belabor the obvious.  -- Lawrence Hirsch''',
r'''It is stupid to get drunk.  -- Solomon''',
r'''It is the business of little minds to shrink.  -- Carl Sandburg''',
r'''It is the business of scientists to explain away the magic in the world.''',
r'''It is the business of the future to be dangerous.  -- Hawkwind''',
r'''It is the confession, not the priest, that gives us absolution.  -- Oscar Wilde''',
r'''It is the last straw that breaks the camel's back.''',
r'''It is the nature of people to love, then destroy, then love again...  -- God?''',
r'''It is the sick oyster which possesses the pearl.  -- J. A. Shedd''',
r'''It is the spectator, and not life, that art really mirrors.  -- Oscar Wilde''',
r'''It is the wise bird who builds his nest in a tree.''',
r'''It is to no purpose to counsel him who is lucky.  -- Torriano''',
r'''It is tragic when a man outlives his body.  -- Sigmund Freud''',
r'''It is unwise to be too sure on one's wisdom.  -- Mohandas Gandhi''',
r'''It is your concern when your neighbor's wall is on fire.  -- Horace''',
r'''It isn't the whistle that moves the train.''',
r'''It may not be true but it is well contrived.  -- Giordano Bruno''',
r'''It pays to be obvious, especially if you have a reputation for subtlety.''',
r'''It pleases me as much to doubt as to know.  -- Dante''',
r'''It takes a certain brilliance to keep a simple idea simple.  -- Allan Roth''',
r'''It takes a lot of courage to show your dreams to someone else.  -- Erma Bombeck''',
r'''It takes all sorts to make a world.  -- Thomas Shelton''',
r'''It takes less time to do a thing right than to explain why you did it wrong.''',
r'''It takes two to make a quarrel.''',
r'''It was a dream of perfect bliss, too beautiful to last.  -- T. H. Bayly''',
r'''It was fear that first made gods in the world.  -- Statius''',
r'''It was only in my forties that I started to feel young.  -- Henry Miller''',
r'''It's a cold bowl of chili when love lets you down.  -- Neil Young''',
r'''It's a terrific burden being right and competent all the time.  -- Lee Coit''',
r'''It's a total freedom when the other person says:  Do what you want to do.  -- Coit''',
r'''It's all in your mind, you know...''',
r'''It's all right to be Goliath, but always act like David.  -- Phil Knight''',
r'''It's better that we disagree than be in agreement and all be wrong.  -- Kahn''',
r'''It's easier to fool people than to convince them that they've been fooled.''',
r'''It's easier to get forgiveness for being wrong than forgiveness for being right.''',
r'''It's easy to sit up and take notice, but hard to get up and take action.''',
r'''It's for fun.  Money's just the way we keep score.  -- Henry Tyroon''',
r'''It's hard to be reasonable with someone who isn't.''',
r'''It's not a question of who's right and who's wrong, but of what do we do now?  -- Oren Lyons''',
r'''It's not bragging if you can back it up.  -- Muhammed Ali''',
r'''It's not difference that creates problems; it's dominance that creates problems.''',
r'''It's not how old you are, but how you are old.''',
r'''It's the job of the press to comfort the afflicted and afflict the comfortable.''',
r'''It's the little things that count, especially when nobody is looking.''',
r'''It's the money you don't spend that gives you the freedom to build wealth.''',
r'''It's the thought that counts.  -- Confucius''',
r'''It's time to take on self-creation and move away from the tribal.  -- Carolyn Myss''',
r'''It's tough to bargain with someone who has nothing to lose.''',
r'''It's very hard to define entropy for the entire universe.  -- Lawrence Shulman''',
r'''It's what a fellow thinks he knows that hurts him.''',
r'''It's what you do after you're born that counts.  -- John Taylor''',
r'''It's your love that defines you, not who loves you.''',
r'''Jesus don't walk on water no more; his feet leak.  -- Edward Abbey''',
r'''Jesus was killed by a Moral Majority.''',
r'''Job descriptions are hideously cumulative.  -- Scott Adams''',
r'''Judge a man by his foes as well as by his friends.  -- Joseph Conrad''',
r'''Judge not, and neither condemn, for you know not why a thing occurs...  -- God?''',
r'''Judge people by what they are, not where they are.''',
r'''Judging is like telling God that the divine doesn't know what it's doing.  -- Carolyn Myss''',
r'''Jumping to conclusions is a dangerous exercise.''',
r'''Just because you arrive does not mean your map is correct.''',
r'''Justice delayed is justice denied.  -- old French proverb''',
r'''Justice is incidental to law and order.  -- J. Edgar Hoover''',
r'''Keep a diary, and some day it'll keep you.  -- Mae West''',
r'''Keep an open mind, but not so open that your brains fall out.  -- Kallis''',
r'''Keep the promises you've made to yourself.  -- Paul Sassenrath''',
r'''Keep your boss's boss off your boss's back.''',
r'''Keep your laws off my body!''',
r'''Keep your old love letters.  Throw away your old bank statements.  -- Schmich''',
r'''Key aspects of advertising:  Attention, interest, motivation.''',
r'''Kill reverence and you've killed the hero in man.  -- Ayn Rand''',
r'''Kind hearts are soonest wronged.  -- Breton''',
r'''Kindness comes of will.''',
r'''Kindness is like a boomerang:  It always comes back.''',
r'''Kisses are a better fate than wisdom.''',
r'''Kissing a smoker is like licking an ash tray.''',
r'''Kites rise highest against the wind -- not with it.  -- Winston Churchill''',
r'''Know yourself thoroughly and compromise carefully.  -- Will Limon''',
r'''Knowing through intellect is merely another power.  -- Ram Dass''',
r'''Knowledge comes, but wisdom lingers.  -- Tennyson''',
r'''Knowledge is better than ignorance.''',
r'''Knowledge is knowing that you do not know.''',
r'''Knowledge is power.  -- Francis Bacon''',
r'''Knowledge makes one laugh, but wealth makes one dance.  -- George Herbert''',
r'''Knowledge need never be justified by utility.''',
r'''Knowledge steepens our soul's angle of repose.  -- John Taylor''',
r'''Knowledge without common sense is folly.''',
r'''Knowledge without practice makes but half an artist.''',
r'''Lack of capability is usually disguised by lack of interest.  -- Alan Silverstein''',
r'''Lack of money is the root of all evil.  -- George Shaw''',
r'''Language is the most powerful tool ever invented anywhere by anyone.  -- Asimov''',
r'''Large standard deviations indicate failure to account for hidden effects.''',
r'''Laugh when you can; cry when you must.''',
r'''Laughter is the closest distance between two people.  -- Victor Borge''',
r'''Law is the process by which the unmanifest becomes the manifest.  -- Deepak Chopra''',
r'''Law makers should not be law breakers.''',
r'''Law stands mute in the midst of arms.  -- Cicero''',
r'''Law, without force, is impotent.  -- Pascal''',
r'''Laws are made to protect citizens, not please them.  -- Judge Dredd''',
r'''Laws are spider webs through which big flies pass and little ones get caught.''',
r'''Laws grind the poor, and rich men rule the law.  -- Goldsmith''',
r'''Lazy people should learn a lesson from the way ants live.  -- Solomon''',
r'''Leaders have a bias for action.  -- Jack Canfield''',
r'''Learn from other people's mistakes; you don't have time to make your own.''',
r'''Learn how to say no without feeling the need to explain why.''',
r'''Learn to be flexible; it makes the curves in your life much easier to maneuver.''',
r'''Learn to be intense without being tense.  Pressure is not tension.  -- Joe Torre''',
r'''Learn to disagree without being disagreeable.  -- Peter Chantilis''',
r'''Learn to evaluate how much energy you have invested in your perceptions.  -- Carolyn Myss''',
r'''Learn to forgive by practicing forgiveness.''',
r'''Learn to pause, or nothing worthwhile can catch up to you.''',
r'''Learned men are the cisterns of knowledge, not the fountainheads.''',
r'''Learning is not compulsory...  Neither is survival.  -- W. Edwards Deming''',
r'''Learning is the eye of the mind.  -- Thomas Draxe''',
r'''Learning is the product of self-organization.''',
r'''Learning makes a good man better and an ill man worse.''',
r'''Learning without thought is labor lost; thought without learning is perilous.''',
r'''Leave no stone unturned.  -- Euripides''',
r'''Lend and lose; so play fools.  -- John Ray''',
r'''Lend money to a bad debtor and she will hate you.''',
r'''Less is more.  -- Robert Browning''',
r'''Let a fool be made serviceable according to his folly.  -- Joseph Conrad''',
r'''Let a fool hold his tongue and he will pass for a sage.  -- Publilius Syrus''',
r'''Let all your conclusions be tentative.''',
r'''Let everything you own be either beautiful or useful.''',
r'''Let go of things that don't serve you.  -- Marianne Neifert''',
r'''Let him that would move the world first move himself.  -- Socrates''',
r'''Let life be short; else shame will be too long.''',
r'''Let nature take her own course.  -- Torriano''',
r'''Let not your sun go down on your wrath.  -- St. Paul''',
r'''Let other people praise you, even strangers; never do it yourself.  -- Solomon''',
r'''Let patience grow in your garden always.''',
r'''Let reason rule all your actions.  -- Thomas Draxe''',
r'''Let sleeping dogs lie.  -- Leng-Tzu''',
r'''Let thy speech be better than silence, or be silent.  -- Dionysius the Elder''',
r'''Let us rest our eyes on the fleecy skies and the cool, green hills of Earth.''',
r'''Let us run with patience the race that is set before us.  -- Hebrews 12:1''',
r'''Let what comes, come.  Let what goes, go.  What remains is true.''',
r'''Let your words be the very picture of your heart.  -- John Wesley''',
r'''Let's make the facts louder than the opinion.  -- Kait Parker''',
r'''Leveraging always beats prototyping.''',
r'''Liar:  One who tells an unpleasant truth.''',
r'''Liars begin by imposing upon others, but end by deceiving themselves.''',
r'''Liars have need of good memories.''',
r'''Liberty don't work as good in practice as it does in speeches.  -- Will Rogers''',
r'''Liberty is always dangerous, but it is the safest thing we have.  -- Fosdick''',
r'''Liberty is not for the faint of heart.  -- Mark Laslo''',
r'''Life attracts life.  -- Paulo Coelho''',
r'''Life can hardly survive truly interesting times.  -- Philip Morrison''',
r'''Life can only be understood backward, but it must be lived forward.  -- Soren Kierkegaard''',
r'''Life consists of many little things, but to do them well is a big thing.''',
r'''Life consists of what a man is thinking of all day.  -- Emerson''',
r'''Life creates the conditions that are conducive to life.''',
r'''Life defies one line characterization.  -- Eugene Miya''',
r'''Life imitates art -- but badly.  -- Edward Abbey''',
r'''Life imitates art far more than art imitates life.  -- Oscar Wilde''',
r'''Life is 10% what happens to me and 90% how I react to it.  -- Lou Holz''',
r'''Life is a brief interlude between nothingness and eternity.''',
r'''Life is a business which does not cover its expenses.  -- Schopenhauer''',
r'''Life is a comedy to him who thinks, and a tragedy to him who feels.  -- Walpole''',
r'''Life is a game in which what is not, is more important than what is.  -- Erhard''',
r'''Life is a handicap event, and a winner may finish deep in the pack.  -- Sheehan''',
r'''Life is a meaningless comma in the sentence of time.  -- Garrat & Kidd''',
r'''Life is a series of collisions with the future.  -- Jose Ortega y Gasset''',
r'''Life is a situation comedy that will never be canceled.  -- Steve Bhaerman''',
r'''Life is a whim of several billion cells to be you for a while.''',
r'''Life is a yo-yo, and mankind ties knots in the string.''',
r'''Life is cruel?  Compared to what?  -- Edward Abbey''',
r'''Life is either a daring adventure or it is nothing at all.  -- Helen Keller''',
r'''Life is for the living.''',
r'''Life is half spent before we know what it is.''',
r'''Life is information that replicates.  -- Christoph Adami''',
r'''Life is just an appetizer.''',
r'''Life is just one damned thing after another.  -- Frank O'Malley''',
r'''Life is just too complicated to be smart all the time.  -- Scott Adams''',
r'''Life is like a room full of open doors that close as you get older.''',
r'''Life is like an onion:  You peel off layer after layer, and find nothing in it.''',
r'''Life is like photography, you use the negative to develop.  -- Steve Bhaerman''',
r'''Life is like riding a bicycle.  To keep your balance, you must keep moving.''',
r'''Life is not a dress rehearsal.''',
r'''Life is not a problem to be solved, but a reality to be experienced.''',
r'''Life is not a process of discovery, but a process of creation.  -- God?''',
r'''Life is not a spectator sport.''',
r'''Life is not having been told that the man has just waxed the floor.  -- Nash''',
r'''Life is not so short but that there is always time enough for courtesy.''',
r'''Life is one long process of tiring.  -- Samuel Butler''',
r'''Life is one long struggle in the dark.  -- Titus Carus''',
r'''Life is really generous to those who pursue their destiny.  -- Paulo Coelho''',
r'''Life is short, but it is long enough to ruin any man who wants to be ruined.''',
r'''Life is short; don't waste too much time rearranging the atoms.  -- Alan Silverstein''',
r'''Life is shot at us point-blank.  -- Ortega y Gasset''',
r'''Life is stranger than fiction; love is stronger than friction.''',
r'''Life is sweet.''',
r'''Life is the childhood of our immortality.  -- Johann von Goethe''',
r'''Life is the cumulative effect of a handful of significant shocks.  -- Nassim Taleb''',
r'''Life is the first gift, love is the second, and understanding is the third.''',
r'''Life is the greatest bargain:  We get it for nothing.  -- H. Ayalti''',
r'''Life is the living you do; death is the living you don't do.  -- Joseph Pintauro''',
r'''Life is the only game in which the object of the game is to learn the rules.''',
r'''Life is the process of making and distributing free lunches.  -- Tom von Alten''',
r'''Life is the urge to ecstasy.''',
r'''Life is too important to take seriously.  -- Corky Siegel''',
r'''Life is too short to be little.  -- Disraeli''',
r'''Life is too short to eat boring food.''',
r'''Life is too tragic for sadness:  Let us rejoice.  -- Edward Abbey''',
r'''Life is unfair.  And it's not fair that life is unfair.  -- Edward Abbey''',
r'''Life is what happens to us while we are making other plans.  -- Thomas La Mance''',
r'''Life is what you do while you are waiting to die.  -- Nikos Kazantzakis''',
r'''Life isn't about finding yourself.  Life is about creating yourself.  -- Shaw''',
r'''Life lies not in living, but in liking.''',
r'''Life meets no one halfway.''',
r'''Life need not be a zero-sum game.''',
r'''Life runs on current sunlight; we run on ancient photosynthesis (fossil fuels).  -- Janine Benyus''',
r'''Life script:  Spells cast upon you in childhood.''',
r'''Life shrinks or expands in proportion to one's courage.  -- Anais Nin''',
r'''Life uses local resources.  -- Janine Benyus''',
r'''Life without a friend, is death without a witness.  -- George Herbert''',
r'''Life wouldn't be so hard if we didn't expect it to be so easy.''',
r'''Life your life so that if someone says, "Be yourself," it's good advice.  -- Orben''',
r'''Life's difficulties are intended to make us better, not bitter.''',
r'''Life's key elements:  Carbon, hydrogen, oxygen, nitrogen, sulfur, phosphorus.''',
r'''Lifeless bees do not gather honey.  -- English proverb''',
r'''Light winnings make heavy purses.''',
r'''Lighten up, while you still can, don't even try to understand...''',
r'''Lightly come, lightly go.''',
r'''Like a river, money must keep flowing; otherwise it begins to stagnate.  -- Deepak Chopra''',
r'''Like any kind of gear, backpacking gear suffers from diminishing returns.  -- Mann''',
r'''Like father, like son.''',
r'''Like winter snow on summer lawn, time past is time gone.''',
r'''Listeners never hear good of themselves.''',
r'''Little and often fills the purse.''',
r'''Little fishes slip through nets, but great fishes are taken.  -- Barclay''',
r'''Little things console us because little things afflict us.  -- Blaise Pascal''',
r'''Little things please little minds.''',
r'''Live and let live.''',
r'''Live each day as if it were your last.  -- Leng-Tzu''',
r'''Live now:  There's plenty of time to be dead later.  -- John Taylor''',
r'''Live with grace.''',
r'''Live your life as if it matters to Life, and it will.  -- Kevin Cook''',
r'''Live your live such that you need not hide your diary.''',
r'''Living means dying.  -- Engels''',
r'''Loan someone a sympathetic ear.''',
r'''Logic doesn't apply to the real world.  -- Marvin Minsky''',
r'''Logic is in the eye of the logician.  -- Gloria Steinem''',
r'''Logical systems are at the mercy of their postulates.''',
r'''Loneliness is a terrible price to pay for independence.''',
r'''Loneliness is God's waiting room.  -- Walter Landor''',
r'''Loneliness is the pain of being alone; solitude is the joy of being alone.''',
r'''Lonely is a man without love.''',
r'''Long before you learn about forgiveness, you learn about tribal justice.  -- Carolyn Myss''',
r'''Long life has long misery.''',
r'''Look afar and see the end from the beginning.''',
r'''Look after the molehills and the mountains will take care of themselves.''',
r'''Look at everything through a tribal perspective.  -- Carolyn Myss''',
r'''Look before you leap.  -- Confucius''',
r'''Look for a life partner who is soul food, not eye candy.  -- Karen Salmansohn''',
r'''Look not on pleasures as they come but as they go.  -- George Herbert''',
r'''Looking breeds liking.  -- Ravenscroft''',
r'''Losing makes winning worthwhile.  -- Reyer''',
r'''Lots of folks confuse bad management with destiny.  -- Frank Hubbard''',
r'''Lovability starts with loving yourself.  -- Will Limon''',
r'''Love (the feeling) is the fruit of love (the verb).  -- Stephen Covey''',
r'''Love and gluttony justify everything.  -- Oscar Wilde''',
r'''Love and scandal are the best sweeteners of tea.''',
r'''Love asks faith, and faith asks firmness.  -- George Herbert''',
r'''Love comes by looking.''',
r'''Love comes from trust, trust comes from experience, and it must be earned.''',
r'''Love comes in at the window and goes out at the door.  -- Gruter''',
r'''Love covers a multitude of faults.  -- Torriano''',
r'''Love everyone, serve everyone, and remember God.  -- Ram Dass''',
r'''Love goes toward love.  -- William Shakespeare''',
r'''Love is a fruit in season at all times and within reach of every hand.''',
r'''Love is a hole in the heart.''',
r'''Love is a human religion in which another is believed in.  -- Robert Seidenberg''',
r'''Love is a much stronger drug than LSD.  -- Ram Dass''',
r'''Love is a product of habit.''',
r'''Love is a sweet torment.''',
r'''Love is a verb.  -- Limon''',
r'''Love is an ideal thing, marriage a real thing...  -- Johann von Goethe''',
r'''Love is blind.''',
r'''Love is divine power.  -- Carolyn Myss''',
r'''Love is free.''',
r'''Love is friendship set on fire.''',
r'''Love is full of fear.  -- William Shakespeare''',
r'''Love is giving more and never keeping score.''',
r'''Love is lawless.''',
r'''Love is measured not in moments of time, but in timeless moments.  -- Bartocei''',
r'''Love is not something you have; it is something you do.  -- Will Limon''',
r'''Love is sweet in the beginning but sour in the ending.  -- William Shakespeare''',
r'''Love is the force that makes us fully human.  -- David Suzuki''',
r'''Love is the greatest gift you can receive.  But you must give it to yourself.''',
r'''Love is unconditional caring for an imperfect being.  -- Scott Peck''',
r'''Love lives in cottages as well as in courts.''',
r'''Love makes a wit of the fool.''',
r'''Love makes all hard hearts gentle.''',
r'''Love makes one fit for any work.  -- George Herbert''',
r'''Love makes the world go round.''',
r'''Love means adapting yourself to another person's needs.  -- Rekha''',
r'''Love means never having to say you're sorry.  -- Love Story''',
r'''Love means telling you why you're sorry.''',
r'''Love needs no teaching.  -- Raleigh  (wrong!)''',
r'''Love never dies of starvation, but often of indigestion.  -- Anne de Lenclos''',
r'''Love relationships are the highest risk investments you will ever make.  -- Limon''',
r'''Love should make marriage, and not marriage love.  -- William Shakespeare''',
r'''Love springs from elements we have within our grasp.  -- Limon''',
r'''Love the future, for you are going to spend the rest of your life there.''',
r'''Love truth, pardon error.  -- Voltaire''',
r'''Love will find a way.''',
r'''Love will not overcome a lack of parity.  -- Will Limon''',
r'''Love your friend with his fault.''',
r'''Love your friend, but look to yourself.  -- James Kelly''',
r'''Love your neighbor, yet don't pull down your hedge.  -- Benjamin Franklin''',
r'''Luck is when preparation and opportunity meet.  -- Trudeau''',
r'''Luck:  Careful planning, well executed.''',
r'''Lucky in life, unlucky in love.  -- E. Phillpotts''',
r'''Lying is a way of taking personal responsibility for reality.  -- G. Keillor''',
r'''Machinery... always requires a search for consumable power.  -- James Carse''',
r'''Machines should work; people should think.''',
r'''Madness takes its toll.''',
r'''Magisterial speech is amplified speech; it is speech that silences.  -- Carse''',
r'''Maine is the only state whose name is just one syllable.''',
r'''Majorities, of course, start with minorities.  -- Robert Moses''',
r'''Make a living, but make room for life.''',
r'''Make allowances for your friends' imperfections as readily as for your own.''',
r'''Make choices and decisions, not judgements and demands.  -- Will Limon''',
r'''Make haste slowly.  -- Benjamin Franklin''',
r'''Make hay while the sun shines.''',
r'''Make it tough enough for the enemy to get in and you won't be able to get out.''',
r'''Make much of what you have.  -- Withals''',
r'''Make not the door wider than the house.''',
r'''Make not two sorrows of one.''',
r'''Make the most of the best and the least of the worst.''',
r'''Making rules is easy, but living by them is virtually impossible.''',
r'''Making variations on a theme is really the crux of creativity.  -- Hofstadter''',
r'''Maktub.  (It is written.)''',
r'''Man and wife make one fool.''',
r'''Man belongs wherever he wants to go.  -- Wernher von Braun''',
r'''Man can believe the impossible, but never the improbable.  -- Oscar Wilde''',
r'''Man cannot discover new oceans unless he has courage to lose sight of the shore.''',
r'''Man does not live by words alone, despite that sometimes he must eat them.''',
r'''Man does what he can, and God what he will.  -- Thomas Draxe''',
r'''Man is a dog's idea of what God should be.  -- Holbrook Jackson''',
r'''Man is a military animal; glories in gunpowder, and loves parade.  -- Bailey''',
r'''Man is a sort of tree that we are too apt to judge by the bark.''',
r'''Man is a wolf to man.  -- Plautus''',
r'''Man is an obligate aerobe.''',
r'''Man is born to live, and not to prepare to live.  -- Boris Pasternak''',
r'''Man is by nature a political animal.  -- Aristotle''',
r'''Man is most nearly himself when he achieves the seriousness of a child at play.''',
r'''Man is not a lovable animal.  -- Edward Abbey''',
r'''Man is not disturbed about things, but by his opinion about things.  -- Epictetus''',
r'''Man is the child of customs, not the child of his ancestors.  -- ibn Khaldun''',
r'''Man is the highest animal because man does the classifying.''',
r'''Man is the measure of all things.  -- Protagoras''',
r'''Man must decide...  What will be the monument of his existence.  -- Frankl''',
r'''Man must shape his tools lest they shape him.  -- Arthur Miller''',
r'''Man proposes, God disposes.  -- Thomas a Kempis''',
r'''Man punishes the action, but God the intention.  -- Fuller''',
r'''Man shall not live by bread alone.  -- New Testament''',
r'''Man weeps to think that he will die soon; a woman that she was born so long ago.''',
r'''Man's extremity is God's opportunity.''',
r'''Man's horizons are bounded by his vision.''',
r'''Man's reach must exceed his grasp, for why else the heavens?  -- Robert Browning''',
r'''Man's vehicle is finite and he's trying to know something about the infinite.''',
r'''Managers can either influence or control, but not both.''',
r'''Manners make the man.''',
r'''Many a man would have been worse if his estate had been better.  -- Franklin''',
r'''Many are called; few are chosen.  Fewer still get to do the choosing.''',
r'''Many are called; few volunteer.''',
r'''Many drops make a flood.''',
r'''Many give advice; few give help.  -- Herbert Salzer''',
r'''Many hands make light work.  -- John Heywood''',
r'''Many lords, many laws.  -- Thomas Draxe''',
r'''Many men counsel others better than themselves.  -- J. Hewes''',
r'''Many pages make a thick book.''',
r'''Many receive advice, few profit by it.  -- Publilius Syrus''',
r'''Many small make a great.''',
r'''Many speak much who cannot speak well.''',
r'''Many things can be done in a day if you don't make that day tomorrow.''',
r'''Many things grow in the garden that were never sown there.''',
r'''Many things happen unlooked for.''',
r'''Many would be cowards if they had courage enough.  -- Thomas Fuller''',
r'''Many young scientists work too much and read and think too little.  -- Max Perutz''',
r'''Marriage is a covenant between two people notarized by God.  -- Bill Miles''',
r'''Marry in haste:  Repent in leisure.''',
r'''Mater artium necessitas.  (Necessity is the mother of invention.)''',
r'''Mathematics and death are never in error.  -- Yvgeney Zamyatin''',
r'''Mathematics is the language God used to write the universe.''',
r'''Maturity is knowing when and where to be immature.''',
r'''Maturity is knowing you are right without needing to prove it.''',
r'''Maximize the serendipity around you.  -- Nassim Taleb''',
r'''May the road rise up to greet you, and the wind always be at your back.  -- Irish''',
r'''May you always have the strength to enjoy your weaknesses.  -- Laura Watson''',
r'''May you live all the days of your life.''',
r'''May you live in interesting times.  -- Chinese curse''',
r'''Maybe I was a little bit too optimistic.  Success can't be predicted.  -- Drake''',
r'''Mediocrity requires aloofness to preserve its dignity.  -- Charles Dawes''',
r'''Memory is the medium of the must-have-been.  -- Julian Jaynes''',
r'''Memory is the mother of all wisdom.  -- Aeschylus''',
r'''Memory should be the starting point of the present.''',
r'''Men always learn from their mistakes how to make new ones.  -- A.J.P. Taylor''',
r'''Men and nations act rationally when all other possibilities are exhausted.''',
r'''Men are but children of a larger growth.  -- Dryden''',
r'''Men are more concerned to use ideas than to understand them.  -- J. H. Randall''',
r'''Men are only fellow voyagers with other creatures in the odyssey of evolution.''',
r'''Men are taught to apologize for their weaknesses; women for their strengths.''',
r'''Men behave wisely once they have exhausted all alternatives.  -- Abba Eban''',
r'''Men dream more about coming home than about leaving.  -- Paulo Coelho''',
r'''Men freely believe that what they wish to desire.  -- Julius Caesar''',
r'''Men have become the tools of their tools.  -- Henry Thoreau''',
r'''Men love to hear well of themselves.  -- Clarke''',
r'''Men love to wonder, and that is the seed of science.''',
r'''Men love with their eyes; women love with their ears.  -- Zsa Zsa Gabor''',
r'''Men still remember the first kiss after women have forgotten the last.''',
r'''Men take only their needs into consideration; never their abilities.  -- Napoleon''',
r'''Men will believe more easily that which they do not understand.  -- de Montaigne''',
r'''p Mercy to the criminal might be cruelty to the people.''',
r'''Metaphysics is a cobweb that the mind weaves around things.  -- Edward Abbey''',
r'''Midnight shakes the memory as a madman shakes a dead geranium.  -- T.S. Eliot''',
r'''Might makes right.''',
r'''Mind manifests in matter.  -- Ram Dass''',
r'''Mind other men, but most yourself.  -- Clarke''',
r'''Minds are like parachutes; they only function when fully open.  -- James Dewar''',
r'''Misery loves company, but company does not reciprocate.''',
r'''Misfortunes arrive on wings and leave on foot.''',
r'''Misfortunes never come alone.''',
r'''Misplaced precision stifles initiative.''',
r'''Mistakes are oft the stepping stones to failure.''',
r'''Mistakes are the ornament of freedom.''',
r'''Mistrust is the most necessary characteristic of the chess player.  -- Tarrasch''',
r'''Moderates give a power base to extremists.  -- Richard Dawkins''',
r'''Moderation in all things.  -- Publius Afer''',
r'''Money alone sets the world in motion.  -- Publius''',
r'''Money answers all things.  -- Old Testament''',
r'''Money can buy friendship but money cannot buy love.''',
r'''Money drives politics, often over cliffs.  -- Jack Schmidt''',
r'''Money has no memory.  -- John Taylor''',
r'''Money is a good servant but a bad master.  -- Francis Bacon''',
r'''Money is like a promise, easier made than kept.''',
r'''Money is like an arm or a leg:  Use it or lose it.  -- Henry Ford''',
r'''Money is often lost for want of money.  -- Thomas Draxe''',
r'''Money is tender when you have it, and tough when you haven't.''',
r'''Money isn't everything; sometimes it isn't even enough.''',
r'''Money makes a man free everywhere.''',
r'''Money makes money.  -- Trafford''',
r'''Money makes the man.''',
r'''Money never goes out of season.''',
r'''Money never made a fool of anybody; it only shows them up.  -- Kin Hubbard''',
r'''Money will say more in one moment than the most eloquent lover can in years.''',
r'''Moral principles can never be compromised; they can only be abandoned.''',
r'''Morality is a private and costly luxury.  -- Henry Adams''',
r'''Morality is an illusion; only ethics is real.''',
r'''Morality is simply the attitude we adopt to people whom we personally dislike.''',
r'''Morality is the root, as well as consequence, of survival.  -- Lawrence Hirsch''',
r'''Morals gain greater clarity when the questionable action is done to you.''',
r'''More belongs to marriage than four bare legs in a bed.''',
r'''More happiness, less stuff:  Shouldn't that be our whole society's objective?  -- Ray Anderson''',
r'''More people are flattered into virtue than bullied out of vice.  -- R. S. Surtees''',
r'''More people would learn from their mistakes if not so busy denying them.  -- Harold Smith''',
r'''Most of the desires we have do not need physical bodies to be satisfied.  -- Dass''',
r'''Most people are unenthusiastic about their work.''',
r'''Most people change because they are forced to.  -- Limon''',
r'''Most people deserve each other.  -- Shirley''',
r'''Most people die at 25 but aren't buried until they're 75.  -- Benjamin Franklin''',
r'''Most people prefer certainty to truth.''',
r'''Most people wouldn't know music if it came up and bit them on the ass.  -- Zappa''',
r'''Most powerful is he who has himself in his own power.  -- Seneca''',
r'''Most religious teachers (try) to prove the unproven by the unprovable.  -- Oscar Wilde''',
r'''Most suicides are committed with a knife... fork, and spoon.''',
r'''Motivation is what gets you started.  Habit is what keeps you going.''',
r'''Mountaineers are almost always right when they "go with their gut."  -- Sturgis''',
r'''Mountains are good for us.  They get us to increase our effort.  -- Paul Nesbit''',
r'''Much law, but little justice.  -- Fuller''',
r'''Much learning makes men mad.  -- Ariosto''',
r'''Much of what we call knowledge is merely a temporary frame around chaos.''',
r'''Much tells me little; little tells me much.  -- John Taylor''',
r'''Mud thrown is ground lost.''',
r'''Muddy water let stand becomes clear.  -- Lao Tse''',
r'''Music clouds the intellect but clarifies the heart.  -- Edward Abbey''',
r'''Music endures and ages far better than books.  -- Edward Abbey''',
r'''Music in the soul can be heard by the universe.  -- Lao Tsu''',
r'''Music is the eye of the ear.  -- Thomas Draxe''',
r'''Must I hold a candle to my shames?  -- William Shakespeare''',
r'''Mutual respect is the key to avoiding conflict.  -- Peter Chantilis''',
r'''My body takes commands from my soul.  -- Carolyn Myss''',
r'''My boys, let us be grave:  Here comes a fool.  -- Dr. Clarke, of Beau Nash''',
r'''My cup runneth over with love.''',
r'''My greatest strength as a consultant is to be ignorant and ask a few questions.''',
r'''My job is an interesting hobby.  I take everything else seriously.  -- Steve Hug''',
r'''My job is just to work on myself, and if anything happens, it happens.  -- Dass''',
r'''My old information was held hostage by the tool I used to create it.  -- Goldfarb''',
r'''My only concern is to set man absolutely, unconditionally free.  -- Krishnamurti''',
r'''My purpose for you is that you should know yourself as me.  -- God?''',
r'''Myth is the highest form of our listening to each other.  -- James Carse''',
r'''Myths are not stories that have meanings, but stories that give meanings.''',
r'''Nagging is the repetition of unpalatable truths.  -- Baroness Edith Summerskill''',
r'''Names and natures do often agree.''',
r'''Narrow gathered, widely spent.''',
r'''Nationalism is an infantile disease; it is the measles of mankind.  -- Einstein''',
r'''Nature abhors a vacuum.''',
r'''Nature always has more imagination than we have.  -- Freeman Dyson''',
r'''Nature bats last.  The laws of physics are equal-opportunity.''',
r'''Nature is content with a little.''',
r'''Nature is indifferent to our love, but never unfaithful.  -- Edward Abbey''',
r'''Nature is not benign.  Natural laws have no pity.  -- Robert Heinlein''',
r'''Nature must be interpreted as matter, energy, and information.  -- Shannon''',
r'''Nature tries everything at least once.  -- Arthur Clarke''',
r'''Nature, time, and patience are the three great physicians.  -- Mapletoft''',
r'''Nature, to be commanded, must be obeyed.  -- Francis Bacon''',
r'''Necessity has no holiday.''',
r'''Necessity is the plea for every infringement of human freedom.  -- William Pitt''',
r'''Needs are a function of what other people have.''',
r'''Negative people have a problem for every solution.''',
r'''Neither a borrower nor a lender be; for loan often loses both itself and friend.''',
r'''Neither in hope nor in fear.  -- motto of Isabella d'Este''',
r'''Neither spread the germs of gossip nor encourage others to do so.''',
r'''Neutrality is at times a greater sin than belligerence.  -- Justice Brandeis''',
r'''Never answer a question until it is asked.''',
r'''Never appeal to a man's "better nature".  He may not have one.  -- Robert Heinlein''',
r'''Never argue with a fool.  People might not know the difference.''',
r'''Never argue with a man who buys ink by the barrel.  -- Greener''',
r'''Never assume villany when mere incompetence suffices.''',
r'''Never attribute to malice that which is adequately explained by stupidity.''',
r'''Never be foolish enough to consider yourself infallible.''',
r'''Never before have so many people known so little about so much.  -- James Burke''',
r'''Never buy a thing you don't want merely because it is dear.  -- Oscar Wilde''',
r'''Never call a man a fool.  Borrow from him.''',
r'''Never change a winning theme.  -- Gerhard Uhlenbruck''',
r'''Never confuse "I love you" with "I want to marry you."  -- Leroy King''',
r'''Never debate; escalate.  -- Carl Trautman''',
r'''Never delegate making yourself happy.''',
r'''Never give up, for that is just the time that the tide will turn.  -- Stowe''',
r'''Never go to sea with two chronometers; take one or three.''',
r'''Never ignore friction.''',
r'''Never insult an alligator until you have crossed the river.''',
r'''Never interrupt when you are being flattered.  -- H. Jackson Brown''',
r'''Never laugh at your own jokes.''',
r'''Never let a major crisis go to waste.  -- Rahm Emanuel''',
r'''Never let them take a picture of you holding a martini.''',
r'''Never let your sense of morals prevent you from doing what is right.  -- Asimov''',
r'''Never let yourself think that you are wiser than you are.  -- Solomon''',
r'''Never lose a holy curiosity.  -- Albert Einstein''',
r'''Never lose your ignorance; you cannot replace it.  -- Erich Remarque''',
r'''Never miss a check, it might be mate.''',
r'''Never move a pawn and you will never lose a game.  -- Siegbert Tarrasch''',
r'''Never outrun that which you can outsmart.''',
r'''Never pay a compliment as though you expected a receipt.''',
r'''Never promise more than you can perform.  -- Publilius Syrus''',
r'''Never put off till tomorrow what can be done today.''',
r'''Never rely on what you think you know.  -- Solomon''',
r'''Never risk what you can't afford to lose.  -- H. Jackson Brown''',
r'''Never say never.''',
r'''Never speak more clearly than you think.  -- Neils Bohr''',
r'''Never swap your integrity for money, power, or fame.  -- H. Jackson Brown''',
r'''Never take a drink when you are feeling sorry for yourself.''',
r'''Never take what you cannot use.  -- H. Jackson Brown''',
r'''Never trust a friend who deserts you at a pinch.  -- Aesop''',
r'''Never trust anyone who can't say:  "I don't know."  -- Greg Goebel''',
r'''Never trust anyone who says money is no object.''',
r'''Never trust the advice of a man in difficulties.  -- Aesop''',
r'''Never try to teach a pig to sing.  It wastes your time and annoys the pig.''',
r'''Never underestimate the power of human stupidity.''',
r'''Never underestimate the stimulation of eccentricity.  -- Neil Simon''',
r'''Never volunteer for anything.  -- Lackland''',
r'''Never wrestle a pig.  You both get dirty and the pig likes it.''',
r'''New systems generate new problems.''',
r'''Newspapers often print the first draft of history.''',
r'''Night is the mother of counsel.''',
r'''Nihilism is the only philosophy that denies its own existence.''',
r'''Nine men in ten are suicides.  -- Benjamin Franklin''',
r'''Nine tenths of wisdom consists in being wise in time.''',
r'''No act of kindness, no matter how small, is ever wasted.  -- Aesop''',
r'''No amount of genius can overcome a preoccupation with detail.''',
r'''No battle plan ever survives contact with the enemy.''',
r'''No bird soars too high if he soars with his own wings.  -- William Blake''',
r'''No bucks, no Buck Rogers.  -- Tom Wolfe''',
r'''No evil proceeds on any grounds of reason.  -- Titus Livius''',
r'''No excellent soul is exempt from a mixture of madness.  -- Aristotle''',
r'''No good building without a good foundation.''',
r'''No light, but rather darkness visible.  -- Milton''',
r'''No lock will hold against the power of gold.''',
r'''No man better knows what good is than he who has endured evil.''',
r'''No man can bargain with a clock.  -- Michael Uhrin''',
r'''No man can be a good ruler unless he has first been ruled.''',
r'''No man can be a patriot on an empty stomach.  -- W. C. Brann''',
r'''No man can play the fool as well as the wise man.''',
r'''No man has a lease of his life.''',
r'''No man is a hero to his valet.  -- Madame Anne Cornuel''',
r'''No man is an island.  -- John Donne''',
r'''No man is good enough to govern another without that other's consent.  -- Lincoln''',
r'''No man is rich enough to buy back his past.  -- Oscar Wilde''',
r'''No man is wise at all times.''',
r'''No man is wise enough to be another man's master.  -- Edward Abbey''',
r'''No man lives so poor as he was born.  -- Fuller''',
r'''No man who needs a monument ever ought to have one.  -- Nathaniel Hawthorne''',
r'''No man's credit is as good as his money.  -- E. W. Howe''',
r'''No man's life, liberty or property are safe while the Legislature is in session.  -- Gideon Tucker''',
r'''No matter how certain you are, always consider that you might be wrong.''',
r'''No matter how much cynicism you have, it is never enough to keep up.  -- Tomlin''',
r'''No matter how smart you are, you spend much of your day being an idiot.  -- Adams''',
r'''No matter what we are talking about, we are talking about ourselves.  -- Prather''',
r'''No matter what you do, you are intuitive.  -- Carolyn Myss''',
r'''No matter who's in my life, they're there by divine design.  -- Carolyn Myss''',
r'''No news is good news.  -- J. Payn''',
r'''No one becomes depraved in a moment.''',
r'''No one can get ahead of you when they are kicking you in the rear.''',
r'''No one can make you feel inferior without your consent.  -- Eleanor Roosevelt''',
r'''No one can out-perform their own self-image.''',
r'''No one ever listened himself out of a job.  -- Calvin Coolidge''',
r'''No one gets off this planet unenlightened.  -- Carolyn Myss''',
r'''No one has yet invented a successful substitute for work.''',
r'''No one is rich enough to do without a neighbor.  -- Danish proverb''',
r'''No one is satisfied with his fortune or dissatisfied with his intellect.''',
r'''No one knows what he can do till he tries.  -- Publilius Syrus''',
r'''No one regards what is before his feet; we all gaze at the stars.''',
r'''No one understands anything that isn't funny.''',
r'''No one understands everything, and no one needs to.  -- J. Redford''',
r'''No opinion has ever been too errant to become creed.  -- Bertrand Russell''',
r'''No pain, no gain.''',
r'''No people do so much harm as those who go about doing good.  -- Mandell Creighton''',
r'''No problem is insoluble in all conceivable circumstances.''',
r'''No problem is so formidable that you can't walk away from it.  -- Schulz''',
r'''No question is so difficult as one to which the answer is obvious.  -- George Shaw''',
r'''No region can include itself as well.  -- Whitehead''',
r'''No rose without a thorn.''',
r'''No snowflake in an avalanche ever feels responsible.  -- Stanislaw Lee''',
r'''No sooner said than done -- so acts your man of worth.  -- Quintus Ennius''',
r'''No tyranny is more fierce than the tyranny of morality.  -- P. D. Ouspensky''',
r'''No value can be put upon good counsel.  -- Howell''',
r'''No word in the English language rhymes with month, orange, silver, or purple.''',
r'''Nobility is expensive, non-productive, and parasitic.  -- Alan Weisman''',
r'''Nobody ever got a rainbow unless they got some rain.  -- Jim Croce''',
r'''Nobody ever got to the top without slipping up.  -- Colin Powell''',
r'''Nobody has so many friends that he can afford to lose one.  -- Edward Abbey''',
r'''Nobody roots for Goliath.  -- Wilt Chamberlain''',
r'''Non Illegitemus Carborundum.  (Don't let the bastards wear you down.)''',
r'''Noncooperation with evil is as much a duty as is cooperation with good.  -- Mohandas Gandhi''',
r'''None knows the weight of another's burden.  -- George Herbert''',
r'''None love the bearer of bad news.  -- Sophocles''',
r'''Nonsense and beauty have close connections.  -- E. M. Forster''',
r'''Nonsense needs complex misdirection to make it sound plausible.  -- Conquest''',
r'''Nostalgia is what turns the past tense into past perfect.''',
r'''Not all who own a harp are harpers.  -- Marcus Terentius Varro''',
r'''Not doing more than average is what keeps the average down.  -- Harvey Mackay''',
r'''Not everyone whose eyes are closed is asleep.  -- Hebrew proverb''',
r'''Not failure, but low aim is sin.  -- Benjamin Mays''',
r'''Not getting what you want is sometimes a stroke of good luck.  -- Brown''',
r'''Not knowing is the hardest thing to know.''',
r'''Not one shred of evidence supports the notion that life is serious.''',
r'''Not only do organisms evolve; the mechanisms by which they evolve, evolve too.''',
r'''Nothing astonishes men so much as common sense and plain dealing.  -- Emerson''',
r'''Nothing beats love at first sight except love with insight.''',
r'''Nothing dries sooner than tears.  -- Cicero''',
r'''Nothing endures but change.  -- Heraclitus''',
r'''Nothing ever fatigues me, except that which I dislike.  -- Jane Austen''',
r'''Nothing focuses the mind like a hanging.  -- Samuel Johnson''',
r'''Nothing goes out of date as fast as our predictions for the future.''',
r'''Nothing great is ever achieved without enthusiasm.  -- Ralph Emerson''',
r'''Nothing in life is to be feared.  It is only to be understood.''',
r'''Nothing in the physical world is stronger than you unless you give it strength.''',
r'''Nothing is as easy as it looks.  -- Murphy''',
r'''Nothing is as simple as we hope it will be.  -- Jim Horning''',
r'''Nothing is but what is not.''',
r'''Nothing is enough for the man to whom enough is too little.  -- Epicurus''',
r'''Nothing is ever accomplished by a reasonable man.  -- Bucy''',
r'''Nothing is ever all said and done.''',
r'''Nothing is impossible for the man who doesn't have to do it himself.  -- Weller''',
r'''Nothing is impossible for the man who will not listen to reason.  -- Blutarsky''',
r'''Nothing is impossible to a willing heart.''',
r'''Nothing is impossible to God.''',
r'''Nothing is more annoying than a low man raised to a high position.  -- Claudian''',
r'''Nothing is more dangerous than an idea when it is the only one you have.''',
r'''Nothing is often a clever thing to do, and always a clever thing to say.''',
r'''Nothing is so fatiguing as the eternal hanging on of an uncompleted task.''',
r'''Nothing is so firmly believed as which is least known.  -- de Montaigne''',
r'''Nothing is so frustrating as a bad situation beginning to improve.  -- Shannon''',
r'''Nothing is so good that somebody, somewhere, will not hate it.  -- Pohl''',
r'''Nothing is sometimes the best thing to say.''',
r'''Nothing makes a vacation seem better than hindsight.''',
r'''Nothing makes for more good old days than a bad memory.''',
r'''Nothing succeeds without a champion.''',
r'''Nothing that is violent is permanent.''',
r'''Nothing that is worth knowing can be taught.  -- Oscar Wilde''',
r'''Nothing ventured, nothing gained.  -- Leng-Tzu''',
r'''Nothing's beautiful from every point of view.  -- Horace''',
r'''Notice how your desires keep manifesting in thoughts.  -- Ram Dass''',
r'''Nowadays, the illiterates can read and write.  -- Alberto Moravia''',
r'''O Lord -- if there is a Lord; save my soul -- if I have a soul.  -- Ernest Renan''',
r'''Obedience is much more seen in little things than in great.  -- Fuller''',
r'''Obedience is the first duty of a soldier.''',
r'''Observation is a passive science, experimentation an active science.  -- Bernard''',
r'''Obstacles are what you see when you take your eyes off your goal.''',
r'''Obstinancy is the strength of the weak.  -- Lavater''',
r'''Occasionally lose sight, never lose vision; nothing is gained through division.''',
r'''Of all forms of caution, caution in love is the most fatal.''',
r'''Of all forms of currency, guilt is the most inconvertible.  -- John Taylor''',
r'''Of course life is finite, but the only sane way to live is to pretend otherwise.  -- Alan Silverstein''',
r'''Of making many books there is no end.  -- Old Testament''',
r'''Of money, wisdom, and good faith there is commonly less than men count upon.''',
r'''Of money, wit, and virtue believe one-fourth of what you hear.  -- Mapletoft''',
r'''Often it's not the water but the cup.  -- John Taylor''',
r'''Oh what a tangled web we weave, when first we practice to deceive.  -- William Shakespeare''',
r'''Old age comes stealing on.''',
r'''Old age is the harbor of all ills.  -- Bion''',
r'''Old age is the most unexpected of things that can happen to a man.  -- Trotsky''',
r'''Old age needs so little, but it needs that little so much.''',
r'''Old friends and old wine and old gold are best.''',
r'''Old friendships bear witness to your life in its entirety.  -- Carol Moss''',
r'''Old love will not be forgotten.  -- T. Heywood''',
r'''Old men go to death; death comes to young men.''',
r'''Old sin makes new shame.''',
r'''Old soldiers never die.  Young ones do.''',
r'''Old thanks pay not for a new debt.  -- Torriano''',
r'''On your journey to consciousness you must go through the dark night of the soul.''',
r'''Once a thief, always a thief.  -- Stevens''',
r'''Once a use and ever a custom.''',
r'''Once a word has been allowed to escape, it cannot be recalled.  -- Horace''',
r'''Once harm has been done, even a fool understands it.  -- Homer''',
r'''Once one has tasted life, death doesn't even seem natural.  -- Philip Roth''',
r'''Once you accept his assumptions even a madman seems reasonable.''',
r'''Once you become a walker, you become a conservationist.  -- Colin Fletcher''',
r'''Once you realize God knows everything, you're free.  -- Ram Dass''',
r'''One 'tis not significant till it be the last one.''',
r'''One bad general is better than two good ones.  -- Lincoln''',
r'''One big pile is better than two little piles.  -- Arlo Guthrie''',
r'''One by one, like leaves from a tree, all my faiths have forsaken me.  -- Teasdale''',
r'''One can acquire everything in solitude except character.  -- Stendahl''',
r'''One can always be kind to people about whom one cares nothing.  -- Oscar Wilde''',
r'''One can hardly please all men.  -- Thomas Draxe''',
r'''One can never consent to creep when one feels the impulse to soar.  -- Keller''',
r'''One can only accept in others what one can accept in oneself.  -- James Baldwin''',
r'''One can't proceed from the informal to the formal by formal means.''',
r'''One cannot prevent a problem by pretending that it doesn't exist.  -- Schumacher''',
r'''One cause is good until the other is understood.''',
r'''One enemy can do more harm than ten friends can do good.''',
r'''One family builds a wall, two families enjoy it.''',
r'''One good turn deserves another.  -- Gaius Petronius''',
r'''One grain fills not a sack, but helps his fellow.''',
r'''One hand cannot applaud.  -- Arabian proverb''',
r'''One has a right to judge a man by the effect he has over his friends.  -- Oscar Wilde''',
r'''One is not superior merely because one sees the world as odious.  -- Chateaubriand''',
r'''One learns to itch where one can scratch.  -- Ernest Bramah''',
r'''One lie or one peanut...  One leads to another.''',
r'''One lives in the hope of becoming a memory.  -- A. Porchia''',
r'''One mad action is not enough to prove a man mad.  -- Fuller''',
r'''One man's ceiling is another man's floor.  -- Paul Simon''',
r'''One man's gain is another man's loss.  -- D. H. Lawrence''',
r'''One man's magic is another man's engineering.''',
r'''One man's theology is another man's belly laugh.  -- Robert Heinlein''',
r'''One master in any house is enough.  -- Erasmus''',
r'''One may sooner fall than rise.  -- Thomas Draxe''',
r'''One meets his destiny often on the road he takes to avoid it.''',
r'''One must be frank to be relevant.  -- Corazon Aquino''',
r'''One must imagine Sisyphus happy.  -- Albert Camus''',
r'''One never goes so far as when one doesn't know where one is going.  -- Johann von Goethe''',
r'''One never loses anything by politeness.''',
r'''One nuclear bomb can ruin your whole day.''',
r'''One of the fundamental laws of creation is that energy comes before matter.''',
r'''One of the greatest pains to human nature is the pain of a new idea.  -- Bagehot''',
r'''One of these days is none of these days.''',
r'''One pair of ears dry a hundred tongues.  -- George Herbert''',
r'''One pardons in the degree that one loves.  -- Le Rochefoucauld''',
r'''One person tells a falsehood, a hundred repeat it as true.''',
r'''One person with courage makes a majority.''',
r'''One picture is worth more than ten thousand words.  -- Chinese proverb''',
r'''One poison drives out another.''',
r'''One positive weighs more than twenty negatives.''',
r'''One seldom sees a monument to a committee.''',
r'''One should have faith in rain but never trust it.''',
r'''One should never do anything one cannot talk about after dinner.  -- Oscar Wilde''',
r'''One sows and another reaps.''',
r'''One success is worth more than a thousand failures.''',
r'''One tale is good till another is told.''',
r'''One way to get into trouble is to be right at the wrong time.''',
r'''One without education is compelled to use his brains.''',
r'''One word is worth a thousand pictures.  If it's the right word.  -- Edward Abbey''',
r'''One's real life is often the life that one does not lead.''',
r'''Only 10% of anything can be in the top 10%.''',
r'''Only a ballplayer's errors are published every day.''',
r'''Only a fool has no doubts.''',
r'''Only a fool is astonished by the foolishness of mankind.  -- Edward Abbey''',
r'''Only a mediocre person is always at his best.  -- Somerset Maugham''',
r'''Only a moralist advocates a virtue even to those incapable of it.  -- Wall''',
r'''Only a strong player knows how weakly he plays.  -- Saviely Tartakower''',
r'''Only at the planes below the fourth chakra do you need to maintain a body.''',
r'''Only cowards insult dying majesty.  -- Aesop''',
r'''Only fools are positive.  -- Moe Howard''',
r'''Only fools say it can't be done.''',
r'''Only God can make random selections.''',
r'''Only ideas that we actually live by are of any value.  -- Hermann Hesse''',
r'''Only invest in products and companies you can explain to a six year old.  -- Morgan Housel''',
r'''Only military people deal with randomness with genuine... intellectual honesty.  -- Nassim Taleb''',
r'''Only one person in a thousand knows the trick of really living in the present.''',
r'''Only that in you which is me can hear what I'm saying.  -- Ram Dass''',
r'''Only the educated are free.  -- Epictetus''',
r'''Only the ephemeral is of lasting value.  -- Ionesco''',
r'''Only the rich preach contentment to the poor.''',
r'''Only those who attempt the absurd can achieve the impossible.''',
r'''Only what we partly know inspires us with the desire to know more.  -- Emerson''',
r'''Only when you journey fully conscious to the pain do you gain the wisdom.''',
r'''Ontogeny recapitulates phylogeny.''',
r'''Onward through the fog.''',
r'''Opinions cannot survive if one has no chance to fight for them.  -- Thomas Mann''',
r'''Opportunities are often things you haven't noticed the first time around.''',
r'''Opportunity makes the thief.''',
r'''Opposites attract.  -- Leng-Tzu''',
r'''Oppression makes a wise man mad.''',
r'''Optimization hinders evolution.''',
r'''Orthodoxy is a relaxation of the mind accompanied by a stiffening of the heart.''',
r'''Other people's tools work only in other people's gardens.''',
r'''Other times, other manners.''',
r'''Our bodies were designed to have integrity.  -- Carolyn Myss''',
r'''Our business in life is not to succeed but to continue to fail in high spirits.''',
r'''Our fantasies are stepping stones to our realities.  -- Mae Jameson, astronaut''',
r'''Our greatest weariness comes from work not done.  -- Eric Hoffer''',
r'''Our idea was if you couldn't find a job, you'd make one for yourself.  -- Packard''',
r'''Our investment in another creates the level of involvement we have with them.''',
r'''Our life stories and the history of the world were written by the same hand.''',
r'''Our money can never be as valuable as our memories or our friendships.  -- Ogburn''',
r'''Our nature demands love, and our happiness depends on it.''',
r'''Our property must intrude on another, stand in another's way.  -- James Carse''',
r'''Our self image is our window to our world.  -- Limon''',
r'''Our sins and our debts are often more than we think.  -- Howell''',
r'''Our spirit is fuel; it is energy.  -- Carolyn Myss''',
r'''Our stuff has become a "footprint" that is trampling on our Garden of Eden.  -- Norris Burkes''',
r'''Our sun rises precisely where we choose to see it rise.  -- John Taylor''',
r'''Our whole society is addicted to debt.  -- Peter Nelson''',
r'''Our wires are attached to the fact that financial energy equals sexual energy.''',
r'''Ours is a world of nuclear giants and ethical infants.  -- Omar Bradley''',
r'''Out of sight, out of mind.  -- Leng-Tzu''',
r'''Out there, we are all part of the food chain.''',
r'''Over my mask / is your mask of me.  -- Mitsuye Yamada''',
r'''Own the market rather than try to outsmart it.  -- Allan Roth''',
r'''Pack it in, pack it out.''',
r'''Pain is inevitable, but suffering is our choice.''',
r'''Pain makes cowards of us all.  -- Vince Lombardi''',
r'''Painted pictures are dead speakers.  -- Breton''',
r'''Paradise for a happy man lies in his own good nature.  -- Edward Abbey''',
r'''Passion is as crucial as rocket fuel when you're trying to leave Earth.  -- Andrew Chaiken''',
r'''Past cure, past care.''',
r'''Patch griefs with proverbs.''',
r'''Patience is a flower that grows not in every one's garden.  -- Thomas Draxe''',
r'''Patience is a minor form of despair, disguised as virtue.  -- Bierce''',
r'''Patience is the best remedy for every trouble.  -- Titus Maccius Plautus''',
r'''Patience is the companion of wisdom.  -- St. Augustine''',
r'''Patience under old injuries invites new ones.''',
r'''Patience, time, and money accommodate all things.  -- George Herbert''',
r'''Patriotism is inherently belligerent.  -- James Carse''',
r'''Pauca sed matura.  (Few but excellent.)  -- Gauss''',
r'''Paul's Law of Reorganizations:  Tornados don't bother earthworms.''',
r'''Pawn endings are to chess what putting is to golf.  -- Cecil Purdy''',
r'''Pay attention to what you want to control.  -- Carolyn Myss''',
r'''Pay attention to your body.  It doesn't lie.''',
r'''Pay attention, and you will have understanding.  -- Solomon''',
r'''Peace is the work of strong men; war, the courage of the cowardly.''',
r'''Peace of mind makes the body healthy, but jealousy is like cancer.  -- Solomon''',
r'''Peanuts are one of the ingredients of dynamite.''',
r'''Penny wise, pound foolish.''',
r'''People are better than their theology.  -- Emerson''',
r'''People are lonely because they build walls instead of bridges.  -- Joseph Newton''',
r'''People become how they're treated.  -- Doug McKenzie''',
r'''People don't care how much you know until they know how much you care.''',
r'''People don't govern better than they campaign.  -- Tom von Alten''',
r'''People don't want to write.  They want to have written.  -- Graham Greene''',
r'''People get better if you pay attention to them.  -- Steven Bratman''',
r'''People like to talk more than they like to listen.  -- Scott Adams''',
r'''People live as if they'll never die, then die as if they had never lived.''',
r'''People lose their health to make money, then lose their money to regain health.''',
r'''People love high ideals, but they got to be about 33-percent plausible.  -- Rogers''',
r'''People mistake obscurity for profundity.''',
r'''People often don't value what they don't pay for.  -- H. Jackson Brown''',
r'''People only accept change in necessity, and see necessity only in crisis.  -- Jean Monnet''',
r'''People only notice squeaky wheels.''',
r'''People only pay attention to what they discover for themselves.  -- Semple''',
r'''People optimize that which is measured.  -- Tom DeMarco''',
r'''People say they don't have enough time, but they have all the time there is.''',
r'''People should be measured in feats, not feet.''',
r'''People sucking on the public teat have an obligation not to bite it.''',
r'''People support that which they help to create.''',
r'''People tend to make rules for others and exceptions for themselves.''',
r'''People think love is an emotion.  Love is good sense.  -- Ken Kesey''',
r'''People think they're thinking when they're merely rearranging their prejudices.''',
r'''People who can least afford to pay rent pay rent.''',
r'''People who can most afford to pay rent build equity.''',
r'''People who censor books are usually illiterate.  -- John MacDonald''',
r'''People who cry frequently enjoy better health overall.  -- Victor Parachin''',
r'''People who do know history repeat it as long as it is profitable.  -- Les Earnest''',
r'''People who don't have goals work for those who do.  -- Jack Canfield''',
r'''People who have nothing to say are never at loss in talking.  -- Josh Billings''',
r'''People who live in glass houses shouldn't throw stones.''',
r'''People who prefer the finer things in life prefer people.''',
r'''People who set traps for others get caught themselves.  -- Solomon''',
r'''People who value security more than liberty will have neither.  -- Ben Franklin''',
r'''People who work sitting down get paid more than people who work standing up.''',
r'''People with a hot temper do foolish things; wiser people remain calm.  -- Solomon''',
r'''People with narrow minds usually have broad tongues.''',
r'''People would never do anything if they knew what they were getting into.''',
r'''Peoples' opinions change, but the conviction of their correctness never does.''',
r'''Perceived necessity makes prostitutes of us all.''',
r'''Perception is reality, but perception is not necessarily truth.''',
r'''Perfection is a minor virtue.  -- Edward Abbey''',
r'''Perhaps it was because Nero played the fiddle that they burned Rome.''',
r'''Perhaps we invented God to take the burden of self-judgement from us.''',
r'''Perserverance is not a long race; it is many short races one after another.''',
r'''Personal attacks demean those who make them.''',
r'''Personal finance is 80% behavior and 20% head knowledge.  -- Dave Ramsey''',
r'''Personal integrity is cleaning up your mess in a public restroom.''',
r'''Personality is the psychological equivalent of scar tissue.''',
r'''Personality is to man what perfume is to a flower.  -- Charles Schwab''',
r'''Persons who disagree with you are always emotional and employ faulty reasoning.''',
r'''Pessimist:  Man who looks for a pink slip before the money in his pay envelope.''',
r'''Philosophers only interpret the world differently; the point is, to change it.''',
r'''Philosophy is to the real world as masturbation is to sex.  -- Karl Marx''',
r'''Philosophy just fools you into thinking what you do is right.  -- O'Connor''',
r'''Philosophy will clip an angel's wings.  -- John Keats''',
r'''Physical strength can never permanently withstand the impact of spiritual force.''',
r'''Physicians kill more than they cure.  -- Burton''',
r'''Pictures are the books of the unlearned.  -- Fuller''',
r'''Pictures worth a thousand words take ten thousand times as long to draw.''',
r'''Pigs treat us as equals.  -- Winston Churchill''',
r'''Place your clothes and weapons where you can find them in the dark.''',
r'''Plain dealing is praised more than practiced.  -- Clarke''',
r'''Plan carefully what you do, and whatever you do will turn out right.  -- Solomon''',
r'''Plan for success, and deal with failure.  -- Paul Rygaard''',
r'''Plan to throw one away; you will, anyhow.  -- Frederick Brooks''',
r'''Plans are nothing; planning is everything.''',
r'''Plants are at the bottom of the food chain and do their own mining.''',
r'''Plants stand still and wait to be counted.  -- John Harper''',
r'''Play is not the absence of work.''',
r'''Playing a game shows some of one's character.  How one loses shows all of it.''',
r'''Pleasure in the job puts perfection in the work.  -- Aristotle''',
r'''Plenty breeds pride.  -- Gascoigne''',
r'''Plug yourself into the attitude of gratitude.  -- Carolyn Myss''',
r'''Poison is poison though it comes in a golden cup.''',
r'''Political power grows out of the barrel of a gun.  -- Mao Zedong''',
r'''Politicians are the only people who create problems, then campaign against them.  -- Charlie Reese''',
r'''Politics has slain its thousands, but religion has slain its tens of thousands.  -- Sean O'Casey''',
r'''Pollution is merely a misplaced resource.''',
r'''Poor is a man whose words die with him.  -- John Taylor''',
r'''Popular consensus says that reality is based on popular consensus.''',
r'''Possessions create pain.''',
r'''Post hoc, ergo propter hoc.  (After this, therefore caused by this.)''',
r'''Post proelium, praemium.  (After the battle, the reward.)''',
r'''Poverty is being invisible... excluded from community.  It is internal exile.''',
r'''Poverty is the mother of all arts.''',
r'''Poverty is the parent of revolution and crime.  -- Aristotle''',
r'''Power attracts the corruptible.  -- David Brin''',
r'''Power corrupts, and absolute power corrupts absolutely.''',
r'''Power does not corrupt man; fools in a position of power corrupt power.  -- Shaw''',
r'''Power grows out of someone else's dependency.''',
r'''Power is poison.''',
r'''Power rules, but love wins.''',
r'''Power to the peaceful.''',
r'''Practice is the best of all instructors.  -- Publilius''',
r'''Practice makes permanent.''',
r'''Practice may not make perfect, but it makes permanent.  -- John Milton''',
r'''Practice random acts of intelligence and senseless acts of self-control.''',
r'''Practice random acts of kindness and senseless acts of beauty.''',
r'''Practice yourself what you preach.  -- Titus Plautus''',
r'''Praise in public, scold in private.''',
r'''Praise makes good men better, and bad men worse.''',
r'''Praise the child, and you make love to the mother.''',
r'''Praise the sea, but keep on land.  -- Florio''',
r'''Pray for what you want, but work for what you need.''',
r'''Pray to God, but keep rowing to shore.  -- Russian proverb''',
r'''Prayer should be the key of the day and the lock of the night.''',
r'''Prayer should never be answered; if it is... it becomes correspondence.  -- Oscar Wilde''',
r'''Prejudice is being down on something you are not up on.''',
r'''Preserve the old, but know the new.''',
r'''Pretense is always a prologue.  -- Michael Uhrin''',
r'''Prevention is better than cure.''',
r'''Pride feels no pain.''',
r'''Principles have no real force except when one is well fed.  -- Mark Twain''',
r'''Prior Planning Prevents Piss Poor Performance.''',
r'''Problems that go away by themselves come back by themselves.  -- Davis''',
r'''Procrastination is the fertilizer that makes difficulties grow.''',
r'''Productivity is often not worth the personal price.''',
r'''Professional sales people do not compromise their integrity for a sale.''',
r'''Professionals are predictable, it is the amateurs that are dangerous.''',
r'''Program yourself to become intuitively aware.  -- Carolyn Myss''',
r'''Progress is made by lazy men looking for an easier way to do things.  -- Robert Heinlein''',
r'''Progress stops on satisfaction.  -- Mika Salkola''',
r'''Promise is debt.''',
r'''Promises are like pie-crust, made to be broken.  -- Ward''',
r'''Promising costs nothing; it's the delivering that kills you.''',
r'''Promising is the eve of giving.''',
r'''Promptness is its own reward, if one lives by the clock instead of the sword.''',
r'''Proof by repeated assertion is no proof at all.''',
r'''Prophecy is many times the principal cause of the events foretold.  -- Hobbes''',
r'''Proposals, as understood by the proposer, will be judged otherwise by others.''',
r'''Prosperity is only an instrument to be used, not a deity to be worshipped.''',
r'''Prosperity makes friends; adversity tries them.  -- Publilius Syrus''',
r'''Prototype designs always work.  -- Don Vonada''',
r'''Prototyping is always unexpectedly expensive.  -- Alan Silverstein''',
r'''Providing too much information defeats the purpose of providing any.  -- John Roberts''',
r'''Psychoanalysis is the mental disease whose therapy it claims to be.  -- Kraus''',
r'''Psychotherapy is just as high as the psychotherapist.  -- Ram Dass''',
r'''Public goods, privately provided, tend to be under-provided.''',
r'''Public property is never so well taken care of as private property.  -- Cobbett''',
r'''Punctuality is the virtue of the bored.  -- Evelyn Waugh''',
r'''Puritan:  A person who pours righteous indignation into the wrong things.''',
r'''Put all your eggs in one basket and -- WATCH THAT BASKET.  -- Mark Twain''',
r'''Put not your trust in money, but put your money in trust.  -- Oliver Holmes''',
r'''Put your brain in gear before starting your mouth in motion.''',
r'''Put your genius into your life.  Put only your talent into your work.''',
r'''Put your trust in those who are worthy.''',
r'''Quality is not a stage in the process.  It is the way of the process.''',
r'''Quality, without quantity, is little thought of.''',
r'''Quantum mechanics are the dreams stuff is made of.''',
r'''Question authority.''',
r'''Questions are never indiscreet; answers sometimes are.  -- Oscar Wilde''',
r'''Quick believers need broad shoulders.  -- George Herbert''',
r'''Quickly come, quickly go.''',
r'''Quiet the outer world, so that the inner world might bring you sight.  -- God?''',
r'''Quietness is a great treasure.  -- Henderson''',
r'''Quit while you're ahead.  -- Leng-Tzu''',
r'''Rainbows are just to look at, not to really understand.''',
r'''Rank has its privileges.''',
r'''Rather a man without money than money without a man.''',
r'''Rather sell than be poor.  -- John Ray''',
r'''Readers are not interested in the mechanics of authorship.  -- A. A. Milne''',
r'''Reading is thinking with someone else's head instead of one's own.''',
r'''Reading is to the mind what exercise is to the body.  -- Sir Richard Steele''',
r'''Reading makes a full man; conference a ready man; and writing an exact man.''',
r'''Real joy comes from doing something worthwhile.''',
r'''Real love stories never have endings.''',
r'''Real men don't feel the need to prove it.''',
r'''Real politics are the possession and distribution of power.  -- Benjamin Disraeli''',
r'''Real poverty is lack of books.  -- Colette''',
r'''Real wealth can only increase.  -- R. Buckminster Fuller''',
r'''Reality is the flaw in the perfection of nothingness.''',
r'''Reality is when it happens to you.''',
r'''Reality often astonishes theory.  -- Tom Magliozzi''',
r'''Reason and love keep little company nowadays.  -- William Shakespeare''',
r'''Reason has always existed, but not always in a reasonable form.  -- Karl Marx''',
r'''Reason has seldom failed us because it has seldom been tried.  -- Edward Abbey''',
r'''Reason rules all things.''',
r'''Reasonable people find it difficult to... understand unreasonable behaviour.  -- Carlo Cipolla''',
r'''Rebellion lay in his way, and he found it.''',
r'''Records were made to be broken.''',
r'''Red clouds in the east, rain the next day.''',
r'''Red sky at night, sailors delight; red sky at morning, sailors take warning.''',
r'''Reformers should be conscious of the law of unintended consequences.  -- Stone''',
r'''Refuse to replicate your own dehumanization.  -- Lillian Roybal-Rose''',
r'''Regardless of how many times you are right, you will sometimes be wrong.''',
r'''Relationships are a wonderful way of getting your buttons pushed.  -- Lee Coit''',
r'''Religion has done love a great service by making it a sin.  -- Anatole France''',
r'''Religion is a defense against the experience of God.  -- Carl Jung''',
r'''Religion is certainty without proofs.  -- Amiel''',
r'''Religion is the fashionable substitute for Belief.  -- Oscar Wilde''',
r'''Religion is the opium of the people.  -- Karl Marx''',
r'''Religion is what keeps the poor from murdering the rich.  -- Napoleon''',
r'''Religion may be morally useful without being intellectually sustainable.  -- Mill''',
r'''Religion stops a thinking mind.''',
r'''Religion... enables humans who don't have all the answers to think that they do.  -- Bill Maher''',
r'''Religions are like glow worms, they require darkness to shine.  -- Schopenhauer''',
r'''Religions die when they are proved to be true.  -- Oscar Wilde''',
r'''Religions revolve madly around sexual questions.  -- Remy de Gourmont''',
r'''Rely on the two finest teachers, trial and error.  -- Colin Fletcher''',
r'''Remain as much as possible in the state of the witness.  -- Ram Dass''',
r'''Remember that there is an outside world to see and enjoy.  -- Hans Liepmann''',
r'''Remember the poor -- it costs nothing.  -- Josh Billings''',
r'''Remember them as they were and write them off.  -- Ernest Hemingway''',
r'''Remember to never split an infinitive.  -- William Safire''',
r'''Remembering is for those who have forgotten.  -- Chinese proverb''',
r'''Repeated failure is no guarantee of eventual success.''',
r'''Reproduction is the ultimate form of consumption.''',
r'''Reputation is commonly measured by acres.''',
r'''Research should begin and end in the library.  -- Michael Shimkin''',
r'''Research:  See what everyone saw, but think what no one else thought.''',
r'''Resentment is the most precious flower of poverty.  -- Carson McCullers''',
r'''Resist the urge to tinker.  -- Scott Adams''',
r'''Resoluteness sleeps in a bed of knowledge.  -- John Taylor''',
r'''Respect must be earned, not commanded.''',
r'''Respect the past, knowing it was once all that was humanly possible.''',
r'''Respect the role luck has played on some of your role models.  -- Morgan Housel''',
r'''Revelation is not sealed.  (Direct connection to Truth remains obtainable.)''',
r'''Revenge is mine, saith the lord.  -- Bible''',
r'''Revenge is sweet.''',
r'''Rich folk have many friends.''',
r'''Rich folks's money is always on paper; poor folks's money is in cash.''',
r'''Rich:  You have enough money that your money works for you, and not vice-versa.''',
r'''Riches cover a multitude of woes.''',
r'''Riches have wings.''',
r'''Riches serve a wise man but command a fool.''',
r'''Right wrongs no man.  -- Henderson''',
r'''Ripen tomatoes stem end up at room temperature.''',
r'''Rising equity glidepaths create a "Heads you win, tails you don't lose" outcome.  -- Pfau and Kitces''',
r'''Rivers need a spring.  -- George Herbert''',
r'''Rock gives reality to the otherwise abstract notion of transhuman time.  -- Edward Abbey''',
r'''Rocks might teach us life's secrets, were it not for the language barrier.''',
r'''Romance addiction is an invention of Western culture.  -- Anne Schaeff''',
r'''Romantic stages are mental illness:  You're "crazy about someone." -- Will Limon''',
r'''Rome was not built in a day.  -- Cervantes''',
r'''Rotten wood cannot be carved.  -- Confucius''',
r'''Rubber bands last longer when refrigerated.''',
r'''Rule 1:  Don't sweat the small stuff.  Rule 2:  It's all small stuff.''',
r'''Rule youth well, and age will rule itself.''',
r'''Ruling a big country is like cooking a small fish.  -- Lao Tsu''',
r'''Sailors go round the world without going into it.''',
r'''Sailors have a port in every storm.  -- J. T. Smith''',
r'''Salary is no object:  Strive only to keep body and soul apart.''',
r'''Sanity is nothing more than the ability to live in harmony with nature's laws.''',
r'''Satire does not look pretty upon a tombstone.''',
r'''Saving face is important.  Give your opponent the opportunity to withdraw.''',
r'''Say no, then negotiate.  -- Helga''',
r'''Saying and doing are two different things.  -- J. de Luna''',
r'''Scandal is gossip made tedious by morality.  -- Oscar Wilde''',
r'''Scatter with one hand, gather with two.  -- Howell''',
r'''Scholarship is polite argument.  -- Philip Rieff''',
r'''Science and conscience belong together.  -- Gerhard Uhlenbruck''',
r'''Science can progress on the basis of error as long as it is not trivial.''',
r'''Science demands a tolerance for ambiguity.  -- Carl Sagan''',
r'''Science has no enemy but the ignorant.  -- L. Digges''',
r'''Science is always wrong.  It never solves a problem without creating ten more.''',
r'''Science is magic that works.  -- Kurt Vonnegut''',
r'''Science is more than a body of knowledge; it is a way of thinking.  -- Carl Sagan''',
r'''Science is sometimes a cruel mistress.''',
r'''Science is the process for sorting out the possible from the impossible.  -- Tom Siegfried''',
r'''Science is the topography of ignorance.  -- Oliver Holmes''',
r'''Science is the whore of industry and the handmaiden of war.  -- Edward Abbey''',
r'''Science is trustworthy precisely because it can fail.  -- Stuart Firestein''',
r'''Science without religion is lame, religion without science is blind.  -- Einstein''',
r'''Science's great tragedy:  The slaying of a beautiful hypothesis by an ugly fact.''',
r'''Science, based on evidence, cares nothing for what you personally like or don't.''',
r'''Science:  An orderly arrangement of what at the moment seem to be facts.''',
r'''Science:  No thing is nothing.  -- Gerhard Uhlenbruck''',
r'''Science:  Nonsense does not always make no sense.  -- Gerhard Uhlenbruck''',
r'''Science:  The creation of dilemmas by the solution of mysteries.''',
r'''Science:  To see or not to see, that's the main question.  -- Gerhard Uhlenbruck''',
r'''Scientific minds do not so much provide right answers as ask right questions.''',
r'''Scientific progress:  Milestones or millstones?  -- Gerhard Uhlenbruck''',
r'''Scientists keep romantics honest; romantics keep scientists human.''',
r'''Scientists... can often recognize nonsense when they come across it.  -- Crick''',
r'''Scripts determine the destiny and the identity of the individual.  -- Eric Berne''',
r'''Search for life, and Life will find you.  -- Kevin Cook''',
r'''Searching for the invisible is not for the faint of heart.  -- Stephen Hawking''',
r'''Season your words with kindness; someday you might have to eat them.''',
r'''Second thoughts are best.''',
r'''Second-rate people hire third-rate people.''',
r'''Secrecy is the beginning of tyranny.''',
r'''Sed quis custodiet ipsos Custodes?  (Who guards the Guardians?)''',
r'''See things symbolically instead of literally.  -- Carolyn Myss''',
r'''See yourself as a success and your success is assured.''',
r'''Seek and ye shall find.  -- Bible''',
r'''Seek not to understand that you may believe but believe that you may understand.''',
r'''Seek the road which makes death a fulfillment.  -- Dag Hammarskjold''',
r'''Seek the testimony of the few; and number not voices, but weight them.  -- Kant''',
r'''Seeking for the Buddha's nature is much like riding an ox in search of the ox.''',
r'''Seize the day; put no trust in the morrow!  -- Horace''',
r'''Seldom seen, soon forgotten.''',
r'''Self do, self have.''',
r'''Self-abuse is the most certain road to the grave.  -- G. M. Calhoun''',
r'''Self-determination does not negate self-control.''',
r'''Self-hatred is the source of all problems on the planet.  -- Oprah Winfrey''',
r'''Self-justification is not the same thing as lying or making excuses.  -- Tavris and Aronson''',
r'''Self-preservation is the first law of nature.''',
r'''Self-veiling is a contradictory act -- a free suspension of our freedom.  -- Carse''',
r'''Selling the solution is often more difficult than solving the problem.  -- Salzer''',
r'''Seriousness is the only refuge of the shallow.  -- Oscar Wilde''',
r'''Servants make the worst masters.''',
r'''Set aside a little time every once in a while to experience silence.  -- Deepak Chopra''',
r'''Set goals that have many ways of being realized.  -- Scott Adams''',
r'''Seven turns out to be a very hip number in the melodrama.  -- Ram Dass''',
r'''Severe enforcement of a bad law will hasten its repeal.  -- Lawrence Hirsch''',
r'''Sex appeal is 50% what you've got and 50% what people think you've got.''',
r'''Sex discriminates against the shy and ugly.''',
r'''Shakespeare and Dante divide the world between them.  -- T. S. Eliot''',
r'''Shame is an improper emotion invented by pietists to oppress the human race.''',
r'''She bore a great soul in a little body.  -- Quiller-Couch''',
r'''She did not think he deserved the compliment of rational opposition.  -- Austin''',
r'''She runs the gamut of emotions from A to B.  -- Dorothy Parker''',
r'''Shielding men from the effects of folly fills the world with fools.  -- Spencer''',
r'''Ships fear fire more than water.  -- George Herbert''',
r'''Short acquaintance brings repentance.  -- John Ray''',
r'''Show me one man who deserves to live forever.  -- Edward Abbey''',
r'''Show you care about security, or security will show it "cares" about you.''',
r'''Sic transit gloria mundi.  (So passes away the glory of the world.)  -- Kempis''',
r'''Sickness shows us what we are.  -- Fuller''',
r'''Sight is a faculty; seeing is an art.  -- George Beston''',
r'''Silence cannot be misquoted.''',
r'''Silence is sometimes the best answer.''',
r'''Silence is the element in which great things fashion themselves.  -- Carlyle''',
r'''Silence is the unbearable repartee.  -- Charles Dickens''',
r'''Silence is wisdom, when speaking is folly.  -- Fuller''',
r'''Silence seldom hurts.  -- Fuller''',
r'''Simple jobs always get put off because there will be time to do them later.''',
r'''Simple pleasures are the last refuge of the complex.''',
r'''Simple pleasures are the last refuge of the complex.  -- Oscar Wilde''',
r'''Simple tasks should be simple, and complex tasks should be possible.  -- Ed Moore''',
r'''Simplicity does not precede complexity, but follows it.''',
r'''Simplicity may be a gift, but I think complexity is much more interesting.  -- Elizabeth Quill''',
r'''Sin boldly.  -- Martin Luther''',
r'''Sin has many tools, but a lie is the handle that fits them all.''',
r'''Sin lies only in hurting other people unnecessarily.  -- Robert Heinlein''',
r'''Sin that is hidden is half-forgiven.  -- G. Fenton''',
r'''Sing, sing a song of joy, for love and understanding!''',
r'''Singleness is gaining a sense of self you will not compromise for someone else.''',
r'''Six feet of earth make all men equal.''',
r'''Skepticism is a barren coast, without a harbor or a lighthouse.''',
r'''Skepticism is dangerous.  That's exactly its function.  -- Carl Sagan''',
r'''Skepticism is the beginning of faith.  -- Oscar Wilde''',
r'''Skepticism is the mark and even the pose of the educated mind.  -- John Dewey''',
r'''Skeptics laugh in order not to weep.  -- Anatole France''',
r'''Slang:  Language that doffs its coat, spits on its hands, and goes to work.''',
r'''Sleep is the best meditation.  -- Tenzin Gyatso, XIV Dalai Lama''',
r'''Sleep is the brother of death.''',
r'''Sloth is a somatic skepticism, the way the flesh doubts.  -- E. M. Cioran''',
r'''Slowly, but surely, humanity makes real the dreams of the wise.  -- A. France''',
r'''Small opportunities are often the beginning of great enterprises.  -- Demosthenes''',
r'''Small profits and quick returns.''',
r'''Small rain lays great dust.  -- John Ray''',
r'''Small streams of caring become a pool of love.''',
r'''Small things make mean men proud.  -- William Shakespeare''',
r'''Smart folks speak from experience.  Smarter folks, from experience, don't speak.''',
r'''Smooth seas do not make for good sailors.''',
r'''So I have promised you, I'll be as good as my word.  -- William Shakespeare''',
r'''So long as you stay vague, nothing changes.  -- Carolyn Myss''',
r'''So long as your will is in a fog, you will be an addict.  -- Carolyn Myss''',
r'''So many ask God to grant so much, and then take so much for granted!  -- White''',
r'''So many men, so many minds.  -- Terence''',
r'''So many men, so many opinions; every one his own way.''',
r'''So of cheerfulness, or a good temper, the more it is spent, the more remains.''',
r'''Social innovations tend to the level of minimum tolerable well-being.''',
r'''Social problems are very much harder than scientific ones.  -- Richard Feynman''',
r'''Social skills require rapidly inferring meaning from facial expression.''',
r'''Societies that rely on conscription to survive do not deserve to exist.''',
r'''Society attacks early, when the individual is helpless.  -- B.F. Skinner''',
r'''Society is a mule, not a car; if pressed harder, it will kick and throw you off.''',
r'''Society is defined by its boundaries; a culture is defined by its horizon.''',
r'''Soft words and hard arguments.  -- John Ray''',
r'''Soldiers in peace are like chimneys in summer.''',
r'''Solitude is the nest of thought.''',
r'''Solitude:  A great place to visit, but a bad place to stay.''',
r'''Some lives are tragic, some ridiculous.  Most are both at once.  -- Edward Abbey''',
r'''Some men are alive simply because it is against the law to kill them.  -- Ed Howe''',
r'''Some men are like a clock on the roof; they are useful only to the neighbors.''',
r'''Some men rob you with a six-gun, others with a fountain pen.  -- Woodie Guthrie''',
r'''Some men succeed in spite of their faults, others because of them.  -- McKeown''',
r'''Some of us are becoming the men we wanted to marry.  -- Gloria Steinem''',
r'''Some of us learn from other peoples' errors.  The rest must be the other people.''',
r'''Some people are too lazy to put food in their own mouths.  -- Solomon''',
r'''Some people believe anything if you whisper it.''',
r'''Some people live from the chin up.''',
r'''Some people read because they are too lazy to think.''',
r'''Some people think they are worth a lot of money simply because they have it.''',
r'''Some rise by sin and some by virtue fall.''',
r'''Some self-veiling is present in all finite games.  -- James Carse''',
r'''Some tasks are easier to do than to delegate.  -- Alan Silverstein''',
r'''Some things have to be believed to be seen.''',
r'''Someone whom you reject today, will reject you tomorrow.''',
r'''Something must be left to chance.  -- W. C. Russell''',
r'''Sometimes even to live is an act of courage.  -- Seneca''',
r'''Sometimes I wonder whether God enjoys Christmas.  -- Horace Rumpole''',
r'''Sometimes I worry about being a success in a mediocre world.  -- Lily Tomlin''',
r'''Sometimes it takes a painful experience to make us change our ways.  -- Solomon''',
r'''Sometimes it takes wisdom to stop beating your head against the wall.''',
r'''Sometimes let things happen, but sometimes make things happen.''',
r'''Sometimes something worth doing is worth overdoing.  -- David Letterman''',
r'''Sometimes you must tread water until you know which way is the shore.  -- Zeidman''',
r'''Somewhere, something incredible is waiting to be known.  -- Carl Sagan''',
r'''Sooner begun, sooner done.''',
r'''Sooner or later the worst possible set of circumstances is bound to occur.''',
r'''Sorrow is always dry.''',
r'''Sorrow is good for nothing but sin.  -- Camden''',
r'''Sorrow makes silence her best orator.  -- S. Daniel''',
r'''Sorrow shared is halved; joy shared is doubled.''',
r'''Sorrow will pay no debt.''',
r'''Sorry I wrote you such a long letter; I didn't have time to write a short one.''',
r'''Space is to place as eternity is to time.  -- Joseph Joubert''',
r'''Space is unforgiving.  -- Louis Friedman''',
r'''Spacetime tells matter how to move, and matter tells spacetime how to curve.  -- John Wheeler''',
r'''Spare the rod and spoil the child.  -- Old Testament''',
r'''Spare when you are young, and spend when you are old.''',
r'''Spatial boundaries are evident in every finite conflict.  -- James Carse''',
r'''Speak fitly, or be silent wisely.''',
r'''Speak not of my debts, unless you mean to pay them.  -- George Herbert''',
r'''Speak only well of people and you will never have to whisper.''',
r'''Speak well of your friend, of your enemy say nothing.  -- Mapletoft''',
r'''Speak when you are spoken to.  -- John Ray''',
r'''Speaking or writing without thinking is like shooting without aiming.  -- Glasow''',
r'''Speech is silver, silence is golden.''',
r'''Speeches are like babies:  Easy to conceive, but extremely hard to deliver.''',
r'''Speed doesn't kill, indecision does.  Speed just reduces your available choices.''',
r'''Spend enough time confirming the need and the need will disappear.''',
r'''Spend more time planning your marriage than your wedding.''',
r'''Spending less money creates more time.  -- Jeff Yeager''',
r'''Spirituality is the sense of awe and wonder for the creation that surrounds us.  -- Norris Burkes''',
r'''Squander nothing, share everything.''',
r'''Stagnation is stopping in one's tracks and waiting for death to approach.''',
r'''Standard is better than better.  Standard plus better is better yet.''',
r'''Start being grateful for the person even though you can't see the gift.  -- Coit''',
r'''Starvation is no laughing matter.  -- Thackeray''',
r'''Statistics are no substitute for judgement.  -- Henry Clay''',
r'''Statistics should support common sense.  -- Nancy Kanwisher''',
r'''Staying the same is the first step towards getting worse.  -- Jon Kedrowski''',
r'''Steady movement is more important than speed, much of the time.  -- Corwin''',
r'''Step back for a moment and witness the choices you make.  -- Deepak Chopra''',
r'''Sticks and stones may break my bones but names will never hurt me.  -- Leng-Tzu''',
r'''Stocks let us eat well.  Bonds let us sleep well.''',
r'''Stolen water is sweeter.  Stolen bread tastes better.  -- Solomon''',
r'''Stone walls have ears, and a bird of the air shall carry the matter.  -- Scott''',
r'''Stop one from digging his grave and he will hit you over the head with a shovel.''',
r'''Stop tolerating in your leaders what you would not tolerate in your friends.''',
r'''Straight trees have crooked roots.  -- Lyly''',
r'''Strangers are just friends who have never met.  -- John Taylor''',
r'''Stress is an equal opportunity destroyer.  -- Brian Seaward''',
r'''Strike while the iron is hot.  -- Chaucer''',
r'''Strive for perfection; settle for happiness.''',
r'''Stronger is one who holds back while pushing forward.  -- John Taylor''',
r'''Study to be quiet, and to do your own business.  -- Saint Paul''',
r'''Stupid people advertise their ignorance.  -- Solomon''',
r'''Stupidity is immune to education.  -- Scott Adams''',
r'''Stupidity, like virtue, is its own reward.  -- Bill Davidsen''',
r'''Sturgeon's Law:  Ninety percent of everything is crud.''',
r'''Substance is one of the greatest of our illusions.  -- Eddington''',
r'''Success breeds comfort, and comfort breeds failure.''',
r'''Success comes from aspiration, desperation, perspiration, and inspiration.''',
r'''Success covers a multitude of blunders.  -- George Shaw''',
r'''Success gives man big head, also big belly.  -- Confucius''',
r'''Success has a thousand fathers, but failure is an orphan.''',
r'''Success is built on a willingness to fail.''',
r'''Success is getting what you want; happiness is wanting what you get.''',
r'''Success is merely a matter of luck.  Ask any failure.  -- Earl Wilson''',
r'''Success is not a destination; it is a journey.  -- Zig Ziglar''',
r'''Success is not forever and failure isn't fatal.''',
r'''Success is not the immunity of adversity but the proof that you've conquered it!''',
r'''Success is the ability to fulfill your desires with effortless ease.  -- Deepak Chopra''',
r'''Success is the sole earthly judge of right and wrong.  -- Adolph Hitler''',
r'''Success isn't permanent and failure isn't fatal.  -- Mike Ditka''',
r'''Success makes a fool seem wise.  -- Mapletoft''',
r'''Success never happens until you decide to leave mediocrity.''',
r'''Such sights as this are reserved for those who will suffer to behold them.''',
r'''Sudden friendship, sure repentance.  -- James Kelly''',
r'''Suffering is purification:  It's like the fire that gets you straight.  -- Dass''',
r'''Suffering plus meaning equals wisdom.  -- Evan Hodkins''',
r'''Supercompetence is more objectionable than incompetence.''',
r'''Surprise is a crucial element in most finite games.  -- James Carse''',
r'''Surrender your game, in which you have certain mastery, in order to go for more.''',
r'''Survival isn't a hobby, it's an attitude.  -- Len McDougall''',
r'''Survival of the species is everyone's business.''',
r'''Surviving is one thing; enjoying survival is another.  -- Michael Lindemman''',
r'''Suspicion always haunts the guilty mind.  -- William Shakespeare''',
r'''Sweet appears sour when we pay.  -- Howell''',
r'''Sweet April showers do spring May flowers.  -- Thomas Tusser''',
r'''Systems resemble the organizations that create them.  -- Johnson''',
r'''Tact in audacity is knowing how far you can go without going too far.  -- Cocteau''',
r'''Tact is the art of making a point without making an enemy.''',
r'''Tailors and writers must mind the fashion.  -- Lyly''',
r'''Take all things as they come, and be content.  -- Davies''',
r'''Take away my good name and take away my life.  -- John Ray''',
r'''Take care of the feet, and the miles take care of themselves.''',
r'''Take care of the luxuries and the necessities will take care of themselves.''',
r'''Take care of the pennies and the dollars will take care of themselves.''',
r'''Take care of the sense and the sound will take care of itself.  -- Lewis Carroll''',
r'''Take no more on you than you're able to bear.  -- James Kelly''',
r'''Take only pictures, leave only footprints, kill only time.''',
r'''Take out the garbage or live with the stink.  -- Sam Kaplan''',
r'''Take total responsibility for yourself and your own happiness.  -- Vikki Coit''',
r'''Take what you can use and let the rest go by.  -- Ken Kesey''',
r'''Take your fee while the patient is still in pain.  -- John of Salisbury''',
r'''Take your own thoughts seriously, for they will shape you.  -- Einstein''',
r'''Taking a break in the middle is not so rewarding as when the job is finished.''',
r'''Talk of an angel and you will hear his wings.''',
r'''Talk of the devil, and he is presently at your elbow.  -- Torriano''',
r'''Talk sense to a fool and he calls you foolish.  -- Euripides''',
r'''Talk to a man about himself and he will listen for hours.  -- Benjamin Disraeli''',
r'''Talkers are no good doers.  -- William Shakespeare''',
r'''Talking much about oneself can also be a means to conceal oneself.  -- Friedrich Nietzsche''',
r'''Talking pays no toll.  -- George Herbert''',
r'''TANSTAAFL:  There ain't no such thing as a free lunch.  -- Robert Heinlein''',
r'''Tantra means using the senses to go beyond the senses.  -- Ram Dass''',
r'''Tastes differ.''',
r'''Tears will get you sympathy.  Sweat will get you results.''',
r'''Technology is dominated by those who manage what they do not understand.''',
r'''Technology is no more of a problem now than it has always been.  -- J. Redford''',
r'''Technology will continue to make our lives harder.  -- Scott Adams''',
r'''Technology:  The knack of so arranging the world that we need not experience it.''',
r'''Television proves that people will look at anything, rather than each other.''',
r'''Tell a child he got one right, not 99 wrong.''',
r'''Tell a lie and find a truth.''',
r'''Tell me whom you love, and I will tell you who you are.  -- Houssaye''',
r'''Tell the truth and run.  -- Yugoslav proverb''',
r'''Tempt not a desperate man.  -- William Shakespeare''',
r'''Ten persons who speak make more noise than 10,000 who are silent.  -- Napoleon''',
r'''Tensions are normal in the claustrophobia of powerless subcultures.  -- Gary Wolf''',
r'''Thank God we don't get all the government we pay for.  -- Will Rogers''',
r'''That never ends ill which begins in God's name.  -- Clarke''',
r'''That sick man is not to be pitied who has his cure in his sleeve.  -- Fuller''',
r'''That that is past, cannot be recalled or helped.  -- Thomas Draxe''',
r'''That the world is, is the mystical.  -- Ludwig Wittgenstein''',
r'''That which is easily done is soon believed.  -- Codrington''',
r'''That which is everybody's business is nobody's business.  -- Izaak Walton''',
r'''That which is incapable of proof itself is not proof of anything else.  -- Shelley''',
r'''That which is not good for the swarm, neither is it good for the bee.''',
r'''That which is possible is inevitable.  -- William Williams''',
r'''That which is truth will rise to the surface.  -- Ram Dass''',
r'''That which is well done is twice done.''',
r'''That's one small step for a man; one giant leap for mankind.  -- Neil Armstrong''',
r'''The "silly" question is the first intimation of some totally new development.''',
r'''The ability to tax is the ability to control.''',
r'''The absent are never without fault, nor the present without excuse.  -- Franklin''',
r'''The absurd is the essential concept and the first truth.  -- Albert Camus''',
r'''The abuse of greatness is when it disjoins remorse from power.  -- William Shakespeare''',
r'''The advance of a language is retarded by sensitive ears.  -- Thomas McKeown''',
r'''The advertisement is the most truthful part of a newspaper.  -- Thomas Jefferson''',
r'''The answers to prayers are usually found in those who pray.''',
r'''The art of writing is knowing when to stop.  -- Josh Billings''',
r'''The attacker must vanquish; the defender need only survive.''',
r'''The author writes in my book; why should I not write in his?  -- John Taylor''',
r'''The average dog is a nicer person than the average person.  -- Andrew Rooney''',
r'''The average life of an organization chart is six months.  -- Scott Adams''',
r'''The average nutritional value of promises is roughly zero.''',
r'''The average person's left hand does 56% of the typing.''',
r'''The awakening is to the realization that you are in fact being guided.  -- Dass''',
r'''The balance between ecology and society is exquisitely delicate.  -- Alan Weiseman''',
r'''The basic raw material of the universe is non-material.  -- Deepak Chopra''',
r'''The basis of optimism is sheer terror.''',
r'''The bee sucks honey out of the bitterest flowers.  -- Nashe''',
r'''The beginning of wisdom is to call things by their proper name.  -- Confucius''',
r'''The belly is not filled with fair words.  -- John Ray''',
r'''The belly is the truest clock.''',
r'''The best carpenter makes the fewest chips.''',
r'''The best climber in the world is the one who's having the most fun.  -- Alex Lowe''',
r'''The best defense is a good offense.''',
r'''The best grapefruit are thin-skinned and flat on top and bottom, not pointy.''',
r'''The best investment on Earth, is Earth.''',
r'''The best is the enemy of the good.  -- Voltaire''',
r'''The best mirror is an old friend.''',
r'''The best people, like the best wines, come from the hills.  -- Edward Abbey''',
r'''The best places of all, I have never mentioned.  -- Edward Abbey''',
r'''The best prophet of the future is the past.''',
r'''The best remedy for any problem is to avoid it.  -- Len McDougall''',
r'''The best substitute for brains is silence.''',
r'''The best thing to spend on your children is time.''',
r'''The best things in life are free.  -- Confucius''',
r'''The best things in life...  Aren't things.''',
r'''The best time to plant a tree is 20 years ago.''',
r'''The best way not to find a (love) partner is to attempt to find a partner.''',
r'''The best way to cheer yourself up is to try to cheer somebody else up.  -- Twain''',
r'''The best way to get rid of worries is to let them die of neglect.''',
r'''The best way to keep your friends is not to give them away.''',
r'''The best way to make your dreams come true is to wake up.  -- H. Power''',
r'''The best way to predict the future is to create it.  -- Peter Drucker''',
r'''The best way to predict your future is to create it.  -- Alan Kay''',
r'''The better part of valor is discretion.  -- William Shakespeare''',
r'''The bigger one thing is, the smaller it makes another thing.  -- Elizabeth Goudge''',
r'''The bigger they are, the harder they fall.''',
r'''The biggest difference between time and space is that you can't reuse time.''',
r'''The biggest mistake is not learning from all your other mistakes.''',
r'''The blind hear your whisper, the deaf see your wink.  -- Thomas McKeown''',
r'''The book which most should be forbidden is a catalog of forbidden books.''',
r'''The bottom line rests on Earth.  -- David Brower''',
r'''The brain allows man to escape from the laws of evolution...  -- Loren Eiseley''',
r'''The brain works from the moment of birth until you stand up to speak in public.''',
r'''The brainwashed do not know they are brainwashed.  -- Wendy Williams''',
r'''The brevity of life calls for good wine.  -- L. Bohn''',
r'''The brighter you are, the more you have to learn.  -- Don Herold''',
r'''The burnt child dreads the fire.''',
r'''The busiest men have the most time.''',
r'''The busiest people are those whose time is their own.''',
r'''The buyer needs a hundred eyes, the seller but one.''',
r'''The Caesar salad was named for hotel owner Caesar Cardini of Tijuana, Mexico.''',
r'''The cat that chases two mice catches none.  -- Leng-Tzu''',
r'''The chief danger in life is that you might take too many precautions.  -- Adler''',
r'''The clearest way into the universe is through a forest wilderness.  -- John Muir''',
r'''The confused mind always says, "no".''',
r'''The consequences of events are as important as the probabilities of outcomes.''',
r'''The correct prayer is never a prayer of supplication, but of gratitude.  -- God?''',
r'''The correlation between confidence and future regret is incredibly high.  -- Morgan Housel''',
r'''The covetous man is ever in want.  -- Horace''',
r'''The coward does it with a kiss, the brave man with a sword.  -- Oscar Wilde''',
r'''The creative is found in anyone who is prepared for surprise.  -- James Carse''',
r'''The cuckoo bird does not lay his own eggs.''',
r'''The cup of our happiness is hollowed out by the flow of our tears.  -- Gibran''',
r'''The curve of pleasure is hyperbolic:  First steps largest and most significant.''',
r'''The customer is always right.''',
r'''The dark side of the moon is harder to see; beaming light on it costs energy.  -- Nassim Taleb''',
r'''The day has eyes, the night has ears.  -- Fergusson''',
r'''The dead are gone, and the show must go on.  -- Karl Wallenda''',
r'''The dearer a thing is, the cheaper as a general rule we sell it.  -- Butler''',
r'''The degree of civilization in a society can be judged by entering its prisons.''',
r'''The descent to Hades is the same from every place.  -- Anaxagoras''',
r'''The desire to become enlightened is still you desiring something.  -- Ram Dass''',
r'''The deterioration of our planet is an outward mirror of an inner condition.  -- David Suzuki''',
r'''The development of the will is the essential core of your spiritual journey.''',
r'''The devil can cite Scripture for his purpose.  -- William Shakespeare''',
r'''The devil dances in an empty pocket.''',
r'''The Devil must not be believed even when he tells the truth.  -- Thomas Aquinas''',
r'''The devil tempts the busy man, but the idle man tempts the devil.''',
r'''The die is cast.  -- Gaius Julius Caesar''',
r'''The difference between ideas and results is a good manager.''',
r'''The difference between theory and practice is less in theory than in practice.''',
r'''The difference between tragedy and humor is whether it is happening to you.''',
r'''The dinosaurs became extinct because they didn't have a space program.  -- Niven''',
r'''The discerning person is always at a disadvantage.''',
r'''The distrust of wit is the beginning of tyranny.  -- Edward Abbey''',
r'''The door is the key.''',
r'''The dose makes the poison.  -- Dr. Bruce Ames''',
r'''The duty of the patriot is to protect his country from the government.  -- Paine''',
r'''The early bird catches the worm.  -- Confucius''',
r'''The Earth has all the time in the world -- and we don't.  -- Oren Lyons''',
r'''The Earth is not inherited from our parents, but borrowed from our children.''',
r'''The Earth is our mother; our nine months are up.''',
r'''The easiest way to steal is to let the victim think he's doing the stealing.''',
r'''The effort required to correct your course increases exponentially with time.''',
r'''The employer generally gets the employees he deserves.  -- Walter Bilbey''',
r'''The end crowns the work.''',
r'''The end does not justify the means, whatever people may say.  -- Thomas''',
r'''The end justifies the means.  -- Hermann Busenbaum''',
r'''The end makes all equal.''',
r'''The end of anything is better than its beginning.  -- Old Testament''',
r'''The end of labor is to gain leisure.''',
r'''The environment is as high as I am.  -- Ram Dass''',
r'''The errors to avoid are those that eliminate opportunities to try again.''',
r'''The essence of wealth is life energy.  -- Deepak Chopra''',
r'''The essential is invisible to the eye.  -- St. Exupery''',
r'''The essential thing is not to have conquered but to have fought well.''',
r'''The evils of controversy are temporary, its benefits are permanent.  -- R. Hall''',
r'''The exception proves the rule.''',
r'''The exercise of power always presupposes resistance.  -- James Carse''',
r'''The external world is socially constructed.  -- Ellen Langer''',
r'''The eye is a radical, the tongue an anarchist, the ear a conservative.  -- McKeown''',
r'''The eyes have one language everywhere.  -- George Herbert''',
r'''The face is no index to the heart.''',
r'''The fact that no one understands you doesn't mean you're an artist.''',
r'''The fairest flowers soonest fade.''',
r'''The falsely dramatic drives out the truly dull.''',
r'''The farmer doesn't go to work; he wakes up surrounded by it.''',
r'''The farther you go, the less you know.  -- Lao Tsu''',
r'''The fashion wears out more apparel than the man.  -- William Shakespeare''',
r'''The fear of evil is worse than the event.  -- Marmion''',
r'''The feeling of love is your experience of God.  -- Conversations with God''',
r'''The feminists have a legitimate grievance.  But so does everyone else.  -- Edward Abbey''',
r'''The fewer his years, the fewer his tears.  -- Fuller''',
r'''The fewer the influences in one's life, the more ill-balanced they become.''',
r'''The field cannot well be seen from within the field.  -- Emerson''',
r'''The finest eloquence is that which gets things done.''',
r'''The finite play for life is serious; the infinite play of life is joyous.''',
r'''The finite player plays for immortality; the infinite player plays as a mortal.''',
r'''The fire that warms us at a distance will burn us when near.''',
r'''The first and last frosts are the worst.  -- George Herbert''',
r'''The first duty of a revolutionary is to get away with it.  -- Abbie Hoffman''',
r'''The first love is the fastest.''',
r'''The first principle is that you must not fool yourself...  -- Richard Feynmann''',
r'''The first requisite for immortality is death.  -- Stanislaw Lem''',
r'''The first rule is to last.  -- Dan Rather''',
r'''The first rule of business is that the customer always comes first.''',
r'''The first step to helping the world is finding peace in your own mind.  -- Hayward''',
r'''The first symptom of a heart problem is chest pain; the second is denial.''',
r'''The first thing every child learns is that he is not the entire universe.''',
r'''The first version always gets thrown away.''',
r'''The foolish ask questions that the wise cannot answer.  -- Oscar Wilde''',
r'''The foot feels the foot when it feels the ground.  -- Buddha''',
r'''The fossil hunter does not kill, he resurrects.  -- Dr. George Simpson''',
r'''The fragile should break early, while it's still small.  -- Nassim Taleb''',
r'''The French Revolution was accomplished before it happened.''',
r'''The function of consciousness is to tell us the story of our lives.  -- Hayward''',
r'''The future is a race between education and catastrophe.  -- H. G. Wells''',
r'''The future is purchased by the present.  -- Samuel Johnson''',
r'''The future just ain't what it used to be.  -- Yogi Berra  (It never was.)''',
r'''The future just isn't what it used to be, but the past's as good as it ever was.''',
r'''The future will be increasingly less predictable.  -- Nassim Taleb''',
r'''The game is much more interesting than we thought it was.  -- Ram Dass''',
r'''The game of enlightenment starts from exactly where you are at this moment.''',
r'''The gap between your thoughts is your connection to pure potentiality.  -- Deepak Chopra''',
r'''The gem cannot be polished without friction, nor man perfected without trial.''',
r'''The gift of flight is reserved for those who jump.  -- Marley Porter''',
r'''The gods match you question for question.  -- Carolyn Myss''',
r'''The gods never show off -- they don't have to.  -- Carolyn Myss''',
r'''The gods play in divine paradox.  -- Carolyn Myss''',
r'''The gods, too, are fond of a joke.  -- Aristotle''',
r'''The golden age never was the present age.''',
r'''The Golden Rule is of no use to you whatever unless you realize it is your move.''',
r'''The golden rule is that there is no golden rule.  -- Bernard Shaw''',
r'''The good thing about science is that it's true whether or not you believe in it.  -- Neil Tyson''',
r'''The graveyards are full of indispensable people.''',
r'''The greater the man, the greater the crime.''',
r'''The greater your dreams, the more terrible your nightmares.  -- Edward Abbey''',
r'''The greatest ability is dependability.''',
r'''The greatest fool may ask more than the wisest man can answer.  -- Colton''',
r'''The greatest gift you can give someone is to be whole and not dependent on them.''',
r'''The greatest gifts we give cannot be seen.  -- Carolyn Myss''',
r'''The greatest griefs are those we cause ourselves.  -- Sophocles''',
r'''The greatest hazard in life is to risk nothing.  Only people who risk are free.''',
r'''The greatest man in history was the poorest.''',
r'''The greatest mistake is to sacrifice health for any other advantage.''',
r'''The greatest obstacle to communication is the perception it already occurred.''',
r'''The greatest of faults is to be conscious of none.''',
r'''The greatest pleasure in life is doing what people say you cannot do.  -- Bagehot''',
r'''The greatest prayer is patience.''',
r'''The greatest productive force is human selfishness.  -- Robert Heinlein''',
r'''The greatest remedy for anger is delay.''',
r'''The greatest scholars are not the best preachers.  -- E. Leigh''',
r'''The greatest skill appears to be fumbling.  -- Lao Tsu''',
r'''The greatest use of life is to spend it on something that outlasts it.  -- James''',
r'''The greatest victory is graceful acceptance of defeat.''',
r'''The guiding principle of science is economy of explanation.  -- A. N. Whitehead''',
r'''The hand of a truly great engineer is nearly invisible.  -- Rork Kuick''',
r'''The hand that kindles cannot quench the flame.''',
r'''The hand that rocks the cradle rules the world.''',
r'''The hard thing to do is the right thing to do.  -- John MacDonald''',
r'''The harder I work, the more luck I seem to have.  -- Thomas Jefferson''',
r'''The harder the conflict, the more glorious the triumph.  -- Thomas Paine''',
r'''The harder you work the luckier you get.''',
r'''The hardest part of ethics is holding to them when they are used against you.''',
r'''The hardest thing in the world is to put feeling, deep feeling, into words.''',
r'''The hardest thing to learn in life is which bridge to cross and which to burn.''',
r'''The head never starts to swell until the mind stops growing.''',
r'''The heart has its reasons which reason knows nothing of.  -- Blaise Pascal''',
r'''The heart is wiser than the intellect.''',
r'''The highest form of generalship is to conquer the enemy by strategy.''',
r'''The highest form of ignorance is rejecting something you know nothing about.  -- Wayne Dyer''',
r'''The highest that a man can attain is to be able to do.  -- Georg Gurdjieff''',
r'''The highway to virtue isn't paved at all.''',
r'''The hippo has no sting, but the wise man would rather be sat upon by the bee.''',
r'''The horrible fact is people don't know what they want until you give it to them.''',
r'''The horrors of war, great as they are, pale before the horror of evil unopposed.''',
r'''The hour which gives us life begins to take it away.  -- Seneca''',
r'''The human body is centuries in advance of the physiologist.  -- Roger Bannister''',
r'''The human brain has figured out a lot about how it works.  -- Tom Siegfreid''',
r'''The human mind seeks to resolve internal conflict, even by false means.''',
r'''The human race has one really effective weapon, and that is laughter.  -- Twain''',
r'''The human soul is not satisfied by worldly things.  -- Oren Lyons''',
r'''The idle man does not know what it is to enjoy rest.''',
r'''The idle mind knows not what it is it wants.  -- Quintus Ennius''',
r'''The important is seldom urgent; the urgent is seldom important.  -- Eisenhower''',
r'''The important thing is not to stop questioning.''',
r'''The impossible is what no one can do until someone does.''',
r'''The Indian discovered the white man in 1492.  -- Stan Freberg''',
r'''The indoor life is the next best thing to premature burial.  -- Edward Abbey''',
r'''The industrial corporation is the natural enemy of nature.  -- Edward Abbey''',
r'''The industrial way of life leads to the industrial way of death.  -- Edward Abbey''',
r'''The infinite player does not die at the end of play, but in the course of play.''',
r'''The ink with which all history is written is merely fluid prejudice.''',
r'''The job is to finish the journey in one lifetime.  -- Ram Dass''',
r'''The journey in this lifetime is about how to plug your spirit in with wisdom.''',
r'''The joyfulness of infinite play... Learning to start something we cannot finish.''',
r'''The knowledge that makes us cherish innocence makes innocence unattainable.''',
r'''The laborer is worthy of his hire.  -- New Testament''',
r'''The last Christian died on a cross.  -- Friedrich Nietzsche''',
r'''The last drop makes the cup run over.''',
r'''The last regret is usually the worst.''',
r'''The last thing one discovers in writing a book is what to put first.  -- Pascal''',
r'''The last vestiges of the old Republic have been swept away.''',
r'''The law has for its end not justice but peace.  -- Thomas McKeown''',
r'''The law is not the same at morning and at night.  -- George Herbert''',
r'''The laws of physics always override the laws of economics.  -- Dan Holohan''',
r'''The leader is the slave of history.  -- Leo Tolstoi''',
r'''The least questioned assumptions are often the most questionable.  -- Paul Broca''',
r'''The less a statesman amounts to, the more he loves the flag.''',
r'''The less between you and nature, the more you appreciate nature.  -- Fletcher''',
r'''The less I speak, the more I meditate.  -- Kyd''',
r'''The less one has to do, the less time one finds to do it in.  -- Chesterfield''',
r'''The less you have to do, the less time you find to do it in.''',
r'''The license never belongs to the licensed, nor the commission to the officer.''',
r'''The life which is unexamined is not worth living.  -- Plato''',
r'''The light of a hundred stars does not equal the light of the moon.''',
r'''The limits of cheap equipment will be tested by the weather.''',
r'''The limits of our rational mind are becoming more apparent sooner.  -- Ram Dass''',
r'''The little I know, I owe to my ignorance.  -- Sacha Guitry''',
r'''The longer we live, the more wonders we see.  -- James Kelly''',
r'''The longer you keep your temper the better it will get.''',
r'''The longer you look at it the less you will like it.''',
r'''The longest part of the journey is the passing of the gate.''',
r'''The love of money and the love of learning rarely meet.  -- George Herbert''',
r'''The love of the wicked is more dangerous than their hatred.  -- Fuller''',
r'''The love that's too violent will not last long.  -- James Kelly''',
r'''The lure of the marvelous blunts our critical faculties.  -- Carl Sagan''',
r'''The magic of the unknown path is, it's not contaminated by your expectations.''',
r'''The majority of the stupid is invincible and guaranteed for all time.  -- Einstein''',
r'''The man at the top of the mountain didn't fall there.  -- Vince Lombardi''',
r'''The man who can make hard things easy is the educator.  -- Ralph Emerson''',
r'''The man who has never been flogged has never been taught.  -- Menander''',
r'''The man who raises a fist has run out of ideas.  -- H. G. Wells''',
r'''The man who runs may fight again.  -- Menander''',
r'''The man who wakes up and finds himself a success hasn't been asleep.''',
r'''The map is not the territory.''',
r'''The mark of adulthood is postponing gratification.''',
r'''The master's eye makes the horse fat.  -- Plutarch''',
r'''The meaning of our existence is not invented by ourselves, but rather detected.''',
r'''The meaning of your communication is the response that you get.''',
r'''The measure of anyone's freedom is what he can do without.  -- L. M. Montgomery''',
r'''The medicine, the more bitter it is, the more better it is in working.  -- Lyly''',
r'''The medium is the message.  -- Marshall McLuhan''',
r'''The meek shall inherit the Earth.  The bold shall inherit the stars.''',
r'''The mere imparting of information is not education.  -- Carter Woodson''',
r'''The mind has no power at all without the heart.  -- Carolyn Myss''',
r'''The mind is a terrible master and a wonderful servant.  -- Ram Dass''',
r'''The mind is an erogenous zone.  -- J. D. Salinger''',
r'''The mind is not a vessel to be filled but a fire to be kindled.  -- Plutarch''',
r'''The mind... in itself can make a Heaven of Hell, a Hell of Heaven.  -- Milton''',
r'''The minute a man is convinced that he is interesting, he isn't.  -- Leacock''',
r'''The minute I need something from you, I'm setting myself up for unhappiness.''',
r'''The moment one definitely commits oneself, then providence moves too.  -- Murray''',
r'''The money you refuse will never do you good.  -- Mapletoft''',
r'''The Moon is not a destination -- it is a direction.  -- Mike Collins, astronaut''',
r'''The more corrupt a society, the more numerous its laws.  -- Edward Abbey''',
r'''The more easily you get your wealth, the sooner you will lose it.  -- Solomon''',
r'''The more energetically clear we get, the more honest we must become.  -- Carolyn Myss''',
r'''The more fantastic an ideology or theology, the more fanatic its adherents.''',
r'''The more humble the more honorable.  -- Clarke''',
r'''The more I help others to succeed, the more I succeed.  -- Ray Kroc''',
r'''The more I want to get something done, the less I call it work.  -- Richard Bach''',
r'''The more light a torch gives, the shorter it lasts.  -- Fuller''',
r'''The more noble, the more humble.  -- Thomas Draxe''',
r'''The more of anything, the less the value of every such thing.  -- Alan Silverstein''',
r'''The more one has, the more one desires.  -- Torriano''',
r'''The more people talk on the phone, the less money they make.''',
r'''The more the merrier.  -- Confucius''',
r'''The more there's in it, the more there's of it.  -- Jonathan Swift''',
r'''The more things a man is ashamed of, the more respectable he is.  -- Bernard Shaw''',
r'''The more urgency dominates your life, the more importance does not.  -- Covey''',
r'''The more we disagree, the more chance there is that at least one of us is right.''',
r'''The more we live by our intellect, the less we understand the meaning of life.''',
r'''The more you know, the less you think you know.''',
r'''The more you know, the more it hurts.  -- Old Testament''',
r'''The more you learn, the less you know.''',
r'''The more you say, the less people remember.''',
r'''The more you sweat in peace, the less you bleed in war.''',
r'''The more you sweat in training, the less you bleed in combat.''',
r'''The mosquito exists to keep the mighty humble.  -- Alan Silverstein''',
r'''The most asked question in the world:  "What will 'they' say?"  -- Carolyn Myss''',
r'''The most dangerous animals in the woods have six legs.  -- Len McDougall''',
r'''The most exhausting thing in life is being insincere.  -- Anne Lindberg''',
r'''The most formidable weapon against errors of every kind is reason.  -- Paine''',
r'''The most generous gift relieves the recipient of the debt of gratitude.''',
r'''The most hopelessly stupid man is he who is not aware that he is wise.''',
r'''The most important thing in life is not the triumph but the struggle.''',
r'''The most important things are hardest to say, because words diminish them.''',
r'''The most incomprehensible thing about the world is that it is comprehensible.''',
r'''The most powerful forms of giving are non-material.  -- Deepak Chopra''',
r'''The most serious struggles are those for sexual property.  -- James Carse''',
r'''The most solid stone is the lowest one in the foundation.''',
r'''The most wasted day of all is that in which we have not laughed.''',
r'''The moving finger writes; and, having writ, moves on.''',
r'''The nearer to the church, the further from God.  -- John Heywood''',
r'''The nearer we approach great men, the clearer we see that they are men.''',
r'''The nearest way to glory is to strive to be what you wish to be thought to be.''',
r'''The night rinses what the day has soaped.''',
r'''The nuclear bomb took all the fun out of war.  -- Edward Abbey''',
r'''The obvious answer is always overlooked.  -- Whitehead''',
r'''The office is designed for "work", not productivity.  -- Scott Adams''',
r'''The old are preoccupied with their pains, the young with their passions.''',
r'''The old fellows stole all our good ideas.  -- Fred Goudy''',
r'''The old men do not grow wise.  They grow careful.  -- Ernest Hemingway''',
r'''The older you get, the more you need people who knew you when you were young.''',
r'''The only absolute attainable knowledge is that life is meaningless.  -- Tolstoy''',
r'''The only certainty is that nothing is certain.  -- Pliny the Elder''',
r'''The only decent thing to do behind a person's back is pat it.''',
r'''The only difference between a rut and a grave is their dimensions.''',
r'''The only feeling warmer than friendship is that of an old love.''',
r'''The only food for thought is more thought.  -- Peter Ustinov''',
r'''The only imperfect thing in nature is the human race.''',
r'''The only monsters in the wilderness are those you brought with you.  -- McDougall''',
r'''The only place where success comes before work is in a dictionary.  -- Sassoon''',
r'''The only problem with seeing too much is that it makes you insane.  -- Phaedrus''',
r'''The only relationship you're guaranteed to be in is the one with yourself.''',
r'''The only reliable information in a newspaper is the date.''',
r'''The only reward of virtue is virtue.  -- Ralph Emerson''',
r'''The only successful substitute for brains is silence.  -- Herbert Prochnow''',
r'''The only thing constant is change.''',
r'''The only thing necessary for the triumph of evil is for good men to do nothing.''',
r'''The only thing one can be sure of changing is oneself.  -- Aldous Huxley''',
r'''The only thing that prisons demonstrably cure is heterosexuality.  -- MacDonald''',
r'''The only thing we have to fear is fear itself.  -- Franklin Roosevelt''',
r'''The only things one never regrets are one's mistakes.  -- Oscar Wilde''',
r'''The only time you can coast in life is when you're going downhill.  -- Merrill''',
r'''The only time you really live fully is from thirty to sixty.  -- Hervey Allen''',
r'''The only valid market survey is a signed purchase order.''',
r'''The only way to amuse some people is to slip and fall on an icy pavement.''',
r'''The only way to entertain some folks is to listen to them.  -- Frank Hubbard''',
r'''The only way to get the best on an argument is to avoid it.  -- Dale Carnegie''',
r'''The only way to have a good relationship is to never, never compromise.  -- Coit''',
r'''The only way to learn is by changing your mind.  -- Orson Scott Card''',
r'''The only winner in the War of 1812 was Tchaikovsky.  -- Solomon Short''',
r'''The opposite of a profound truth may well be another profound truth.  -- Neils Bohr''',
r'''The opposite of addiction is not sobriety; it is human connection.  -- Johann Hari''',
r'''The optimist sees the doughnut, the pessimist, the hole.  -- Wilson''',
r'''The orange that is too hard squeezed yields a bitter juice.  -- Fuller''',
r'''The output of engineers is specifications, not products.  -- Mickey Smith''',
r'''The oxen are slow, but the Earth is patient.''',
r'''The pain passes but the beauty remains.  -- Auguste Renoir''',
r'''The passive voice should never be used.  -- William Safire''',
r'''The past always looks better in the present.''',
r'''The past is history, the future is mystery, and the present is a gift.''',
r'''The path of valor leads but to the grave.''',
r'''The path to the future lies through the corpus callosum.  -- Carl Sagan''',
r'''The pen is mightier than the sword.  -- Leng-Tzu''',
r'''The person who steals an egg will steal a chicken.  -- H. Jackson Brown''',
r'''The person who would know has got to make love with the unknown.  -- Ram Dass''',
r'''The philosopher exists like the saint, only as an ideal.  -- William Dilthey''',
r'''The philosophies of one age have become the absurdities of the next.  -- Osler''',
r'''The place where we do our scientific work is a place of prayer.  -- Needham''',
r'''The plural of anecdote is not data.''',
r'''The plural of spouse is spice.''',
r'''The porcupine with the sharpest quills gets stuck on a tree more often.''',
r'''The power of love overcomes the love of power.  -- Glennon Doyle''',
r'''The power to license is the power to deny.''',
r'''The power to tax involves the power to destroy.  -- John Marshall''',
r'''The present time has one advantage over every other.  It is our own.  -- Colton''',
r'''The press of evolution on man's consciousness is inevitable.  -- Ram Dass''',
r'''The prevailing view of aging is that we essentially rust to death.  -- Shulman''',
r'''The price of greatness is responsibility.''',
r'''The prince of darkness is a gentleman.  -- William Shakespeare''',
r'''The problem with experts is that they do not know what they do not know.  -- Nassim Taleb''',
r'''The proof of the pudding is in the eating.  -- Miguel de Cervantes''',
r'''The prosperous man is never sure that he is loved for himself.''',
r'''The public is an untrustworthy animal.  -- John MacDonald''',
r'''The Public is merely a multiplied "me".  -- Mark Twain''',
r'''The purpose of diplomacy is to prolong a crisis.  -- Spock''',
r'''The purpose of property is to make our titles visible.  -- James Carse''',
r'''The pyramids were as old to the Romans as the Romans are to us.''',
r'''The quality of the answer is proportional to the quality of the question.''',
r'''The quest for success and the quest for truth do not mix well.  -- Kurt Eissler''',
r'''The question is not to whom do I talk, but who listens?  -- God?''',
r'''The race is long and, in the end, it's only with yourself.  -- Mary Schmich''',
r'''The race is not to the swift, nor the battle to the strong.''',
r'''The real evil of old age is not the body's decline, but the soul's indifference.''',
r'''The real geniuses simply have their bright ideas closer together.  -- Lichtenburg''',
r'''The real tragedy of the poor is that they can afford nothing but self-denial.''',
r'''The religion of one age is the literary entertainment of the next.  -- Ralph Emerson''',
r'''The reward of a thing well done is to have done it.  -- Emerson''',
r'''The reward of love is jealousy.  -- Fuller''',
r'''The rich man may dine when he will, the poor man when he may.  -- Erasmus''',
r'''The rich would have to eat money, but luckily the poor provide food.''',
r'''The right to be heard does not include the right to be taken seriously.''',
r'''The right to be let alone is indeed the beginning of all freedom.  -- Douglas''',
r'''The right to revolt has sources deep in our history.  -- Justice William Douglas''',
r'''The ripest fruit falls first.''',
r'''The road to hell is paved with good intentions.  -- Leng-Tzu''',
r'''The root purpose of government is to enable public goods.''',
r'''The rules of an infinite game must change in the course of play.  -- James Carse''',
r'''The saddest moment in a person's life comes but once.''',
r'''The saint must be believed even when he tells the lie.''',
r'''The salvation of man is through love and in love.  -- Viktor Frankl''',
r'''The same knife cuts bread and fingers.''',
r'''The same man cannot be both friend and flatterer.  -- Benjamin Franklin''',
r'''The school of life is a compulsory education.''',
r'''The scriptures are books that offer instruction on the management of power.''',
r'''The sea refuses no river.  -- Lyly''',
r'''The secret to being a successful investor is that there really is no secret.  -- Bill McNabb, Vanguard CEO''',
r'''The self is not something that one finds.  It is something that one creates.''',
r'''The shadow side of the mind is that you are susceptible to illusion.  -- Carolyn Myss''',
r'''The sharper the storm, the sooner it's over.''',
r'''The shifts of Fortune test the reliability of friends.''',
r'''The shortest answer is doing.  -- George Herbert''',
r'''The shortest distance between two people is a smile.  -- Peter Chantilis''',
r'''The sickness of the body may prove the health of the soul.  -- J. Hewes''',
r'''The silliest response to someone threatening you is to hurt yourself.  -- Tom von Alten''',
r'''The sky is no longer the limit.  -- Richard Nixon''',
r'''The sleepy fox has seldom feathered breakfasts.''',
r'''The smallest of good deeds exceeds the greatest of good intentions.''',
r'''The society that creates natural waste creates human waste.  -- James Carse''',
r'''The solace and comfort that religion brings actually comes at a terrible price.  -- Bill Maher''',
r'''The sole thing achieved by any privacy law is to make the bugs smaller.''',
r'''The solution to a problem changes the nature of the problem.  -- Peer''',
r'''The sooner the better.''',
r'''The sooner you die, the longer you're dead.  -- John Quill Taylor''',
r'''The soul is not where it lives, but where it loves.''',
r'''The Soul of the World is nourished by people's happiness.  -- Paulo Coelho''',
r'''The soul would have no rainbow had the eyes no tears.''',
r'''The speech of the man in the street is invariably strong.  -- Emerson''',
r'''The speed of anything depends on the flow of everything.''',
r'''The speed of light is defined to be EXACTLY 299,792,458 meters per second.''',
r'''The spirit indeed is willing, but the flesh is weak.  -- New Testament''',
r'''The squeaky wheel gets the grease.''',
r'''The strong give up and move away, while the weak give up and stay.''',
r'''The strong live off the weak, and the smart live off the strong.''',
r'''The strongest man in the world is he who stands alone.  -- Henrik Ibsen''',
r'''The sun knows no shadows.  -- John Taylor''',
r'''The sun never sets on those who ride into it.  -- RKO Radio''',
r'''The sun shines upon all alike.''',
r'''The sun will set without thy assistance.  -- Talmud''',
r'''The sunlights differ, but there is only one darkness.  -- Ursula LeGuin''',
r'''The superfluous is very necessary.  -- Voltaire''',
r'''The supreme triumph of reason is to cast doubt upon its own validity.  -- Unamuno''',
r'''The surest protection against temptation is cowardice.  -- Mark Twain''',
r'''The sweetest water is in deepest wells.  -- Sir John Beaumont''',
r'''The tactful way to say "wrong" is:  "That turns out not to be the case."''',
r'''The tailor makes the man.  -- Erasmus''',
r'''The task he undertakes is numbering sands and drinking oceans dry.  -- William Shakespeare''',
r'''The task of an educator should be to irrigate the desert, not clear the forest.''',
r'''The test of a vocation is the love of the drudgery it involves.  -- Logan Smith''',
r'''The thief is sorry he is to be hanged, but not that he is a thief.  -- Fuller''',
r'''The thin end of the wedge is to be feared.''',
r'''The thing is that you can tune yourself.  -- Ram Dass''',
r'''The three best ways to get where you want to go are:  Persist, persist, persist.''',
r'''The tigers of wrath are wiser than the horses of instruction.''',
r'''The time to fix the roof is when the sun is shining.''',
r'''The time to retire is when you have enough, and have had enough.''',
r'''The tongue is more venomous than a serpent's sting.''',
r'''The tongue is not steel, yet it cuts.''',
r'''The tragedy of man is what dies inside himself while he still lives.''',
r'''The tragedy of old age is not that one is old, but that one is young.  -- Wilde''',
r'''The training for dying is exactly what the training for living is.  -- Ram Dass''',
r'''The tree in which the sap is stagnant remains fruitless.  -- Hosea Ballou''',
r'''The tribe determines your relationship to reality... and therefore to guidance.''',
r'''The true power of the universe you can BE but you cannot have.  -- Ram Dass''',
r'''The truth a man accepts most willingly is the one he desires.  -- Francis Bacon''',
r'''The truth about a man lies first and foremost in what he hides.  -- Malraux''',
r'''The truth is more important than the facts.  -- Frank Lloyd Wright''',
r'''The truth is rarely pure, and never simple.  -- Oscar Wilde''',
r'''The truth is that the truth is not always true.  -- Gerhard Uhlenbruck''',
r'''The truth shows best being naked.''',
r'''The truth... is the funniest joke in the world.  -- Muhammad Ali''',
r'''The ultimate sin of any celebrity is to be boring.  -- Bo Curry''',
r'''The United States is a nation of laws, badly written and randomly enforced.  -- Frank Zappa''',
r'''The universe is a school of hard knocks for the soul.''',
r'''The universe is hard to comprehend because there is nothing to compare it with.''',
r'''The universe is populated by stable things.  -- Richard Dawkins''',
r'''The universe is the projection of your desires.  -- Ram Dass''',
r'''The universe seems neither benign nor hostile, merely indifferent.  -- Carl Sagan''',
r'''The unknown always passes for the marvelous.  -- Tacitus''',
r'''The unlived life is not worth examining.  -- Guy Kawasaki''',
r'''The use of a quotation is the admission of inadequacy.  -- Samuel Coleridge''',
r'''The used key is always bright.''',
r'''The very remembrance of my former misfortune proves a new one to me.''',
r'''The victory is not in winning but in the courage to enter the race.''',
r'''The voice is the best music.  -- Breton''',
r'''The water flows, but the river stays.  -- John Taylor''',
r'''The way of the world is to praise dead saints and prosecute live ones.  -- Howe''',
r'''The way out is never as easy as the way in.''',
r'''The way to love anything is to realize that it might be lost.''',
r'''The weed of crime bears bitter fruit.''',
r'''The whole is simpler than the sum of its parts.  -- W. Gibbs''',
r'''The will to do, the soul to dare.  -- Sir Walter Scott''',
r'''The will to win is nothing without the will to prepare.  -- Juma Ikangaa''',
r'''The will to win is worthless if you don't get paid for it.  -- Reggie Jackson''',
r'''The wind has no home, and its only clothes are tree branches.  -- Matthew Barry''',
r'''The Winds of Grace are blowing perpetually, we need only raise our sails.''',
r'''The winter of 1932 was so cold that Niagara Falls froze completely solid.''',
r'''The wise shepherd never trusts his flock to a smiling wolf.''',
r'''The wiser you are, the more worries you have.  -- Old Testament''',
r'''The wolf may lose his teeth, but never his memory.  -- Thomas Draxe''',
r'''The word "dog" does not bite.  -- William James''',
r'''The world exists for its own sake, not for ours.  Swallow THAT pill!  -- Edward Abbey''',
r'''The world has no lack of incredibly stupid people.''',
r'''The world hates change, yet it is the only thing that has brought progress.  -- Charles Kettering''',
r'''The world is a madhouse, so it's right that it's patrolled by armed idiots.''',
r'''The world is a stage, but the play is badly cast.  -- Oscar Wilde''',
r'''The world is basically composed of C- students.  -- Donald Wiesner''',
r'''The world is full of cactus, but you don't have to sit on it.  -- Will Foley''',
r'''The world is in danger from two sources:  Order and Disorder.  -- Valery''',
r'''The world is too complex for us.  Evolution didn't keep up.  -- Scott Adams''',
r'''The world must be made safe for democracy.  -- Woodrow Wilson''',
r'''The world owes you nothing.  It was here first.  -- Mark Twain''',
r'''The world population of chickens is about equal to the number of people.''',
r'''The world wants to be deceived.  -- Sebastian Brant''',
r'''The worst cliques are those which consist of one man.  -- George Shaw''',
r'''The worst form of failure is the failure to try.''',
r'''The worst is not so long as we can say, "This is the worst."  -- King Lear''',
r'''The worst thing about new books is, they keep us from reading the old ones.''',
r'''The worst year in the bond market beats the worst day in the stock market.''',
r'''The years wrinkle our skin, but lack of enthusiasm wrinkles our soul.  -- Socrates''',
r'''Them that has, gets.''',
r'''Theory is gray, but the golden tree of life is green.  -- Johann von Goethe''',
r'''There ain't no justice that we can stand to live with.  -- Geis''',
r'''There are 293 ways to make change for a dollar.''',
r'''There are about 550 hairs in the average eyebrow.''',
r'''There are as many realities as you care to imagine.  -- Lawrence Durrell''',
r'''There are but few men who have character enough to lead a life of idleness.''',
r'''There are few sorrows, however poignant, in which a good income is of no avail.''',
r'''There are lots of ways to get wealthy.  Don't constrain yourself.  -- Scott Adams''',
r'''There are more atoms in a glass of water than glasses of water in all oceans.''',
r'''There are more bacteria cells than human cells in a human body.''',
r'''There are more Italians in New York City than in Rome.''',
r'''There are more plastic flamingos in America than real ones.''',
r'''There are more stars in space than grains of sand on every beach on Earth.''',
r'''There are more ways into the woods than out.''',
r'''There are more ways of killing a cat than choking her with cream.''',
r'''There are nights when the wolves are silent and only the moon howls.  -- George Carlin''',
r'''There are no accidents whatsoever in the universe.  -- Ram Dass''',
r'''There are no answers, only cross-references.  -- Weiner''',
r'''There are no menial jobs, only menial attitudes.  -- William Bennett''',
r'''There are no rules around here.  We're trying to accomplish something.  -- Thomas Edison''',
r'''There are no victims in the universe, only creators.  -- Conversations with God''',
r'''There are no victims, only volunteers.  -- Eleanor Roosevelt''',
r'''There are old pilots, and bold pilots, but there are no old bold pilots.''',
r'''There are periods of going out and there are periods of turning back in.  -- Dass''',
r'''There are some things one would rather HAVE DONE than DO.  -- Edward Abbey''',
r'''There are stages in your development where you need a guru.  -- Ram Dass''',
r'''There are three kinds of lies:  Lies, damned lies and statistics.  -- Disraeli''',
r'''There are tough players and nice guys, and I'm a tough player.  -- Bobby Fischer''',
r'''There are two sides to every question.  -- J. Ralph''',
r'''There are two types of pain in life:  Regret, and discipline...  Take your pick.''',
r'''There are wonders enough out there without our inventing any.  -- Carl Sagan''',
r'''There exist tasks that cannot be done by more than 10 people or fewer than 100.''',
r'''There has never been a day in my life when I was not in love.  -- Edward Abbey''',
r'''There is a crack in everything, that's how the light gets in.  -- Leonard Cohen''',
r'''There is a difference between eating and dining.  -- Doug Quarnstrom''',
r'''There is a God-shaped vacuum in every heart.  -- Blaise Pascal''',
r'''There is a great deal of art to creating something that seems artless.  -- Asimov''',
r'''There is a huge gap between advice and help.''',
r'''There is a kind of poetry in simple fact.  -- Edward Abbey''',
r'''There is a lot to be said for not saying a lot.''',
r'''There is a remedy for all things but death.''',
r'''There is a time for all things.''',
r'''There is a time of speaking and a time of being still.  -- William Caxton''',
r'''There is always a wrong way to do something right.  -- Christer Sundqvist''',
r'''There is always an easier way to do it.''',
r'''There is always someone better off than yourself.''',
r'''There is always someone worse off than yourself.''',
r'''There is an immeasurable distance between late and too late.  -- Anne Swetchine''',
r'''There is an X factor in the dynamic of creation when energy becomes matter.''',
r'''There is danger in delaying, good fortune in acting.''',
r'''There is great force hidden in a sweet command.''',
r'''There is hopeful symbolism in... that flags do not wave in a vacuum.  -- Clarke''',
r'''There is more pride in the refusal of an honor than in its acceptance.''',
r'''There is more talk than trouble.  -- Bretnor''',
r'''There is more to life than increasing its speed.  -- Mohandas Gandhi''',
r'''There is more to life than just avoiding death.  -- Jeff Hummel''',
r'''There is never time to do it right, but always time to do it over.''',
r'''There is no battle worth the winning save that against ignorance and fear.''',
r'''There is no better surgeon than one with many scars.''',
r'''There is no bottom to worse.  -- Cohen''',
r'''There is no cure for birth or death save to enjoy the interval.  -- Santayana''',
r'''There is no difference between a wise man and a fool when they fall in love.''',
r'''There is no end to the writing of books, and too much study will wear you out.''',
r'''There is no fear in love; but perfect love casteth out fear.''',
r'''There is no fool to the old fool.  -- John Heywood''',
r'''There is no grief that time does not lessen and soften.''',
r'''There is no heavier burden than a great potential.''',
r'''There is no immaculate conception of disaster.  -- Aneurin Bevan''',
r'''There is no key to the Universe, but it has been left unlocked.  -- Steve Bhaerman''',
r'''There is no law that vulgarity and literary excellence cannot coexist.  -- Hodge''',
r'''There is no love like the first.  -- Howell''',
r'''There is no man really clever who has not found that he is stupid.  -- Chesterson''',
r'''There is no ox so dumb as the orthodox.  -- George Gillette''',
r'''There is no place like home.  -- Dufferin''',
r'''There is no point in being grown up if you can't be childish sometimes. -Dr. Who''',
r'''There is no possibility of conversation with a loudspeaker.  -- James Carse''',
r'''There is no reasoning with a righteous mind.  -- Marcia McConnell Ranch''',
r'''There is no right way to do something wrong.''',
r'''There is no royal road to geometry.  -- Euclid''',
r'''There is no sadder sight than a young pessimist.''',
r'''There is no safety in numbers, or in anything else.  -- James Thurber''',
r'''There is no satisfaction in hanging a man who does not object to it.  -- Shaw''',
r'''There is no science without fancy and no art without facts.  -- Vladimir Nabokov''',
r'''There is no security on this Earth.  There is only opportunity.  -- MacArthur''',
r'''There is no sin except stupidity.  -- Oscar Wilde''',
r'''There is no statute of limitations on stupidity.''',
r'''There is no successful standard that has preceded a successful product.''',
r'''There is no such thing as a context-free message.''',
r'''There is no such thing as a moral or an immoral book.  -- Oscar Wilde''',
r'''There is no such thing as a short-term victory for the environment.  -- Sawhill''',
r'''There is no such thing as pure pleasure; some anxiety always goes with it.''',
r'''There is no trajectory so pathetic as that of an artist in decline.  -- Edward Abbey''',
r'''There is no universal diet suitable for everyone.''',
r'''There is no use in crying over spilled milk.''',
r'''There is no use in having a dog and doing your own barking.''',
r'''There is no virtue that poverty destroys not.''',
r'''There is no way to erase the unwritten law.''',
r'''There is not one word in the Gospels in praise of intelligence.  -- Russell''',
r'''There is nothing in this world constant but inconstancy.  -- Swift''',
r'''There is nothing more restful than taking orders from fools.''',
r'''There is nothing new except what has been forgotten.  -- Marie Antoinette''',
r'''There is nothing new under the sun.  -- Ecclesiastes 1:9''',
r'''There is nothing so easy that it becomes difficult when done with reluctance.''',
r'''There is one good wife in the country, and every man thinks he has her.''',
r'''There is only one way to kill capitalism:  By taxes, taxes, and more taxes.''',
r'''There is only one way to treat a cold, and that is with contempt.  -- Osler''',
r'''There is pain in getting, care in keeping, and grief in losing riches.  -- Draxe''',
r'''There is reason in all things.''',
r'''There is safety in anonymity.  -- Alan Silverstein''',
r'''There is small choice in rotten apples.  -- William Shakespeare''',
r'''There is too much beauty upon this Earth for lonely men to bear.  -- Le Gallienne''',
r'''There is unmanifest and manifest and it's all right here now.  -- Ram Dass''',
r'''There may be many reasons for who we are, but there are no excuses.  -- Limon''',
r'''There never was a good war or a bad peace.  -- Benjamin Franklin''',
r'''There never was a good war or a bad revolution.  -- Edward Abbey''',
r'''There really is a Santa Claus...  If you're willing to accept the job.''',
r'''There seems no plan because it is all plan.  -- C. S. Lewis''',
r'''There will be sleeping enough in the grave.  -- Benjamin Franklin''',
r'''There would be no great ones if there were no little ones.''',
r'''There's a fine line between an attitude problem and thinking clearly.  -- Heller''',
r'''There's a great deal of difference between doing and saying.  -- Torriano''',
r'''There's a point at which "being early" becomes "being wrong."  -- John Waggoner''',
r'''There's a verse in the Bible that says anything you want.''',
r'''There's a whole WORLD in a mud puddle!  -- Doug Clifford''',
r'''There's never a bad time to buy stocks, but there are bad times to sell.''',
r'''There's nothing like matter of fact; seeing is believing.  -- Abruthnot''',
r'''Therefore love moderately; long love does so.  -- William Shakespeare''',
r'''These days the gods deliver their lessons by burning up mountains of money.''',
r'''These little things are great to little men.  -- Oliver Goldsmith''',
r'''They all sweated beneath the same sun; looked up in wonder at the same moon.''',
r'''They also serve who only stand and wait.  -- John Milton''',
r'''They die well that live well.  -- Thomas Draxe''',
r'''They have been at a great feast of languages, and stolen the scraps.''',
r'''They love dancing well that dance among thorns.  -- Camden''',
r'''They love too much that die for love.  -- Cotgrave''',
r'''They must have the defects of their qualities.  -- Balzac''',
r'''They never love us, whom we mistrust.  -- Clarke''',
r'''They talk most who have the least to say.  -- Matthew Prior''',
r'''They that live longest, must die at last.  -- Thomas Draxe''',
r'''They who love most are least set by.  -- Howell''',
r'''They're so heavenly minded that they're no earthly good.''',
r'''Things are not always what they seem.  -- Phaedrus''',
r'''Things determine each other, but man is ultimately self-determining.  -- Frankl''',
r'''Things do not change; we change.  -- Thoreau''',
r'''Things get worse under pressure.''',
r'''Things present are judged by things past.  -- Sanford''',
r'''Think globally; act locally.  -- Rene Dubos''',
r'''Think it through, then follow through.  -- Rickenbacker''',
r'''Think on the end before you begin.''',
r'''Think twice of a good bargain.  -- Edgeworth''',
r'''Thinking is the talking of the soul with itself.  -- Plato''',
r'''Thinking is very far from knowing.  -- Stevens''',
r'''Thinking is wise, planning is better, doing is best.''',
r'''This is the beginning of the end.  -- Talleyrand''',
r'''This is to be taken with a grain of salt.  -- Trapp''',
r'''This nuclear arms race...  [will only] make the rubble bounce.  -- Churchill''',
r'''This sentence contradicts itself -- no actually it doesn't.  -- Hofstadter''',
r'''This sentence does not have the property it claims not to have.  -- Boeninger''',
r'''This statement is unprovable.  -- Goedel''',
r'''This was the most unkindest cut of all.  -- William Shakespeare''',
r'''This world might be only illusion -- but it's the only illusion we've got.''',
r'''Those making the worst use of their time are first to complain of its brevity.''',
r'''Those sensible enough to give good advice are sensible enough to give none.''',
r'''Those that make the best use of their time have none to spare.  -- Fuller''',
r'''Those were the days when men were men and giants walked the earth.''',
r'''Those who are not busy being born are busy dying.''',
r'''Those who become wise are happy; wisdom will give them life.  -- Solomon''',
r'''Those who can make you believe absurdities can make you commit atrocities.  -- Voltaire''',
r'''Those who cannot change their minds cannot change anything.  -- George Shaw''',
r'''Those who cannot forget the past are condemned to remember it.  -- Goodman Ace''',
r'''Those who desire eternal life, live badly.  -- Pubililius Syrus''',
r'''Those who do not know how to fight worry die young.  -- Dale Carnegie''',
r'''Those who do the most usually demand the least.''',
r'''Those who fear death most are those who enjoy life least.  -- Edward Abbey''',
r'''Those who follow the crowd will never be followed by a crowd.  -- John Maxwell''',
r'''Those who in quarrels interpose, must often wipe a bloody nose.''',
r'''Those who learn nothing from history are doomed to repeat it.  -- Santayana''',
r'''Those who live by the sword, die by the sword.''',
r'''Those who stand in the middle of the road get hit by traffic going both ways.''',
r'''Those who talk don't know.  Those who don't talk, know.''',
r'''Those who work much do not work hard.  -- Henry Thoreau''',
r'''Those who worked the hardest are the last to surrender.  -- Gary Ward''',
r'''Thou didst create the night, but I made the lamp.  -- unknown Urdu Poet''',
r'''Thou has not half the power to do me harm, as I have to be hurt.''',
r'''Thou hast seen nothing yet.  -- Miguel de Cervantes''',
r'''Though I walk through the valley of the shadow of death, I will fear no evil.''',
r'''Though the fox run, the chicken has wings.  -- George Herbert''',
r'''Thought is free.  -- Gower''',
r'''Three hours a day will produce as much as a man ought to write.  -- Trollope''',
r'''Three thermodynamics laws:  You can't win, break even, or get out of the game.''',
r'''Throw it away?  There is no away.''',
r'''Time ain't money when all you got is time.''',
r'''Time and tide wait for no man.''',
r'''Time and truth try all.  -- Porter''',
r'''Time as he grows old teaches all things.  -- Aeschylus''',
r'''Time consumes all things.''',
r'''Time flies when you're having fun.''',
r'''Time goes, you say?  Ah no!  Time stays, WE go.  -- Austin Dobson''',
r'''Time in the market beats timing the market.''',
r'''Time is a flexible and renewable resource.''',
r'''Time is but the stream I go a-fishing in.  -- Henry Thoreau''',
r'''Time is money.''',
r'''Time is often said to be money, but it is more:  It is life.  -- Avebury''',
r'''Time is the best healer, when it isn't a killer.  -- D H Lawrence''',
r'''Time is the best healer.''',
r'''Time is the father of truth.''',
r'''Time is the most valuable thing a man can spend.  -- Theophrastus''',
r'''Time is the rider that breaks youth.  -- George Herbert''',
r'''Time is very dangerous without a rigid routine.  -- Flannery O'Connor''',
r'''Time is, time was, and time is past.  -- Greene''',
r'''Time reveals all things.  -- Erasmus''',
r'''Time stays not the fool's leisure.  -- Cotgrave''',
r'''Time tries truth.''',
r'''Time undermines us.  -- George Herbert''',
r'''Time will not tell.  -- Steve Hug''',
r'''Time works wonders.''',
r'''Time wounds all heels.  -- Jane Ace''',
r'''Timely blossom, timely ripe.  -- Clarke''',
r'''Times change and we with them.''',
r'''To acquire knowledge, one must study; but to acquire wisdom, one must observe.''',
r'''To an artist, a metaphor is as real as a dollar.  -- Tom Robbins''',
r'''To ask is not a crime.  To be rejected is not a calamity.  -- Chinese proverb''',
r'''To avoid criticism, do nothing, say nothing, be nothing.  -- Aristotle''',
r'''To avoid earthquakes, when you find a fault, just don't dwell on it.  -- Bhaerman''',
r'''To avoid sickness, eat less.  To prolong life, worry less.  -- Chu Hui Weng''',
r'''To be a fool at the right time is also an art.''',
r'''To be adult is to be alone.  -- Jean Rostland''',
r'''To be alive at all involves some risk.  -- Harold MacMillan''',
r'''To be at home everywhere is to neutralize space.  -- James Carse''',
r'''To be beloved is above all bargains.  -- George Herbert''',
r'''To be great is to be misunderstood.  -- Ralph Emerson''',
r'''To be ignorant of one's ignorance is the malady of the ignorant.  -- Alcott''',
r'''To be intoxicated is to feel sophisticated but not be able to say it.''',
r'''To be is to be related.  -- C. J. Keyser''',
r'''To be miserable you must have leisure to wonder if you are happy or not.  -- Shaw''',
r'''To be powerful is to have one's words obeyed.  -- James Carse''',
r'''To be remembered, write things worth reading or do things worth writing.''',
r'''To be wise, the only thing you need to know is when to say "I don't know."''',
r'''To be, never try to seem.''',
r'''To become outstanding, one must be an outsider.  -- Gerhard Uhlenbruck''',
r'''To climb the ladder of success you must get through the crowd at the bottom.''',
r'''To communicate is the beginning of understanding.  -- AT&T''',
r'''To conquer fear is the beginning of wisdom.  -- Bertrand Russell''',
r'''To conquer without risk is to triumph without glory.  -- El Cid''',
r'''To convince someone they are wrong, let them have their way.''',
r'''To criticize the incompetent is easy; to criticize the competent is harder.''',
r'''To defend the Saigon regime is not worth one more human life.  -- Senator Muskie''',
r'''To deny the Constitution is to provoke revolution.''',
r'''To die tomorrow is no worse than dying on any other day.  -- Paulo Coelho''',
r'''To do nothing is in every man's power.''',
r'''To do the impossible, you must see the invisible.  -- Murdock''',
r'''To do two things at once is to do neither.  -- Publilius Syrus''',
r'''To double your joy, divide it with someone.''',
r'''To double your misery, divide it with your neighbor.  -- Christer Sundqvist''',
r'''To endure what is unendurable is true endurance.  -- Japanese proverb''',
r'''To every rule there is a exception, and vice versa.''',
r'''To experience the elements, you must get out of the vehicle.''',
r'''To extend your limits, you must push them...  And it often hurts.''',
r'''To feel absolutely right is the beginning of the end.  -- Albert Camus''',
r'''To fight your karma is just as frustrating as to accept your karma. -- Deepak Chopra''',
r'''To follow another is evil; it does not matter who it is.  -- Krishnamurti''',
r'''To fright a bird is not the way to catch it.''',
r'''To get back one's youth, one has merely to repeat one's follies.  -- Oscar Wilde''',
r'''To give happiness is to deserve happiness.''',
r'''To have a crisis is one thing.  To dwell in perpetual crisis is another.''',
r'''To have died once is enough.''',
r'''To have knowledge, you must first have reverence for the Lord.  -- Solomon''',
r'''To him that has lost his taste, sweet is sour.''',
r'''To him who is in fear, everything rustles.  -- Sophocles''',
r'''To improve averages, focus on the worst.  -- Tomoo Matsubara''',
r'''To improve people's behaviors, change their pictures of their roles.  -- Covey''',
r'''To invent, you need a good imagination and a pile of junk.  -- Thomas Edison''',
r'''To invoke randomness is to plead ignorance.  -- Nassim Taleb''',
r'''To keep your friends, treat them kindly; to kill them, treat them often.''',
r'''To keep your life simple, keep your needs simple.''',
r'''To laugh at men of sense is the privilege of fools.''',
r'''To lead people, you must follow behind.  -- Lao Tsu''',
r'''To light a candle is to cast a shadow.''',
r'''To live dishonestly costs you biologically.  -- Carolyn Myss''',
r'''To live is to suffer; to survive is to find meaning in the suffering.  -- Allport''',
r'''To live off a garden you practically must live in it.''',
r'''To look at a painting, many things are needed, and the first of them is a chair.''',
r'''To love is to admire with the heart; to admire is to love with the mind.''',
r'''To love is wise; to hate is foolish.  -- Bertrand Russell''',
r'''To love oneself is the beginning of a life-long romance.  -- Oscar Wilde''',
r'''To make an apple pie from scratch, you must first create the universe.  -- Carl Sagan''',
r'''To make something dirt cheap, make it out of dirt.  -- Donald Sadoway''',
r'''To many, total abstinence is easier than perfect moderation.  -- St. Augustine''',
r'''To me, faith is not just a noun but also a verb.  -- President Jimmy Carter''',
r'''To Mother Nature, you are just self-propelled carrion.  -- Kenneth Rowberry''',
r'''To profit from good advice requires as much wisdom as to give it.''',
r'''To promise and give nothing is comfort to a fool.  -- Thomas Draxe''',
r'''To realize one's destiny is a person's only real obligation.  -- Paulo Coelho''',
r'''To refuse praise is to seek praise twice.''',
r'''To regret nothing is the beginning of wisdom.''',
r'''To remember is to take the body time-traveling.  -- Deepak Chopra''',
r'''To retain those who are present, be loyal to those who are absent.  -- Covey''',
r'''To save a single life is better than to build a seven story pagoda.''',
r'''To see a need and wait to be asked, is to already refuse.''',
r'''To see God clearly, all illusion must fail you.  -- Carolyn Myss''',
r'''To stay youthful, stay useful.''',
r'''To strive, to seek, and not to yield.  -- Alfred Lord Tennyson''',
r'''To succeed one must have access to success.  -- Gerhard Uhlenbruck''',
r'''To teach is to learn twice.  -- Joseph Joubert''',
r'''To the landlords belong the doorknobs.''',
r'''To the man with an empty stomach, food is God.  -- Mohandas Gandhi''',
r'''To them it is us who are the enemy.  -- N. F. Simpson''',
r'''To thine own self be true.''',
r'''To those who fought for it, freedom has a flavor the protected will never know.''',
r'''To transform the world, we must begin with ourselves.  -- Krishnamurti''',
r'''To travel hopefully is better than to arrive safely.  -- Robert Stevenson''',
r'''To use the machine for control is to be controlled by the machine.  -- Carse''',
r'''To use violence is to already be defeated.  -- Chinese proverb''',
r'''To your employer, are you profit or overhead?''',
r'''Today is the first day of the rest of your life.  -- Birgitta Yavari''',
r'''Today is the scholar of yesterday.''',
r'''Today is what yesterday made it.''',
r'''Tolerance requires intolerance of those who preach intolerance.  -- Danny Low''',
r'''Tomorrow never comes.''',
r'''Tomorrow, you can be anywhere.''',
r'''Too bad ignorance isn't painful.''',
r'''Too busy to laugh?  Then you are too busy.''',
r'''Too clever is dumb.  -- Ogden Nash''',
r'''Too far east is west.''',
r'''Too many cooks spoil the broth.  -- Kingsley''',
r'''Too much liberty spoils all.''',
r'''Too much money makes one mad.  -- Howell''',
r'''Too much of one thing is not good.''',
r'''Too much of ought is good for nought.''',
r'''Tradition does not mean to guard the ashes, but to keep the flame burning.''',
r'''Tragedy is a joke we haven't figured out yet.  -- Garrison Keillor''',
r'''Tragedy is learning the wrong thing from a fiasco.''',
r'''Train yourself to spot the difference between the sensational and the empirical.  -- Nassim Taleb''',
r'''Travelers change climates, not conditions.''',
r'''Treat wisdom as your sister, and insight as your closest friend.  -- Solomon''',
r'''Treat your friend as if he might become an enemy.  -- Publilius Syrus''',
r'''Trees must be distinguished from the forest -- even if there is but one tree.''',
r'''Tribal permission lets you not take responsibility for where your energy goes.''',
r'''Trouble brings experience and experience brings wisdom.''',
r'''Troubles are like babies; they only grow by nursing.''',
r'''True greatness is rarely achieved without collateral damage.  -- James Tabor''',
r'''True happiness will be found only in true love.''',
r'''True science teaches us to doubt and, in ignorance, to refrain.  -- Bernard''',
r'''True storytellers do not know their own story.  -- James Carse''',
r'''True success is the experience of the miraculous.  -- Deepak Chopra''',
r'''True wealth is free time:  Freedom from drudgery and unwanted commitments.  -- Daniel Newman''',
r'''Truly simple systems... require infinite testing.  -- Norman Augustine''',
r'''Trust everyone...  Then cut the cards.''',
r'''Trust in Allah, but tie your camel.  -- Arabian proverb''',
r'''Trust not a new friend nor an old enemy.''',
r'''Truth emerges more readily from error than from confusion.  -- Francis Bacon''',
r'''Truth fears no trial.''',
r'''Truth is a matching grant.  -- Carolyn Myss''',
r'''Truth is hard to find and even harder to obscure.''',
r'''Truth is just truth.  You can't have opinions about truth.  -- P. Shickele''',
r'''Truth is only believed when someone has invented it well.  -- George Santayana''',
r'''Truth is stranger than fiction.''',
r'''Truth is the highest form of human motivation.  -- Stephen Covey''',
r'''Truth may be lost in a crowd.  -- Wilson''',
r'''Truth might be blamed, but cannot be shamed.''',
r'''Truth will come to light.  -- William Shakespeare''',
r'''Truth's best ornament is nakedness.  -- Fuller''',
r'''Truth, in matters of religion, is simply the opinion that has survived.  -- Oscar Wilde''',
r'''Truths and roses have thorns about them.  -- Mapletoft''',
r'''Truths too fine spun are subtle fooleries.  -- Mapletoft''',
r'''Try always all ways.  -- Gerhard Uhlenbruck''',
r'''Try not to become a man of success but rather a man of value.  -- Albert Einstein''',
r'''Try not.  Do.  Or do not.  There is no try.  -- est''',
r'''Try to forget everything.  What you can't forget -- that's what you learned.''',
r'''Try to have a rational conversation with someone who's in love.''',
r'''Try to imagine what life would be like without bureaucracy.''',
r'''Try to relax and enjoy the crisis.  -- Ashleigh Brilliant''',
r'''Trying to define yourself is like trying to bite your own teeth.  -- Alan Watts''',
r'''Trying to have too much fun is self-defeating.''',
r'''Trying to squash a rumor is like trying to unring a bell.  -- Shana Alexander''',
r'''Turn enemies into friends by doing something nice for them.  -- H. Jackson Brown''',
r'''TV is chewing gum for the eyes.  -- Frank Lloyd Wright''',
r'''Twelve significant photographs in any one year is a good crop.  -- Ansel Adams''',
r'''Two captains will sink the ship.''',
r'''Two eyes can see more than one.''',
r'''Two feet on the ground are worth one in the mouth.''',
r'''Two fools in one house are too many.''',
r'''Two heads are better than one.''',
r'''Two is company, three's a crowd.  -- Leng-Tzu''',
r'''Two marks of a holy person:  Giving, and forgiving.''',
r'''Two mediocre ideas do not add up to one great idea.''',
r'''Two men look out through the same bars; one sees mud, and one the stars.''',
r'''Two of a trade seldom agree.''',
r'''Two things do prolong your life:  A quiet heart and a loving wife.  -- Deloney''',
r'''Two wrongs don't make a right.''',
r'''Ultimately, everything becomes food.  -- John Taylor''',
r'''Unconditional love means the capacity to not have private agendas.  -- Carolyn Myss''',
r'''Uncontrolled anger is an athlete's worst enemy.  -- Reggie Rivers''',
r'''Under a dictatorship, everything that is not forbidden is obligatory.''',
r'''Under every stone sleeps a scorpion.  -- Taverner''',
r'''Unhappy the land that is in need of heroes.  -- Bertolt Brecht''',
r'''Unless women share sexual risk taking, they cause their own objectification.''',
r'''Unrepeatability is a characteristic of culture everywhere.  -- James Carse''',
r'''Use it or lose it.''',
r'''Use makes mastery.  -- Taverner''',
r'''Use the mind to obtain wisdom, not the power to control.  -- Carolyn Myss''',
r'''Use the simplest solution that suffices.''',
r'''Using drugs is an attempt to make up for the good times that one hasn't had.''',
r'''Values and beliefs make perfect sense to the people who hold them.''',
r'''Values are caught, not taught.  -- Dobson''',
r'''Variety is the spice of life, but monotony buys the groceries.''',
r'''Variety is the spice of life.  -- Confucius''',
r'''Veni, vidi, vici.  (I came, I saw, I conquered.)  -- Julius Caesar''',
r'''Veni, Vidi, Visa.  (I came, I saw, I bought.)''',
r'''Vests are to suits as seat-belts are to cars.''',
r'''Victims see what is; survivalists see what can be.  -- Len McDougall''',
r'''Victory lies not in sleep's defeat.  -- John Taylor''',
r'''Vincit qui patitur:  He conquers, who endures.  -- Percy Cerutty''',
r'''Violence is the last refuge of the incompetent.  -- Salvador Hardin''',
r'''Virtue is its own revenge.  -- E. Y. Harburg''',
r'''Virtue is its own reward.  -- John Dryden''',
r'''Virtue is not hereditary.  -- Thomas Paine''',
r'''Virtue is not left to stand alone.  He who practices it will have neighbors.''',
r'''Virtue is the beauty of the mind.''',
r'''Virtue is the only true nobility.''',
r'''Virtue never grows old.''',
r'''Volumes might be written upon the impiety of the pious.  -- Herbert Spencer''',
r'''Wait for that wisest of all counselors, Time.  -- Pericles''',
r'''Wake not a sleeping wolf.  -- William Shakespeare''',
r'''Wake up each day saying "Good morning, God", not "Good God, morning!"''',
r'''Walk softly and carry a big stick.''',
r'''Walls have ears.  -- Shelton''',
r'''Want to forget all your troubles?  Wear tight shoes.''',
r'''War hath no fury like a non-combatant.  -- Charles Montague''',
r'''War is an equal opportunity destroyer.''',
r'''War is death's feast.''',
r'''War is much too important a matter to be left to the generals.  -- Clemenceau''',
r'''War is soon begun, but not so quickly brought to an end.''',
r'''War is terrorism with a bigger budget.''',
r'''War is the last refuge of incompetent statesmen.''',
r'''War is the real enemy.''',
r'''War makes thieves, and peace hangs them.''',
r'''War spares not the brave, but the cowardly.  -- Anacreon''',
r'''War, hunting, and love, are as full of trouble as pleasure.  -- Buckminster Fuller''',
r'''Warning:  Humor may be hazardous to your illness.  -- Ellie Katz''',
r'''Wars bring scars.  -- Clarke''',
r'''Waste is the antiproperty that becomes the possession of losers.  -- James Carse''',
r'''Waste not fresh tears over old griefs.  -- Euripides''',
r'''Wasting time is an important part of life.  -- Ashleigh Brilliant''',
r'''We all do murder the things we love, mostly by the word unsaid.  -- William Etkin''',
r'''We all have a story to live.  What story are you living?  -- Greg Rose''',
r'''We all have style, but few have class.''',
r'''We all know what you mean; it's just that you mean it so poorly.  -- John Taylor''',
r'''We all like our relatives when we're little.  -- Kin Hubbard''',
r'''We all live in a state of ambitious poverty.  -- Decimus Junius Juvenalis''',
r'''We all live under the same sky, but we don't all have the same horizon.''',
r'''We are all born mad.  Some remain so.  -- Samuel Beckett''',
r'''We are all directly above the center of the earth.''',
r'''We are all in the gutter, but some of us are looking at the stars.  -- Wilde''',
r'''We are all in the same boat, shooting holes in the hull.  -- David Grinspoon''',
r'''We are all in this alone.  -- Lily Tomlin''',
r'''We are all ONE, say the gurus.  Aye, I might agree -- but one WHAT?  -- Edward Abbey''',
r'''We are all volunteers.  -- Pat Czarnik''',
r'''We are all worms.  But I do believe I am a glowworm.  -- Winston Churchill''',
r'''We are always looking, or should be, for what really inspires us.  -- Peter Tyson''',
r'''We are an impossibility in an impossible universe.  -- Ray Bradbury''',
r'''We are anthill men upon an anthill world.  -- Ray Bradbury''',
r'''We ARE as gods and might as well get good at it.  -- Whole Earth Catalog''',
r'''We are as organized energetically as we are physically.  -- Carolyn Myss''',
r'''We are becoming a nation of private opulence and public squalor.''',
r'''We are being educated when we know it least.  -- David Gardner''',
r'''We are born dying.  -- Caleb Finch (scientist)''',
r'''We are confronted with insurmountable opportunities.  -- Walt Kelly''',
r'''We are divinity in disguise.  -- Deepak Chopra''',
r'''We are drowning in information.  -- EO Wilson''',
r'''We are each our own devil, and we make this world our hell.  -- Oscar Wilde''',
r'''We are going to have peace even if we have to fight for it.  -- Dwight Eisenhower''',
r'''We are here on earth to fart around; don't let anybody tell you any different.''',
r'''We are here to let go of that which we are not.''',
r'''We are how the universe I's itself.  -- Alan Watts''',
r'''We are in fact mystics without monasteries.  -- Carolyn Myss''',
r'''We are known by the company we keep.''',
r'''We are loved in spite of what we are.  -- Victor Hugo''',
r'''We are not alone.''',
r'''We are not here for a long time.  We are here for a good time.''',
r'''We are not humans on a spiritual path, rather we are spirits on a human path.''',
r'''We are not meant to mourn our traumas for more than a short time.  -- Carolyn Myss''',
r'''We are not punished for our sins, but by them.''',
r'''We are not victims of the world we see, but of the way we see the world.''',
r'''We are old enough to be wiser.  -- John Wesley''',
r'''We are only now beginning to recognize we need to learn to love unconditionally.''',
r'''We are seeing the empowerment of the individual to conduct war.  -- John Robb''',
r'''We are social animals; hell is other people.  -- Nassim Taleb''',
r'''We are the sum of all the lives we once lived.''',
r'''We are what we pretend to be.  -- Kurt Vonnegut Jr.''',
r'''We are who we are in relating to others.  -- James Carse''',
r'''We avoid attributing cleverness to someone else -- unless it is an enemy.''',
r'''We become what we do.''',
r'''We can embody the truth, but we cannot know it.  -- Yates''',
r'''We can lick gravity, but sometimes the paperwork is overwhelming.  -- Von Braun''',
r'''We can live without our friends, but not without our neighbors.  -- James Kelly''',
r'''We can only hate in others what we first hate in ourselves.  -- John Taylor''',
r'''We can only pay our debt to the past by putting the future in debt to ourselves.''',
r'''We can only write well of that which we know.  -- John Taylor''',
r'''We can't break the real spiritual laws.  -- Lee Coit''',
r'''We can't change, but we can expand.  -- Nelson''',
r'''We cannot do everything at once, but we can do something at once.  -- Coolidge''',
r'''We come too late to say anything which has not been said already.  -- Bruyere''',
r'''We define genius as constructive reaction against one's training.  -- Berenson''',
r'''We do not count a man's years, until he has nothing else to count.  -- Emerson''',
r'''We do not remember days; we remember moments.''',
r'''We do not spontaneously learn that we don't learn that we don't learn.  -- Nassim Taleb''',
r'''We don't call it sin today, we call it self-expression.  -- Baroness Stocks''',
r'''We don't even understand in the West what it means to train consciousness.''',
r'''We don't get perspective on what's close to us until we spend time away from it.  -- Mark Manson''',
r'''We don't know a millionth of one percent about anything.  -- Thomas Edison''',
r'''We don't know how to give gifts of energy -- we still give gifts of matter.''',
r'''We don't know who discovered water, but we're certain it wasn't a fish.  -- Barlow''',
r'''We don't recognize the significant events in our lives while they're happening.''',
r'''We don't stop hiking because we grow old, we grow old because we stop hiking.''',
r'''We don't want God to be a wild force.  -- Carolyn Myss''',
r'''We dwell at the bottom of the sky.''',
r'''We expect others to act rationally even though we are irrational.  -- Scott Adams''',
r'''We get too soon old and too late smart.''',
r'''We give advice, but we cannot give the wisdom to profit by it.  -- Rochefoucauld''',
r'''We have all the land now we will ever have.  -- Orville Freeman''',
r'''We have art that we do not die of the truth.  -- Friedrich Nietzsche''',
r'''We have global influence but lack global control.  -- David Grinspoon''',
r'''We have lingered long enough on the shores of the Cosmic Ocean.  -- Carl Sagan''',
r'''We have met the enemy, and he is us.  -- Walt Kelly''',
r'''We have nothing to fear but our own inertia.  -- Rich Lamb''',
r'''We have nowhere else to go...  This is all we have.  -- Margaret Mead''',
r'''We have to walk as slow as our slowest person to keep society f*ing moving.  -- Jim Jeffries''',
r'''We laugh at death because we know death will have the last laugh on us.  -- Lou Grant (Mary Tyler Moore show)''',
r'''We live in a global village but it is filled with neighbors from hell.  -- Low''',
r'''We love others the way we would like them to love us.''',
r'''We make a living by what we get, but we make a life by what we give.  -- Churchill''',
r'''We may love a place and still be dangerous to it.  -- Wallace Stegner''',
r'''We may make our plans, but God has the last word.  -- Solomon''',
r'''We might be alone.  We might not be alone.  Either way the idea is staggering.''',
r'''We must choose:  The stars or the dust.  Which shall it be?''',
r'''We must make up our minds to be ignorant of much, if we would know anything.''',
r'''We need less emotion and more thought.  -- Richard Dawkins''',
r'''We need to look at multiple lives to test and shape our own.  -- Mary Bateson''',
r'''We never find out anything new, we just remember it.  -- Ram Dass''',
r'''We not only live in a cage, we build the cage, and live in a corner of it.''',
r'''We ought not to permit a cottage industry in the God business.  -- John Marchi''',
r'''We owe it to ourselves to question everything.''',
r'''We prefer to speak evil of ourselves rather than not speak of ourselves at all.''',
r'''We promise according to our hopes, and perform according to our fears.''',
r'''We promise more in a day than we can fulfill in a year.''',
r'''We promise what we want, but deliver what we got before.''',
r'''We really want to save the wilderness because the wilderness really saves us.  -- Brooke Williams''',
r'''We reclaim what we love by being activists on its behalf.  -- Marc Salkin''',
r'''We remember our dreams; we do not remember our sleep.  -- Marguerite Yourgenar''',
r'''We secure our friends not by accepting favors but by doing them.  -- Thucydides''',
r'''We see only what we know.  -- Johann von Goethe''',
r'''We see things not as they are, but as we are.''',
r'''We seldom repent talking too little, but very often talking too much.  -- Bruyere''',
r'''We set up relationships initially on the basis of false advertising.  -- Coit''',
r'''We should learn from our mistakes, but how... unless we first admit we made any?  -- Tavris and Aronson''',
r'''We take issue even with perfection.  -- Pascal''',
r'''We take on the strength of that which we overcome.''',
r'''We take photos as a return ticket to a moment otherwise gone.  -- Katie Thurmes''',
r'''We teach others how to treat us.  -- Wayne Dyer''',
r'''We that are young shall never see so much nor live so long.  -- William Shakespeare''',
r'''We think that if we can label a thing we have understood it.  -- Sangharakshita''',
r'''We use machines against ourselves...  And machinery against itself.  -- Carse''',
r'''We usually get what we order from life.  -- Limon''',
r'''We want God to be a mental, logical force because that feels so controllable.''',
r'''We will be asked to do something we can't tolerate just to develop endurance.''',
r'''We win some, we lose some, and some get rained out.''',
r'''We would like to train for wisdom, not knowledge.  -- Ram Dass''',
r'''We would rather be ruined by praise than saved by criticism.  -- Norman Peale''',
r'''We're motivated to seek rewards; this urge exceeds our pleasure in getting them.''',
r'''We, all of us, have a vested interest in keeping the game going.  -- God?''',
r'''Wealth comes from excellence, and not excellence from wealth.  -- Plato''',
r'''Wealth goes to wealth.  -- Torriano''',
r'''Wealth is not so much possessed as it is performed.  -- James Carse''',
r'''Wealth protects the rich; poverty destroys the poor.  -- Solomon''',
r'''Wealthy is having the freedom to maximize one's life experiences.  -- Mark Manson''',
r'''Weapon:  An index of the lack of development of a culture.''',
r'''Welcome to the Future!  It's just starting now ...''',
r'''Well begun is half done.  -- Aristotle''',
r'''Well done is better than well said.''',
r'''Well, one must get an idea someplace.  -- Stephen Hawking''',
r'''Were Heaven preferable to Earth, suicide would be a sacrament.  -- William Wall''',
r'''What a joy it is to find just the right word for the right occasion!  -- Solomon''',
r'''What a strange game.  The only winning move is not to play.  -- WOPR (War Games)''',
r'''What are we doing?  Nothing.  -- Ram Dass''',
r'''What avail are forty freedoms without a blank spot on the map?  -- Leopold''',
r'''What awful irony is this?  We are as gods, but know it not.''',
r'''What can be asserted without evidence can be dismissed without evidence.  -- Christopher Hitchens''',
r'''What cannot be cured must be endured.''',
r'''What changes can you personally make to get the results you want?''',
r'''What color is a chameleon on a mirror?''',
r'''What confounds a society is not serious opposition, but lack of seriousness.''',
r'''What consciousness means is being aware of where your energy goes.  -- Carolyn Myss''',
r'''What convinces is conviction.  -- Lyndon Johnson''',
r'''What could we do together that we would both really enjoy doing?  -- Lee Coit''',
r'''What do you care what other people think?  -- Richard Feynmann''',
r'''What do you mean, it's too late?  We're not dead yet!  -- Shampoo (the movie)''',
r'''What does "done" look like?''',
r'''What does it all mean?''',
r'''What does not destroy me, makes me stronger.  -- Friedrich Nietzsche''',
r'''What excuses stand in your way?  How can you eliminate them?  -- Roger von Oech''',
r'''What fools these mortals be.  -- Lucius Seneca''',
r'''What garlic is to salad, insanity is to art.''',
r'''What good is progress if it is unevenly distributed?''',
r'''What got you here won't get you there.  -- Marshall Goldsmith''',
r'''What happens to your fist when you open your hand?  -- Zen proverb''',
r'''What I aspired to be, and was not, comforts me.  -- Robert Browning''',
r'''What I ought to do, I can; if I can, why don't I?''',
r'''What I tell you three times is true.  -- Robert Heinlein''',
r'''What is a "free gift"?  Aren't all gifts free?''',
r'''What is a magician but a practicing theorist?  -- Obi-Wan Kenobi''',
r'''What is beautiful is good and who is good will soon also be beautiful.  -- Sappho''',
r'''What is chaos but matter disturbed by immaterial forces?  -- Herbert Read''',
r'''What is done to children, they will do to society.''',
r'''What is food to one, is to others bitter poison.  -- Titus Lucretius Carus''',
r'''What is history but a fable agreed upon?  -- Napoleon Bonaparte''',
r'''What is life without a character?  -- Trusler''',
r'''What is new is not true and what is true is not new.''',
r'''What is obvious to you is not obvious to others...  And vice versa.''',
r'''What is the blessing here?  -- Vikki Coit''',
r'''What is the sound of one hand clapping?  -- Zen proverb''',
r'''What is the vector that is orthogonal to itself?''',
r'''What love means is that we are sharing a common state together.  -- Ram Dass''',
r'''What matters is not how often you are right, but... your cumulative errors.  -- Nassim Taleb''',
r'''What must be, must be.  -- John Wesley''',
r'''What on earth would a man do with himself if something did not stand in his way?''',
r'''What one believes to be true either is true or becomes true.  -- John Lilly''',
r'''What one can conceive and believe one can achieve.''',
r'''What part of my Self do I wish to experience now in the face of this calamity?''',
r'''What really changes your life is the passionate pursuit of something you love.''',
r'''What really matters is not the choice you make but your attitude about it.''',
r'''What separates the flyers from the walkers is the ability to take off.  -- Carl Sagan''',
r'''What sin has not been committed in the name of efficiency?''',
r'''What soon grows old?  Gratitude.  -- Aristotle''',
r'''What the fool does in the end, the wise man does at the beginning.''',
r'''What the government gives it must first take away.  -- Dan Quayle''',
r'''What the scientists have in their briefcases is terrifying.  -- Nikita Khruschev''',
r'''What the world really needs is more love and less paperwork.  -- Pearl Bailey''',
r'''What this country needs is more free speech worth listening to.  -- Hansel Duckett''',
r'''What tribal rules are you plugged into?  -- Carolyn Myss''',
r'''What we do not understand we do not possess.  -- Johann von Goethe''',
r'''What we first learn, we best can.  -- James Kelly''',
r'''What we know about the human possibility is so absurdly trivial thus far.''',
r'''What we obtain too cheap, we esteem too lightly.  -- Thomas Paine''',
r'''What we resist, persists.''',
r'''What we see depends on mainly what we look for.  -- John Lubbock''',
r'''What will you do when the new wears off and the old shines through?''',
r'''What would you attempt to do if you knew you could not fail?  -- Schuller''',
r'''What you are, not what you have, is what makes you rich.''',
r'''What you do in the time of your greatest trial can be your greatest triumph.''',
r'''What you do speaks so loudly that I cannot hear what you say.  -- Ralph Emerson''',
r'''What you don't know can hurt you, but you won't know it.''',
r'''What you don't know won't help you much either.  -- Bennett''',
r'''What you enjoy is much more important than what you have.''',
r'''What you expect in relationships with others you must first find in yourself.''',
r'''What you have caused, you can change.  -- Limon''',
r'''What you leave alone today will come back to haunt you tomorrow.  -- Confucius''',
r'''What you see but can't see over is as good as infinite.  -- Thomas Carlyle''',
r'''Whatever begins in freedom cannot end in necessity.  -- James Carse''',
r'''Whatever else you get, get insight.  -- Solomon''',
r'''Whatever has been well said by anyone is my property.  -- Seneca''',
r'''Whatever is funny is subversive.  -- George Orwell''',
r'''Whatever it is, I fear Greeks even when they bring gifts.  -- Virgil''',
r'''Whatever man has done, man may do.  -- C. Reade''',
r'''Whatever occurs from love is always beyond good and evil.  -- Friedrich Nietzsche''',
r'''Whatever the game is, play it as a professional.  -- Peter Medawar''',
r'''Whatever you can do, or dream you can, begin it.  -- Johann von Goethe''',
r'''Whatever you do will be insignificant, but it is very important that you do it.''',
r'''Whatever you want to do, do it now.  There are only so many tomorrows.  -- Landon''',
r'''Whatsoever was the father of a disease, an ill diet was the mother.  -- Herbert''',
r'''When a couple starts keeping score, there is no winning, just degrees of losing.''',
r'''When a man says money can't do anything, that settles it:  He hasn't any.  -- Howe''',
r'''When a man's house is on fire, it's time to break off chess.  -- James Fuller''',
r'''When a paradigm shifts, everyone goes back to zero.  -- Joel Barker''',
r'''When a thing is done advice comes too late.  -- G. Delamothe''',
r'''When all men speak, no man hears.  -- James Kelly''',
r'''When all think alike, then no one is listening.  -- Walter Lippman''',
r'''When among apes, one must play the ape.''',
r'''When an experience comes along, you just note it and just let it go.  -- Ram Dass''',
r'''When an expert stops learning, he is no longer an expert.''',
r'''When angry count ten before you speak.  If very angry a hundred.  -- Jefferson''',
r'''When children stand quiet they have done some ill.  -- George Herbert''',
r'''When cutting down trees, remember to pause now and then to sharpen your axe.''',
r'''When does later become never?''',
r'''When elephants fight, the grass loses.''',
r'''When everyone agrees with me, I know I am wrong.''',
r'''When faith and hope fail try charity; it is love in action.''',
r'''When fortune knocks, be sure to open the door.  -- Boyer''',
r'''When fortune smiles, embrace her.''',
r'''When God is invoked by the state, it's all too easy for the state to become God.''',
r'''When guns are outlawed, only outlaws will have guns.  -- Art Denman''',
r'''When I get angry...  I've made some kind of a law that's not true.  -- Vikki Coit''',
r'''When I know who I am, you and I are one.  -- Hanuman''',
r'''When I rest, I rust.  -- Fritz Thyssen''',
r'''When ideas fail, words come in very handy.  -- Johann von Goethe''',
r'''When in doubt, do as doubters do.  -- John Taylor''',
r'''When in doubt, follow your heart.''',
r'''When in doubt, leave out the adjective.''',
r'''When in doubt, take all the defaults.''',
r'''When injustice becomes law, resistance becomes duty.  -- Thomas Jefferson''',
r'''When it is dark enough you can see the stars.  -- Ralph Emerson''',
r'''When leaders act contrary to conscience, we must act contrary to leaders.''',
r'''When love and skill work together, expect a masterpiece.  -- John Ruskin''',
r'''When money talks there are few interruptions.''',
r'''When people are free to do as they please, they usually imitate each other.''',
r'''When people are least sure, they are most dogmatic.  -- John Galbraith''',
r'''When people are stressed, common sense goes out the window.  -- Brian Seaward''',
r'''When people share their fears with you, share your courage back.''',
r'''When pleasure remains, does it remain a pleasure?''',
r'''When pointing out another's mistake, always consider their feelings.''',
r'''When poverty comes in at the doors, love leaps out at the windows.''',
r'''When sex is good, it is only 2% of a marriage; but when it is bad, it is 98%.''',
r'''When something of great importance is given to you, it is always born humbly.''',
r'''When sorrow is asleep, wake it not.  -- MA Stoddart''',
r'''When success turns a person's head, he is facing failure.''',
r'''When the belly is full the mind is among the maids.''',
r'''When the blind lead the blind they both fall over the cliff.''',
r'''When the candles are out all women are fair.  -- Plutarch''',
r'''When the cat is away, the mice will play.''',
r'''When the dust is clear, one knows if he is riding a horse or an ass.  -- Chinese''',
r'''When the gods wish to punish us they answer our prayers.  -- Oscar Wilde''',
r'''When the going seems easy, check that you're not going downhill.''',
r'''When the grid is at capacity there is little margin for error.''',
r'''When the mind is denied the sting of losing, it never figures out how to win.  -- Jonah Lehrer''',
r'''When the need arises, anything within reach becomes a hammer.''',
r'''When the only choices are win or lose, everyone loses.  -- Limon''',
r'''When the situation is hopeless, there's nothing to worry about.  -- Edward Abbey''',
r'''When the student is ready, the teacher appears.  -- Hindu proverb''',
r'''When the toes are hot, the hiking boots are shot.''',
r'''When the wind is great, bow before it; when the wind is heavy, yield to it.''',
r'''When two friends have a common purse, one sings and the other weeps.  -- Mapletoft''',
r'''When two men in a business always agree, one of them is unnecessary.  -- Wrigley''',
r'''When up to your ass in alligators, you forget your goal was to drain the swamp.''',
r'''When war begins then hell opens.  -- Torriano''',
r'''When war is looked upon as vulgar, it will cease to be popular.  -- Oscar Wilde''',
r'''When we are flat on our backs there is no way to look but up.  -- Roger Babson''',
r'''When we begin the journey of the self, it seems to require a stage of aloneness.''',
r'''When we have gold, we are in fear; when we have none, we are in danger.  -- Draxe''',
r'''When we have not what we like, we must like what we have.  -- Bussy-Rabutin''',
r'''When we succeed in being the only speaker, there is no speaker at all.  -- Carse''',
r'''When we take the secure path we sign on for the lesson there is no such thing.''',
r'''When wine is in, wit is out.  -- Hall''',
r'''When you ain't got nothin', you got nothin' to lose.''',
r'''When you are at Rome live in the Roman style.  -- St. Ambrose''',
r'''When you are average, you are as close to the bottom as to the top.''',
r'''When you are in a hole, stop digging.''',
r'''When you are in command, command.  -- Admiral Nimitz''',
r'''When you are not going within, come from within as you deal with the world.''',
r'''When you are ready to face life alone, you are ready for marriage.  -- Fisher''',
r'''When you are tribal, you will be religious, but you won't be spiritual.  -- Carolyn Myss''',
r'''When you change the way you look at things, the things you look at change.  -- Wayne Dyer''',
r'''When you dig another out of trouble, you have a place to bury your own.''',
r'''When you don't talk, things get awfully quiet.  -- Martha Hartly''',
r'''When you finally become a perfect parent, you are unemployed.  -- Barbara Coloroso''',
r'''When you find yourself walking through hell, keep walking! -- Winston Churchill''',
r'''When you get angry your IQ drops 20 points.  -- Douglas Baskins''',
r'''When you get what you want you don't want it as much.''',
r'''When you go out to buy, don't show your silver.''',
r'''When you have a fight with your conscience and get licked, you win.  -- Nuggets''',
r'''When you have no agenda with power, all of it comes to you.  -- Carolyn Myss''',
r'''When you have seen one nuclear war, you have seen them all.''',
r'''When you have to kill a man it costs nothing to be polite.  -- Winston Churchill''',
r'''When you invest your energy in being a victim, you say to God, "You screwed up."''',
r'''When you invoke heaven, heaven comes.  -- Carolyn Myss''',
r'''When you judge another, you do not define them, you define yourself.  -- Wayne Dyer''',
r'''When you kill time you murder success.''',
r'''When you look into an abyss, the abyss also looks into you.  -- Friedrich Nietzsche''',
r'''When you lose, don't lose the lesson.  -- H. Jackson Brown''',
r'''When you make a pact with the devil, word it very carefully.''',
r'''When you mean no, say it in a way that's not ambiguous.  -- H. Jackson Brown''',
r'''When you need professional advice, get it from professionals.  -- Brown''',
r'''When you play for more than you can afford to lose, then you know the game.''',
r'''When you quit working, retire TO something, not FROM something.''',
r'''When you shoot an arrow of truth, dip its point in honey.  -- Arabian proverb''',
r'''When you starve with a tiger, the tiger starves last.''',
r'''When you talk to yourself, or about yourself, watch your language!  -- Will Limon''',
r'''When you try to bring your mind to one point, at first it speeds up incredibly.''',
r'''When you turn honest it limits your choices.  -- Carolyn Myss''',
r'''When you want something, all the universe conspires to help you achieve it.''',
r'''When you're tired, small problems seem big, and big problems are insurmountable.''',
r'''When you've won the game, stop playing.  -- William Bernstein''',
r'''When your work speaks for itself, don't interrupt.  -- Henry Kaiser''',
r'''Whenever people agree with me I always feel I must be wrong.  -- Oscar Wilde''',
r'''Whenever you possibly can, do good to those who need it.  -- Solomon''',
r'''Where are you at?  Where are you going?  What must you do to get there?''',
r'''Where drums beat, laws are silent.''',
r'''Where ignorance is bliss it is foolish to borrow your neighbor's newspaper.''',
r'''Where love is not, there is hatred.  -- Thomas Draxe''',
r'''Where love is, there is faith.''',
r'''Where on Earth is the early warning system for man-made disasters?  -- Goodman''',
r'''Where pain predominates, agony can be a valued teacher.  -- Frank Herbert''',
r'''Where people live there will be tragedy.  -- Tom Stybr''',
r'''Where there is much light there is also much shadow.  -- Johann von Goethe''',
r'''Where there is whispering there is lying.''',
r'''Where there's a will, there's a way.''',
r'''Where there's smoke, there's fire.''',
r'''Where you stand depends on where you sit.  -- Rufus Miles''',
r'''Whereof one cannot speak, thereof one must be silent.  -- Wittgenstein''',
r'''Wherever a man exercises authority, there is a man who resists authority!''',
r'''Wherever there is a secret, there must be something wrong.''',
r'''Wherever they burn books, they will eventually burn people.  -- H. Heine''',
r'''Whether you think you can or you can't, you're right.  -- Henry Ford''',
r'''While there is life, there is hope.  -- Publius Afer''',
r'''While we are sleeping, two-thirds of the world is plotting to do us in.  -- Dean Rusk''',
r'''Who chooses to compete with another can also choose to play with another.''',
r'''Who does not trust enough will not be trusted.  -- Lao Tsu''',
r'''Who goeth a-borrowing goeth a-sorrowing.  -- Thomas Tusser''',
r'''Who has not a good tongue, ought to have good hands.  -- John Ray''',
r'''Who is more busy than he that has least to do?  -- Thomas Draxe''',
r'''Who is worse shod than the shoemaker's wife?''',
r'''Who knows most, speaks least.  -- Torriano''',
r'''Who knows what evil lurks in the minds of men?  The Shadow knows.''',
r'''Who knows what he knows and what he doesn't know is one who knows.  -- Confucius''',
r'''Who likes not his business, his business likes not him.  -- T. Wright''',
r'''Who lives by hope will die by hunger.''',
r'''Who never wins can rarely lose, who never climbs as rarely falls.  -- Whittier''',
r'''Who steals my purse steals trash.  -- William Shakespeare''',
r'''Who swims in sin shall sink in sorrow.''',
r'''Who to himself is law no law doth need, offends no law, and is a king indeed.''',
r'''Whoever MUST play, cannot PLAY.  -- James Carse''',
r'''Whoever rows the boat doesn't have time to rock it.''',
r'''Whoever would lie usefully should lie seldom.''',
r'''Whole civilizations rise from stories -- and can rise from nothing else.  -- Carse''',
r'''Whom we love best, to them we can say least.''',
r'''Why are we all put here to suffer and die?''',
r'''Why attack God?  He might be as miserable as we are.''',
r'''Why be a man when you can be a success?  -- Bertold Brecht''',
r'''Why do I live in the desert?  Because the desert is the locus Dei.  -- Edward Abbey''',
r'''Why do we study poverty instead of wealth?''',
r'''Why doesn't everybody leave everybody else the hell alone?  -- Jimmy Durante''',
r'''Why I oppose the nuclear arms race:  I prefer the human race.  -- Edward Abbey''',
r'''Why look for more knowledge when you do not pay attention to what you know?''',
r'''Why look here for the joke?  It is all around us.''',
r'''Why not go out on a limb?  Isn't that where the fruit is?''',
r'''Why should a rich man steal?  -- John Ray''',
r'''Why should ANYTHING exist?  NOTHING would be tidier.  -- Edward Abbey''',
r'''Wicked people cannot sleep unless they have done something wrong.  -- Solomon''',
r'''Wilderness begins in the human mind.  -- Edward Abbey''',
r'''Wilderness... is the only thing left that is worth saving.  -- Edward Abbey''',
r'''Will is no skill.''',
r'''Win without boasting and lose without excuse.''',
r'''Winners never quit and quitters never win.''',
r'''Winners outrun defeat by not stopping; losers give in to defeat by not starting.''',
r'''Wisdom consists of the anticipation of consequences.  -- Norman Cousins''',
r'''Wisdom is experience assimilated.''',
r'''Wisdom is knowing what to do next.''',
r'''Wisdom is knowing what to do with what you know.  -- J. Winter Smith''',
r'''Wisdom is long, violence is short.  -- Carl van Doren''',
r'''Wisdom is ofttimes nearer when we stoop than when we soar.  -- William Wordsworth''',
r'''Wisdom is rarely found on the best-seller list.''',
r'''Wisdom is to live in harmony with the world at the moment it is.  -- Ram Dass''',
r'''Wisdom is what's left after we smarten up.''',
r'''Wise men change their minds; fools never do.''',
r'''Wise men have their mouth in their heart; fools have their heart in their mouth.''',
r'''Wise men learn by other men's mistakes; fools, by their own.  -- Plautus''',
r'''Wise men make proverbs and fools repeat them.  -- Palmer''',
r'''Wise men propose, and fools determine.''',
r'''Wise men see more from the bottoms of wells than fools see from mountain tops.''',
r'''Wise people learn when they can.  Fools learn when they must.  -- Wellington''',
r'''Wish in one hand and spit in the other -- see which one gets full first.''',
r'''Wishful thinking is far less likely to produce results than direct action.''',
r'''Wishing without work is like fishing without bait.  -- Frank Tyger''',
r'''Wit has truth in it.  Wisecracking is simply calisthenics with words.''',
r'''Wit is the only wall between us and the dark.''',
r'''With clothes the new are best; with friends the old are best.''',
r'''With enough qualifiers, everything is special.  -- Alan Silverstein''',
r'''With just enough of learning to misquote.  -- Byron''',
r'''With stupidity the gods themselves struggle in vain.  -- von Schiller''',
r'''With the foolish we should play the fool.  -- Menander''',
r'''With what fortitude we bear the suffering of others.  -- Thomas McKeown''',
r'''Within half a percent, pi seconds is a nanocentury.  -- Tom Duff''',
r'''Without adventure, civilization is in full decay.  -- Alfred Whitehead''',
r'''Without execution, vision is just another word for hallucination.  -- Mark Hurd''',
r'''Without fear, there is no courage.  -- Jeffrey Smith''',
r'''Without fools there would be no wisdom.''',
r'''Without love intelligence is dangerous; without intelligence love is not enough.''',
r'''Without music, life would be a mistake.  -- Friedrich Nietzsche''',
r'''Without wood, a fire goes out; without gossip, quarreling stops.  -- Solomon''',
r'''Women are wiser than men because they know less and understand more.  -- Stephens''',
r'''Women blink nearly twice as much as men.''',
r'''Women nod acknowledgment; men nod agreement.  -- Lillian Roybal-Rose''',
r'''Wonder is the daughter of ignorance.''',
r'''Wonders will never cease.''',
r'''Words and feathers the wind carries away.''',
r'''Words are but wind.''',
r'''Words are only painted fire; a book is the fire itself.  -- Mark Twain''',
r'''Words are the least reliable purveyor of Truth.  -- Conversations with God''',
r'''Words are the voice of the heart.''',
r'''Words are, of course, the most powerful drug used by mankind.  -- Kipling''',
r'''Words bind men.''',
r'''Words have a longer life than deeds.  -- Pindar''',
r'''Words may pass, but blows fall heavy.  -- John Ray''',
r'''Words must be weighed, not counted.''',
r'''Work expands to fill the time available for its completion.  -- Parkinson''',
r'''Work is a form of nervousness.  -- Don Herold''',
r'''Work is love made visible.  -- Kalil Gibran''',
r'''Work is the worst thing you can do for your health.  -- Howard Brubaker''',
r'''Work like you don't need the money; love like you've never been hurt.''',
r'''World War IV will be fought with sticks and stones.  -- Albert Einstein''',
r'''Worrying is the most natural and spontaneous of all human functions.  -- Thomas''',
r'''Worth seeing?  Yes, but not worth going to see.''',
r'''Would that my hand were as swift as my tongue.  -- Alfieri''',
r'''Would you rather be right, or would you rather be happy?  -- Tom Magliozzi''',
r'''Wrinkles should merely indicate where smiles have been.  -- Mark Twain''',
r'''Writing about music is like dancing about architecture.''',
r'''Wrong has no warranty.''',
r'''Wrong laws make short governance.  -- Harding''',
r'''Wrong never comes right.''',
r'''Years know more than books.  -- George Herbert''',
r'''Yes, I can summon my creativity.  -- Madonna''',
r'''You always find what you are looking for in the last place you look.''',
r'''You are a creator; you create with your every thought.  -- Esther Hicks''',
r'''You are a wish to be here wishing yourself.  -- Philip Whalen''',
r'''You are almost as happy as you think you are.''',
r'''You are an energetic being long before you are a physical being.  -- Carolyn Myss''',
r'''You are becoming more simultaneous with God than linear with humanity.  -- Carolyn Myss''',
r'''You are just a visitor to the history factory.  -- Tony Snow''',
r'''You are never too old to become younger.  -- Mae West''',
r'''You are not original if your peers agree with what you are doing.  -- Heimlich''',
r'''You are not paid enough to worry about your job.''',
r'''You are only here for a short visit.  So be sure to stop and smell the flowers.''',
r'''You are only responsible for the effort, not the outcome.''',
r'''You are taking yourself far too seriously.''',
r'''You are terrified of how truth can change your life.  -- Carolyn Myss''',
r'''You are the only authority on what is best for you.  -- Hugh Prather''',
r'''You are what you eat.  -- Adelle Davis''',
r'''You become more and more like a river.  -- Ram Dass''',
r'''You can "get" knowledge, but you can only BE wise.  -- Ram Dass''',
r'''You can always find what you are not looking for.''',
r'''You can always pick up your needle and move to another groove.  -- Timothy Leary''',
r'''You can always tell luck from ability by its duration.''',
r'''You can be sincere and still be wrong.  -- Walter Lippmann''',
r'''You can be young without money, but you can't be old without it.  -- Tennessee Williams''',
r'''You can bear anything if it isn't your own fault.  -- Katharine Gerould''',
r'''You can do anything you want, but not everything you want.''',
r'''You can easily play a joke on a man who likes to argue:  Agree with him.  -- Howe''',
r'''You can fix a bad page, but you can't fix a blank page.  -- anonymous''',
r'''You can fool too many of the people too much of the time.  -- James Thurber''',
r'''You can lead a boy to college but you cannot make him think.  -- Elbert Hubbard''',
r'''You can lead a horse to water, but you cannot make it drink.''',
r'''You can live outside the law, but you must be honest.''',
r'''You can make it foolproof, but you can't make it damnfoolproof.  -- Naeser''',
r'''You can make it illegal, but you can't make it unpopular.''',
r'''You can move the world with an idea, but you have to think of it first.''',
r'''You can neither win nor lose if you don't run the race.  -- David Bowie''',
r'''You can never do just one thing.  -- Hardin''',
r'''You can never get enough of what you don't really want.  -- Huston Smith''',
r'''You can never run away.  Not ever.  The only way out is in.  -- Junot Diaz''',
r'''You can no more win a war than you can win an earthquake.  -- Jeanette Rankin''',
r'''You can only improve on saying nothing by saying nothing often.  -- Frank Tyger''',
r'''You can own a dog, but you can only feed a cat.''',
r'''You can send your relationship to an early grave with a series of little digs.''',
r'''You can shear a sheep many times, but you can only skin it once.''',
r'''You can tell the ideas of a nation by its advertisements.  -- George Douglas''',
r'''You can't cross a chasm in two small jumps.  -- David Lord George''',
r'''You can't cross the sea merely by staring at the water.  -- Rabindranath Tagore''',
r'''You can't depend on the man who made the mess to clean it up.  -- Richard Nixon''',
r'''You can't depend on your eyes when your imagination is out of focus.  -- Mark Twain''',
r'''You can't erase a dream, you can only wake me up.  -- Peter Frampton''',
r'''You can't fall off the floor.  -- Paul''',
r'''You can't fool heaven.  -- Carolyn Myss''',
r'''You can't get to the light without going through the darkness.  -- Carolyn Myss''',
r'''You can't have a better tomorrow when you are mostly thinking of yesterday.''',
r'''You can't have other people do your pushups for you.  -- Jack Canfield''',
r'''You can't have your cake and eat it too.''',
r'''You can't help getting older, but you don't have to get old.  -- George Burns''',
r'''You can't love someone else unless you can first love yourself.  -- Bruce Fisher''',
r'''You can't produce a baby in one month by impregnating nine women!  -- Handel''',
r'''You can't simulate pain intellectually.  You must live through it.  -- MacKinnon''',
r'''You can't study the darkness by flooding it with light.  -- Edward Abbey''',
r'''You can't take money with you when you die.  -- Marryat''',
r'''You can't teach an old dog new tricks.  -- Leng-Tzu''',
r'''You can't tell which way the train went by looking at the track.''',
r'''You can't tie two rocks together and expect them to float.  -- Jesse Berst''',
r'''You cannot achieve the impossible without attempting the absurd.''',
r'''You cannot antagonize and influence at the same time.''',
r'''You cannot fool all of the people all the time.  -- Abraham Lincoln''',
r'''You cannot give what you do not have.''',
r'''You cannot have a science without measurement.  -- R. W. Hamming''',
r'''You cannot have trust without U.''',
r'''You cannot hold a man down without staying down with him.  -- Booker Washington''',
r'''You cannot kill time without injuring eternity.  -- Thoreau''',
r'''You cannot live a meaningless life; it's against the spiritual rules.  -- Carolyn Myss''',
r'''You cannot lose what you never had.''',
r'''You cannot make your candle brighter by blowing out someone else's.''',
r'''You cannot play at chess if you are kindhearted.''',
r'''You cannot propel yourself forward by patting yourself on the back.''',
r'''You cannot reshape human nature without mutilating human beings.  -- Edward Abbey''',
r'''You cannot see farther than others by standing on the feet of giants.''',
r'''You cannot see the city for the houses.''',
r'''You cannot see the forest for the trees.''',
r'''You cannot shake hands with a clenched fist.  -- Indira Gandhi''',
r'''You cannot use your friends and have them too.''',
r'''You catch more bees with honey than vinegar.''',
r'''You do not know a bird from the shell out of which it hatched.''',
r'''You do not know your friend until you have quarreled with him.  -- Thomas McKeown''',
r'''You don't drown by falling in water.  You drown by staying there.  -- R. Allen''',
r'''You don't get a second chance to make a first impression.''',
r'''You don't have to agree in order to understand.  -- Lillian Roybal-Rose''',
r'''You don't have to know, you just have to know who knows.  -- John Taylor''',
r'''You don't know a person until you have divided an inheritance with him.''',
r'''You don't know what to ask for to make you happy because you've never had it.''',
r'''You don't manage people.  You manage things.  You lead people.  -- Grace Hooper''',
r'''You don't need a weatherman to know which way the wind blows.''',
r'''You either learn as you go or don't.  -- John Taylor''',
r'''You either set standards, or you follow them.''',
r'''You get half of what you pay for.''',
r'''You get the most of what you need the least.''',
r'''You get what you don't pay for.  -- John C. Bogle, founder of Vanguard Group''',
r'''You get what you pay for.  -- Leng-Tzu''',
r'''You have a strict obligation have no opinion about things you don't understand  -- Morgan Housel''',
r'''You have no inalienable right to another's continued affection.''',
r'''You have no obligation to always love someone you once loved.''',
r'''You have no obligation to have an opinion about anything.  -- Morgan Housel''',
r'''You have not converted a man because you have silenced him.  -- John Morley''',
r'''You have the power to influence all with whom you come in contact.''',
r'''You have to play harder than you work to make working worthwhile.''',
r'''You have to, at each level, go beyond that level.  -- Ram Dass''',
r'''You improvise!  You adapt!  You overcome!  -- Clint Eastwood''',
r'''You just can't recreate that color blue on Earth, I don't know why.  -- Astronaut Scott Parazynski''',
r'''You keep your heart and mind separate because they have so much power.  -- Carolyn Myss''',
r'''You know how to win a victory, Hannibal, but not how to use it.  -- Maharbal''',
r'''You know not what is success or failure in the soul's reckoning.  -- God?''',
r'''You know what is wrong with a lot more confidence than you know what is right.  -- Nassim Taleb''',
r'''You live only once, but in that life you must die a thousand different deaths.''',
r'''You might as well be you.  Then you know if someone likes you, they like you.''',
r'''You might not be responsible for falling down, but you are for getting back up.''',
r'''You miss 100% of the shots you never take.  -- Wayne Gretzky''',
r'''You must awake for your dreams to come true.''',
r'''You must learn the rules of the game, then play better than anyone else.  -- Albert Einstein''',
r'''You must look where it is not, as well as where it is.  -- Buckminster Fuller''',
r'''You must love, honor, and cherish yourself to do a good job with anyone else.''',
r'''You must pass failure on your way to success.''',
r'''You must transcend the rational mind; transcend the knower who knows.  -- Dass''',
r'''You need chaos in your soul to give birth to a dancing star.  -- Friedrich Nietzsche''',
r'''You need not sow weeds.  -- Fuller''',
r'''You never "find" time, but you can always "make" time.''',
r'''You never gain something but that you lose something.  -- Henry Thoreau''',
r'''You never know what is enough until you know what is more than enough.  -- Blake''',
r'''You never know what you can do till you try.''',
r'''You never lose, but sometimes the clock runs out on you.  -- Vince Lombardi''',
r'''You never own anything but that it owns you too.  -- St. Exupery''',
r'''You only betray yourself when you ignore the inner dreams for your life.''',
r'''You only learn the value of a minute after it's past.  -- Eugene Miya''',
r'''You only learn who has been swimming naked when the tide goes out.  -- Jimmy Buffett''',
r'''You only live once but, if you live right, once is enough.''',
r'''You pay more for your schooling than your learning is worth.  -- Clarke''',
r'''You philosophers are sages in your maxims and fools in your conduct.  -- Franklin''',
r'''You raise your voice when you should reinforce your argument.  -- Samuel Johnson''',
r'''You use dualism to go beyond dualism.  -- Ram Dass''',
r'''You want it bad, you will get it bad.  -- Savage''',
r'''You will face every thought and fear that has authority over you.  -- Carolyn Myss''',
r'''You will never get dizzy doing a good turn.''',
r'''You will never get enough approval to feel good about yourself.  -- Lee Coit''',
r'''You will remain deaf to my explanations until you suspect yourself of falsehood.''',
r'''You won't have an economy on a dead planet.  -- David Brower''',
r'''You're going to the experience of the transcendence of separateness.  -- Ram Dass''',
r'''You're not really diversified unless something you own makes you uncomfortable.''',
r'''You're twice as biased as you think you are; four times if you disagree.  -- Morgan Housel''',
r'''You're twice as gullible as you think you are.  -- Morgan Housel''',
r'''You've got to risk it all to have it all.  -- Ram Dass''',
r'''Young men may die, but old must die.''',
r'''Young men think old men are fools; but old men know young men are fools.''',
r'''Young men's knocks old men feel.  -- John Ray''',
r'''Young saint, old devil.''',
r'''Your ability to experience joy is tied to your ability to experience pain.''',
r'''Your actions prove what you think of yourself.  -- Will Limon''',
r'''Your attitude is more important than your aptitude.  -- Peter Chantilis''',
r'''Your best dreams may not come true; fortunately, neither will your worst dreams.''',
r'''Your best revenge is to live a happy life.''',
r'''Your biggest handicap is what you think intuitive sight is.  -- Carolyn Myss''',
r'''Your biography becomes your biology -- and that is law.  -- Carolyn Myss''',
r'''Your body is the greatest instrument you'll ever own.  -- Mary Schmich''',
r'''Your choices are half chance.  So are everybody else's.  -- Mary Schmich''',
r'''Your circle of competence is probably 90% smaller than you think it is.  -- Morgan Housel''',
r'''Your education begins where what is called your education is over.''',
r'''Your face is an exercise in fractal curves.  -- John Taylor''',
r'''Your family gave you the best they knew at the time.  -- Carolyn Myss''',
r'''Your first amendment means I can say the second amendment sucks dicks.  -- Jim Jeffries''',
r'''Your first friend is worth the next thousand.  -- John Taylor''',
r'''Your happiness is intertwined with your outlook on life.''',
r'''Your heart doesn't lie to your head; your head lies to your heart.  -- Carolyn Myss''',
r'''Your imagination, my dear fellow, is worth more than you imagine.  -- Louis Aragon''',
r'''Your last mistake is your best teacher.''',
r'''Your life would be very empty if you had nothing to regret.''',
r'''Your mind understands what you have been taught; your heart, what is true.''',
r'''Your money burns a hole in your pocket.''',
r'''Your soul is on a mission from God to have experiences and return to God.''',
r'''Your spirit and your body thrive on living honorably.  -- Carolyn Myss''',
r'''Your superstitions still have you by the short hairs.  -- Carolyn Myss''',
r'''Your teachers are often people who have been right around you.  -- Ram Dass''',
r'''Your thought is the parent which gives birth to all things.  -- God?''',
r'''Your vision will become clear only when you look into your heart.  -- Carl Jung''',
r'''Your winning smile is your greatest asset.''',
r'''Youth and age will never agree.''',
r'''Youth and white paper take any impression.  -- Edgeworth''',
r'''Youth had been a habit of hers so long that she could not part with it.''',
r'''Youth is a blunder; maturity a struggle; old age a regret.''',
r'''Youth is not a time of life but a state of mind.''',
r'''Youth is the trustee of posterity.''',
r'''Youth will be served.  -- Borrow''',
r'''Youth will have its swing.  -- Clarke''',
r'''Youth...  It is a wonder that anyone ever outgrows it.''',
r'''Zeal without knowledge is fire without light.  -- Fuller''',
r'''Zeal, when it is a virtue, is a dangerous one.  -- Fuller''',
r'''Zen is not easy.  It takes effort to attain nothingness.''',
r'''Zen is the sound of the ax chopping.  Chopping logic.  -- Edward Abbey''',
]
